package com.goodt.dremio.connector.config;

import com.goodt.dremio.connector.service.DremioCache;
import com.goodt.dremio.connector.system.ExpiredConcurrentHashMap;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class CacheConfig {

    @Value("${app-cfg.cache.permission.expiry_period}")
    private long permExpiry;

    @Value("${app-cfg.cache.permission.cleaner_period}")
    private long permCleanerPeriod;

    @Value("${app-cfg.cache.tablepermission.expiry_period}")
    private long tabPermExpiry;

    @Value("${app-cfg.cache.tablepermission.cleaner_period}")
    private long tabPermCleanerPeriod;

    @Value("${app-cfg.cache.datasettablepermission.expiry_period}")
    private long datasetTabPermExpiry;

    @Value("${app-cfg.cache.datasettablepermission.cleaner_period}")
    private long datasetTabPermCleanerPeriod;

    private static final int SECOND = 1000;

    private static final int MINUTE = 60 * SECOND;

    @Bean
    public DremioCache dremioCache() {
        return new DremioCache(
                new ExpiredConcurrentHashMap<>("Permission_tab", MINUTE * permExpiry, MINUTE * permCleanerPeriod),
                new ExpiredConcurrentHashMap<>("Table-permission_tab", MINUTE * tabPermExpiry, MINUTE * tabPermCleanerPeriod),
                new ExpiredConcurrentHashMap<>("Dataset-table-permission_tab", MINUTE * datasetTabPermExpiry, MINUTE * datasetTabPermCleanerPeriod)
        );
    }
}
