package com.goodt.dremio.connector.config;

import com.goodt.dremio.connector.service.clients.DremioClient;
import com.goodt.dremio.connector.service.clients.DrillClient;
import com.goodt.dremio.connector.service.clients.PermissionClient;
import com.goodt.dremio.connector.service.impl.AuthHeaderInterceptor;
import feign.AsyncFeign;
import feign.Feign;
import feign.Request;
import feign.Target;
import feign.jackson.JacksonDecoder;
import feign.jackson.JacksonEncoder;
import feign.okhttp.OkHttpClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.concurrent.TimeUnit;

@Configuration
public class ClientsConfig {

    @Value("${app-cfg.sur.url}")
    private String hostSUR;

    @Autowired
    private AuthHeaderInterceptor interceptor;

    @Bean
    public PermissionClient permissionClient() {
        return AsyncFeign.asyncBuilder()
                .client(new OkHttpClient())
                .encoder(new JacksonEncoder())
                .decoder(new JacksonDecoder())
                .options(new Request.Options(6, TimeUnit.SECONDS, 60000, TimeUnit.SECONDS, true))
                .requestInterceptor(interceptor)
                .target(PermissionClient.class, hostSUR);
    }

    @Bean
    public DremioClient dremioClient() {
        return Feign.builder()
                .client(new OkHttpClient())
                .encoder(new JacksonEncoder())
                .decoder(new JacksonDecoder())
                .options(new Request.Options(6, TimeUnit.SECONDS, 60000, TimeUnit.SECONDS, true))
                .target(DremioClient.class, "http:localhost");
    }

    @Bean
    public DrillClient drillClient() {
        return Feign.builder()
                .client(new OkHttpClient())
                .encoder(new JacksonEncoder())
                .decoder(new JacksonDecoder())
                .options(new Request.Options(6, TimeUnit.SECONDS, 60000, TimeUnit.SECONDS, true))
                .target(Target.EmptyTarget.create(DrillClient.class));
    }
}
