package com.goodt.dremio.connector.config;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.security.oauth2.resource.PrincipalExtractor;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.oauth2.config.annotation.web.configuration.EnableResourceServer;
import org.springframework.security.oauth2.config.annotation.web.configuration.ResourceServerConfigurerAdapter;
import org.springframework.web.cors.CorsConfiguration;
import org.springframework.web.cors.UrlBasedCorsConfigurationSource;
import org.springframework.web.filter.CorsFilter;

import com.goodt.dremio.connector.security.AppAuthenticationEntryPoint;
import com.goodt.dremio.connector.security.KeyCloakUserInfoExtractorService;

@Configuration
@EnableResourceServer
@ConditionalOnProperty(value = "app-cfg.keyCloak.isEnabled", havingValue = "true")
public class SecurityResourceConfig extends ResourceServerConfigurerAdapter {

    @Override
    public void configure(HttpSecurity http) throws Exception {
        http.headers().frameOptions().sameOrigin();
        http.cors();
        http
                .authorizeRequests()
                .antMatchers("/", "/callback", "/build-info", "/login**", "/webjars/**", "/error**", "/api/ping").permitAll()
                .antMatchers("/swagger-ui.html", "/swagger-ui/**").permitAll()
                .antMatchers("/api/**").authenticated()
                .and()
                .exceptionHandling().authenticationEntryPoint(new AppAuthenticationEntryPoint())
                .and()
                .logout().permitAll().logoutSuccessUrl("/");
    }

    @Bean
    public CorsFilter corsFilter(CorsConfig corsConfig) {
        UrlBasedCorsConfigurationSource source = new UrlBasedCorsConfigurationSource();
        CorsConfiguration config = new CorsConfiguration();
        config.setAllowCredentials(true);
        config.setAllowedOriginPatterns(corsConfig.getAllowedOrigins());
        config.setAllowedHeaders(corsConfig.getAllowedHeaders());
        config.setAllowedMethods(corsConfig.getAllowedMethods());
        source.registerCorsConfiguration("/api/**", config);
        return new CorsFilter(source);
    }

    @Bean
    public PrincipalExtractor getPrincipalExtractor() {
        return new KeyCloakUserInfoExtractorService();
    }
}
