package com.goodt.dremio.connector.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpHeaders;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.config.http.SessionCreationPolicy;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;
import org.springframework.web.cors.CorsConfiguration;
import org.springframework.web.cors.UrlBasedCorsConfigurationSource;
import org.springframework.web.filter.CorsFilter;

import javax.servlet.http.HttpServletResponse;

import com.goodt.dremio.connector.security.JwtAuthenticationFilter;

import static com.goodt.dremio.connector.utils.ResponseErrorMessageUtil.setResponseError;

@Configuration
@EnableWebSecurity
@ConditionalOnProperty(value = "app-cfg.keyCloak.isEnabled", havingValue = "false")
public class SecurityWebConfig extends WebSecurityConfigurerAdapter {

    @Autowired
    private JwtAuthenticationFilter jwtAuthenticationFilter;

    @Override
    protected void configure(final HttpSecurity http) throws Exception {
        http.headers().frameOptions().sameOrigin();
        http.cors();
        http.csrf().disable()
                .sessionManagement().sessionCreationPolicy(SessionCreationPolicy.STATELESS)
                .and()
                .authorizeRequests().antMatchers("/", "/callback", "/login**", "/webjars/**", "/error**", "/build-info", "/api/ping", "/swagger-ui/**", "/swagger-ui.html").permitAll()
                .and()
                .authorizeRequests().antMatchers("/api/**").authenticated()
                .and()
                .exceptionHandling()
                .authenticationEntryPoint((request, response, authException) -> {
                    if (request.getHeader(HttpHeaders.AUTHORIZATION) == null) {
                        setResponseError(response, HttpServletResponse.SC_UNAUTHORIZED, "Authentication Failed: Invalid Authorization Header");
                    } else {
                        setResponseError(response, HttpServletResponse.SC_UNAUTHORIZED, "Authentication Failed: Invalid Json Web Token");
                    }
                })
                .and()
                .addFilterBefore(jwtAuthenticationFilter, UsernamePasswordAuthenticationFilter.class)
                .logout().permitAll().logoutSuccessUrl("/");
    }

    @Bean
    public CorsFilter corsFilter(CorsConfig corsConfig) {
        UrlBasedCorsConfigurationSource source = new UrlBasedCorsConfigurationSource();
        CorsConfiguration config = new CorsConfiguration();
        config.setAllowCredentials(true);
        config.setAllowedOriginPatterns(corsConfig.getAllowedOrigins());
        config.setAllowedHeaders(corsConfig.getAllowedHeaders());
        config.setAllowedMethods(corsConfig.getAllowedMethods());
        source.registerCorsConfiguration("/api/**", config);
        return new CorsFilter(source);
    }
}
