package com.goodt.dremio.connector.controller;

import io.swagger.v3.oas.annotations.Hidden;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import com.goodt.dremio.connector.asm.ConnectionAsm;
import com.goodt.dremio.connector.dto.ConnectionRes;
import com.goodt.dremio.connector.entities.Connection;
import com.goodt.dremio.connector.service.ConnectionService;
import me.goodt.micro.core.util.Responses;

@Slf4j
@RestController
@RequestMapping(value = "/api/v1/connections", produces = "application/json")
public class ConnectionController extends AbstractController {

    @Value("${app-cfg.sur.isEnabled}")
    private boolean isSurEnabled;
    @Getter
    @Autowired
    private ConnectionService service;
    @Getter
    @Autowired
    private ConnectionAsm asm;

    @GetMapping
    public List<ConnectionRes> getAll() {
        List<Connection> list;
        if (isSurEnabled) {
            list = getService().getAll();
        } else {
            list = getService().getAll(getSessionId());
        }
        return asm.toList(list);
    }

    @GetMapping({"{id}"})
    public ConnectionRes getById(@PathVariable Long id) {
        if (isSurEnabled) {
            return this.getService().getById(id, (entity) -> this.getAsm().toRes(entity));
        } else {
            return this.getService().getById(id, getSessionId(), (entity) -> this.getAsm().toRes(entity));
        }
    }

    @PostMapping
    public ConnectionRes create(@RequestBody ConnectionRes res) {
        return this.getService().create((entity) -> this.getAsm().create(entity, res, getSessionId()), (entity) -> this.getAsm().toRes(entity), res);
    }

    @PutMapping({"{id}"})
    public ConnectionRes update(@PathVariable Long id, @RequestBody ConnectionRes res) {
        if (!isSurEnabled) {
            this.getService().getById(id, getSessionId(), (entity) -> this.getAsm().toRes(entity));
        }
        return this.getService().update(id, (entity) -> this.getAsm().update(entity, res), (entity) -> this.getAsm().toRes(entity), res);
    }

    @PostMapping({"{id}/clone"})
    public ConnectionRes clone(@PathVariable Long id) {
        if (!isSurEnabled) {
            this.getService().getById(id, getSessionId(), (entity) -> this.getAsm().toRes(entity));
        }
        return this.getService().clone(id, (entity) -> this.getAsm().toRes(entity));
    }

    @DeleteMapping("{id}")
    public ResponseEntity<Void> delete(@PathVariable Long id) {
        if (!isSurEnabled) {
            this.getService().getById(id, getSessionId(), (entity) -> this.getAsm().toRes(entity));
        }
        this.getService().delete(id);
        return Responses.ok();
    }
}
