package com.goodt.dremio.connector.controller;

import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.security.access.AccessDeniedException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseStatus;

import javax.security.auth.message.AuthException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

import me.goodt.micro.core.util.MediaTypes;
import com.goodt.dremio.connector.dto.err.ConnectorException;
import com.goodt.dremio.connector.dto.err.ResponseErr;
import com.goodt.dremio.connector.entity.response.ExceptionResult;
import com.goodt.dremio.connector.exceptions.*;

import static com.goodt.dremio.connector.utils.ResponseErrorMessageUtil.setResponseError;

@Slf4j
@ControllerAdvice
public class GlobalControllerAdvice {

    @Autowired
    private ObjectMapper om;

    @ExceptionHandler(ConnectorException.class)
    public void handleWfmException(HttpServletResponse response, ConnectorException ex) throws IOException {
        response.setStatus(ex.status());
        String strJson = om.writeValueAsString(ResponseErr.of("error", ex.code()));
        response.setContentType(MediaTypes.JSON_UTF8);
        response.setHeader(HttpHeaders.CACHE_CONTROL, "no-cache");
        response.getWriter().write(strJson);
    }

    @ExceptionHandler(value = {AccessDeniedException.class})
    public void commence(HttpServletRequest request, HttpServletResponse response, AccessDeniedException accessDeniedException) throws IOException {
        log.debug(String.format("Access to resource is forbidden (403) for request: \"%s\" message: \"%s\"", request.getRequestURL(), accessDeniedException.getMessage()));
        setResponseError(response, HttpServletResponse.SC_FORBIDDEN, String.format("Access Denied: \"%s\"", accessDeniedException.getMessage()));
    }

    @ExceptionHandler(value = {Exception.class})
    public void commence(HttpServletRequest req, HttpServletResponse response, Exception e) throws IOException {
        log.error("An error (500) occurred during request: \"{}\" \"{}\" error message: \"{}\"", req.getMethod(), req.getRequestURL(), e.getMessage());
        setResponseError(response, 500, e);
    }

    @ExceptionHandler(PermissionInfoException.class)
    @ResponseStatus(value = HttpStatus.SERVICE_UNAVAILABLE)
    public ExceptionResult getPermissionInfoException(PermissionInfoException ex) {
        return new ExceptionResult(ex.getMessage());
    }

    @ExceptionHandler(ParserException.class)
    @ResponseStatus(value = HttpStatus.INTERNAL_SERVER_ERROR)
    public ExceptionResult queryException(ParserException ex) {
        return new ExceptionResult(ex.getMessage());
    }

    @ExceptionHandler(UserPermissionsException.class)
    @ResponseStatus(value = HttpStatus.INTERNAL_SERVER_ERROR)
    public ExceptionResult getPermissionsException(UserPermissionsException ex) {
        return new ExceptionResult(ex.getMessage());
    }

    @ExceptionHandler(CatalogResultException.class)
    @ResponseStatus(value = HttpStatus.SERVICE_UNAVAILABLE)
    public ExceptionResult getEntityByPathException(CatalogResultException ex) {
        return new ExceptionResult(ex.getMessage());
    }

    @ExceptionHandler(RootEntityException.class)
    @ResponseStatus(value = HttpStatus.SERVICE_UNAVAILABLE)
    public ExceptionResult getMainCatalogException(RootEntityException ex) {
        return new ExceptionResult(ex.getMessage());
    }

    @ExceptionHandler(AuthException.class)
    @ResponseStatus(value = HttpStatus.UNAUTHORIZED)
    public ExceptionResult getUnathorizedException(AuthException ex) {
        return new ExceptionResult(ex.getMessage());
    }
}
