package com.goodt.dremio.connector.controller;

import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.entity.permissions.InfoPermission;
import com.goodt.dremio.connector.entity.permissions.PermissionResponse;
import com.goodt.dremio.connector.exceptions.UserPermissionsException;
import com.goodt.dremio.connector.repository.impl.DremioQueryImpl;
import com.goodt.dremio.connector.service.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.UUID;

@Slf4j
@RestController
@RequestMapping(value = "/api", produces = "application/json")
public class PermissionController extends AbstractController {

    @Value("${app-cfg.system.data.catalog}")
    private String permissionsCatalog;
    @Autowired
    ClientPull clientPull;
    @Autowired
    DremioCache cache;
    @Autowired
    SchemaProviderFactory schemaProviderFactory;
    @Autowired
    IDremioPermissions permissions;

    @GetMapping("/v1/permissions")
    public PermissionResponse getPermissions(String connection) {
        UUID logId = UUID.randomUUID();
        final String employeeId = getSessionEmployeeId();
        clientPull.get(connection);

        final ConnectionCtx ctx = clientPull.get(connection);
        final DremioQueryImpl dremioQuery = new DremioQueryImpl(ctx, cache, permissionsCatalog);

        try {
            log.debug("{}: /getPermissions has been called with employee id = {}", logId, employeeId);
            return permissions.getPermissionsList(employeeId, logId, dremioQuery);
        } catch (Exception ex) {
            log.error(logId + ": В процессе получения списка разрешений пользователя произошла ошибка: " + ex.getMessage(), ex);
            throw new UserPermissionsException(ex);
        }
    }

    @GetMapping("/v1/permissions-info")
    public List<InfoPermission> getPermissionsInfo(@RequestParam(name = "connection", required = false) String connectionCode) {
        UUID logId = UUID.randomUUID();
        log.debug("{}: /permissions-info has been called", logId);

        final SchemaProvider schemaProvider = schemaProviderFactory.get(clientPull.get(connectionCode), connectionCode);
        return null;
    }
}
