package com.goodt.dremio.connector.parser;

import com.goodt.dremio.connector.config.RsModeConfig;
import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.dto.UserInfo;
import com.goodt.dremio.connector.entity.query.QueryRequest;
import com.goodt.dremio.connector.entity.query.QueryResult;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import java.util.UUID;

@Slf4j
@RequiredArgsConstructor
public abstract class AbstractDataLoader implements DataLoader {

    protected final UUID logId;

    protected final QueryRequest query;

    protected final PermissionsAppender permissions;

    protected final RsModeConfig rsModeConfig;

    public Authentication getAuthentication() {
        return SecurityContextHolder.getContext().getAuthentication();
    }

    protected UserInfo getUserInfo() {
        return (UserInfo) getAuthentication().getPrincipal();
    }

    @NotNull
    @Override
    public QueryResult load(ConnectionCtx ctx) {
        final UserInfo userInfo = getUserInfo();
        String perm = createPermissions(userInfo, ctx);
        return loadDataSql(perm);
    }

    protected abstract QueryResult loadDataSql(String perm);

    protected abstract QueryCreator getQueryCreator();

    protected String createPermissions(UserInfo userInfo, ConnectionCtx ctx) {
        return permissions.get(ctx, query.getQuerySchema(), userInfo, logId);
    }

    protected Long getSchemaLimit(String rsMode) {
        if (rsMode != null && rsModeConfig.getRsModeCustom().containsKey(rsMode)) {
            return rsModeConfig.getRsModeCustom().get(rsMode);
        } else {
            return rsModeConfig.getRsModeDefault();
        }
    }
}
