package com.goodt.dremio.connector.parser;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.BooleanSupplier;

public abstract class AbstractOperators implements Operators {

    private final Map<String, Operator> opMap = new HashMap<>();

    protected AbstractOperators() {
        opMap.put(Op.EQ.code(), (List<String> args, String col, String table) -> eq(args, col, table));
        opMap.put(Op.NE.code(), (List<String> args, String col, String table) -> ne(args, col, table));
        opMap.put(Op.LT.code(), (List<String> args, String col, String table) -> lt(args, col, table));
        opMap.put(Op.LOE.code(), (List<String> args, String col, String table) -> loe(args, col, table));
        opMap.put(Op.GT.code(), (List<String> args, String col, String table) -> gt(args, col, table));
        opMap.put(Op.GOE.code(), (List<String> args, String col, String table) -> goe(args, col, table));
        opMap.put(Op.IN.code(), (List<String> args, String col, String table) -> in(args, col, table));
        opMap.put(Op.NOT_IN.code(), (List<String> args, String col, String table) -> notIn(args, col, table));
        opMap.put(Op.BETWEEN.code(), (List<String> args, String col, String table) -> between(args, col, table));
        opMap.put(Op.NOT_BETWEEN.code(), (List<String> args, String col, String table) -> notBetween(args, col, table));
        opMap.put(Op.LIKE.code(), (List<String> args, String col, String table) -> like(args, col, table));
        opMap.put(Op.MAX.code(), (List<String> args, String col, String table) -> max(args, col, table));
        opMap.put(Op.MIN.code(), (List<String> args, String col, String table) -> min(args, col, table));
    }

    public Operator getOp(String operator) {
        final Operator op = opMap.get(operator);
        if (op == null) {
            throw new UnsupportedOperationException(String.format("Operator %s not supported in %s provider", operator, name()));
        }
        return op;
    }

    protected void assertArg(Op op, String argFmt, List<String> args, BooleanSupplier funcCheck) {
        if (!funcCheck.getAsBoolean()) {
            throw new IllegalArgumentException(String.format("Условие %s принимает %s, но передано %d", op.code(), argFmt, args.size()));
        }
    }
}
