package com.goodt.dremio.connector.parser;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.UUID;

import com.goodt.dremio.connector.config.RsModeConfig;
import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.entity.query.QueryRequest;
import com.goodt.dremio.connector.parser.click_house.ClickHouseDataLoader;
import com.goodt.dremio.connector.parser.dremio.DremioDataLoader;
import com.goodt.dremio.connector.parser.drill.DrillDataLoader;
import com.goodt.dremio.connector.parser.drill.DrillPermissions;
import com.goodt.dremio.connector.parser.pg.PgDataLoader;
import com.goodt.dremio.connector.parser.pg.PgPermissions;
import com.goodt.dremio.connector.repository.IDremioQuery;
import com.goodt.dremio.connector.repository.impl.DremioQueryImpl;
import com.goodt.dremio.connector.service.ClientPull;
import com.goodt.dremio.connector.service.DremioCache;
import com.goodt.dremio.connector.service.impl.DremioPermissions;

@Slf4j
@Component
public class DataLoadFactory {

    @Autowired
    private DremioPermissions permissionsDremio;
    @Autowired
    private PgPermissions pgPermissions;
    @Autowired
    private DrillPermissions drillPermissions;
    @Autowired
    ClientPull clientPull;
    @Autowired
    DremioCache cache;
    @Autowired
    RsModeConfig rsModeConfig;
    @Value("${app-cfg.system.data.catalog}")
    private String permissionsCatalog;

    public DataLoader get(QueryRequest query) {
        final UUID logId = UUID.randomUUID();
        log.info("{}: query({})", logId, query.toString());
        final ConnectionCtx ctx = clientPull.get(query.getConnection());
        switch (ctx.provider()) {
            case PG:
                return new PgDataLoader(logId, query, pgPermissions, ctx, rsModeConfig);
            case DRILL:
                return new DrillDataLoader(logId, query, drillPermissions, ctx, rsModeConfig);
            case CLICK_HOUSE:
                return new ClickHouseDataLoader(logId, query, drillPermissions, ctx, rsModeConfig);
            default:
                IDremioQuery q = new DremioQueryImpl(ctx, cache, permissionsCatalog);
                return new DremioDataLoader(logId, query, q, permissionsDremio, rsModeConfig);
        }
    }
}
