package com.goodt.dremio.connector.parser.dremio;

import com.goodt.dremio.connector.config.RsModeConfig;
import com.goodt.dremio.connector.entity.query.QueryRequest;
import com.goodt.dremio.connector.entity.query.QueryResult;
import com.goodt.dremio.connector.parser.AbstractDataLoader;
import com.goodt.dremio.connector.parser.PermissionsAppender;
import com.goodt.dremio.connector.parser.QueryCreator;
import com.goodt.dremio.connector.repository.IDremioQuery;
import lombok.extern.slf4j.Slf4j;
import org.hibernate.boot.model.naming.IllegalIdentifierException;

import java.util.UUID;

@Slf4j
public class DremioDataLoader extends AbstractDataLoader {

    private final IDremioQuery dremioQuery;

    public DremioDataLoader(UUID logId, QueryRequest query, IDremioQuery dremioQuery, PermissionsAppender permissions, RsModeConfig rsModeConfig) {
        super(logId, query, permissions, rsModeConfig);
        this.dremioQuery = dremioQuery;
    }

    @Override
    protected QueryCreator getQueryCreator() {
        return new DremioQueryCreator(query.getQuerySchema());
    }

    protected QueryResult loadDataSql(String perm) {
        QueryCreator parser = getQueryCreator();
        String sql;
        try {
            sql = parser.parse(perm);
        } catch (Exception e) {
            log.error("dremio parser error", e);
            throw new RuntimeException(e);
        }
        QueryResult rez;
        if (query.getQuerySchema().getFields() == null && !query.isDebug()) {
            throw new IllegalArgumentException("Schema fields must be filled.");
        }
        String initialSql = sql;
        Long schemaLimit = getSchemaLimit(query.getRsmode());
        if (schemaLimit < query.getLimit()) {
            throw new IllegalArgumentException("Query limit cannot exceed schema limit");
        }
        if (query.getLimit() > 0) {
            sql += " LIMIT " + query.getLimit() + " OFFSET " + query.getOffset();
            rez = dremioQuery.execute(sql, logId);
            Long rowCount = rez.getRowCount();
            if (query.getLimit() == rowCount || query.getOffset() > 0) {
                rez.setRowCount(dremioQuery.getRowCount(initialSql));
            }
        } else {
            sql += " LIMIT " + schemaLimit + " OFFSET " + query.getOffset();
            rez = dremioQuery.execute(sql, logId);
            Long rowCount = rez.getRowCount();
            if (schemaLimit.equals(rowCount) || query.getOffset() > 0) {
                throw new IllegalIdentifierException("Result rows count cannot exceed schema limit");
            }
        }
        if (rez.getRowCount() == 0) {
            rez.fillEmptyData();
        }
        if (query.isDebug()) {
            rez.setSql(sql);
        }
        return rez;
    }
}
