package com.goodt.dremio.connector.parser.dremio;

import com.goodt.dremio.connector.parser.AbstractOperators;
import com.goodt.dremio.connector.parser.Op;

import java.util.List;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

public class DremioOperators extends AbstractOperators {

    private static final Pattern numPattern = Pattern.compile("-?\\d+([\\.]\\d+)?");

    @Override
    public String name() {
        return "Dremio";
    }

    @Override
    public String eq(List<String> args, String colName, String table) {
        assertArg(Op.EQ, "1 аргумент", args, () -> args.size() == 1);
        return args.get(0) == null ? col(colName) + " is null" : col(colName) + " = " + valueOf(args.get(0));
    }

    @Override
    public String ne(List<String> args, String colName, String table) {
        assertArg(Op.NE, "1 аргумент", args, () -> args.size() == 1);
        return col(colName) + " != " + valueOf(args.get(0));
    }

    @Override
    public String lt(List<String> args, String colName, String table) {
        assertArg(Op.LT, "1 аргумент", args, () -> args.size() == 1);
        return col(colName) + " < " + valueOf(args.get(0));
    }

    @Override
    public String loe(List<String> args, String colName, String table) {
        assertArg(Op.LOE, "1 аргумент", args, () -> args.size() == 1);
        return col(colName) + " <= " + valueOf(args.get(0));
    }

    @Override
    public String gt(List<String> args, String colName, String table) {
        assertArg(Op.GT, "1 аргумент", args, () -> args.size() == 1);
        return col(colName) + " > " + valueOf(args.get(0));
    }

    @Override
    public String goe(List<String> args, String colName, String table) {
        assertArg(Op.GOE, "1 аргумент", args, () -> args.size() == 1);
        return col(colName) + " >= " + valueOf(args.get(0));
    }

    @Override
    public String in(List<String> args, String colName, String table) {
        assertArg(Op.IN, "1 и более аргументов", args, () -> args.size() > 0);
        return col(colName) + " IN " + "(" + valueOf(args) + ")";
    }

    @Override
    public String notIn(List<String> args, String colName, String table) {
        assertArg(Op.NOT_IN, "1 и более аргументов", args, () -> args.size() > 0);
        return col(colName) + " NOT IN " + "(" + valueOf(args) + ")";
    }

    @Override
    public String between(List<String> args, String colName, String table) {
        assertArg(Op.BETWEEN, "2 аргумента", args, () -> args.size() == 2);
        return col(colName) + " BETWEEN " + valueOf(args.get(0)) + " AND " + valueOf(args.get(1));
    }

    @Override
    public String notBetween(List<String> args, String colName, String table) {
        assertArg(Op.NOT_BETWEEN, "2 аргумента", args, () -> args.size() == 2);
        return col(colName) + " NOT BETWEEN " + valueOf(args.get(0)) + " AND " + valueOf(args.get(1));
    }

    @Override
    public String like(List<String> args, String colName, String table) {
        assertArg(Op.LIKE, "1 и более аргументов", args, () -> args.size() > 0);
        List<String> arr = args.stream().map(val -> col(colName) + " LIKE " + valueOf(val, false)).collect(Collectors.toList());
        return "(" + arr.stream().reduce((str1, str2) -> str1 + " OR " + str2).get() + ")";
    }

    @Override
    public String max(List<String> args, String colName, String table) {
        assertArg(Op.MAX, "1 аргумент", args, () -> args.size() == 1);
        return col(colName) + " = (SELECT MAX (" + col(args.get(0)) + ") FROM " + table + ")";
    }

    @Override
    public String min(List<String> args, String colName, String table) {
        assertArg(Op.MIN, "1 аргумент", args, () -> args.size() == 1);
        return col(colName) + " = (SELECT MIN (" + col(args.get(0)) + ") FROM " + table + ")";
    }

    private String col(String colName) {
        return colName == null ? null : "\"" + colName.replace("\"", "\"\"") + "\"";
    }

    private String valueOf(Object vl) {
        return valueOf(vl, true);
    }

    private String valueOf(Object vl, boolean convertToNumber) {
        if (vl == null) {
            return null;
        }

        if (vl instanceof Double) {
            if (convertToNumber && isNumber((String) vl)) {
                return ((String) vl).replaceAll("\'", "\'\'");
            }
        }
        if (vl instanceof String) {
            return "\'" + ((String) vl).replaceAll("\'", "\'\'") + "\'";
        }
        if (vl instanceof List) {
            final List<String> list = (List<String>) vl;
            if (list.isEmpty()) {
                return null;
            }
            return list(list.stream().map(x -> valueOf(x)).collect(Collectors.toList()));
        }

        return vl.toString();
    }

    private String list(List<String> list) {
        if (list == null || list.isEmpty()) {
            return null;
        }

        return list.stream().reduce((str1, str2) -> str1 + ", " + str2).get();
    }

    private boolean isNumber(String vl) {
        if (vl == null) {
            return false;
        }

        return numPattern.matcher(vl).matches();
    }
}
