package com.goodt.dremio.connector.security;

import com.goodt.dremio.connector.config.JwtKeyConfig;
import com.goodt.dremio.connector.dto.UserInfo;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtException;
import io.jsonwebtoken.Jwts;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Service;

import static com.goodt.dremio.connector.dto.Constansts.USER_ADMIN_FLAG;
import static com.goodt.dremio.connector.security.GlobalDefs.*;

@Slf4j
@Service
@ConditionalOnBean(JwtKeyConfig.class)
public class JwtService {

    @Autowired
    private JwtKeyConfig jwtKeyConfig;

    public void validateToken(String jwt) {
        try {
            Jwts.parserBuilder().setSigningKey(jwtKeyConfig.getPublicKey()).build().parseClaimsJws(jwt);
        } catch (Exception ex) {
            log.error("Invalid Json Web Token", ex);
            throw new JwtException("Invalid Json Web Token");
        }
    }

    public UserInfo getUserInfo(String jwt) {
        final UserInfo info = new UserInfo();
        Claims claims = getClaims(jwt);
        info.setId((String) claims.get(KEYCLOAK_ID_TAG));
        info.setUserName((String) claims.get(KEYCLOAK_USERNAME_TAG));
        info.setName((String) claims.get(KEYCLOAK_NAME_TAG));
        info.setEmployeeId((String) claims.get(KEYCLOAK_EMPLOYEE_ID_TAG));
        info.setTechUser((Boolean) claims.get(KEYCLOAK_IS_TECH_USER_TAG));
        info.setAdmin(USER_ADMIN_FLAG.equals(claims.get(DREMIO_ADMIN)));
        return info;
    }

    private Claims getClaims(String jwt) {
        return Jwts.parserBuilder().setSigningKey(jwtKeyConfig.getPublicKey()).build().parseClaimsJws(jwt).getBody();
    }
}
