package com.goodt.dremio.connector.security;

import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.security.oauth2.resource.PrincipalExtractor;

import java.util.List;
import java.util.Map;

import com.goodt.dremio.connector.dto.UserInfo;

import static com.goodt.dremio.connector.dto.Constansts.ANONYMOUS_USER;
import static com.goodt.dremio.connector.dto.Constansts.USER_ADMIN_FLAG;
import static com.goodt.dremio.connector.security.GlobalDefs.*;

@Slf4j
public class KeyCloakUserInfoExtractorService implements PrincipalExtractor {

    @Override
    public Object extractPrincipal(Map<String, Object> map) {
        final UserInfo userInfo = new UserInfo();
        if (map.containsKey(KEYCLOAK_ID_TAG)) {
            log.debug(String.format("principal \"id\": %s", map.get(KEYCLOAK_ID_TAG)));
            userInfo.setId(map.get(KEYCLOAK_ID_TAG).toString());
        }

        if (map.containsKey(KEYCLOAK_NAME_TAG)) {
            log.debug(String.format("principal \"name\": %s", map.get(KEYCLOAK_NAME_TAG)));
            userInfo.setName(map.get(KEYCLOAK_NAME_TAG).toString());
        }

        if (map.containsKey(KEYCLOAK_USERNAME_TAG)) {
            log.debug(String.format("principal \"user_name\": %s", map.get(KEYCLOAK_USERNAME_TAG)));
            userInfo.setUserName(map.get(KEYCLOAK_USERNAME_TAG).toString());
        }

        if (map.containsKey(KEYCLOAK_EMPLOYEE_ID_TAG)) {
            log.debug(String.format("principal \"employee_id\": %s", map.get(KEYCLOAK_EMPLOYEE_ID_TAG)));
            userInfo.setEmployeeId(map.get(KEYCLOAK_EMPLOYEE_ID_TAG).toString());
        } else {
            userInfo.setEmployeeId(ANONYMOUS_USER);
        }

        if (map.containsKey(KEYCLOAK_GROUP_TAG)) {
            log.info(String.format("principal \"groups\": %s", map.get(KEYCLOAK_GROUP_TAG)));
            userInfo.setGroups((List<String>) map.get(KEYCLOAK_GROUP_TAG));
        }

        if (map.containsKey(KEYCLOAK_IS_TECH_USER_TAG)) {
            log.debug(String.format("principal \"is_tech_user\": %s", map.get(KEYCLOAK_IS_TECH_USER_TAG)));
            userInfo.setTechUser((Boolean) map.get(KEYCLOAK_IS_TECH_USER_TAG));
        }

        final Integer admin = (Integer) map.get(DREMIO_ADMIN);
        userInfo.setAdmin(admin != null && USER_ADMIN_FLAG.equals(admin.longValue()));

        return userInfo;
    }
}
