package com.goodt.dremio.connector.service;

import com.zaxxer.hikari.HikariDataSource;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.entity.api.CatalogResult;
import com.goodt.dremio.connector.entity.api.FieldDesc;
import com.goodt.dremio.connector.entity.api.RootEntity;

@Slf4j
public class SchemaProviderClickHouse implements SchemaProvider {
    private static final String GET_TABLES_LIST_TEMPLATE = "SELECT table_name as catalog_name FROM INFORMATION_SCHEMA.TABLES WHERE table_name NOT LIKE '%s' AND table_schema = '%s'";
    private static final String INNER_TABLES_TEMPLATE = "%inner%";
    private static final String GET_COLUMNS_LIST = "SELECT name, type FROM system.columns WHERE table = '%s'";
    private final ConnectionCtx ctx;

    public SchemaProviderClickHouse(ConnectionCtx ctx) {
        this.ctx = ctx;
        if (!((HikariDataSource) ctx.template().getDataSource()).isReadOnly()) {
            ((HikariDataSource) ctx.template().getDataSource()).setReadOnly(true);
        }
    }

    @Override
    public List<RootEntity> getMainCatalog() {
        final List<RootEntity> rez = new ArrayList<>();
        String query = String.format(GET_TABLES_LIST_TEMPLATE, INNER_TABLES_TEMPLATE, ctx.schema());
        ctx.template().query(query, rs -> {
            RootEntity e = new RootEntity();
            final String tableName = rs.getString("catalog_name");
            e.setId(tableName);
            e.setPath(Collections.singletonList(tableName));
            e.setType("DATASET");
            rez.add(e);
        });
        return rez;
    }

    @Override
    public CatalogResult getEntityByPath(List<String> path) {
        final String table = path.stream().reduce((s1, s2) -> s1 + "." + s2).orElse("");
        final ArrayList<FieldDesc> fields = new ArrayList<>();
        final CatalogResult rez = new CatalogResult().setFields(fields);
        rez.setId(table);
        rez.setPath(Collections.singletonList(table));

        ctx.template().query(String.format(GET_COLUMNS_LIST, table), rs -> {
            final FieldDesc f = new FieldDesc()
                    .setName(rs.getString("name"))
                    .setType(new FieldDesc().setName(rs.getString("type")));
            fields.add(f);
        });
        return rez;
    }
}
