package com.goodt.dremio.connector.service;

import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.dto.DremioCatalogResp;
import com.goodt.dremio.connector.dto.DremioV3Resp;
import com.goodt.dremio.connector.entity.api.CatalogResult;
import com.goodt.dremio.connector.entity.api.FieldDesc;
import com.goodt.dremio.connector.entity.api.RootEntity;
import com.goodt.dremio.connector.exceptions.DremioApiException;
import com.goodt.dremio.connector.exceptions.PermissionInfoException;
import com.goodt.dremio.connector.service.clients.DremioClient;
import com.goodt.dremio.connector.service.impl.DremioTokenizer;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;

import java.util.*;

@Slf4j
@RequiredArgsConstructor
public class SchemaProviderDremio implements SchemaProvider {

    private final ConnectionCtx ctx;

    private final DremioClient dremioClient;

    private final DremioTokenizer dremioTokenizer;
    @Value("${app-cfg.system.data.catalog}")
    String permissionsCatalog;

    @Override
    public List<RootEntity> getMainCatalog() {
        final String token = dremioTokenizer.get(ctx);
        log.debug(String.format("getMainCatalog(_authToken=%s)", token));

        try {
            final DremioV3Resp v3 = dremioClient.getV3Catalog(ctx.api(), token);
            if (v3.getData() != null) {
                return v3.getData();
            }
        } catch (Exception ex) {
            throw new DremioApiException(ex);
        }

        return Collections.emptyList();
    }

    @Override
    public CatalogResult getEntityByPath(List<String> catPath) {
        final String token = dremioTokenizer.get(ctx);
        log.debug(String.format("getMainCatalog(_authToken=%s)", token));

        try {
            CatalogResult catResult = new CatalogResult();
            final String path = String.join("/", catPath);
            final DremioCatalogResp resp = dremioClient.getPathCatalog(ctx.api(), token, path);
            catResult.setId(resp.getId());
            catResult.setEntityType(resp.getEntityType());
            catResult.setPath(catPath);

            if (resp.getChildren() != null) {
                catResult.setChildren(resp.getChildren());
            } else {
                catResult.setType(resp.getType());
                catResult.setFields(resp.getFields());
            }

            return catResult;
        } catch (Exception ex) {
            throw new DremioApiException(ex);
        }
    }

    public List<String> getPermissionInfo() {
        log.info("permissions-info()");

        try {
            CatalogResult catalogResult = getEntityByPath(Arrays.asList(permissionsCatalog, "permission"));

            List<String> permissionsList = new ArrayList<>();
            final String token = dremioTokenizer.get(ctx);
            for (int k = 0; k < catalogResult.getFields().size(); k++) {
                final FieldDesc fieldDesc = catalogResult.getFields().get(k);
                final String permission = fieldDesc.getName();
                if (!Objects.equals(permission, token)) {
                    permissionsList.add(permission);
                }
            }

            log.debug("\t --->" + permissionsList);
            return permissionsList;
        } catch (Exception ex) {
            log.error("PermissionInfo error", ex);
            throw new PermissionInfoException(ex);
        }
    }
}
