package com.goodt.dremio.connector.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.entity.api.CatalogResult;
import com.goodt.dremio.connector.entity.api.FieldDesc;
import com.goodt.dremio.connector.entity.api.RootEntity;

@Slf4j
@RequiredArgsConstructor
public class SchemaProviderDrill implements SchemaProvider {

    private final ConnectionCtx ctx;
    private final String connectionCode;

    @Override
    public List<RootEntity> getMainCatalog() {
        final List<RootEntity> rez = new ArrayList<>();
        ctx.template().query(String.format("select `table_name` as `catalog_name` from `information_schema`.`tables` where `table_type` = 'TABLE' and `table_schema` = '%s'", connectionCode), rs -> {
            RootEntity e = new RootEntity();
            final String tableName = rs.getString("catalog_name");
            e.setId(tableName);
            e.setPath(Collections.singletonList(tableName));
            e.setType("DATASET");
            rez.add(e);
        });

        return rez;
    }

    @Override
    public CatalogResult getEntityByPath(List<String> path) {
        final String table = path.stream().reduce((s1, s2) -> s1 + "." + s2).orElse("");
        final ArrayList<FieldDesc> fields = new ArrayList<>();
        final CatalogResult rez = new CatalogResult().setFields(fields);
        rez.setId(table);
        rez.setPath(Collections.singletonList(table));

        final String tablesQuery = "select column_name, data_type from information_schema.columns where table_schema = '%s' and table_name = '%s' order by ordinal_position";
        ctx.template().query(String.format(tablesQuery, connectionCode, table), rs -> {
            final FieldDesc f = new FieldDesc().setName(rs.getString("column_name")).setType(new FieldDesc().setName(rs.getString("data_type")));
            fields.add(f);
        });

        return rez;
    }
}
