package com.goodt.dremio.connector.service;

import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.dto.err.ConnectorException;
import com.goodt.dremio.connector.service.clients.DremioClient;
import com.goodt.dremio.connector.service.impl.DremioTokenizer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class SchemaProviderFactory {

    @Autowired
    private DremioClient dremioClient;
    @Autowired
    private DremioTokenizer dremioTokenizer;

    public SchemaProvider get(ConnectionCtx ctx, String connectionCode) {
        switch (ctx.provider()) {
            case DREMIO:
                return new SchemaProviderDremio(ctx, dremioClient, dremioTokenizer);
            case PG:
                return new SchemaProviderPg(ctx);
            case DRILL:
                return new SchemaProviderDrill(ctx, connectionCode);
            case CLICK_HOUSE:
                return new SchemaProviderClickHouse(ctx);
        }
        throw ConnectorException.of("Unknown provider " + ctx.provider());
    }
}
