package com.goodt.dremio.connector.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.entity.api.CatalogResult;
import com.goodt.dremio.connector.entity.api.FieldDesc;
import com.goodt.dremio.connector.entity.api.RootEntity;

@Slf4j
@RequiredArgsConstructor
public class SchemaProviderPg implements SchemaProvider {

    private final ConnectionCtx ctx;

    @Override
    public List<RootEntity> getMainCatalog() {
        final String q = "select table_schema, table_name from (" +
                "  select table_schema, table_name, table_catalog from information_schema.tables " +
                "  union " +
                "  select table_schema, table_name, table_catalog from information_schema.views " +
                ") t " +
                "where table_schema = '%s' and table_catalog = '%s' and t.table_name not in ('databasechangelog', 'databasechangeloglock', 'pg_stat_statements') " +
                "order by table_name";
        String sql = String.format(q, ctx.schema(), ctx.authKey());
        final List<RootEntity> rez = new ArrayList<>();
        ctx.template().query(sql, rs -> {
            RootEntity e = new RootEntity();
            final String tableName = rs.getString("table_name");
            e.setId(tableName);
            e.setPath(Collections.singletonList(tableName));
            e.setType("DATASET");
            rez.add(e);
        });

        return rez;
    }

    @Override
    public CatalogResult getEntityByPath(List<String> path) {
        final String tab = path.get(0);
        final ArrayList<FieldDesc> fields = new ArrayList<>();
        final CatalogResult rez = new CatalogResult().setFields(fields);
        rez.setId(tab);
        rez.setPath(Collections.singletonList(tab));

        final String cols = "column_name, data_type";
        final String q = "select %s from information_schema.columns where table_schema = '%s' and table_catalog = '%s' and table_name = '%s' order by ordinal_position";
        String sql = String.format(q, cols, ctx.schema(), ctx.authKey(), tab);
        ctx.template().query(sql, rs -> {
            final FieldDesc f = new FieldDesc().setName(rs.getString("column_name")).setType(new FieldDesc().setName(rs.getString("data_type")));
            fields.add(f);
        });
        return rez;
    }
}
