package com.goodt.dremio.connector.service.impl;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.*;

import com.goodt.dremio.connector.entity.permissions.EmployeePermissions;
import com.goodt.dremio.connector.entity.permissions.PermissionResponse;
import com.goodt.dremio.connector.exceptions.PermissionsListException;
import com.goodt.dremio.connector.repository.IDremioQuery;
import com.goodt.dremio.connector.service.AbstractPermissionsAppender;
import com.goodt.dremio.connector.service.IDremioPermissions;

import static com.goodt.dremio.connector.dto.Constansts.ANONYMOUS_USER;

@Slf4j
@Service
public class DremioPermissions extends AbstractPermissionsAppender implements IDremioPermissions {


    public PermissionResponse getPermissionsList(String empId, UUID logId, IDremioQuery dremioQuery) {
        log.debug("{}: getPermissionsList({})", logId, empId);

        try {
            EmployeePermissions empPermissions = dremioQuery.getEmployeePermissions(empId, new ArrayList<>(), logId);
            PermissionResponse permissionResponse = new PermissionResponse();
            List<Map<String, String>> permissions = new ArrayList<>();
            Set<String> permissionsList = empPermissions.getPermissions().keySet();
            for (int rowNum = 0; rowNum < empPermissions.getPermissionsCount(); rowNum++) {
                Map<String, String> permissionRow = new HashMap<>();
                for (String permissionName : permissionsList) {
                    String permissionValue = empPermissions.getPermissions().get(permissionName).get(rowNum);
                    permissionRow.put(permissionName, permissionValue);
                }

                permissions.add(permissionRow);
            }
            permissionResponse.setPermissions(permissions);
            permissionResponse.setEmployeeId(empId.equals(ANONYMOUS_USER) ? null : empId);
            return permissionResponse;
        } catch (Exception ex) {
            log.error("Ошибка getPermissionsList", ex);
            throw new PermissionsListException(ex);
        }
    }

    @Override
    protected String quoteColumn(String columnName) {
        return "\"" + columnName + "\"";
    }
}
