package com.goodt.dremio.connector.service.impl;

import com.goodt.dremio.connector.dto.ConnectionCtx;
import com.goodt.dremio.connector.dto.DremioLogin;
import com.goodt.dremio.connector.dto.DremioLoginResp;
import com.goodt.dremio.connector.exceptions.DremioAuthException;
import com.goodt.dremio.connector.service.clients.DremioClient;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

@Slf4j
@Component
@RequiredArgsConstructor
public class DremioTokenizer {

    private static final long BUFFER_TIME = 3600000;

    @Autowired
    private DremioClient dremioClient;

    public String get(ConnectionCtx ctx) {
        log.info("getAuthToken()");

        if (isTokenExpire(ctx)) {
            log.debug("\t--> Get auth token from dremio");
            refreshToken(ctx);
        }
        return ctx.token();
    }

    private synchronized void refreshToken(ConnectionCtx ctx) {
        try {
            final DremioLogin req = new DremioLogin().setUserName(ctx.login()).setPassword(ctx.password());
            final DremioLoginResp tokenData = dremioClient.login(ctx.api(), req);
            ctx.token("_dremio" + tokenData.getToken());
            ctx.expireDate(new Date(tokenData.getExpires() - BUFFER_TIME));
        } catch (Exception ex) {
            throw new DremioAuthException(ex);
        }
    }

    private boolean isTokenExpire(ConnectionCtx ctx) {
        if (ctx.expireDate() == null || ctx.token() == null) {
            return true;
        }

        log.debug("t--> Dremio token expired at {}", ctx.expireDate());
        return new Date().compareTo(ctx.expireDate()) >= 0;
    }
}
