package com.goodt.dremio.connector.parser;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.commons.io.IOUtils;
import org.junit.jupiter.api.Test;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.jdbc.DataSourceAutoConfiguration;
import org.springframework.boot.autoconfigure.jdbc.DataSourceTransactionManagerAutoConfiguration;
import org.springframework.boot.autoconfigure.orm.jpa.HibernateJpaAutoConfiguration;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;

import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;

import com.goodt.dremio.connector.dao.AdapterDao;
import com.goodt.dremio.connector.dao.ConnectionDao;
import com.goodt.dremio.connector.entity.query.QuerySchema;
import com.goodt.dremio.connector.exceptions.ParserException;
import com.goodt.dremio.connector.parser.drill.DrillQueryCreator;
import com.goodt.dremio.connector.service.ClientPull;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;

@SpringBootTest
@EnableAutoConfiguration(exclude = {DataSourceAutoConfiguration.class, DataSourceTransactionManagerAutoConfiguration.class, HibernateJpaAutoConfiguration.class})
class DrillQueryCreatorTest {

    String schemaCatalog = "./test_parse_schema/";
    String parseResultCatalog = "drill/test_parse_result/";

    @MockBean
    ConnectionDao connectionDao;
    @MockBean
    AdapterDao adapterDao;
    @MockBean
    ClientPull clientPull;

    @Test
    void testSchema1() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema1.json");
        String checkedSql = getResultString("parseResult1.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema2() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema2.json");
        String checkedSql = getResultString("parseResult2.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema3() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema3.json");
        String checkedSql = getResultString("parseResult3.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema4() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema4.json");
        String checkedSql = getResultString("parseResult4.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema5() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema5.json");
        String checkedSql = getResultString("parseResult5.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema6() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema6.json");
        String checkedSql = getResultString("parseResult6.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema7() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema7.json");
        String checkedSql = getResultString("parseResult7.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        System.out.println(sql);
        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema8() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema8.json");
        String checkedSql = getResultString("parseResult8.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema9() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema9.json");
        String checkedSql = getResultString("parseResult9.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema10() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema10.json");
        String checkedSql = getResultString("parseResult10.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema11() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema11.json");
        String checkedSql = getResultString("parseResult11.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema12() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema12.json");
        String checkedSql = getResultString("parseResult12.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema13() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema13.json");
        String checkedSql = getResultString("parseResult13.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema14() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema14.json");
        String checkedSql = getResultString("parseResult14.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema15() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema15.json");
        String checkedSql = getResultString("parseResult15.sql");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");
        String sql = parser.parse(null);

        assertEquals(checkedSql, sql);
    }

    @Test
    void testSchema16() throws IOException {
        QuerySchema querySchema = getQuerySchema("querySchema16.json");

        DrillQueryCreator parser = new DrillQueryCreator(querySchema, "test-connection");

        assertThrows(ParserException.class, () -> parser.parse(null));
    }

    private String getResultString(String resultFileName) throws IOException {
        InputStream inputStream = getClass().getClassLoader().getResourceAsStream(parseResultCatalog + resultFileName);
        return IOUtils.toString(inputStream, StandardCharsets.UTF_8.name());
    }

    private QuerySchema getQuerySchema(String schemaFileName) throws IOException {
        InputStream inputStream = getClass().getClassLoader().getResourceAsStream(schemaCatalog + schemaFileName);
        String jsonStr = IOUtils.toString(inputStream, StandardCharsets.UTF_8.name());
        ObjectMapper objectMapper = new ObjectMapper();
        return objectMapper.readValue(jsonStr, QuerySchema.class);
    }
}