package com.goodt.dremio.connector.service;

import com.goodt.dremio.connector.dao.AdapterDao;
import com.goodt.dremio.connector.dao.ConnectionDao;
import com.goodt.dremio.connector.entity.permissions.EmployeePermissions;
import com.goodt.dremio.connector.entity.permissions.PermissionResponse;
import com.goodt.dremio.connector.repository.IDremioQuery;
import com.goodt.dremio.connector.service.impl.DremioPermissions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.jdbc.DataSourceAutoConfiguration;
import org.springframework.boot.autoconfigure.jdbc.DataSourceTransactionManagerAutoConfiguration;
import org.springframework.boot.autoconfigure.orm.jpa.HibernateJpaAutoConfiguration;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.test.context.ContextConfiguration;

import java.util.*;
import java.util.concurrent.CompletableFuture;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.doReturn;

@SpringBootTest
@ContextConfiguration
@EnableAutoConfiguration(exclude = {
        DataSourceAutoConfiguration.class,
        DataSourceTransactionManagerAutoConfiguration.class,
        HibernateJpaAutoConfiguration.class
})
class DremioPermissionsRestrictionsTest {

    @Mock
    IDremioQuery dremioQuery;
    @Mock
    IDremioPermissions permissions;
    @MockBean
    ConnectionDao connectionDao;
    @MockBean
    AdapterDao adapterDao;
    @MockBean
    ClientPull clientPull;
    @InjectMocks
    IDremioPermissions dremioPermissions = new DremioPermissions();

    @BeforeEach
    void setUp() {

    }

    @Test
    void testGetPermissionsList_1() {
        doReturn(getEmployeePermissionsFull()).when(dremioQuery).getEmployeePermissions(any(), any(), any());

        PermissionResponse checkedResult = dremioPermissions.getPermissionsList("100", UUID.randomUUID(), dremioQuery);
        PermissionResponse expectedResult = getFullPermissionResponse();
        assertEquals(expectedResult, checkedResult);
    }

    @Test
    void testGetPermissionsList_2() {
        doReturn(getEmployeePermissionsPartial()).when(dremioQuery).getEmployeePermissions(any(), any(), any());

        PermissionResponse checkedResult = dremioPermissions.getPermissionsList("100", UUID.randomUUID(), dremioQuery);
        PermissionResponse expectedResult = getPartialPermissionResponse();
        assertEquals(expectedResult, checkedResult);
    }

    private CompletableFuture<EmployeePermissions> getEmployeePermissionsEmpty() {
        EmployeePermissions employeePermissions = new EmployeePermissions("100");
        return CompletableFuture.completedFuture(employeePermissions);
    }

    private EmployeePermissions getEmployeePermissionsFull() {
        EmployeePermissions employeePermissions = new EmployeePermissions("100");
        Map<String, List<String>> permissions = new HashMap<>();
        List<String> divisionId = Arrays.asList("1", "1", "1");
        permissions.put("$divisionId", divisionId);
        List<String> systemRoleId = Arrays.asList("1", "1", "1");
        permissions.put("$systemRoleId", systemRoleId);
        List<String> kpi = Arrays.asList("income", "salary", "efficiency");
        permissions.put("$kpi", kpi);

        employeePermissions.setPermissions(permissions);
        employeePermissions.setPermissionsCount(3);

        return employeePermissions;
    }

    private EmployeePermissions getEmployeePermissionsPartial() {
        EmployeePermissions employeePermissions = new EmployeePermissions("100");
        Map<String, List<String>> permissions = new HashMap<>();
        List<String> divisionId = Arrays.asList(null, "1", "1");
        permissions.put("$divisionId", divisionId);
        List<String> systemRoleId = Arrays.asList("1", "1", "1");
        permissions.put("$systemRoleId", systemRoleId);
        List<String> kpi = Arrays.asList("income", "salary", "efficiency");
        permissions.put("$kpi", kpi);

        employeePermissions.setPermissions(permissions);
        employeePermissions.setPermissionsCount(3);

        return employeePermissions;
    }

    private PermissionResponse getFullPermissionResponse() {
        PermissionResponse permissionResponse = new PermissionResponse();
        permissionResponse.setEmployeeId("100");

        Map<String, String> perm_1 = new HashMap<>();
        perm_1.put("$divisionId", "1");
        perm_1.put("$kpi", "income");
        perm_1.put("$systemRoleId", "1");

        Map<String, String> perm_2 = new HashMap<>();
        perm_2.put("$divisionId", "1");
        perm_2.put("$kpi", "salary");
        perm_2.put("$systemRoleId", "1");

        Map<String, String> perm_3 = new HashMap<>();
        perm_3.put("$divisionId", "1");
        perm_3.put("$kpi", "efficiency");
        perm_3.put("$systemRoleId", "1");

        List<Map<String, String>> permissions = Arrays.asList(perm_1, perm_2, perm_3);
        permissionResponse.setPermissions(permissions);

        return permissionResponse;
    }

    private PermissionResponse getPartialPermissionResponse() {
        PermissionResponse permissionResponse = new PermissionResponse();
        permissionResponse.setEmployeeId("100");

        Map<String, String> perm_1 = new HashMap<>();
        perm_1.put("$divisionId", null);
        perm_1.put("$kpi", "income");
        perm_1.put("$systemRoleId", "1");

        Map<String, String> perm_2 = new HashMap<>();
        perm_2.put("$divisionId", "1");
        perm_2.put("$kpi", "salary");
        perm_2.put("$systemRoleId", "1");

        Map<String, String> perm_3 = new HashMap<>();
        perm_3.put("$divisionId", "1");
        perm_3.put("$kpi", "efficiency");
        perm_3.put("$systemRoleId", "1");

        List<Map<String, String>> permissions = Arrays.asList(perm_1, perm_2, perm_3);
        permissionResponse.setPermissions(permissions);

        return permissionResponse;
    }
}