package com.goodt.dremio.connector.springconfig;

import org.jose4j.jwk.RsaJsonWebKey;
import org.jose4j.jwk.RsaJwkGenerator;
import org.jose4j.jws.AlgorithmIdentifiers;
import org.jose4j.jws.JsonWebSignature;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.security.PublicKey;

@Configuration
public class PublicKeyTestConfig {

    @Bean
    public PublicKey getPublicKey() {
        return getRsaJsonWebKey().getPublicKey();
    }

    @Bean
    RsaJsonWebKey getRsaJsonWebKey() {
        try {
            RsaJsonWebKey rsaJsonWebKey = RsaJwkGenerator.generateJwk(2048);
            rsaJsonWebKey.setKeyId("k1");

            return rsaJsonWebKey;
        } catch (Exception ex) {
            return null;
        }
    }

    @Bean
    JsonWebSignature getJsonWebSignature() {
        try {
            JsonWebSignature jws = new JsonWebSignature();
            jws.setKey(getRsaJsonWebKey().getPrivateKey());
            jws.setKeyIdHeaderValue(getRsaJsonWebKey().getKeyId());
            jws.setAlgorithmHeaderValue(AlgorithmIdentifiers.RSA_USING_SHA256);

            return jws;
        } catch (Exception ex) {
            return null;
        }
    }
}
