package com.goodt.drive.fileupload.application.configuration;

import io.micrometer.core.instrument.binder.db.PostgreSQLDatabaseMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmGcMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmHeapPressureMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmMemoryMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmThreadMetrics;
import io.micrometer.core.instrument.binder.system.FileDescriptorMetrics;
import io.micrometer.core.instrument.binder.system.UptimeMetrics;
import io.micrometer.prometheus.PrometheusConfig;
import io.micrometer.prometheus.PrometheusMeterRegistry;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.sql.DataSource;

@Configuration
@EnableConfigurationProperties
@ConfigurationProperties
public class AppConfig {
    public AppConfig() {

    }

    public AppConfig(String apiVersion, String environment, KeyCloakConfig keyCloakConfig, boolean useS3, boolean useWebDav, boolean fileSystem) {
        this.apiVersion = apiVersion;
        this.environment = environment;
        this.keyCloakConfig = keyCloakConfig;
        this.useS3 = useS3;
        this.useWebDav = useWebDav;
        this.fileSystem = fileSystem;
    }

    public String getEnvironment() {
        return environment;
    }

    public void setEnvironment(String environment) {
        this.environment = environment;
    }

    public String getApiVersion() {
        return apiVersion;
    }

    public void setApiVersion(String apiVersion) {
        this.apiVersion = apiVersion;
    }

    public KeyCloakConfig getKeyCloakConfig() {
        return keyCloakConfig;
    }

    public void setKeyCloakConfig(KeyCloakConfig keyCloakConfig) {
        this.keyCloakConfig = keyCloakConfig;
    }

    public boolean isUseS3() {
        return useS3;
    }

    public void setUseS3(boolean useS3) {
        this.useS3 = useS3;
    }

    public boolean isUseWebDav() {
        return useWebDav;
    }

    public void setUseWebDav(boolean useWebDav) {
        this.useWebDav = useWebDav;
    }

    public boolean isFileSystem() {
        return fileSystem;
    }

    public void setFileSystem(boolean fileSystem) {
        this.fileSystem = fileSystem;
    }

    @Bean
    public PrometheusMeterRegistry createMicrometer() {
        PrometheusMeterRegistry registry = new PrometheusMeterRegistry(PrometheusConfig.DEFAULT);
        new io.micrometer.core.instrument.binder.system.ProcessorMetrics().bindTo(registry);
        new JvmHeapPressureMetrics().bindTo(registry);
        new JvmThreadMetrics().bindTo(registry);
        new JvmGcMetrics().bindTo(registry);
        new JvmMemoryMetrics().bindTo(registry);
        new UptimeMetrics().bindTo(registry);
        new FileDescriptorMetrics().bindTo(registry);

        return registry;
    }

    @Value("${appConfig.version}")
    private String apiVersion;

    @Value("${appConfig.environment}")
    private String environment;

    @Value("${appConfig.useS3}")
    private boolean useS3;

    @Value("${appConfig.useWebDav}")
    private boolean useWebDav;

    @Value("${appConfig.fileSystem}")
    private boolean fileSystem;

    @Autowired
    private KeyCloakConfig keyCloakConfig;
}
