package com.goodt.drive.fileupload.application.configuration;

import io.minio.MinioClient;
import lombok.extern.log4j.Log4j2;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.PostConstruct;

@Slf4j
@Configuration
@ConditionalOnProperty(value = "appConfig.useS3", havingValue = "true")
public class MinioConfig {

    @PostConstruct
    public void init() {
        log.info(String.format("fileSystem: %s", appConfig.isFileSystem()));
        log.info(String.format("useS3: %s", appConfig.isUseS3()));
        log.info(String.format("useWebDav: %s", appConfig.isUseWebDav()));
        log.info("MinioConfig is created!!!");
    }

    public MinioConfig() {

    }

    public MinioConfig(String url, String accessKey, String secretKey, String bucketName) {
        this.url = url;
        this.accessKey = accessKey;
        this.secretKey = secretKey;
        this.bucketName = bucketName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getAccessKey() {
        return accessKey;
    }

    public void setAccessKey(String accessKey) {
        this.accessKey = accessKey;
    }

    public String getSecretKey() {
        return secretKey;
    }

    public void setSecretKey(String secretKey) {
        this.secretKey = secretKey;
    }

    public String getBucketName() {
        return bucketName;
    }

    public void setBucketName(String bucketName) {
        this.bucketName = bucketName;
    }

    @Value("${appConfig.minio.url}")
    private String url;

    @Value("${appConfig.minio.accessKey}")
    private String accessKey;

    @Value("${appConfig.minio.secretKey}")
    private String secretKey;

    @Value("${appConfig.minio.bucketName}")
    private String bucketName;

    @Autowired
    private AppConfig appConfig;

    @Bean
    public MinioClient s3Client() {
        return MinioClient.builder()
                .endpoint(url)
                .credentials(accessKey, secretKey)
                .build();
    }
}
