package com.goodt.drive.fileupload.application.controllers.api;

import com.goodt.drive.fileupload.application.dto.UploadDto;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;

import com.goodt.drive.fileupload.application.services.IFileUploadService;

@CrossOrigin
@RestController
public class FileUploadController extends BaseController {

    @Operation(summary = "Метод загрузки файла на сервер", description = "Метод загрузки файла на сервер", tags = {"fileupload"})
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "В случае если не возникло проблем с загрузкой файла",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "500", description = "В случае если что-то пошло не так.",
                    content = @Content(schema = @Schema(implementation = String.class))),
    })
    @PostMapping(value = "/api/fileupload/upload", consumes = {MediaType.MULTIPART_FORM_DATA_VALUE})
    public String upload(
            @io.swagger.v3.oas.annotations.parameters.RequestBody(description = "загружаемый файл")
            @RequestParam(name = "file") MultipartFile file, HttpServletRequest request) {
        return fileUploadService.uploadFile(file, request);
    }

    @Operation(summary = "Метод загрузки файла на сервер (изменен формат ответа)", description = "Метод загрузки файла на сервер (изменен формат ответа)", tags = {"fileupload"})
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "В случае если не возникло проблем с загрузкой файла",
                    content = @Content(schema = @Schema(implementation = UploadDto.class))),
            @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "500", description = "В случае если что-то пошло не так.",
                    content = @Content(schema = @Schema(implementation = String.class))),
    })
    @PostMapping(value = "/api/fileupload/upload-new", consumes = {MediaType.MULTIPART_FORM_DATA_VALUE})
    public UploadDto uploadNew(
            @io.swagger.v3.oas.annotations.parameters.RequestBody(description = "загружаемый файл")
            @RequestParam(name = "file") MultipartFile file, HttpServletRequest request) {
        String uri = fileUploadService.uploadFile(file, request);
        String name = file.getOriginalFilename();
        UploadDto dto = new UploadDto(uri, name);
        return dto;
    }

    @Operation(summary = "Метод загрузки файла на сервер", description = "Метод загрузки файла на сервер", tags = {"fileupload"})
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "В случае если не возникло проблем с загрузкой файла",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "500", description = "В случае если что-то пошло не так.",
                    content = @Content(schema = @Schema(implementation = String.class))),
    })
    @PutMapping(value = "/api/fileupload/upload", consumes = {MediaType.MULTIPART_FORM_DATA_VALUE})
    public String uploadPut(
            @io.swagger.v3.oas.annotations.parameters.RequestBody(description = "загружаемый файл")
            @RequestParam(name = "file") MultipartFile file, HttpServletRequest request) {
        return fileUploadService.uploadFile(file, request);
    }

    @Operation(summary = "Скачивание файла", description = "Скачивание файла", tags = {"fileupload"})
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "В случае если не возникло проблем с загрузкой файла",
                    content = @Content(schema = @Schema(implementation = ResponseEntity.class))),
            @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "500", description = "В случае если что-то пошло не так.",
                    content = @Content(schema = @Schema(implementation = String.class))),
    })
    @GetMapping("/api/fileupload")
    public ResponseEntity<?> getUrl(
            @Parameter(name = "name", description = "Имя файла, который хотим скачать")
            @RequestParam(name = "name") String fileName,
            HttpServletRequest request) {
        return fileUploadService.downloadFile(fileName, request);
    }

    @Autowired
    private IFileUploadService fileUploadService;
}
