package com.goodt.drive.fileupload.application.services;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.goodt.drive.fileupload.application.dto.BuildInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import java.io.InputStream;
import java.net.URL;

@Slf4j
@Service
public class BuildInfoServiceImpl implements BuildInfoService {

    private static final String BUILD_INFO_FILE_NAME = "build-info.json";

    private BuildInfo buildInfo = new BuildInfo();

    @PostConstruct
    public void initialize() {
        ClassLoader classLoader = getClass().getClassLoader();
        URL buildInfoUrl = classLoader.getResource(BUILD_INFO_FILE_NAME);
        if (buildInfoUrl == null) {
            log.error("File '{}' not found.", BUILD_INFO_FILE_NAME);
            return;
        }

        try {
            try (InputStream in = getClass().getResourceAsStream("/" + BUILD_INFO_FILE_NAME)) {
                final ObjectMapper mapper = new ObjectMapper();
                buildInfo = mapper.readValue(in, BuildInfo.class);
            }
        } catch (Exception e) {
            String errorMessage = String.format("File '%s' can't be loaded.", BUILD_INFO_FILE_NAME);
            log.error(errorMessage, e);
            return;
        }

        log.info("File '{}' loaded.", BUILD_INFO_FILE_NAME);
    }

    public BuildInfo getBuildInfo() {
        return buildInfo;
    }
}
