package com.goodt.drive.fileupload.application.utils;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.Jwt;
import io.jsonwebtoken.Jwts;
import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;

import java.security.PublicKey;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import static com.goodt.drive.fileupload.application.utils.TextConstants.*;

@Slf4j
@UtilityClass
public class JwtUtil {

    public static Claims getClaims(String jwt, PublicKey publicKey) {
        if (publicKey == null) {
            String[] splitJwt = jwt.split("\\.");
            String unsignedJwt = String.format("%s.%s.", splitJwt[0], splitJwt[1]);
            Jwt<?, ?> jwtObject = Jwts.parser().parse(unsignedJwt);
            return (Claims) jwtObject.getBody();
        }
        return Jwts.parser().setSigningKey(publicKey).parseClaimsJws(jwt).getBody();
    }

    public static List<String> getUserRolesFromJwt(String jwt, PublicKey publicKey) {
        Claims claims = getClaims(jwt, publicKey);
        if (claims.containsKey(REALM_ACCESS)) {
            Object object = claims.get(REALM_ACCESS);
            Map<String, List<String>> realmAccess;
            if (object instanceof LinkedHashMap) {
                realmAccess = (LinkedHashMap<String, List<String>>) object;
                return realmAccess.get(ROLES);
            }
        }
        log.info(REALM_ACCESS_NOT_FOUND_IN_JWT, REALM_ACCESS);
        return null;
    }
}
