package com.goodt.drive.fileupload.application.utils;

import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;

import javax.servlet.http.HttpServletRequest;
import java.util.Objects;
import java.util.UUID;

@Slf4j
public class UploadUtil {

    private UploadUtil() {
    }

    public static String getNewFileName(String originalFilename) {
        UUID uuid = UUID.randomUUID();
        return String.format("%s%s", uuid, Objects.requireNonNull(originalFilename)
                .substring(originalFilename.lastIndexOf(".")));
    }

    public static MediaType getMediaTypeForFileName(HttpServletRequest request, String fileName) {
        String mineType = request.getServletContext().getMimeType(fileName);
        try {
            return MediaType.parseMediaType(mineType);
        } catch (Exception e) {
            log.info("Could not determine file type");
            return MediaType.APPLICATION_OCTET_STREAM;
        }
    }

    public final static String UPLOAD = "/upload";
    public final static String NAME_PARAMETER = "?name=";
}
