package com.goodt.drive.fileupload.security;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtException;
import io.jsonwebtoken.Jwts;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Service;

import com.goodt.drive.fileupload.application.configuration.JwtKeyConfig;
import com.goodt.drive.fileupload.application.data.UserInfo;

import static com.goodt.drive.fileupload.application.utils.JwtUtil.getClaims;
import static com.goodt.drive.fileupload.application.utils.TextConstants.*;

@Slf4j
@Service
@RequiredArgsConstructor
@ConditionalOnBean(JwtKeyConfig.class)
public class JwtService {

    private final JwtKeyConfig jwtKeyConfig;

    public boolean validateToken(String jwt) {
        try {
            Jwts.parser().setSigningKey(jwtKeyConfig.getPublicKey()).parseClaimsJws(jwt);
            return true;
        } catch (Exception ex) {
            log.error(INVALID_JWT, ex);
            throw new JwtException(INVALID_JWT);
        }
    }

    public UserInfo getUserInfo(String jwt) {
        UserInfo info = new UserInfo();
        Claims claims = getClaims(jwt, jwtKeyConfig.getPublicKey());
        info.setUserName((String) claims.get(USER_NAME));
        info.setName((String) claims.get(NAME));
        info.setEmployeeId((String) claims.get(EMPLOYEE_ID));
        info.setIsTechUser((Boolean) claims.get(IS_TECH_USER));
        return info;
    }
}
