package com.goodt.drive.supeditor.application.configuration;

import com.querydsl.jpa.JPQLQueryFactory;
import com.querydsl.jpa.impl.JPAQueryFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.factory.config.ConfigurableBeanFactory;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;

import javax.persistence.EntityManager;

@Configuration
@EnableConfigurationProperties
@ConfigurationProperties
public class AppConfig {
    
    public AppConfig(){
        
    }
    
    public AppConfig(String apiVersion, String environment, String databaseDriver, String databaseUrl, String databaseUsername,
                     String databasePassword, String appKey, KeyCloakConfig keyCloakConfig, ProjectConfig projectConfig){
        this.apiVersion = apiVersion;
        this.environment = environment;
        this.databaseDriver = databaseDriver;
        this.databaseUrl = databaseUrl;
        this.databaseUsername = databaseUsername;
        this.databasePassword = databasePassword;
        this.appKey = appKey;
        
        this.keyCloakConfig = keyCloakConfig;
        this.projectConfig = projectConfig;
    }
    
    public String getEnvironment(){
        return environment;
    }
    
    public void setEnvironment(String environment) {
        this.environment = environment;
    }
    
    public String getDatabaseDriver(){
        return databaseDriver;
    }
    
    public void setDatabaseDriver(String databaseDriver) {
        this.databaseDriver = databaseDriver;
    }
    
    public String getDatabaseUrl(){
        return databaseUrl;
    }
    
    public void setDatabaseUrl(String databaseUrl) {
        this.databaseUrl = databaseUrl;
    }
    
    public String getApiVersion(){
        return apiVersion;
    }
    
    public void setApiVersion(String apiVersion) {
        this.apiVersion = apiVersion;
    }
    
    public KeyCloakConfig getKeyCloakConfig(){
        return keyCloakConfig;
    }
    
    public void setKeyCloakConfig(KeyCloakConfig keyCloakConfig){
        this.keyCloakConfig = keyCloakConfig;
    }

    public ProjectConfig getProjectConfig() {
        return projectConfig;
    }

    public void setProjectConfig(ProjectConfig projectConfig) {
        this.projectConfig = projectConfig;
    }

    public String getDatabaseUsername() {
        return databaseUsername;
    }

    public void setDatabaseUsername(String databaseUsername) {
        this.databaseUsername = databaseUsername;
    }

    public String getDatabasePassword() {
        return databasePassword;
    }

    public void setDatabasePassword(String databasePassword) {
        this.databasePassword = databasePassword;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    @Value("${appConfig.version}")
    private String apiVersion;
    
    @Value("${appConfig.environment}")
    private String environment;
    
    @Value("${appConfig.dbDriver}")
    private String databaseDriver;
    
    @Value("${appConfig.dbUrl}")
    private String databaseUrl;
    
    @Value("${appConfig.dbUsername}")
    protected String databaseUsername;

    @Value("${appConfig.dbPassword}")
    protected String databasePassword;

    @Value("${appConfig.appKey}")
    protected String appKey;
    
    @Autowired
    private KeyCloakConfig keyCloakConfig;

    @Autowired
    private ProjectConfig projectConfig;

    @Bean
    @Scope(ConfigurableBeanFactory.SCOPE_PROTOTYPE)
    public JPQLQueryFactory jpqlQueryFactory(EntityManager em) {
        return new JPAQueryFactory(() -> em);
    }
}
