package com.goodt.drive.supeditor.application.configuration;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.datatype.jsr310.JavaTimeModule;
import feign.Feign;
import feign.Request;
import feign.form.FormEncoder;
import feign.jackson.JacksonDecoder;
import feign.okhttp.OkHttpClient;
import lombok.extern.slf4j.Slf4j;
import okhttp3.ConnectionPool;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.PostConstruct;
import java.util.concurrent.TimeUnit;

import com.goodt.drive.supeditor.application.services.clients.*;

@Slf4j
@Configuration
public class ClientsConfig {

    @Value("${appConfig.keyCloak.using.api}")
    private String hostKeycloak;

    ObjectMapper om;

    @PostConstruct
    void init() {
        om = new ObjectMapper()
                .configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false)
                .registerModule(new JavaTimeModule());
    }

    @Bean
    public KeyCloakApi keyCloakApi() {
        final okhttp3.OkHttpClient client = new okhttp3.OkHttpClient.Builder()
                .connectionPool(new ConnectionPool(10, 4L, TimeUnit.MINUTES))
                .build();
        return Feign.builder()
                .client(new OkHttpClient(client))
                .decoder(new JacksonDecoder(om))
                .encoder(new FormEncoder())
                .options(new Request.Options(10, TimeUnit.SECONDS, 10, TimeUnit.SECONDS, true))
                .target(KeyCloakApi.class, hostKeycloak);
    }
}
