package com.goodt.drive.supeditor.application.configuration;

import com.goodt.drive.supeditor.application.authentication.AppAuthenticationEntryPoint;
import com.goodt.drive.supeditor.application.services.users.KeyCloakUserInfoExtractorService;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.security.oauth2.resource.PrincipalExtractor;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.oauth2.config.annotation.web.configuration.EnableResourceServer;
import org.springframework.security.oauth2.config.annotation.web.configuration.ResourceServerConfigurerAdapter;
import org.springframework.security.oauth2.provider.token.ResourceServerTokenServices;


@Configuration
@EnableResourceServer
@RequiredArgsConstructor
@ConditionalOnProperty(value = "appConfig.keyCloak.isEnabled", havingValue = "true")
public class ResourceServerConfig extends ResourceServerConfigurerAdapter {
    @Override
    public void configure(HttpSecurity http) throws Exception {
        
        http.headers().frameOptions().sameOrigin();
        http.cors();
        http.csrf().disable()
            .authorizeRequests().antMatchers("/", "/callback", "/login**", "/webjars/**", "/error**").permitAll()
            .and()
            .authorizeRequests().antMatchers("/api/ping").permitAll()
            .and()
            .authorizeRequests().antMatchers(HttpMethod.GET,
                        "/api/project",
                        "/api/project/listall",
                        "/api/project/{id}/export"
                ).permitAll()
            .and()
            .authorizeRequests().antMatchers(HttpMethod.OPTIONS,
                        "/api/project",
                        "/api/project/{id}/export"
                ).permitAll()
            .and()
            .authorizeRequests().antMatchers("/project/**").authenticated()
            .and()
            .authorizeRequests().antMatchers("/api/**").authenticated()
            .and()
            .authorizeRequests().antMatchers("/h2-console/**").permitAll()
            .and()
            .authorizeRequests().antMatchers("/swagger-ui.html").permitAll()
            .and()
            .authorizeRequests().antMatchers("/swagger-ui/**").permitAll()
            .and()
            .exceptionHandling().authenticationEntryPoint(new AppAuthenticationEntryPoint())
            .and()
            .logout().permitAll().logoutSuccessUrl("/");
    }
    
    @Bean
    public PrincipalExtractor getPrincipalExtractor(){
        return new KeyCloakUserInfoExtractorService();
    }
}
