package com.goodt.drive.supeditor.application.configuration;

import lombok.RequiredArgsConstructor;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.annotation.Order;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.security.config.Customizer;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.config.http.SessionCreationPolicy;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;

import javax.servlet.http.HttpServletResponse;

import com.goodt.drive.supeditor.application.security.JwtAuthenticationFilter;

import static com.goodt.drive.supeditor.application.utils.ResponseErrorMessageUtil.setResponseError;

@Configuration
@EnableWebSecurity
@RequiredArgsConstructor
@Order(2)
@ConditionalOnProperty(value = "appConfig.keyCloak.isEnabled", havingValue = "false")
public class WebSecurityConfig extends WebSecurityConfigurerAdapter {

    private final JwtAuthenticationFilter jwtAuthenticationFilter;

    @Override
    protected void configure(final HttpSecurity http) throws Exception {
        http.headers().frameOptions().sameOrigin();
            http.csrf().disable();
        http.cors(Customizer.withDefaults())
            .sessionManagement().sessionCreationPolicy(SessionCreationPolicy.STATELESS)
            .and()
            .authorizeRequests().antMatchers("/", "/callback", "/login**", "/webjars/**", "/error**").permitAll()
            .and()
            .authorizeRequests().antMatchers("/api/ping").permitAll()
            .and()
            .authorizeRequests().antMatchers(HttpMethod.GET,
                                             "/api/project",
                                             "/api/project/listall",
                                             "/api/project/{id}/export"
            ).permitAll()
            .and()
            .authorizeRequests().antMatchers(HttpMethod.OPTIONS,
                                             "/api/project",
                                             "/api/project/{id}/export"
            ).permitAll()
            .and()
            .authorizeRequests().antMatchers("/project/**").authenticated()
            .and()
            .authorizeRequests().antMatchers("/api/**").authenticated()
            .and()
            .authorizeRequests().antMatchers("/h2-console/**").permitAll()
            .and()
            .authorizeRequests().antMatchers("/swagger-ui.html").permitAll()
            .and()
            .authorizeRequests().antMatchers("/swagger-ui/**").permitAll()
            .and()
            .exceptionHandling()
            .authenticationEntryPoint(
                    (request, response, authException) -> {
                        if (request.getHeader(HttpHeaders.AUTHORIZATION) == null)
                            setResponseError(response, HttpServletResponse.SC_UNAUTHORIZED, "Authentication Failed: Invalid Authorization Header");
                        else
                            setResponseError(response, HttpServletResponse.SC_UNAUTHORIZED, "Authentication Failed: Invalid Json Web Token");
                    }
            )
            .and()
            .addFilterBefore(jwtAuthenticationFilter, UsernamePasswordAuthenticationFilter.class)
            .logout().permitAll().logoutSuccessUrl("/");
    }
}
