package com.goodt.drive.supeditor.application.controllers.api;

import com.goodt.drive.supeditor.application.configuration.AppConfig;
import com.goodt.drive.supeditor.application.data.UserInfo;
import com.goodt.drive.supeditor.application.dto.keycloak.TokenDataDtoBase;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.security.oauth2.resource.PrincipalExtractor;
import org.springframework.context.ApplicationContext;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.oauth2.provider.authentication.OAuth2AuthenticationDetails;

public abstract class BaseController {

    public ApplicationContext getContext() {
        return context;
    }

    public PrincipalExtractor getPrincipalExtractor() {
        return context.getBean(PrincipalExtractor.class);
    }

    public Authentication getAuthentication() {
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        return authentication;
    }

    public TokenDataDtoBase getUserTokenDataDtoBase() {
        return new TokenDataDtoBase(
                ((OAuth2AuthenticationDetails) getAuthentication().getDetails()).getTokenType(),
                ((OAuth2AuthenticationDetails) getAuthentication().getDetails()).getTokenValue()
        );
    }

    protected UserInfo getUserInfo() {
        return (UserInfo) getAuthentication().getPrincipal();
    }

    protected String getSessionEmployeeId() {
        UserInfo userInfo = (UserInfo) getAuthentication().getPrincipal();
        return userInfo.getEmployeeId() != null ? userInfo.getEmployeeId() : null;
    }

    protected String getSessionId() {
        Object principal = getAuthentication().getPrincipal();
        if (principal instanceof String) {
            return null;
        }
        UserInfo userInfo = (UserInfo) principal;
        return userInfo.getId() != null ? userInfo.getId() : null;
    }

    public AppConfig getAppConfig() {
        return appConfig;
    }

    @Autowired
    ApplicationContext context;

    @Autowired
    AppConfig appConfig;
}
