package com.goodt.drive.supeditor.application.controllers.api;

import com.goodt.drive.supeditor.application.configuration.AppConfig;
import com.goodt.drive.supeditor.application.dto.InfoDto;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;


@RestController
public class InfoController extends BaseController{
    
    @Operation(summary = "Получение базовой информации о сервисе", description = "Получение базовой информации о сервисе (версия, профиль, используемая БД и сервер авторизации)", tags = { "info" })
    @ApiResponses(value = { 
                     @ApiResponse(responseCode = "200", description = "В случае если удалось построить DTO (все необходимые настройки заданы в yml-файле)", 
                                  content = @Content(array = @ArraySchema(schema = @Schema(implementation = InfoDto.class)))),
                     @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                                  content = @Content(schema = @Schema(implementation = String.class))),
                     @ApiResponse(responseCode = "500", description = "В случае если: что-то сломалось или не полностью сконфигрурировано приложение",
                                  content = @Content(schema = @Schema(implementation = String.class))),
    })
    @GetMapping("/api/info")
    public InfoDto get(){
        AppConfig config = getAppConfig();
        return new InfoDto(config.getApiVersion(), config.getEnvironment(), config.getDatabaseDriver(), 
                           config.getDatabaseUrl(), config.getKeyCloakConfig().getBaseUrl());
    }
    
    @Operation(summary = "Получение информации о текущем пользователе", description = "Получение информации о текущем пользователе (по сути выхлоп с UserInfo)", tags = { "info" })
    @ApiResponses(value = { 
                     @ApiResponse(responseCode = "200", description = "В случае если удалось прочитать информацию о пользователе из сервиса авторизации", 
                                  content = @Content(array = @ArraySchema(schema = @Schema(implementation = InfoDto.class)))),
                     @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                                  content = @Content(schema = @Schema(implementation = String.class))),
                     @ApiResponse(responseCode = "500", description = "В случае если: что-то сломалось или не полностью сконфигрурировано приложение",
                                  content = @Content(schema = @Schema(implementation = String.class))),
    })
    @GetMapping("/api/info/me")
    public Object getMe() {
        return getAuthentication().getPrincipal();
    }
}
 