package com.goodt.drive.supeditor.application.dao;

import com.querydsl.core.types.ExpressionUtils;
import com.querydsl.core.types.Predicate;
import com.querydsl.core.types.dsl.Expressions;
import org.springframework.stereotype.Repository;

import javax.persistence.EntityManager;

import java.util.ArrayList;
import java.util.List;

import com.goodt.drive.supeditor.application.model.entities.DataConnectorEntity;
import com.goodt.drive.supeditor.application.model.entities.QDataConnectorEntity;
import me.goodt.micro.core.dao.AbstractDao;

@Repository
public class DataConnectorDao extends AbstractDao<DataConnectorEntity, Long> {

    private static final QDataConnectorEntity meta = QDataConnectorEntity.dataConnectorEntity;

    public DataConnectorDao(EntityManager em) {
        super(DataConnectorEntity.class, em);
    }

    public List<DataConnectorEntity> findAll(String ownerId, boolean onlyClosed) {
        List<Predicate> predicates = new ArrayList<>();
        if (ownerId != null) {
            predicates.add(meta.ownerId.eq(ownerId));
        }
        if (onlyClosed) {
            predicates.add(meta.dateTo.isNotNull());
        } else {
            predicates.add(meta.dateTo.isNull().or(Expressions.currentTimestamp().between(meta.dateFrom, meta.dateTo)));
        }
        return query().selectFrom(meta)
                .where(ExpressionUtils.allOf(predicates))
                .orderBy(meta.dateFrom.asc())
                .fetch();
    }
}
