package com.goodt.drive.supeditor.application.dao;

import com.querydsl.core.types.ExpressionUtils;
import com.querydsl.core.types.Predicate;
import com.querydsl.core.types.dsl.Expressions;
import org.springframework.stereotype.Repository;

import javax.persistence.EntityManager;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import com.goodt.drive.supeditor.application.model.entities.FolderEntity;
import com.goodt.drive.supeditor.application.model.entities.QFolderEntity;
import me.goodt.micro.core.dao.AbstractDao;

@Repository
public class FolderDao extends AbstractDao<FolderEntity, Long> {

    private static final QFolderEntity meta = QFolderEntity.folderEntity;

    public FolderDao(EntityManager em) {
        super(FolderEntity.class, em);
    }

    public List<FolderEntity> findAll(String ownerId, Long parentId, Long projectTypeId, List<Long> idList, Set<String> ownerIdList) {
        List<Predicate> predicates = new ArrayList<>();
        if (ownerId != null && ownerIdList.size() > 0) {
            predicates.add(Expressions.anyOf(
                    meta.ownerId.eq(ownerId),
                    Expressions.allOf(
                            meta.ownerId.in(ownerIdList),
                            meta.isSharedGroup.eq(true)
                    )
            ));
        } else if (ownerId != null) {
            predicates.add(meta.ownerId.eq(ownerId));
        } else if (ownerIdList.size() > 0) {
            predicates.add(Expressions.allOf(
                    meta.ownerId.in(ownerIdList),
                    meta.isSharedGroup.eq(true)
            ));
        }
        if (idList != null) {
            predicates.add(meta.id.in(idList));
        } else if (parentId != null) {
            predicates.add(meta.parent.id.in(parentId));
        } else {
            predicates.add(meta.parent.isNull());
        }
        predicates.add(meta.projectType.id.eq(projectTypeId));

        return query().selectFrom(meta)
                .where(ExpressionUtils.allOf(predicates))
                .fetch();
    }
}
