package com.goodt.drive.supeditor.application.dao;

import com.querydsl.core.types.ExpressionUtils;
import com.querydsl.core.types.dsl.Expressions;
import org.springframework.stereotype.Repository;

import javax.persistence.EntityManager;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Set;

import com.goodt.drive.supeditor.application.model.entities.ProjectEntity;
import com.goodt.drive.supeditor.application.model.entities.QProjectEntity;
import me.goodt.micro.core.dao.AbstractDao;

@Repository
public class ProjectDao extends AbstractDao<ProjectEntity, Long> {

    private static final QProjectEntity meta = QProjectEntity.projectEntity;

    public ProjectDao(EntityManager em) {
        super(ProjectEntity.class, em);
    }

    public Optional<ProjectEntity> findBySlug(String slug) {
        return Optional.ofNullable(query().selectFrom(meta)
                .where(meta.slug.eq(slug))
                .fetchFirst());
    }

    public List<ProjectEntity> findAllByFolderId(Long id) {
        return query().selectFrom(meta)
                .where(meta.folder.id.eq(id))
                .fetch();
    }

    public List<ProjectEntity> findAll(String ownerId, Long folderId, Long projectTypeId, Set<String> ownerIdList) {
        List<com.querydsl.core.types.Predicate> predicates = new ArrayList<>();
        if (ownerId != null && ownerIdList.size() > 0) {
            predicates.add(Expressions.anyOf(
                    meta.ownerId.eq(ownerId),
                    Expressions.allOf(
                            meta.ownerId.in(ownerIdList),
                            meta.isSharedGroup.eq(true)
                    )
            ));
        } else if (ownerId != null) {
            predicates.add(meta.ownerId.eq(ownerId));
        } else if (ownerIdList.size() > 0) {
            predicates.add(Expressions.allOf(
                    meta.ownerId.in(ownerIdList),
                    meta.isSharedGroup.eq(true)
            ));
        }
        if (folderId != null) {
            predicates.add(meta.folder.id.eq(folderId));
        } else {
            predicates.add(meta.folder.isNull());
        }
        predicates.add(meta.projectType.id.eq(projectTypeId));

        return query().selectFrom(meta)
                .where(ExpressionUtils.allOf(predicates))
                .orderBy(meta.dateFrom.asc())
                .fetch();
    }
}
