package com.goodt.drive.supeditor.application.model.entities;

import java.util.Date;
import lombok.Getter;
import lombok.Setter;
import org.springframework.data.domain.Persistable;

import javax.persistence.*;

import me.goodt.micro.core.entity.AbstractEntity;

@Getter
@Setter
@MappedSuperclass
public abstract class BaseEntity extends AbstractEntity<Long> implements Persistable<Long> {

    public final static String SEQUENCE_BASE_GENERATOR = "base_generator";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = SEQUENCE_BASE_GENERATOR)
    private Long id;

    @Column(name = "date_from", nullable = false, columnDefinition="TIMESTAMP DEFAULT CURRENT_TIMESTAMP")
    @Temporal(TemporalType.TIMESTAMP)
    private Date dateFrom;

    @Column(name = "date_to", nullable = true, columnDefinition="TIMESTAMP DEFAULT NULL")
    @Temporal(TemporalType.TIMESTAMP)
    private Date dateTo;

    @Transient
    private boolean isNew = true;

    public Long getId(){
        return id;
    }

    @PrePersist
    @PostLoad
    void markNotNew() {
        this.isNew = false;
    }

    public BaseEntity setId(Long id) {
        this.id = id;
        this.markNotNew();
        return this;
    }
}
