package com.goodt.drive.supeditor.application.services;

import javassist.NotFoundException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

import com.goodt.drive.supeditor.application.dao.DataConnectorDao;
import com.goodt.drive.supeditor.application.dto.DataConnectorDto;
import com.goodt.drive.supeditor.application.model.entities.DataConnectorEntity;

@Service
public class DataConnectorServiceImpl implements IDataConnectorService {

    @Autowired
    private DataConnectorDao dataConnectorDao;

    @Override
    public DataConnectorEntity find(Long id) throws NotFoundException {
        return dataConnectorDao.findById(id)
                .orElseThrow(() -> new NotFoundException(String.format("DataConnectorEntity with id \"%d\" not found", id)));
    }

    @Override
    public List<DataConnectorEntity> findAll(String ownerId, boolean onlyClosed) {
        return dataConnectorDao.findAll(ownerId, onlyClosed);
    }

    @Override
    public DataConnectorEntity create(DataConnectorDto dto, String ownerId) throws NotFoundException {
        DataConnectorEntity entity = new DataConnectorEntity();
        entity.setName(dto.getName());
        entity.setDescription(dto.getDescription());
        entity.setUrl(dto.getUrl());
        entity.setDataUrl(dto.getDataUrl());
        entity.setOwnerId(ownerId);
        entity.setDateFrom(new Date());
        return dataConnectorDao.save(entity);
    }

    @Override
    public DataConnectorEntity update(DataConnectorDto dto) throws NotFoundException {
        DataConnectorEntity entity = find(dto.getId());
        entity.setName(dto.getName());
        entity.setDescription(dto.getDescription());
        entity.setUrl(dto.getUrl());
        entity.setDataUrl(dto.getDataUrl());
        return dataConnectorDao.save(entity);
    }

    @Override
    public void delete(Long id) throws NotFoundException {
        DataConnectorEntity dataConnectorEntity = find(id);
        dataConnectorEntity.setDateTo(new Date());
        dataConnectorDao.save(dataConnectorEntity);
    }

    @Override
    public void restore(Long id) throws NotFoundException {
        DataConnectorEntity dataConnectorEntity = find(id);
        dataConnectorEntity.setDateTo(null);
        dataConnectorDao.save(dataConnectorEntity);
    }
}
