package com.goodt.drive.supeditor.application.services;

import com.goodt.drive.supeditor.application.dto.*;
import com.goodt.drive.supeditor.application.exceptions.git.TagsAlreadyExistsException;
import com.goodt.drive.supeditor.application.model.entities.ProjectContentEntity;
import com.goodt.drive.supeditor.application.model.entities.ProjectEntity;
import javassist.NotFoundException;
import org.eclipse.jgit.api.errors.GitAPIException;
import org.springframework.web.multipart.MultipartFile;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.List;
import java.util.Optional;
import java.util.Set;


public interface IProjectService {
    ProjectEntity find(Long id) throws NotFoundException;

    ProjectContentEntity findContent(Long projectId, String filepath) throws NotFoundException;

    ProjectEntity findBySlug(String slug) throws NotFoundException;

    List<ProjectEntity> findAll(String ownerId, Long folderId, Long projectTypeId, Set<String> ownerIdList);
    List<ProjectEntity> findAll();

    ProjectEntity create(ProjectDto dto, String ownerId) throws NotFoundException;

    ProjectEntity update(ProjectDto dto) throws NotFoundException;

    ProjectEntity updateData(ProjectDataDto dto) throws NotFoundException, IOException;

    ProjectEntity updateTheme(ProjectThemeDto dto) throws NotFoundException, IOException;

    ProjectEntity shareGroup(Long id, SharedGroupPermissionDto sharedGroupPermissionDto) throws NotFoundException;

    ProjectEntity unshareGroup(Long id) throws NotFoundException;

    ProjectCommitDto commitProject(String ownerId, Long id, String comment, List<String> tag, String email) throws NotFoundException, IOException, GitAPIException, TagsAlreadyExistsException;

    Optional<ProjectCommitDto> getLastCommitInfo(String ownerId, Long id) throws NotFoundException, IOException, GitAPIException;
    List<ProjectCommitDto> getCommitAll(String ownerId, Long id) throws NotFoundException, IOException, GitAPIException;

    ByteArrayOutputStream exportProject(Long id, String ref) throws IOException;

    ProjectEntity importProject(String ownerId, ProjectDto dto, MultipartFile archive) throws NotFoundException, IOException;

    ProjectEntity cloneProject(ProjectDto dto, String ownerId) throws NotFoundException, IOException;

    void delete(Long id) throws NotFoundException, IOException;
    String replaceProjectId(String data, Long projectId);
    void replaceProjectIdByProject(Long projectId) throws NotFoundException, IOException;
}
