package com.goodt.drive.supeditor.application.services;

import com.goodt.drive.supeditor.GlobalDefs;
import com.goodt.drive.supeditor.application.model.entities.ProjectContentEntity;
import com.goodt.drive.supeditor.application.dto.ProjectPageDto;
import com.goodt.drive.supeditor.application.dao.ProjectContentDao;

import javassist.NotFoundException;
import org.apache.commons.io.FileExistsException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.transaction.Transactional;
import java.io.IOException;
import java.util.List;

@Service
public class ProjectPageServiceImpl implements IProjectPageService {

    @Override
    public ProjectContentEntity find(Long projectId, String pageId) throws NotFoundException {
        return projectContentDao.find(projectId, GlobalDefs.PAGES_DIRNAME, getPageFilename(pageId))
                .orElseThrow(() -> new NotFoundException(String.format("Project file \"%d\" \"%s/%s\" not found", projectId, GlobalDefs.PAGES_DIRNAME, getPageFilename(pageId))));
    }

    @Override
    public List<ProjectContentEntity> findAll(Long projectId) throws NotFoundException {
        return projectContentDao.findAll(projectId, GlobalDefs.PAGES_DIRNAME);
    }

    @Override
    public ProjectContentEntity create(ProjectPageDto dto) throws NotFoundException, IOException {
        if (projectContentDao.exists(dto.getProjectId(), GlobalDefs.PAGES_DIRNAME, getPageFilename(dto.getPageId()))) {
            throw new FileExistsException(String.format("ProjectContent with projectId \"%d\" and pageId \"%s\" already exists", dto.getProjectId(), dto.getPageId()));
        }
        return projectContentDao.save(new ProjectContentEntity(dto.getProjectId(), GlobalDefs.PAGES_DIRNAME, getPageFilename(dto.getPageId())), dto.getData().getBytes());
    }

    @Override
    @Transactional
    public ProjectContentEntity update(ProjectPageDto dto) throws NotFoundException, IOException {
        return projectContentDao.save(new ProjectContentEntity(dto.getProjectId(), GlobalDefs.PAGES_DIRNAME, getPageFilename(dto.getPageId())), dto.getData().getBytes());
    }

    @Override
    @Transactional
    public void delete(Long projectId, String pageId) throws NotFoundException, IOException {
        projectContentDao.delete(projectId, GlobalDefs.PAGES_DIRNAME, getPageFilename(pageId));
    }

    private String getPageFilename(String pageId) {
        return String.format("%s%s", pageId, GlobalDefs.PAGES_FILE_SUFFIX);
    }

    @Autowired
    private ProjectContentDao projectContentDao;

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

}
