package com.goodt.drive.supeditor.application.services.clients;

import feign.RequestInterceptor;
import feign.RequestTemplate;
import org.springframework.http.HttpHeaders;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.oauth2.provider.authentication.OAuth2AuthenticationDetails;

import com.goodt.drive.supeditor.application.dto.keycloak.TokenDataDtoBase;
import com.goodt.drive.supeditor.application.security.CustomWebAuthenticationDetails;

public class AuthHeaderInterceptor implements RequestInterceptor {

    private final boolean keycloakEnabled;

    public AuthHeaderInterceptor(boolean keycloakEnabled) {
        this.keycloakEnabled = keycloakEnabled;
    }

    @Override
    public void apply(RequestTemplate template) {
        final TokenDataDtoBase token = getUserTokenDataDtoBase();
        if (token != null) {
            template.header(HttpHeaders.AUTHORIZATION, token.getTokenType() + " " + token.getAccessToken());
        }
        template.header("x-app-name", "supeditor");
    }

    public TokenDataDtoBase getUserTokenDataDtoBase() {
        try {
            final Object details = getAuthentication().getDetails();
            if (keycloakEnabled) {
                final OAuth2AuthenticationDetails oAuthDet = (OAuth2AuthenticationDetails) details;
                return new TokenDataDtoBase(oAuthDet.getTokenType(), oAuthDet.getTokenValue());
            }
            final CustomWebAuthenticationDetails customDet = (CustomWebAuthenticationDetails) details;
            return new TokenDataDtoBase(customDet.getTokenType(), customDet.getTokenValue());
        } catch (Exception ex) {
            return null;
        }
    }

    public Authentication getAuthentication() {
        return SecurityContextHolder.getContext().getAuthentication();
    }
}
