package com.goodt.drive.supeditor.application.services.jwt;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtException;
import io.jsonwebtoken.Jwts;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Service;

import com.goodt.drive.supeditor.application.configuration.JwtKeyConfig;
import com.goodt.drive.supeditor.application.data.UserInfo;

@Slf4j
@Service
@RequiredArgsConstructor
@ConditionalOnBean(JwtKeyConfig.class)
public class JwtService {

    private final JwtKeyConfig jwtKeyConfig;

    public boolean validateToken(String jwt) {
        try {
            Jwts.parser().setSigningKey(jwtKeyConfig.getPublicKey()).parseClaimsJws(jwt);
            return true;
        } catch (Exception ex) {
            log.error("Invalid Json Web Token", ex);
            throw new JwtException("Invalid Json Web Token");
        }
    }

    public UserInfo getUserInfo(String jwt) {
        UserInfo info = new UserInfo();
        Claims claims = getClaims(jwt);
        info.setId((String) claims.get("sub"));
        info.setUserName((String) claims.get("user_name"));
        info.setName((String) claims.get("name"));
        info.setEmployeeId((String) claims.get("employee_id"));
        info.setTechUser((Boolean) claims.get("is_tech_user"));
        return info;
    }

    private Claims getClaims(String jwt) {
        return Jwts.parser().setSigningKey(jwtKeyConfig.getPublicKey()).parseClaimsJws(jwt).getBody();
    }
}
