package com.goodt.drive.supeditor.application.services.logging;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.goodt.drive.supeditor.application.controllers.api.BaseController;
import com.goodt.drive.supeditor.application.data.LogInfoAboutMethod;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.slf4j.Marker;
import org.slf4j.MarkerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import java.util.UUID;

@Service
public class LoggerServiceImpl extends BaseController implements ILoggerService {

    @PostConstruct
    private void init() {
        objectMapper.setDateFormat(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss"));
    }

    @Override
    public void createLog(UUID hash, String methodUrl, Map<String, Object> getParams, Object postParams) throws JsonProcessingException {
        logger.info(METHOD_LOG, getStringLogObject(createLogObject(hash, methodUrl, getParams, postParams)));
    }

    private LogInfoAboutMethod createLogObject(UUID hash, String methodUrl, Map<String, Object> getParams, Object postData) {
        return new LogInfoAboutMethod(
                hash,
                new Timestamp(new Date().getTime()),
                methodUrl,
                getSessionEmployeeId(),
                getParams,
                postData
        );
    }

    private String getStringLogObject(Object logObject) throws JsonProcessingException {
        return objectMapper.writeValueAsString(logObject);
    }

    private final ObjectMapper objectMapper = new ObjectMapper();
    private final Logger logger = LoggerFactory.getLogger(this.getClass());
    private final Marker METHOD_LOG = MarkerFactory.getMarker("METHOD_LOG");
}
