package com.goodt.drive.supeditor.application.model.dao;

import com.goodt.drive.supeditor.GlobalDefs;
import com.goodt.drive.supeditor.application.configuration.ProjectConfig;
import com.goodt.drive.supeditor.application.dao.ProjectContentDao;
import com.goodt.drive.supeditor.application.model.entities.ProjectContentEntity;
import com.goodt.drive.supeditor.utils.FunctionalTestBase;
import org.apache.commons.io.FileUtils;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Files;
import java.util.List;
import java.util.Optional;

@SpringBootTest
@ActiveProfiles("functests")
public class TestProjectContentDao extends FunctionalTestBase {

    @BeforeEach
    public void setupContext() {
        try {
            File file;
            file = new File(projectConfig.getPath(), String.format("%d/%s", 1L, "delete-test-file.txt"));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s", 1L, GlobalDefs.MAIN_JSON_FILENAME));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("{\"json\":\"data\",\"picture\":\"upload/1/filename.jpg\"}");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s", 1L, GlobalDefs.STYLE_CSS_FILENAME));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("theme-css");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s", 1L, GlobalDefs.STYLE_LESS_FILENAME));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("theme-less");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s", 2L, GlobalDefs.MAIN_JSON_FILENAME));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("{\"json\":\"data\"}");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s/%s", 1L, GlobalDefs.PAGES_DIRNAME, "conf1-page1.json"));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("{\"json-p-1\":\"data-p-1\",\"picture-p-1\":\"upload/1/filename-p-1.jpg\"}");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s", 6L, GlobalDefs.MAIN_JSON_FILENAME));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("{\"test\":\"test-1\",\"filename\":\"upload/123/file.jpg\",\"filename2\":\"upload/345/file2.jpg\"}");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s", 7L, GlobalDefs.MAIN_JSON_FILENAME));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("{\"json\":\"data\"}");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s", 8L, GlobalDefs.MAIN_JSON_FILENAME));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("{\"json\":\"data\"}");
            }

            file = new File(projectConfig.getPath(), String.format("%d/%s/%s", 1L, GlobalDefs.PAGES_DIRNAME, "conf1-page2.json"));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("conf page data 2");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s/%s", 1L, GlobalDefs.PAGES_DIRNAME, "conf1-page3.json"));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("conf page data 3");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s/%s", 1L, GlobalDefs.PAGES_DIRNAME, "conf1-page4.json"));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("conf page data 4");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s/%s", 2L, GlobalDefs.PAGES_DIRNAME, "conf2-page1.json"));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("");
            }
            file = new File(projectConfig.getPath(), String.format("%d/%s/%s", 6L, GlobalDefs.PAGES_DIRNAME, "conf6-page1.json"));
            if (!file.getParentFile().exists()) {
                Files.createDirectories(file.getParentFile().toPath());
            }
            if (!file.exists()) {
                Files.createFile(file.toPath());
            }
            try (PrintWriter printWriter = new PrintWriter(file)) {
                printWriter.write("{\"test\":\"test-1\",\"filename\":\"upload/123/file.jpg\",\"filename2\":\"upload/345/file2.jpg\"}");
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    @AfterEach
    public void downContext() throws IOException {
        FileUtils.deleteDirectory(new File(projectConfig.getPath()));
    }

    @Test
    public void testFind() {
        Optional<ProjectContentEntity> dto = projectContentDao.find(1L, GlobalDefs.MAIN_JSON_FILENAME);
        Assertions.assertTrue(dto.isPresent());
        ProjectContentEntity projectContentEntity = dto.get();
        Assertions.assertEquals(GlobalDefs.MAIN_JSON_FILENAME, projectContentEntity.getFilename());
        Assertions.assertEquals(1L, projectContentEntity.getProjectId());
        Assertions.assertTrue(projectContentEntity.getLength() > 0);
        Assertions.assertNotNull(projectContentEntity.getByteContent());
    }

    @Test
    public void testFind_WithSubfolder() {
        Optional<ProjectContentEntity> dto = projectContentDao.find(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page1.json");
        Assertions.assertTrue(dto.isPresent());
        ProjectContentEntity projectContentEntity = dto.get();
        Assertions.assertEquals("conf1-page1.json", projectContentEntity.getFilename());
        Assertions.assertEquals(GlobalDefs.PAGES_DIRNAME, projectContentEntity.getFolder());
        Assertions.assertEquals(1L, projectContentEntity.getProjectId());
    }

    @Test
    public void testExists() {
        boolean exists = projectContentDao.exists(1L, GlobalDefs.MAIN_JSON_FILENAME);
        Assertions.assertTrue(exists);
    }

    @Test
    public void testExists_NotFound() {
        boolean exists = projectContentDao.exists(1L, "not-found-file");
        Assertions.assertFalse(exists);
    }

    @Test
    public void testExists_WithFolder() {
        boolean exists = projectContentDao.exists(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page1.json");
        Assertions.assertTrue(exists);
    }

    @Test
    public void testExists_WithFolder_NotFound() {
        boolean exists = projectContentDao.exists(1L, GlobalDefs.PAGES_DIRNAME, "not-found-file");
        Assertions.assertFalse(exists);
    }
    
    @Test
    public void testFindAll() {
        List<ProjectContentEntity> dtos = projectContentDao.findAll(1L);
        Assertions.assertTrue(dtos.size() > 0);
    }

    @Test
    public void testFindAllRecursive() {
        List<ProjectContentEntity> dtos = projectContentDao.findAllRecursive(1L);
        Assertions.assertTrue(dtos.size() > 0);
    }

    @Test
    public void testDelete() throws IOException {
        boolean deleted = projectContentDao.delete(1L, "delete-test-file.txt");
        Assertions.assertTrue(deleted);
    }

    @Test
    public void testDelete_WithSubfolder() throws IOException {
        boolean deleted = projectContentDao.delete(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page3.json");
        Assertions.assertTrue(deleted);
    }

    @Test
    public void testDeleteAll() throws IOException {
        boolean deleted = projectContentDao.deleteAll(1L);
        Assertions.assertTrue(deleted);
    }

    @Test
    public void testDeleteAll_WithSubfolder() throws IOException {
        boolean deleted = projectContentDao.deleteAll(1L, GlobalDefs.PAGES_DIRNAME);
        Assertions.assertTrue(deleted);
    }

    @Test
    public void testSave() throws IOException {
        ProjectContentEntity entity = new ProjectContentEntity(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page44.json");
        ProjectContentEntity newEntity = projectContentDao.save(entity, "new data content".getBytes());
        Assertions.assertEquals(1L, newEntity.getProjectId());
        Assertions.assertEquals(GlobalDefs.PAGES_DIRNAME, newEntity.getFolder());
        Assertions.assertEquals("conf1-page44.json", newEntity.getFilename());
        Assertions.assertEquals("new data content", new String(newEntity.getByteContent()));
        Assertions.assertTrue(newEntity.getLength() > 0);
        Assertions.assertNotNull(newEntity.getByteContent());
    }

    @Autowired
    private ProjectConfig projectConfig;

    @Autowired
    private ProjectContentDao projectContentDao;
}
