package com.goodt.drive.supeditor.application.model.dao;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Optional;

import com.goodt.drive.supeditor.application.dao.ProjectDao;
import com.goodt.drive.supeditor.application.model.entities.ProjectEntity;
import com.goodt.drive.supeditor.utils.FunctionalTestBase;

public class TestProjectDao extends FunctionalTestBase {

    @Autowired
    private ProjectDao projectDao;

    @Test
    public void testFindById() {
        Optional<ProjectEntity> entity = projectDao.findById(1L);
        Assertions.assertTrue(entity.isPresent());
        Assertions.assertEquals("conf 1 title", entity.get().getTitle());
        Assertions.assertEquals(false, entity.get().isSharedGroup());
        Assertions.assertEquals(false, entity.get().isCanSharedGroupEdit());
    }

    @Test
    public void testFindAll() {
        List<ProjectEntity> entities = projectDao.findAll();
        Assertions.assertTrue(entities.size() > 0);
    }

    @Test
    public void testFindBySlug() {
        Optional<ProjectEntity> entity = projectDao.findBySlug("conf-1-slug");
        Assertions.assertTrue(entity.isPresent());
        Assertions.assertEquals("conf-1-slug", entity.get().getSlug());
        Assertions.assertEquals("conf 1 title", entity.get().getTitle());
    }

    @Test
    public void testFindAllByFolderId() {
        List<ProjectEntity> entities = projectDao.findAllByFolderId(1L);
        Assertions.assertTrue(entities.size() > 0);
        Assertions.assertTrue(entities.stream().allMatch(projectEntity -> projectEntity.getFolder().getId().equals(1L)));
    }
}
