package com.goodt.drive.supeditor.application.model.services;

import javassist.NotFoundException;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import java.util.List;
import java.util.Optional;

import com.goodt.drive.supeditor.application.dao.DataConnectorDao;
import com.goodt.drive.supeditor.application.dto.DataConnectorDto;
import com.goodt.drive.supeditor.application.model.entities.DataConnectorEntity;
import com.goodt.drive.supeditor.application.services.IDataConnectorService;
import com.goodt.drive.supeditor.utils.FunctionalTestBase;

@SpringBootTest
@ActiveProfiles("functests")
public class TestDataConnectorService extends FunctionalTestBase {

    @Test
    public void testFind() throws NotFoundException {
        DataConnectorEntity entity = dataConnectorService.find(1L);
        Assertions.assertNotNull(entity);
    }

    @Test
    public void testFind_NotFound() {
        Assertions.assertThrows(NotFoundException.class, () -> dataConnectorService.find(9999L));
    }

    @Test
    public void testFindAll() {
        List<DataConnectorEntity> entities = dataConnectorService.findAll("test-owner-id", false);
        Assertions.assertTrue(entities.size() > 0);
        Assertions.assertTrue(entities.stream().allMatch(folderEntity -> folderEntity.getOwnerId().equals("test-owner-id")));
        Assertions.assertTrue(entities.stream().allMatch(folderEntity -> folderEntity.getDateTo() == null));
    }

    @Test
    public void testFindAll_Closed() {
        List<DataConnectorEntity> entities = dataConnectorService.findAll("test-owner-id", true);
        Assertions.assertTrue(entities.size() > 0);
        Assertions.assertTrue(entities.stream().allMatch(entity -> entity.getOwnerId().equals("test-owner-id")));
        Assertions.assertTrue(entities.stream().allMatch(entity -> entity.getDateTo() != null));
    }

    @Test
    public void testFindAll_ByOwner() {
        List<DataConnectorEntity> entities = dataConnectorService.findAll("test-owner-id-2", false);
        Assertions.assertTrue(entities.size() > 0);
        Assertions.assertTrue(entities.stream().allMatch(entity -> entity.getOwnerId().equals("test-owner-id-2")));
    }

    @Test
    public void testCreate() throws NotFoundException {
        DataConnectorDto dto = new DataConnectorDto(null, "new-name", "new description", "new url", "new data url", null);
        DataConnectorEntity entity = dataConnectorService.create(dto, "test-owner-id");
        Assertions.assertNotNull(entity);

        Optional<DataConnectorEntity> newEntityOptional = dataConnectorDao.findById(entity.getId());
        Assertions.assertTrue(newEntityOptional.isPresent());
        DataConnectorEntity newEntity = newEntityOptional.get();
        Assertions.assertEquals("new-name", newEntity.getName());
        Assertions.assertEquals("new description", newEntity.getDescription());
        Assertions.assertEquals("new url", newEntity.getUrl());
        Assertions.assertEquals("new data url", newEntity.getDataUrl());

    }

    @Test
    public void testUpdate() throws NotFoundException {
        DataConnectorDto dto = new DataConnectorDto(2L, "upd-name-2", "upd description 2", "upd url 2", "new data url", null);
        DataConnectorEntity updEntity = dataConnectorService.update(dto);
        Assertions.assertNotNull(updEntity);
        Assertions.assertEquals("upd-name-2", updEntity.getName());
        Assertions.assertEquals("upd description 2", updEntity.getDescription());
        Assertions.assertEquals("upd url 2", updEntity.getUrl());
        Assertions.assertEquals("new data url", updEntity.getDataUrl());
    }

    @Test
    public void testDelete() throws NotFoundException {
        dataConnectorService.delete(3L);
        Optional<DataConnectorEntity> dataConnectorEntity = dataConnectorDao.findById(3L);
        Assertions.assertNotNull(dataConnectorEntity.get().getDateTo());
    }

    @Test
    public void testRestore() throws NotFoundException {
        dataConnectorService.restore(5L);
        Optional<DataConnectorEntity> dataConnectorEntity = dataConnectorDao.findById(5L);
        Assertions.assertNull(dataConnectorEntity.get().getDateTo());
    }

    @Autowired
    private IDataConnectorService dataConnectorService;

    @Autowired
    private DataConnectorDao dataConnectorDao;
}
