package com.goodt.drive.supeditor.application.model.services;

import com.goodt.drive.supeditor.GlobalDefs;
import com.goodt.drive.supeditor.application.configuration.ProjectConfig;
import com.goodt.drive.supeditor.application.model.entities.ProjectContentEntity;
import com.goodt.drive.supeditor.application.dto.ProjectPageDto;
import com.goodt.drive.supeditor.application.dao.ProjectContentDao;
import com.goodt.drive.supeditor.application.services.IProjectPageService;
import com.goodt.drive.supeditor.utils.FunctionalTestBase;
import javassist.NotFoundException;
import org.apache.commons.io.FileUtils;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import java.io.File;
import java.io.IOException;
import java.util.List;

@SpringBootTest
@ActiveProfiles("functests")
public class TestProjectPageService extends FunctionalTestBase  {

    @BeforeEach
    public void setupContext() {
        try {
            projectContentDao.save(new ProjectContentEntity(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page1.json"), "{\"json-p-1\":\"data-p-1\",\"picture-p-1\":\"upload/1/filename-p-1.jpg\"}".getBytes());
            projectContentDao.save(new ProjectContentEntity(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page2.json"), "conf page data 2".getBytes());
            projectContentDao.save(new ProjectContentEntity(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page3.json"), "conf page data 3".getBytes());
            projectContentDao.save(new ProjectContentEntity(1L, GlobalDefs.PAGES_DIRNAME, "conf1-page4.json"), "conf page data 4".getBytes());
            projectContentDao.save(new ProjectContentEntity(2L, GlobalDefs.PAGES_DIRNAME, "conf2-page1.json"), "".getBytes());
            projectContentDao.save(new ProjectContentEntity(6L, GlobalDefs.PAGES_DIRNAME, "conf6-page1.json"), "".getBytes());
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    @AfterEach
    public void downContext() throws IOException {
        FileUtils.deleteDirectory(new File(projectConfig.getPath()));
    }

    @Test
    public void testFindPage() throws NotFoundException {
        ProjectContentEntity entity = projectPageService.find(1L, "conf1-page1");
        Assertions.assertNotNull(entity);
    }

    @Test
    public void testFindPage_NotFound() {
        Assertions.assertThrows(NotFoundException.class, () -> projectPageService.find(9999L, "conf9999-page9999"));
    }

    @Test
    public void testFindPageAll() throws NotFoundException, IOException {
        List<ProjectContentEntity> entities = projectPageService.findAll(1L);
        Assertions.assertTrue(entities.size() > 0);
        Assertions.assertTrue(entities.stream().allMatch(dto -> dto.getProjectId().equals(1L)));
    }

    @Test
    public void testCreatePage() throws NotFoundException, IOException {
        ProjectPageDto dto = new ProjectPageDto(1L, "new-conf-page-test-1", "conf page data 1");
        ProjectContentEntity entity = projectPageService.create(dto);
        Assertions.assertNotNull(entity);
    }

    @Test
    public void testUpdatePage() throws NotFoundException, IOException {
        ProjectPageDto dto = new ProjectPageDto(1L, "conf1-page2", "upd data conf 1 page 2");
        ProjectContentEntity entity = projectPageService.update(dto);
        Assertions.assertNotNull(entity);
        Assertions.assertEquals(1L, entity.getProjectId());
        Assertions.assertEquals("conf1-page2.json", entity.getFilename());
        Assertions.assertEquals("upd data conf 1 page 2", new String(entity.getByteContent()));
    }

    @Test
    public void testDeletePage() throws NotFoundException, IOException {
        projectPageService.delete(1L, "conf1-page3");
        Assertions.assertThrows(NotFoundException.class, () -> projectPageService.find(1L, "conf1-page3"));
    }

    @Autowired
    private ProjectConfig projectConfig;

    @Autowired
    private IProjectPageService projectPageService;
    
    @Autowired
    private ProjectContentDao projectContentDao;
}
