package com.goodt.drive.supeditor.application.model.services;

import com.goodt.drive.supeditor.application.model.entities.TagEntity;
import com.goodt.drive.supeditor.application.services.ITagService;
import com.goodt.drive.supeditor.utils.FunctionalTestBase;
import javassist.NotFoundException;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

@SpringBootTest
@ActiveProfiles("functests")
public class TestTagService extends FunctionalTestBase  {

    @Test
    public void testFind() throws NotFoundException {
        TagEntity folderEntity = tagService.findByName("tag 1 name");
        Assertions.assertNotNull(folderEntity);
    }

    @Test
    public void testFind_NotFound() {
        Assertions.assertThrows(NotFoundException.class, () -> tagService.findByName("tag 1 name not found"));
    }

    @Test
    public void testFindAllByNameList() {
        List<TagEntity> entities = tagService.findAllByNameList(Arrays.asList("tag 1 name", "tag 2 name", "tag 1 name not found"));
        Assertions.assertEquals(2, entities.size());
        Assertions.assertTrue(entities.stream().anyMatch(tagEntity -> tagEntity.getName().equals("tag 1 name")));
        Assertions.assertTrue(entities.stream().anyMatch(tagEntity -> tagEntity.getName().equals("tag 2 name")));
    }

    @Test
    public void testFindAllByNameList_Empty() {
        List<TagEntity> entities = tagService.findAllByNameList(new ArrayList<>());
        Assertions.assertEquals(0, entities.size());
    }

    @Test
    public void testFindAll() {
        List<TagEntity> entities = tagService.findAll();
        Assertions.assertTrue(entities.size() > 0);
    }

    @Test
    public void testCreate() throws NotFoundException {
        TagEntity folderEntity = tagService.create("new tag name test");
        Assertions.assertNotNull(folderEntity);
    }

    @Autowired
    private ITagService tagService;
}
