package com.goodt.drive.supeditor.application.rest;

import com.goodt.drive.supeditor.application.configuration.AppConfig;
import com.goodt.drive.supeditor.application.dto.TokenResponseDto;
import com.goodt.drive.supeditor.application.dto.UserDto;
import com.goodt.drive.supeditor.utils.IntegrationalTestBase;
import org.junit.Assert;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.web.client.TestRestTemplate;
import org.springframework.boot.web.server.LocalServerPort;
import org.springframework.http.*;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.web.reactive.function.BodyInserters;
import org.springframework.web.reactive.function.client.WebClient;

@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
@ActiveProfiles("integrationaltests")
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
public class TestUserController extends IntegrationalTestBase {

    @LocalServerPort
    private int port;

    @Autowired
    private TestRestTemplate restTemplate;

    private String hostName = "http://localhost:" + port;
    private HttpHeaders requestHeaders;

    @BeforeAll
    public void setup() {
        WebClient client = WebClient.builder()
                .baseUrl(appConfig.getKeyCloakConfig().getBaseUrl())
                .build();
        TokenResponseDto result = client.post().uri(appConfig.getKeyCloakConfig().getTokenUrl())
                .header(HttpHeaders.CONTENT_TYPE, MediaType.APPLICATION_FORM_URLENCODED_VALUE)
                .body(BodyInserters.fromFormData("client_id", appConfig.getKeyCloakConfig().getClientId())
                        .with("client_secret", appConfig.getKeyCloakConfig().getClientSecret())
                        .with("grant_type", "password")
.with("username", appConfig.getKeyCloakConfig().getUsername())
                        .with("password", appConfig.getKeyCloakConfig().getPassword()))
                .retrieve().bodyToMono(TokenResponseDto.class).block();

        hostName = "http://localhost:" + port;
        requestHeaders = new HttpHeaders();
        requestHeaders.add("authorization", String.format("%s %s", result.getTokenType(), result.getAccessToken()));
    }

    @Test
    public void testGetAll() {
        HttpEntity request = new HttpEntity<>(requestHeaders);

        ResponseEntity<UserDto> response = restTemplate.exchange(
                hostName + "/api/user/info",
                HttpMethod.GET,
                request,
                UserDto.class
        );
        Assert.assertEquals(HttpStatus.OK, response.getStatusCode());
        Assert.assertTrue(response.getBody().getId().length() > 0);
    }

    @Autowired
    AppConfig appConfig;
}
