import { SDK, PromiseCancelable, SDKError, SDKCancelRequestError } from './sdk';
import { AxiosInstance, AxiosRequestConfig, CancelTokenSource } from 'axios/index';

export interface ITransportRequest {
    /**
     * url
     */
    url: string;
    /**
     * request method
     */
    method?: string;
    /**
     * params
     */
    params?: Record<string, any>;
    /**
     * request options (axios)
     */
    options?: Record<string, any>;
}

export class Http {

    private _axios: AxiosInstance;

    private _requests: PromiseCancelable[];

    constructor({
        getBaseURL,
        getHeaders,
        beforeRequest,
        processResponseError
    }: { getBaseURL: () => string, getHeaders: () => Record<string, string>,
        beforeRequest: (sdk: SDK) => Promise<void>,
        processResponseError: (error: Error) => Error
    });

    public readonly baseURL: string;

    // @ts-ignore
    /**
     *
     * @param {string} url
     * @param {string} [method='get']
     * @param {object} [params]
     * @param {object} [options]
     * @return {PromiseCancelable}
     * @private
     */
    request({ url, method = 'get', params, options }: ITransportRequest): PromiseCancelable

    /**
     * Отменяет все активные запросы
     */
    cancelActiveRequests();

    /**
     *
     * @param {string} url
     * @param {string} [method='get']
     * @param {object} [params]
     * @param {object} [options]
     * @return {[import('axios').AxiosRequest, import('axios').CancelTokenSource]}
     * @private
     */
    private _buildRequest({
        url,
        method,
        params,
        options
    }: { url: string, method?: string, params?: Record<string, any>, options?: Record<string, any> }): [AxiosRequestConfig, CancelTokenSource]

    private _setupHandlers();

    private _setupAxios();

    private _axiosResolveHandler: ({ data }: { data: any }) => any;

    private _axiosRejectHandler: (e: Error) => never;

    /**
     * @private
     * @param {Promise} promise
     * @param {CancelTokenSource} source
     * @return {PromiseCancelable}
     */
    private _cancelable(promise: Promise<any>, source: CancelTokenSource): PromiseCancelable;

    /**
     * @private
     * @param {PromiseCancelable} promise
     */
    private _addRequest(promise: PromiseCancelable): void;

    /**
     * @private
     * @param {PromiseCancelable} promise
     */
    private _removeRequest(promise: PromiseCancelable): void;

    /**
     * @private
     * @param error
     * @return {Error} error
     */
    private _handleError(error: Error): Error;

    /**
     * @private
     * @param error
     * @return {Error} error
     */
    private _buildError(error: Error): SDKError | SDKCancelRequestError;
}