import Vue from 'vue';
import * as sdk from './sdk';

let i = new sdk.SDK({ host: 'https://localhost:4400' });
i.beforeRequest = () =>
    new Promise(resolve => {
        i.config.authToken = `${Math.random().toString(16).substr(2)}`;
        i.config.admin = true;
        resolve();
    });
let queryList = [
    {
        $fields: {},
        $from: ['_test', 'data'],
        $metrics: [],
        $dimensions: [],
        $filters: [],
        $sort: []
    },
    {
        $from: ['test', 'test_dataset'],
        $fields: {
            store_name: 'store_name',
            value_category: 'value_category'
        },
        $metrics: [{ категории: { $gc: 'value_category' } }],
        $dimensions: [], //[{ магазин: 'store_name' }],
        $filters: [],
        $sort: []
    },
    {
        $from: ['test', 'test_dataset'],
        $fields: {
            store_name: 'store_name',
            date_from: 'date_from'
        },
        $metrics: [],
        $dimensions: [],
        $filters: [{ date_from: { $btw: ['#year-start#', '#year-end#'] } }],
        $sort: []
    },
    {
        $from: ['test', 'zips'],
        $fields: {
            ид: '_id',
            штат: 'state',
            город: 'city',
            популяция: 'pop'
        },
        $metrics: [{ 'кол-во городов': { $count: 'город' } }],
        $dimensions: [{ 'название штата': 'штат' }],
        $filters: [
            { 'кол-во городов': { $gt: [10] } },
            { популяция: { $gt: [50000] } },
            { штат: { $lk: ['C%'] } }
        ],
        $sort: [{ 'кол-во городов': 'desc' }]
    },
    {
        $from: ['test', 'zips'],
        $fields: {
            ид: '_id',
            штат: 'state',
            город: 'city',
            популяция: 'pop'
        },
        $metrics: [
            { id: { $v: 'ид' } },
            { 'название штата': { $v: 'штат' } },
            { 'название города': { $v: 'город' } },
            { 'популяция города': { $v: 'популяция' } }
        ],
        $dimensions: [],
        $filters: [{ 'название штата': { $eq: ['NY'] } }, { популяция: { $max: ['популяция'] } }],
        $sort: [{ 'название штата': 'asc' }, { 'название города': 'asc' }]
    }
];

new Vue({
    el: '#app',
    data() {
        return {
            dremioUrl: '',
            queryList,
            query: null,
            error: null,
            data: [],
            loading: false,
            queryDD: {
                $from: ['test', 'zips'],
                $fields: {
                    район: '_id',
                    штат: 'state',
                    город: 'city',
                    популяция: 'pop'
                },
                $metrics: [{ 'общая популяция': { $sum: 'популяция' } }],
                $dimensions: [],
                $filters: [],
                $sort: [{ 'общая популяция': 'desc' }]
            },
            dimensionList: { название: ['штат', 'город', 'район'] },
            queryHelper: null
        };
    },
    computed: {
        dimensionNames() {
            return this.query ? sdk.Query.queryDimensionNames(this.query) : [];
        },
        metricNames() {
            return this.query ? sdk.Query.queryMetricNames(this.query) : [];
        },
        fieldNames() {
            return this.query ? sdk.Query.queryFieldNames(this.query) : [];
        }
    },
    created() {
        let queryHelper = new sdk.Query({
            query: this.queryDD,
            dimensionList: this.dimensionList
        });
        this.queryHelper = queryHelper;
        //
        i.getPermissions()
            .then(permissions => console.log('my permissions:', permissions))
            .catch(e => (this.error = e));
        i.getDremioUrl()
            .then(url => {
                this.dremioUrl = url;
            })
            .then(() => i.getEntityByPath(['demo']));
    },
    methods: {
        load(query) {
            this.query = query;
            this.loading = true;
            this.error = null;
            i.cancelActiveRequests();
            i.getData(query, 0, 10, true)
                .then(data => (this.data = data))
                .catch(e => (this.error = e))
                .finally(() => (this.loading = false));
            //i.cancelActiveRequests();
        },
        getDimensionField(name) {
            if (!this.query) {
                return name;
            }
            let f = sdk.Query.queryGetDimensionField(this.query, name);
            return f ? f : name;
        }
    }
});
