export namespace utils {
    function firstKey(obj: any): string;

    function replaceKey(obj: any, keyOld: any, keyNew: any): any;
}

/**
 * @private Returns method url
 * @param {string} host
 * @return {string}
 */
export function buildBaseURL({ host }: { host: string }): string;

/**
 * @param {string} [authToken]
 * @param {boolean} [admin]
 * @param {string} [connection]
 * @return {{}}
 */
// prettier-ignore
export function buildRequestHeaders({
    authToken,
    admin,
    connection
}: { authToken?: string, admin?: boolean, connection?: string }): Record<string, string>

/**
 * @private
 * @param {Function} func
 * @return {Promise}
 */
export function hook(func: () => any): Promise<any>

/**
 * @param {{ url: string, options?: { method?: string } }} action
 * @param {Record<string, string|number>} [pathParams]
 * @param {Record<string, any>} [params]
 * @param {Record<string, string|number|boolean|null>} [queryParams]
 * @param {Record<string, any>} [options]
 * @return {{ url: string, method: string, params?: Record<string, string|number|boolean>, data?: Record<string, any>, options: Record<string, any> }}
 */
export function buildRequestConfig({
     action,
     pathParams,
     params,
     queryParams,
     options
 }: {
    action: { url: string, options?: { method?: string }},
    pathParams?: Record<string, string|number>,
    params?: Record<string, any>,
    queryParams?: Record<string, string|number|boolean|null|undefined>,
    options?: Record<string, any>
}): {
    url: string,
    method: string,
    params: Record<string, any>,
    options: Record<string, any>
}
