/* eslint-disable camelcase */

import { buildRequest, BaseApiService } from '@goodt-common/api';

import { ServiceAction } from './config';

/**
 * @typedef {import('@goodt-common/utils').ISafeResult} SafeResult
 */

export class FileUploadApiService extends BaseApiService {
    /**
     *
     * @param {File} file
     * @return {Promise<SafeResult>}
     */
    uploadFile(file) {
        const params = new FormData();
        params.append('file', file);

        const request = buildRequest({ action: ServiceAction.UPLOAD_FILE, params });

        return this.request(request);
    }

    /**
     * @description Скачивание файла
     * @link https://goodt-dev.goodt.me:8499/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/fileupload/getUrl
     *
     * @param { string } fileName
     * @return {Promise<SafeResult<Blob, Error>>}
     */
    getFile(fileName) {
        const request = buildRequest({
            action: ServiceAction.FILE_UPLOAD_GET,
            params: {
                name: fileName
            }
        });

        return this.request(request);
    }
}
