/* eslint-disable camelcase */
import {
    BaseApiService,
    useExtensions,
    processRequestResult as processRequestResultBase,
    buildRequest
} from '@goodt-common/api';

import { BaseDto } from '@goodt-common/infra';

/**
 *
 * @param {SafeResult} safeResult
 * @param {import('@goodt-common/infra/BaseDto').BaseDto.constructor|function(): any|null} [DtoConstructor]
 * @return {ReturnType<typeof processRequestResultBase>}
 */
const processRequestResult = (safeResult, DtoConstructor) => {
    const resolveDtoJson = (responseJson) => {
        const { id, content, links, ...restJson } = responseJson;
        if (id) {
            return { id, ...restJson };
        }

        if (content) {
            return content;
        }

        return responseJson;
    };

    return processRequestResultBase(safeResult, DtoConstructor, {
        resultTransformer: resolveDtoJson
    });
};

/**
 *
 * @param action
 * @param {BaseDto} DtoConstructor
 * @return {function(...[*]): *}
 */
export const createApiServiceMethod = (action, DtoConstructor) => {
    // prettier-ignore
    return function (...args) {
        const { paramsBuilder } = action;
        return this.request({
            action,
            ...paramsBuilder(...args)
        }, DtoConstructor);
    };
};

/**
 *
 */
export class LearningCourseApiService extends BaseApiService {
    /**
     *
     * @param options
     * @param extensionsDescriptor
     */
    constructor(options, extensionsDescriptor) {
        super(options);
        useExtensions(this, extensionsDescriptor);
    }

    /**
     *
     * @param apiServiceRequest
     * @param DtoConstructor
     * @param { boolean } shouldProcessResult
     * @return {Promise<SafeResult<BaseDto|BaseDto[], Error>>}
     */
    async request(apiServiceRequest, DtoConstructor) {
        return processRequestResult(await super.request(buildRequest(apiServiceRequest)), DtoConstructor);
    }
}

/**
 *
 * @param {import('@goodt-common/api/types').IApiServiceConstructorOptions} options
 * @param {Record<string, Function>} extensionsDescriptor
 * @return {LearningCourseApiService}
 */
export const createLearningCourseApiService = (options, extensionsDescriptor) =>
    new LearningCourseApiService(options, extensionsDescriptor);
