import { ApiClientMethod } from '@goodt-common/api';

const ApiEndpointPaths = {
    EMPLOYEE_TEAM_DIVISION_HEAD: 'employee/teamdivisionhead',
    EMPLOYEE_TEAM_DIVISION_ASSIGNMENTS_TEAM: 'employee/teamdivisionassignmentsteam',
    EMPLOYEE_TEAM_DIVISION_SUBORDINATES: 'employee/teamdivisionsubordinates',
    EMPLOYEE_INFO: 'employee/info',
    EMPLOYEE_LIST: 'employee/list',
    EMPLOYEE_CONDITION: 'employee/condition',
    EMPLOYEE_TEAM_DIVISION_HEAD_HEAD: 'employee/teamdivisionheadhead',
    EMPLOYEE_TEAM_DIVISION_ROLES_TEAM: 'employee/teamdivisionrolesteam',
    EMPLOYEE_DELETE_TEAM_DIVISION_SUCCESSOR: 'employee/deleteteamdivisionsuccessor',

    DIVISION_POSITION: 'division/position', // Получение информации о должностях и их назначениях в подразделении

    ROLE_LIST: 'role/list',
    ROLE_CLEAR_EMPLOYEE: 'role/clearemployeerole',

    DIVISION_TEAM_ROLE: 'divisionteamrole',
    DIVISION_TEAM_ROLE_GET_BY_ID: 'divisionteamrole/:id',
    DIVISION_TEAM_ROLE_SET_BY_ID: 'divisionteamrole/:id',

    DIVISION_TEAM_ASSIGNMENT_ROTATION_COMMIT: 'employee/teamdivisionassignmentrotationcommit',
    DIVISION_TEAM_ASSIGNMENT_ROTATION_WITHDRAW: 'employee/teamdivisionassignmentrotationwithdraw',
    DIVISION_TEAM_ASSIGNMENT_ROTATION_CREATE: 'employee/addteamdivisionassignmentrotation'
};

export const ServiceAction = {
    EMPLOYEE_TEAM_DIVISION_ASSIGNMENTS_GET: {
        url: 'employee/teamdivisionassignments',
        options: {
            cache: {
                lifetime: 60 * 1000 // 60 sec - data updated in backend one time per day during sync
            }
        }
    },
    EMPLOYEE_TEAM_LEGAL_ENTITY_ASSIGNMENTS_GET: {
        url: 'employee/teamlegalentityassignments',
        options: {
            cache: {
                lifetime: 5 * 1000, // 60 sec - data updated in backend one time per day during sync
                dependsOn: () => [ServiceAction.CLEAR_EMPLOYEE_ROLE.url, ServiceAction.ROLE_SET_EMPLOYEE.url]
            }
        }
    },
    EMPLOYEE_TEAM_DIVISION_LEGAL_ENTITY_ASSIGNMENTS_GET: {
        url: 'employee/teamdivisionassignmentslegalentity',
        options: {
            cache: {
                lifetime: 5 * 1000 // R0 sec - data updated in backend one time per day during sync,
            }
        }
    },
    EMPLOYEE_DIVISION_TEAM_SUCCESSOR_ADD: {
        url: 'employee/addteamdivisionsuccessor',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    EMPLOYEE_DIVISION_TEAM_SUCCESSOR_READINESS_SET: {
        url: 'employee/setteamdivisionsuccessorreadiness',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    EMPLOYEE_DIVISION_TEAM_SUCCESSOR_DATE_HR_UPDATE: {
        url: 'employee/divisionteamsuccessorupdatehr',
        options: {
            method: ApiClientMethod.PUT,
            headers: {
                'content-type': 'application/json'
            },
            paramsSerializer: (params) =>
                Object.entries(params).reduce((result, param) => {
                    if (!param[1]) {
                        return result;
                    }

                    return `${result}&${param[0]}=${encodeURI(param[1])}`;
                }, '')
        }
    },
    EMPLOYEE_INFO_BY_ASSIGNMENT: {
        url: 'employee/employeeinfobyassignment'
    },
    ASSIGNMENT_READINESS_GET: {
        url: 'library/assignmentreadiness'
    },
    DIVISION_TEAM_ROLE_SET_BY_ID: {
        url: 'divisionteamrole/:id',
        options: {
            method: ApiClientMethod.PUT,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    DIVISION_INFO_GET: {
        url: 'division/info',
        options: {
            cache: {
                lifetime: 60 * 1000 // 60 sec - data updated in backend one time per day during sync
            }
        }
    }, // Получение информации о подразделении
    DIVISION_LIST_GET: {
        url: 'division/list',
        options: {
            cache: {
                lifetime: 60 * 1000 // 60 sec - data updated in backend one time per day during sync
            }
        }
    }, // Получение информации о списке подразделений
    DIVISION_PATH_GET: {
        url: 'division/path',
        options: {
            cache: {
                lifetime: 60 * 1000 // 60 sec - data updated in backend one time per day during sync
            }
        }
    },
    DIVISION_TEAM_ROLE_FIND: {
        url: 'divisionteamrole/find',
        options: {
            method: ApiClientMethod.POST,
            paramsSerializer: (params) => new URLSearchParams(params)
        }
    },
    COMPETENCE_ASSIGMENT_ACCORDANCE_GET: {
        url: 'competence/assignmentaccordance'
    },
    LIBRARY_ASSIGNMENT_ROTATIONS_GET: {
        url: 'library/assignmentrotation'
    },
    LEGAl_ENTITY_LIST: {
        url: 'legalentity/list'
    },
    LEGAL_ENTITY_INFO: {
        url: 'legalentity/info'
    },
    POSITION_RANKS_GET: {
        url: 'positionrank'
    },
    POSITION_CATEGORIES_GET: {
        url: 'positioncategory'
    },
    REASON_LIST_GET: {
        url: 'reason/list'
    },
    EMPLOYEE_ME_GET: {
        url: 'employee/me'
    },
    IMPORTANCE_CRITERIA_GROUP_LIST_GET: {
        url: 'importancecriteriagroup/list'
    },
    POSITION_IMPORTANCE_CRITERIA_LIST_GET: {
        url: 'positionimportancecriteria/list'
    },
    IMPORTANCE_CRITERIA_LIST: {
        url: 'importancecriteria/list'
    },
    // eslint-disable-next-line id-length
    POSITION_RECALCULATE_IMPORTANCE_CRITERIA_PUT: {
        url: 'position/recalculateimportancecriteria',
        options: {
            method: ApiClientMethod.PUT,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    POSITION_SUCCESSOR_LIST_GET: {
        url: 'position_successor/list'
    },
    POSITION_IMPORTANCE_CRITERIA_CREATE: {
        url: 'positionimportancecriteria/create',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    POSITION_IMPORTANCE_CRITERIA_UPDATE: {
        url: 'positionimportancecriteria/update/:id',
        options: {
            method: ApiClientMethod.PUT,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    POSITION_IMPORTANCE_CRITERIA_DELETE: {
        url: 'positionimportancecriteria/delete/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    POSITION_SUCCESSOR_CREATE: {
        url: 'position_successor/create',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    POSITION_SUCCESSOR_UPDATE: {
        url: 'position_successor/update/:id',
        options: {
            method: ApiClientMethod.PUT,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    POSITION_SUCCESSOR_DELETE: {
        url: 'position_successor/delete/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    POSITION_SUCCESSOR_READINESS_CREATE: {
        url: 'position_successor_readiness/create',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    POSITION_SUCCESSOR_READINESS_UPDATE: {
        url: 'position_successor_readiness/update/:id',
        options: {
            method: ApiClientMethod.PUT,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    POSITION_SUCCESSOR_READINESS_DELETE: {
        url: 'position_successor_readiness/delete/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    ROLE_SET_EMPLOYEE: {
        url: 'role/setemployeerole',
        options: {
            method: ApiClientMethod.POST
        }
    },
    CLEAR_EMPLOYEE_ROLE: {
        url: 'role/clearemployeerole',
        options: {
            method: ApiClientMethod.POST
        }
    },
    ROLE_ASSIGNMENTS_LIST_GET: {
        url: 'role/legalentityassignments',
        options: {
            cache: {
                dependsOn: () => [ServiceAction.CLEAR_EMPLOYEE_ROLE.url, ServiceAction.ROLE_SET_EMPLOYEE.url],
                lifetime: 60 * 1000 // 60 sec - data updated in backend one time per day during sync
            }
        }
    },
    POSITION_IMPORTANCE_LIST_GET: {
        url: 'position_importance/list'
    },
    POSITION_POSITION_IMPORTANCE_GET: {
        url: 'position_position_importance'
    },
    POSITION_POSITION_IMPORTANCE_CREATE_POST: {
        url: 'position_position_importance/create',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'content-type': 'application/json'
            }
        }
    },
    EMPLOYEE_FIND: {
        url: 'employee/find',
        options: {
            method: ApiClientMethod.POST,
            paramsSerializer: (params) => new URLSearchParams(params)
        }
    },
    POSITION_POSITION_IMPORTANCE_DELETE: {
        url: 'position_position_importance/delete/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    POSITION_FIND_GET: {
        url: 'position/find'
    },
    DIVISION_GROUP_GET: {
        url: 'division_group'
    },
    EMPLOYEE_TEAM_DIVISION_SUBORDINATES_TEAM_GET: {
        url: 'employee/teamdivisionsubordinatesteam'
    },
    DIVISION_TEAM_ASSIGNMENT_ROTATION_UPDATE_COMMENT_PUT: {
        url: 'employee/teamdivisionassignmentrotationcomment',
        options: {
            method: ApiClientMethod.PUT,
            paramsSerializer: {
                serialize: (params) => new URLSearchParams(params)
            }
        }
    },
    WORK_EXPERIENCE_TYPE_GET: {
        url: 'workexperiencetype'
    },
    WORK_EXPERIENCE_TYPE_CREATE_POST: {
        url: 'workexperiencetype/create',
        options: {
            method: ApiClientMethod.POST
        }
    }
};

export { ApiEndpointPaths };
