import { BaseApiService, IApiServiceMixinInstance, IApiServiceMixinOptions } from '@goodt-common/api';
import { SafeResult } from '@goodt-common/utils';
import {
    KpiGroupRawDto,
    KpiRawDto,
    KpiDataRawDto,
    KpiMetricDto,
    EmployeeExperienceDto,
    EmployeeProjectDto,
    EmployeeProjectActivityDto,
    EmployeeProjectRoleDto,
    OperationResultDto,
    CompetenceFindDto,
    CompetenceCatalogDto,
    ScaleTypeDto,
    ScaleLevelDto,
    CompetenceDto,
    DivisionTeamCompetenceDto,
    DevelopmentGoalDto,
    EvaluationEventDto,
    DevelopmentFormDto,
    DevelopmentFormCatalogDto,
    EvaluationEventTypeEvaluationRoleDto,
    EvaluationEventTypeDto,
    CompetenceProfileLinkDto,
    CompetenceProfileLinkTypeDto,
    CompetenceProfilePositionDto,
    CompetenceProfileDto,
    ReasonDto,
    AssignmentAccordanceDto,
    DevelopmentGoalCompetenceDto,
    EventDto,
    EmployeeProjectActivityInput,
    EmployeeProjectInput,
    EmployeeProjectRoleInput,
    CustomEmailEventCodeInput,
    CompetenceInput,
    EventInput,
    ParamsForBffPollResultInput,
    CompetenceProfileLinkInput,
    CompetenceProfilePositionInput,
    CompetenceProfileInput,
    TaskAchievementInput,
    KrAchievementInput,
    KrProgressInput,
    DivisionTeamCompetenceDataDeleteInput,
    ReceiverSystemNotificationDto,
    NotificationDynamicRecipientDto,
    NotificationTokenDto,
    SubstituteNotificationContentTemplateInput,
    NotificationContentTemplateDto,
    NotificationLogDto,
    NotificationContentTemplateInput,
    SubstituteNotificationContentTemplateDto
} from './dto';

export interface IRostalentApiServiceMixinOptions extends IApiServiceMixinOptions {}

export interface IRostalentApiServiceMixinInstance extends IApiServiceMixinInstance<TOrgStructureApiService> {}

/**
 *
 */
export class RostalentApiService extends BaseApiService {
    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/ueppc/updateProgress
     * @description Обновление прогресса задачи по его идентификатору. Берется первый попавшийся field с params: {"type":"progress"}
     *
     *
     * @param {number} goalId - Идентификатор цели, для которой необходимо установить прогресс.
     *
     * @param {Object} options - Объект с параметрами для установки прогресса.
     * @param {string} options.progress - Прогресс, который необходимо установить для цели.
     *
     * @returns {Promise<SafeResult<String, Error>>}
     */
    setGoalProgress(goalId: number, { progress }: { progress: string }): Promise<SafeResult<String, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/kpi/getGroupList
     * @description Получение массива групп Kpi по идентификатору типа (type_id)
     *
     * @param {number|string} typeId - идентификатор типа.
     *
     * @return {Promise<SafeResult<KpiGroupRawDto[], Error>>}
     */
    getKpiGroupsByTypeId(typeId: number | string): Promise<SafeResult<KpiGroupRawDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/kpi/getListByGroupId
     * @description Получение массива Kpi по идентификатору группы (group_id)
     *
     * @param {number|string} groupId - идентификатор группы
     * @return {Promise<SafeResult<KpiRawDto[], Error>>}
     */
    getKpiByGroupId(groupId: number | string): Promise<SafeResult<KpiRawDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/kpi/getData
     * @description Получение массива данных Kpi по идентификатору Kpi (kpi_id)
     *
     * @param {number|string} kpiId - идентификатор KPI
     * @return {Promise<SafeResult<KpiDataRawDto[], Error>>}
     */
    getKpiData(kpiId: number | string): Promise<SafeResult<KpiDataRawDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/kpi_metric/getList_4
     * @description Получение массива Kpi метрик
     *
     * @return {Promise<SafeResult<KpiMetricDto[], Error>>}
     */
    getKpiMetrics(): Promise<SafeResult<KpiMetricDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/employee/find
     * @description Получение информации о стаже работы сотрудника
     *
     * @param {[number|string]} employeeId - идентификатор работника
     * @return {Promise<SafeResult<EmployeeExperienceDto[], Error>>}
     */
    getEmployeeExperiences(employeeId: [number | string]): Promise<SafeResult<EmployeeExperienceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/worker_project/getList_3
     * @description Получение массива WorkerProject по набору параметров
     *
     * @return {Promise<SafeResult<EmployeeProjectDto[], Error>>}
     */
    getEmployeesProjects(): Promise<SafeResult<EmployeeProjectDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/worker_project_activity/getList_2
     * @description Получение массива WorkerProjectActivity по набору параметров
     *
     * @return {Promise<SafeResult<EmployeeProjectActivityDto[], Error>>}
     */
    getEmployeesProjectsActivities(): Promise<SafeResult<EmployeeProjectActivityDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/worker_project_role/getList
     * @description Получение массива WorkerProjectRole по набору параметров
     *
     * @return {Promise<SafeResult<EmployeeProjectRoleDto[], Error>>}
     */
    getEmployeesProjectsRoles(): Promise<SafeResult<EmployeeProjectRoleDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/worker_project/create_3
     * @description Создание нового WorkerProject
     *
     * @param {EmployeeProjectInput} employeeProject
     *
     * @return {Promise<SafeResult<Number, Error>>}
     */
    createEmployeeProject({ projectType, projectName }: EmployeeProjectInput): Promise<SafeResult<Number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/worker_project_activity/create_2
     * @description Создание нового WorkerProjectActivity
     *
     * @param {EmployeeProjectActivityInput} employeeProjectActivityInput
     *
     * @return {Promise<SafeResult<Number, Error>>}
     */
    createEmployeeProjectActivity(
        employeeProjectActivityInput: EmployeeProjectActivityInput
    ): Promise<SafeResult<Number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/worker_project_role/create
     * @description Создание нового WorkerProjectRole
     *
     * @param {EmployeeProjectRoleInput} employeeProjectRoleInput
     *
     * @return {Promise<SafeResult<Number, Error>>}
     */
    createEmployeeProjectRole(employeeProjectRoleInput: EmployeeProjectRoleInput): Promise<SafeResult<Number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/event/customEmailEventCode
     * @description Метод по отправке сообщений в кафку (кастомные уведомления). Логика разная в зависимости от переданного кода
     *
     * @param {CustomEmailEventCodeInput} event
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    triggerCustomEmailEventCode(event: CustomEmailEventCodeInput): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @description Создание новой компетенции
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/createCompetence
     *
     * @param { CompetenceInput } competence
     * @return {Promise<SafeResult<Number, Error>>}
     */
    createCompetence(competence: CompetenceInput): Promise<SafeResult<Number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/updateCompetence,
     * @description Обновление компетенции по его идентификатору
     *
     * @param {number} id - идентификатор кометенции
     * @param {CompetenceInput} competenceInput
     *
     * @return {Promise<SafeResult<Number, Error>>}
     */
    updateCompetence(id: number, competenceInput: CompetenceInput): Promise<SafeResult<Number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/competenceFindNew
     * @description По умолчанию флаг is_ids_exclude = false, найдет ID переданные в массиве ids, если флаг = true то найдет все кроме переданных в ids.
     *
     * @param {Object} filter
     * @param {number[]} filter.ids
     * @param {string} filter.name
     * @param {number[]} filter.catalogIds
     * @param {number} filter.masterId
     *
     * @param {Object} [options]
     * @param {boolean} [options.withClosed]
     * @param {boolean} [options.isIdsExclude]
     *
     * @return {Promise<SafeResult<CompetenceFindDto, Error>>}
     */
    getCompetencesByFilterPost(
        {
            ids,
            name,
            catalogIds,
            masterId
        }: {
            ids: number[];
            name: string;
            catalogIds: number[];
            masterId: number;
        },
        { withClosed, isIdsExclude }: { withClosed: boolean; isIdsExclude: boolean }
    ): Promise<SafeResult<CompetenceFindDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/divisionList
     * @description Получение массива рекомендованных компетенции для подразделения по идентификатору подразделения (team)
     *
     * @param {number} divisionTeamId
     * @param {Object} [options]
     * @param {boolean} [options.withClosed]
     *
     * @return {Promise<SafeResult<DivisionTeamCompetenceDto[], Error>>}
     */
    getDivisionTeamCompetences(
        divisionTeamId: number,
        { withClosed }?: { withClosed: boolean }
    ): Promise<SafeResult<DivisionTeamCompetenceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/divisionDelete
     * @description Удаление рекомендованной компетенции для подразделения по идентификатору
     *
     * @param {DivisionTeamCompetenceDataDeleteInput} deleteCompetenceInput
     *
     * @return {Promise<SafeResult<Number, Error>>}
     */
    deleteDivisionTeamCompetence(
        deleteCompetenceInput: DivisionTeamCompetenceDataDeleteInput
    ): Promise<SafeResult<Number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/catalogList_1
     * @description Получение массива каталога компетенций
     *
     * @return {Promise<SafeResult<CompetenceCatalogDto[], Error>>}
     */
    getCompetenceCatalogs(): Promise<SafeResult<CompetenceCatalogDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/development_goal/list_4
     * @description Получение массива целей развития
     *
     * @return {Promise<SafeResult<DevelopmentGoalDto[], Error>>}
     */
    getDevelopmentGoals(): Promise<SafeResult<DevelopmentGoalDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/scale/getScaleType
     * @description Получение информации о типе шкалы
     *
     * @param {number|string} id - идентификатор типа шкалы
     *
     * @return {Promise<SafeResult<ScaleTypeDto, Error>>}
     */
    getScaleTypeById(id: number | string): Promise<SafeResult<ScaleTypeDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/evaluation/getEvaluationEvent
     * @description Получение мероприятия оценки
     *
     * @param {number|string} id
     * @return {Promise<SafeResult<EvaluationEventDto, Error>>}
     */
    getEvaluationEventById(id: number | string): Promise<SafeResult<EvaluationEventDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/getCompetencesByCompetenceProfile
     * @description Получение информации о компетенциях по идентификатору профиля компетенции
     *
     * @param {number|string} competenceProfileId - Идентификатор профиля компетенции
     *
     * @return {Promise<SafeResult<CompetenceDto[], Error>>}
     */
    getCompetencesByCompetenceProfileId(
        competenceProfileId: number | string
    ): Promise<SafeResult<CompetenceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/catalogList_1
     * @description Получение массива компетенций по имени (name) или идентификатору каталога (catalog_id)
     *
     * @param {Object} filter
     * @param {number[]|string[]} filter.ids
     * @param {number|string} filter.catalogId
     * @param {string} filter.name
     * @param {Object} options
     * @param {boolean} options.withClosed
     *
     * @return {Promise<SafeResult<CompetenceDto[], Error>>}
     */
    getCompetencesByFilter(
        {
            ids,
            catalogId,
            name
        }: {
            ids: number[] | string[];
            catalogId: number | string;
            name: string;
        },
        { withClosed }: { withClosed: boolean }
    ): Promise<SafeResult<CompetenceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/development_form/list_8
     * @description Получение массива форм развития по идентификатору каталога (catalog_id)
     *
     * @param {number|string} catalogId
     *
     * @return {Promise<SafeResult<DevelopmentFormDto[], Error>>}
     */
    getDevelopmentForms(catalogId: number | string): Promise<SafeResult<DevelopmentFormDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/development_form/catalogList
     * @description Получение массива каталога форм развития
     *
     * @return {Promise<SafeResult<DevelopmentFormCatalogDto[], Error>>}
     */
    getDevelopmentFormCatalogs(): Promise<SafeResult<DevelopmentFormCatalogDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/evaluation/getAllEvaluationEventTypeEvaluationRole
     * @description Получение актуальных связок роли оценщика и типа мероприятия оценки
     *
     * @param {number | string} evaluationEventTypeId - Идентификатор типа мероприятия оценки
     *
     * @return {Promise<SafeResult<EvaluationEventTypeEvaluationRoleDto[], Error>>}
     */
    getEvaluationEventTypeRoleBindings({
        evaluationEventTypeId
    }: {
        evaluationEventTypeId: number | string;
    }): Promise<SafeResult<EvaluationEventTypeEvaluationRoleDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/evaluation/getEvaluationEventType
     * @description Получение справочника типов мероприятий оценки
     *
     * @param {number | string } id - Идентификатор справочника
     *
     * @return {Promise<SafeResult<EvaluationEventTypeDto[], Error>>}
     */
    getEvaluationEventTypes(id: number | string): Promise<SafeResult<EvaluationEventTypeDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/onboarding/downloadOnboardingTaskFile
     * @description Скачивание файла
     *
     * @param {number | string} id - Идентификатор файла
     *
     * @return {Promise<SafeResult<Object, Error>>}
     */
    downloadTaskFile(id: number | string): Promise<SafeResult<Object, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence_profile_link/getCompetenceProfileLink
     * @description Получение записи о связи пары профилей должностей и типа их связи по ID
     *
     * @param {number | string} id - Идентификатор
     *
     * @return {Promise<SafeResult<CompetenceProfileLinkDto, Error>>}
     */
    getCompetenceProfileLinkById(id: number | string): Promise<SafeResult<CompetenceProfileLinkDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence_profile_link/getAllCompetenceProfileLinkType
     * @description Получение списка типов связей профилей должностей
     *
     * @return {Promise<SafeResult<CompetenceProfileLinkTypeDto, Error>>}
     */
    getCompetenceProfileLinkTypes(): Promise<SafeResult<CompetenceProfileLinkTypeDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/getCompetenceProfilePosition
     * @description Получение информации о связи профиля компетенции и позиции
     *
     * @param {number |string} id - Идентификатор связи
     *
     * @return {Promise<SafeResult<CompetenceProfilePositionDto, Error>>}
     */
    getCompetenceProfilePositionById(id: string | number): Promise<SafeResult<CompetenceProfilePositionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/getCompetenceProfile
     * @description Получение информации о профиле компетенций
     *
     * @param {number | string} id - Идентификатор профиля компетенций
     *
     * @return {Promise<SafeResult<CompetenceProfileDto, Error>>}
     */
    getCompetenceProfileById(id: number | string): Promise<SafeResult<CompetenceProfileDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/scale/getScaleLevels
     * @description Получение информации об актуальных баллах шкал
     *
     * @return {Promise<SafeResult<ScaleLevelDto[], Error>>}
     */
    getScaleLevels(): Promise<SafeResult<ScaleLevelDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/reason/getReasonList
     * @description Получение информации о всех типах причин
     *
     * @return {Promise<SafeResult<ReasonDto[], Error>>}
     */
    getReasons(): Promise<SafeResult<ReasonDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/assignmentAccordance
     * @description Получение процента соответствия назначений по компетенциям
     *
     * @param {Object} options
     * @param {number[] | string[]} options.assignmentFrom
     * @param {number[] | string[]} [options.assignmentTo]
     *
     * @return {Promise<SafeResult<AssignmentAccordanceDto[], Error>>}
     */
    getCompetenceAssignmentsAccordances({
        assignmentFrom,
        assignmentTo
    }: {
        assignmentFrom: number[] | string[];
        assignmentTo: number[] | string[];
    }): Promise<SafeResult<AssignmentAccordanceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/development_goal/list_3
     * @description Получение массива DevelopmentGoalCompetence
     *
     * @return {Promise<SafeResult<DevelopmentGoalCompetenceDto[], Error>>}
     */
    getDevelopmentGoalCompetences(): Promise<SafeResult<DevelopmentGoalCompetenceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/getCompetence
     * @description Получение информации о компетенции, её индикаторах и уровнях индикаторов
     *
     * @param {number | string} id - Идентификатор компетенции
     *
     * @return {Promise<SafeResult<CompetenceDto, Error>>}
     */
    getCompetenceById(id: number | string): Promise<SafeResult<CompetenceDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/deleteCompetenceEvaluationEvent
     * @description Удаление связки компетенции и мероприятия оценки
     *
     * @param {Object} options
     * @param {number | string} options.evaluationEventId
     * @param {number | string} options.competenceId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteCompetenceEvaluationEventBinding({
        evaluationEventId,
        competenceId
    }): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/event/updateDtaRotation
     * @description Создание уведомления для работника о том, что ему нужно подтвердить статус ротации. Обязательные поля: "author_name", "button_link", "division_team_assignment_id"
     *
     * @param {EventInput} eventInput
     *
     * @return {Promise<SafeResult<EventDto, Error>>}
     */
    createEventUpdatedTaRotation(eventInput: EventInput): Promise<SafeResult<EventDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/evaluation/createTaskByParams
     * @description Метод ищет по task_id дочерний с task_type = 172 и заполненным task_type_field_id = 217. Если не находит дочерний таск или пустой филд - ошибка. Входные параметры для метода. Варианты использования: 1) task_id, employee_id, indicator_level_id, comment; 2) task_id, employee_id, competence_id, scale_level_id, comment
     *
     * @param {ParamsForBffPollResultInput} pollKeyResult
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    createEvaluationPollKeyResult(
        pollKeyResultInput: ParamsForBffPollResultInput
    ): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/evaluation/deleteEvaluationEvent
     * @description Удаление мероприятия оценки
     *
     * @param {number | string} id - Идентификатор мероприятия оценки
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteEvaluationEvent(id): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence_profile_link/createCompetenceProfileLink
     * @description Создание записи о типе связи пары профилей должностей
     *
     * @param {CompetenceProfileLinkInput} competenceProfileLinkInput
     *
     * @return {Promise<SafeResult<CompetenceProfileLinkDto, Error>>}
     */
    createCompetenceProfileLink(
        competenceProfileLinkInput: CompetenceProfileLinkInput
    ): Promise<SafeResult<CompetenceProfileLinkDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence_profile_link/deleteCompetenceProfileLink
     * @description Закрытие (date_to != null) записи о типе связи пары профилей должностей по ID
     *
     * @param {number | string} id - Идентификатор
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteCompetenceProfileLink(id: number | string): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/updateCompetenceProfilePosition
     * @description Обновление связи профиля компетенции и позиции
     *
     * @param {number | string} id - Идентификатор связи
     * @param {CompetenceProfilePositionInput} profilePosition
     *
     * @return {Promise<SafeResult<CompetenceProfilePositionDto, Error>>}
     */
    updateCompetenceProfilePosition(
        id: number | string,
        profilePosition: CompetenceProfilePositionInput
    ): Promise<SafeResult<CompetenceProfilePositionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/competence/update_18
     * @description Обновление профиля компетенций
     *
     * @param {number | string} id - Идентификатор профиля компетенций
     * @param {CompetenceProfileInput} competenceProfileInput
     *
     * @return {Promise<SafeResult<CompetenceProfileDto, Error>>}
     */
    updateCompetenceProfile(
        id: number | string,
        competenceProfileInput: CompetenceProfileInput
    ): Promise<SafeResult<CompetenceProfileDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/event/updateDtaRotationCompleted
     * @description Создание уведомления работника о том, что он актуализировал. Обязательные поля: "author_name", "division_team_assignment_id"
     *
     * @param {EventInput} eventInput
     *
     * @return {Promise<SafeResult<EventDto, Error>>}
     */
    createEventRotationCompleted(eventInput: EventInput): Promise<SafeResult<EventDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/event/createTaskAchievement
     * @description Создание факта фиксации достижения цели
     *
     * @param {TaskAchievementInput} taskAchievementInput
     *
     * @return {Promise<SafeResult<EventDto, Error>>}
     */
    createEventTaskAchievement(taskAchievementInput: TaskAchievementInput): Promise<SafeResult<EventDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/event/createKrAchievementEvent
     * @description Фиксация факта фиксации достижения ключевого результата. Метод ожидает во входных данных task_type = 4
     *
     * @param {KrAchievementInput} keyResultAchievementInput
     *
     * @return {Promise<SafeResult<EventDto, Error>>}
     */
    createEventKeyResultAchievement(
        keyResultAchievementInput: KrAchievementInput
    ): Promise<SafeResult<EventDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/event/createKrProgress
     * @description Фиксация прогресса в достижении ключевого результата
     *
     * @param {KrProgressInput} keyResultProgressInput
     *
     * @return {Promise<SafeResult<EventDto, Error>>}
     */
    createKeyResultProgress(keyResultProgressInput: KrProgressInput): Promise<SafeResult<EventDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_receiver_system/getAllNotificationReceiverSystem
     * @description Получение массива notification_receiver_system
     *
     * @return {Promise<SafeResult<ReceiverSystemNotificationDto[], Error>>}
     */
    getReceiverSystemNotifications(): Promise<SafeResult<ReceiverSystemNotificationDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_recipient/getDynamicRecipients
     * @description Получение записей из таблицы notification_recipient, исключая static_employee и static_division
     *
     * @return {Promise<SafeResult<NotificationDynamicRecipientDto[], Error>>}
     */
    getNotificationDynamicRecipients(): Promise<SafeResult<NotificationDynamicRecipientDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_token/getAll
     * @description Получение массива notification_token
     *
     * @return {Promise<SafeResult<NotificationTokenDto[], Error>>}
     */
    getNotificationTokens(): Promise<SafeResult<NotificationTokenDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_template_content/findSubstitutes
     * @description Получение краткой информации из таблицы notification_template_content. При полученном notificationTemplateContentId шаблон с данным идентификатором исключается
     *
     * @param {SubstituteNotificationContentTemplateInput} substituteNotificationContentTemplateInput
     * @return {Promise<SafeResult<SubstituteNotificationContentTemplateDto[], Error>>}
     */
    getSubstituteNotificationContentTemplates(
        substituteNotificationContentTemplateInput: SubstituteNotificationContentTemplateInput
    ): Promise<SafeResult<SubstituteNotificationContentTemplateDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_template_content/getById_1
     * @description Получение notification_template_content
     *
     * @param {number} id
     * @return {Promise<SafeResult<NotificationContentTemplateDto, Error>>}
     */
    getNotificationContentTemplateById(id: number): Promise<SafeResult<NotificationContentTemplateDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_log/load_2
     * @description Загрузка карточки в Журнале уведомлений
     *
     * @param {number} id
     * @return {Promise<SafeResult<NotificationLogDto, Error>>}
     */
    getNotificationLogById(id: number): Promise<SafeResult<NotificationLogDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_template_content/create_7
     * @description Создание notification_template_content
     *
     * @param {NotificationContentTemplateInput} notificationContentTemplateInput
     * @return {Promise<SafeResult<NotificationContentTemplateDto, Error>>}
     */
    createNotificationContentTemplate(
        notificationContentTemplateInput: NotificationContentTemplateInput
    ): Promise<SafeResult<NotificationContentTemplateDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8486/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/notification_template_content/update_7
     * @description Изменение notification_template_content
     *
     * @param {number} id
     * @param {NotificationContentTemplateInput} notificationContentTemplateInput
     * @return {Promise<SafeResult<NotificationContentTemplateDto, Error>>}
     */
    updateNotificationContentTemplate(
        id: number,
        notificationContentTemplateInput: NotificationContentTemplateInput
    ): Promise<SafeResult<NotificationContentTemplateDto, Error>>;
}
