import { BaseDto } from '@goodt-common/infra';

export class StringDto extends BaseDto {}
export class KpiGroupRawDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
    kpi_type_id: number;
}
export class KpiRawDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
    kpi_group_id: number;
    metric_id: number;
    kpi_calculation_model_id: number;
}
export class KpiDataRawDto extends BaseDto {
    id: number;
    plan: number;
    fact: number;
    kpi_id: number;
    period_from: string;
    period_to: string;
    date_from: string;
    date_to: string;
}
export class KpiMetricDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
}
export class EmployeeExperienceDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
}
export class EmployeeProjectDto extends BaseDto {
    id: number;
    project_type: number;
    project_name: string;
}
export class EmployeeProjectActivityDto extends BaseDto {
    id: number;
    project_activity: string;
}
export type EmployeeProjectActivityInput = Omit<EmployeeProjectActivityDto, 'id'>;
export class EmployeeProjectRoleDto extends BaseDto {
    id: number;
    project_role: string;
}
export type EmployeeProjectInput = {
    project_type: number;
    project_name: string;
};
export type EmployeeProjectActivityInput = {
    project_activity: string;
};
export type EmployeeProjectRoleInput = {
    project_role: string;
};
export type CustomEmailEventCodeInput = {
    code: string;
    comment: string;
    compId: number[];
    taskId: number;
    divisionTeamSuccessorId: number;
};
export class OperationResultDto extends BaseDto {
    result: any;
    message: string;
}
export type CompetenceInput = {
    name: string;
    description: string;
    competence_type_id: number;
    competence_catalog_id: number;
    date_from: string;
    date_to: string;
    author_employee_id: number;
    author_input_source_id: number;
    scale_type_id: number;
    on_moderation: boolean;
    master_id: number;
    correct_id: number;
    external_id: string;
};
export class CompetenceTypeDto extends BaseDto {
    id: number;
    name: string;
    date_from: string;
    date_to: string;
}
export class CompetenceCatalogDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    params: string;
    parent_id: number;
    date_from: string;
    date_to: string;
    premoderation_required: boolean;
    indicator_required: boolean;
    external_id: string;
}
export class ScaleLevelShortDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    index: number;
    date_from: string;
    date_to: string;
    level_point: number;
}
export class CompetenceAlgorithmDto extends BaseDto {
    id: number;
    name: string;
    description: string;
}
export class ScaleTypeDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
    level_count: number;
    scale_levels: ScaleLevelShortDto[];
    competence_algorithm: CompetenceAlgorithmDto;
}
export class ScaleLevelDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    index: number;
    date_from: string;
    date_to: string;
    level_point: number;
    scale_type: ScaleTypeDto;
}
export class IndicatorScaleTemplateDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
}
export class IndicatorScaleTemplateLevelDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    index: number;
    date_from: string;
    date_to: string;
    indicator_scale_template: IndicatorScaleTemplateDto;
    level_point: number;
    is_exclude_indicator: boolean;
    is_comment_required: boolean;
}
export class IndicatorLevelShortDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    index: number;
    date_from: string;
    date_to: string;
    scale_level: ScaleLevelDto;
    author_employee_id: number;
    indicator_scale_template_level: IndicatorScaleTemplateLevelDto;
    is_exclude_indicator: boolean;
    is_comment_required: boolean;
    level_point: number;
}
export class IndicatorShortDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    weight: number;
    date_from: string;
    date_to: string;
    author_employee_id: number;
    indicator_levels: IndicatorLevelShortDto[];
    is_short_view: boolean;
    indicator_scale_template: IndicatorScaleTemplateDto;
}
export class CompetenceDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    master: string;
    correct: string;
    date_from: string;
    date_to: string;
    author_employee_id: number;
    author_input_source_id: number;
    competence_type: CompetenceTypeDto;
    competence_catalog: CompetenceCatalogDto;
    scale_type: ScaleTypeDto;
    indicators: IndicatorShortDto[];
    on_moderation: boolean;
    external_id: string;
}
export class CompetenceFindDto extends BaseDto {
    data: CompetenceDto[];
    total_elements: number;
    total_pages: number;
    page: number;
}
export class DivisionTeamCompetenceDto extends BaseDto {
    competence: CompetenceDto;
    weight: number;
    division_team_id: number;
    date_from: string;
    date_to: string;
}
export class DivisionTeamCompetenceDataDto extends BaseDto {
    weight: number;
    division_team_id: number;
    competence_id: number;
    author_employee_id: number;
    date_from: string;
    date_to: string;
}
export class DevelopmentGoalDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
}
export class EvaluationEventGroupTypeDto extends BaseDto {
    id: number;
    name: string;
    date_from: string;
    date_to: string;
}
export class EvaluationEventTypeDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
    evaluation_event_group_type: EvaluationEventGroupTypeDto;
    short_name: string;
    is_evaluated_by_indicator: boolean;
    is_evaluated_by_competence: boolean;
    is_self_evaluation: boolean;
    is_evaluation_result_changable: boolean;
}
export class CompetenceProfileFamilyDto extends BaseDto {
    id: number;
    name: string;
    parent: string;
    date_from: string;
    date_to: string;
}
export class CompetenceProfileClusterDto extends BaseDto {
    id: number;
    name: string;
    icon: string;
    date_from: string;
    date_to: string;
}
export class CompetenceProfileDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    file: string;
    filename: string;
    date_from: string;
    date_to: string;
    competence_profile_family: CompetenceProfileFamilyDto;
    competence_profile_cluster: CompetenceProfileClusterDto;
    commit_date: string;
    education_level_id: number;
    work_duration_months_min: number;
    work_duration_months_recommend: number;
}
export class EvaluationEventPurposeDto extends BaseDto {
    id: number;
    name: string;
    date_from: string;
    date_to: string;
}
export class EvaluationEventCatalogDto extends BaseDto {
    id: number;
    dateFrom: string;
    dateTo: string;
    name: string;
    parent: string;
}
export class EvaluationEventDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    comment: string;
    location: string;
    date_from: string;
    date_to: string;
    evaluation_event_type: EvaluationEventTypeDto;
    competence_profile: CompetenceProfileDto;
    evaluation_event_purpose: EvaluationEventPurposeDto;
    evaluation_event_catalog: EvaluationEventCatalogDto;
    use_competence_profile_assignment: boolean;
    use_competence_profile_successor: boolean;
    text_for_evaluated: string;
    text_for_expert: string;
    event_format: boolean;
    start_date: string;
    end_date: string;
    need_evaluated_agreement: boolean;
    use_specific_profile: boolean;
    is_published: boolean;
    is_agreed: boolean;
}
export class DevelopmentFormTypeDto extends BaseDto {
    id: number;
    name: string;
    date_from: string;
    date_to: string;
}
export class DevelopmentFormCatalogTypeDto extends BaseDto {
    id: number;
    code: number;
    name: string;
    date_from: string;
    date_to: string;
}
export class DevelopmentFormCatalogDto extends BaseDto {
    id: number;
    name: string;
    params: string;
    developmentFormCatalogType: DevelopmentFormCatalogTypeDto;
    index: number;
    parent_id: number;
    date_from: string;
    date_to: string;
    estimation_criteria_id: number;
}
export class DevelopmentFormDto extends BaseDto {
    id: number;
    developmentFormType: DevelopmentFormTypeDto;
    developmentFormCatalog: DevelopmentFormCatalogDto;
    name: string;
    description: string;
    authorEmployeeId: string;
    authorEmployeeInputSource: number;
    isPlannable: boolean;
    isAchievable: boolean;
    estimationCriteriaId: number;
    competenceCountMax: number;
    date_from: string;
    date_to: string;
}
export class EvaluationRoleDto extends BaseDto {
    id: number;
    name: string;
    date_from: string;
    date_to: string;
}
export class EvaluationEventTypeEvaluationRoleDto extends BaseDto {
    index: number;
    evaluation_event_type: EvaluationEventTypeDto;
    evaluation_role: EvaluationRoleDto;
    evaluator_count_min: number;
    evaluator_count_max: number;
    evaluator_count_recommend: number;
    is_event_available: boolean;
    is_employee_available: boolean;
}
export class CompetenceProfileLinkTypeDto extends BaseDto {
    id: number;
    name: string;
    description: string;
}
export class CompetenceProfileLinkDto extends BaseDto {
    id: number;
    dateFrom: string;
    dateTo: string;
    competenceProfileFrom: CompetenceProfileDto;
    competenceProfileTo: CompetenceProfileDto;
    competenceProfileLinkType: CompetenceProfileLinkTypeDto;
}
export class CompetenceProfilePositionDto extends BaseDto {
    id: number;
    date_from: string;
    date_to: string;
    commit_date: string;
    competence_profile: CompetenceProfileDto;
    position_id: number;
    date_inclusion: string;
    date_exclusion: string;
}
export class ReasonDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    type_id: number;
    date_from: string;
    date_to: string;
}
export class AssignmentAccordance extends BaseDto {
    assignmentIds: number[];
    percent: number;
}
export class DevelopmentGoalCompetenceDto extends BaseDto {
    developmentGoal: DevelopmentGoalDto;
    competence: CompetenceDto;
    weight: number;
    author_employee_id: number;
    development_goal_id: number;
    competence_id: number;
    date_from: string;
    date_to: string;
}
export class EventTypeManifestationDto extends BaseDto {
    id: number;
    code: number;
    name: string;
}
export class EstimationCriteriaDto extends BaseDto {
    id: number;
    code: number;
    name: string;
    description: string;
    task_type_id: number;
}
export class EventTypeDto extends BaseDto {
    id: number;
    type: number;
    name: string;
    description: string;
    manifestation: EventTypeManifestationDto;
    criteries: EstimationCriteriaDto[];
    is_important: number;
}
export class EventStatusDto extends BaseDto {
    id: number;
    name: string;
}
export class EventDto extends BaseDto {
    id: number;
    body: string;
    assignment_id: number;
    author_name: string;
    author_image: string;
    event_type: EventTypeDto;
    event_status: EventStatusDto;
    employee_first_name: string;
    employee_last_name: string;
    development_form_name: string;
    poll_id: number;
}

export type EventInput = {
    author_name: string;
    button_link: string;
    button_link_edit: string;
    button_link_update: string;
    update_required_days: number;
    task_id: number;
    employee_assignment_id: number;
    expert_assignment_id: number;
    button_link_one: string;
    button_link_two: string;
    division_team_assignment_id: number;
};
export type ParamsForBffPollResultInput = {
    comment: string;
    task_id: number;
    employee_id: number;
    indicator_level_id: number;
    competence_id: number;
    scale_level_id: number;
};
export type CompetenceProfileLinkInput = {
    competence_profile_id_from: number;
    competence_profile_id_to: number;
    type_id: number;
};
export type CompetenceProfilePositionInput = {
    commitDate: string;
    competenceProfileId: number;
    positionId: number;
    dateInclusion: string;
    dateExclusion: string;
};
export class CompetenceProfileRawDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    file: string;
    filename: string;
    date_from: string;
    date_to: string;
    competence_profile_family_id: number;
    competence_profile_cluster_id: number;
    commit_date: string;
    education_level_id: number;
    work_duration_months_min: number;
    work_duration_months_recommend: number;
}
export type CompetenceProfileInput = Omit<CompetenceProfileRawDto, 'id'>;

export type TaskAchievementInput = {
    competence_id: number[];
    task_id: number;
    assignment_id: number;
    author_name: string;
    author_image: string;
};
export type KrAchievementInput = {
    kr_id: number;
    assignment_id: number;
    author_name: string;
    author_image: string;
    competence_id: number[];
};
export type KrProgressInput = {
    competence_id: number[];
    kr_id: number;
    assignment_id: number;
    author_name: string;
    author_image: string;
};
export type DivisionTeamCompetenceDataDeleteInput = {
    division_team_id: number;
    competence_id: number;
};

export class ReceiverSystemNotificationDto extends BaseDto {
    id: number;
    name: string;
    description: string;
}

export class NotificationDynamicRecipientDto extends BaseDto {
    recipientId: number;
    token: string;
    description: string;
}

export class NotificationTokenDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    shortName: string;
    groupName: string;
}

export class RecipientDto extends BaseDto {
    name: string;
    type: string;
}

export class SubstituteNotificationContentTemplateDto extends BaseDto {
    id: number;
    description: string;
}

export class DivisionRecipientDto extends BaseDto {
    recipientId: number;
    divisionId: number;
    abbreviation: string;
    fullName: string;
    shortName: string;
}

export class EmployeeRecipientDto extends BaseDto {
    recipientId: number;
    employeeId: number;
    firstName: string;
    lastName: string;
    middleName: string;
}

export class AttachmentDto extends BaseDto {
    id: number;
    storageFilePath: string;
    fileName: string;
    fileType: string;
}

export class NotificationContentTemplateDto extends BaseDto {
    id: number;
    notificationTemplateId: number;
    description: string;
    substitute: SubstituteNotificationShortContentTemplateDto;
    bodyJson: string;
    employeeRecipients: EmployeeRecipientDto[];
    divisionRecipients: DivisionRecipientDto[];
    dynamicRecipients: NotificationDynamicRecipientDto[];
    employeeCopyRecipients: EmployeeRecipientDto[];
    divisionCopyRecipients: DivisionRecipientDto[];
    dynamicCopyRecipients: NotificationDynamicRecipientDto[];
    receiverSystem: ReceiverSystemNotificationDto;
    priority: boolean;
    attachments: AttachmentDto[];
    dateFrom: string;
    dateTo: string;
    enabled: boolean;
}

export type SubstituteNotificationContentTemplateInput = {
    notificationTemplateId: number;
    notificationTemplateContentId: number;
};

export class NotificationLogDto extends BaseDto {
    id: number;
    description: string;
    errorMessage: string;
    message: string;
    priority: boolean;
    receiverSystemId: number;
    receiverSystemName: string;
    recipients: string;
    recipientsCopy: string;
    status: string;
    dateModify: string;
    attachments: AttachmentDto[];
    subscribe: string;
}

export type NotificationContentTemplateInput = {
    notificationTemplateId: number;
    receiverSystemId: number;
    description: string;
    substituteId: number;
    priority: boolean;
    enabled: boolean;
    recipientEmployeeIds: number[];
    recipientDivisionIds: number[];
    dynamicRecipientIds: number[];
    copyRecipientEmployeeIds: number[];
    copyRecipientDivisionIds: number[];
    dynamicCopyRecipientIds: number[];
    attachments: AttachmentDto[];
    bodyJson: string;
};
