import { BaseDto } from '@goodt-common/infra';

interface Position {
    id: number;
    categoryId: number;
    positionImportanceId: number;
    dateFrom: string;
    dateTo: string | null;
    fullName: string;
    shortName: string;
}

interface Division {
    id: number;
    parentId: number;
    legalEntityId: number;
    fullName: string;
    shortName: string;
}

interface JobTitle {
    id: number;
    fullName: string;
    shortName: string;
}

interface DivisionTeam {
    id: number;
    fullName: string;
    shortName: string;
}

export class ManagedPositionAssignmentDto extends BaseDto {
    id: number;
    typeId: number;
    employeeId: number;
    dateFrom: string;
    dateTo: string | null;
    fullName: string;
    shortName: string;
    position: Position;
    division: Division;
    jobTitle: JobTitle;
    divisionTeam: DivisionTeam;
}

export class OperationResultDto extends BaseDto {
    result: any;
    message: string;
}

export class KpiGoalTasksDto extends BaseDto {
    id: number;
    legal_name: string;
    full_name: string;
    task_id: number[];
}

export class KpiGoalCheckNumbersDto extends BaseDto {
    confirmed: string[];
    unconfirmed: string[];
}

export class EmployeeInfoDto extends BaseDto {}

interface TaskTypeField {
    id: number;
    value: string;
}

export type UpdateTaskStatusFilter = {
    taskIds: number[];
    taskTypeFields: TaskTypeField[];
    userIds: number[] | number;
    taskTypeIds: number[] | number;
    statusIds: number[];
    processIds: number[];
    targetStatusId: number[] | number;
    comment: string;
};

export type TaskFieldFilter = {
    id: number;
    value: string[];
};

export type EmployeeFilter = {
    employeeIds?: number[];
    divisionId?: number;
    searchToken?: string;
    legalEntityId?: number;
    employeeNumbers?: number[];
    withPatronymic?: boolean;
    jobTitleId?: number;
};

export type EmployeeFilterOutputOptions = {
    page?: number;
    size?: number;
    hasPositionAssignment?: boolean;
};

export type TaskLinksFilter = {
    userIds?: number[];
    taskLinkTypeIds?: number[];
    taskFromId?: number;
    taskToId?: number;
    withTaskFromClosed?: number;
    withTaskToClosed?: boolean;
    withClosedTaskLink?: boolean;
    taskFromUserId?: number;
    taskToUserId?: number;
    taskLinkId?: number;
};

export class DivisionDto extends BaseDto {
    id: number;
    abbreviation: string;
    parent_id: number;
    precursor_id: number;
    date_from: string;
    date_to: string;
    legal_entity_id: number;
    structure_id: number;
    full_name: string;
    short_name: string;
    status_id: number;
    group_id: number;
    external_id: string;
    cost_center_id: number;
}

export class JobTitleDto extends BaseDto {
    id: number;
    abbreviation: string;
    code: string;
    hash: string;
    precursor_id: number;
    date_from: string;
    date_to: string;
    full_name: string;
    short_name: string;
    cluster_id: number;
    is_required_certificate: number;
    external_id: string;
}

export class PositionDto extends BaseDto {
    id: number;
    abbreviation: string;
    stake: number;
    division: DivisionDto;
    precursor_id: number;
    date_from: string;
    date_to: string;
    division_id: number;
    job_title_id: number;
    workplace_id: number;
    work_function_id: number;
    full_name: string;
    short_name: string;
    category_id: number;
    rank_id: number;
    status_id: number;
    position_type_id: number;
    is_key: number;
    is_variable: number;
    position_importance_id: number;
    is_key_management: number;
    job_title: JobTitleDto;
    external_id: string;
    division_short_name: string;
    cost_center_id: number;
}

export class EmployeeDeputyDto extends BaseDto {
    id: number;
    employeeViceId: number;
    employeeSubstituteId: number;
    dateFrom: string;
    dateTo: string;
}

type AssignmentType = {
    id: number;
    abbreviation: string;
    full_name: string;
    short_name: string;
}

export class PositionAssignmentDto extends BaseDto {
    id: number;
    abbreviation: string;
    stake: number;
    position: PositionDto;
    type_id: number;
    precursor_id: number;
    date_from: string;
    date_to: string;
    employee_id: number;
    position_id: number;
    status_id: number;
    placement_id: number;
    substitution_type_id: number;
    full_name: string;
    short_name: string;
    category_id: number;
    probation_date_to: string;
    assignment_type: AssignmentType;
    external_id: string;
}
