import { BaseApiService } from '@goodt-common/api';
import { SafeResult } from '@goodt-common/utils';
import {
    TaskDto,
    UserTaskTreeDto,
    TaskLinkDto,
    TaskMutateInput,
    TaskConditionsDto,
    ProcessDto,
    ProcessTypeDto,
    ProcessStageTypeDto,
    ProcessTaskBindingDto,
    TaskLinkTypeDto,
    TaskTypeDto,
    ProcessStageDto,
    TaskBatchUpdateInput,
    ModuleDto,
    AccessTypeDto,
    UserTypeDto,
    TaskTypeFieldGroupDto,
    TaskTypeFieldTypeDto,
    ComponentTaskTypeFieldDto,
    TaskTypeInputDto,
    CompetenceCommentDto
} from './dto';

import { ProcessTaskBindingFilterInput, TaskFilterInput } from './types';

export class TaskSettingsApiService extends BaseApiService {
    /**
     * Получение списка сущностей "пользовательское дерево задач" для списка заданных идентификаторов
     * пользователей и заданного типа задачи
     *
     * @param {number|number[]} userIds - Массив идентификаторов пользователей
     * @param {number} typeId - Идентификатор типа цели
     * @param {Object} [options={}]
     * @param {number} options.processTypeId - Идентификатор типа процесса
     * @param {number} options.level - Идентификатор уровня
     * @param {boolean} options.history - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {number[]} options.processIds - Массив идентификаторов процессов
     * @param {boolean} options.withClosedTask - Этот флаг устанавливает следующее: если true - то выведутся все цели, если false - выведутся только незавершённые цели
     * @param {boolean} options.withClosedTaskField - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {boolean} options.rootOnly - Этот флаг устанавливает следующее: если true - то выведутся только рутовые цели, если false - выведутся все имеющиеся цели
     * @return {Promise<SafeResult<UserTaskTreeDto[], Error>>}
     */
    getUserTaskTrees(
        userIds: number | number[],
        typeId: number,
        {
            processTypeId,
            level,
            history,
            processIds,
            withClosedTask,
            withClosedTaskField,
            rootOnly
        }?: {
            processTypeId?: number;
            level?: number;
            history?: boolean;
            processIds?: number[];
            withClosedTask?: boolean;
            withClosedTaskField?: boolean;
            rootOnly?: boolean;
        } = {}
    ): Promise<SafeResult<UserTaskTreeDto[], Error>>;

    /**
     * Получение списка сущностей "задача" (одного "дерева" задач) для заданного пользователя
     * и заданного типа задачи
     *
     * @param {number} userId - - Идентификатор пользователя
     * @param {number} typeId  - Идентификатор типа цели
     * @param {Object} [options={}]
     * @param {number} options.processTypeId - Идентификатор типа процесса
     * @param {number} options.level - Идентификатор уровня
     * @param {boolean} options.history - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {number[]} options.processIds - Массив идентификаторов процессов
     * @param {boolean} options.withClosedTask - Этот флаг устанавливает следующее: если true - то выведутся все цели, если false - выведутся только незавершённые цели
     * @param {boolean} options.withClosedTaskField - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {boolean} options.rootOnly - Этот флаг устанавливает следующее: если true - то выведутся только рутовые цели, если false - выведутся все имеющиеся цели
     * @return {Promise<SafeResult<TaskDto[], Error>>}
     */
    getTaskTree(
        userId: number,
        typeId: number,
        {
            processTypeId,
            level,
            history,
            processIds,
            withClosedTask,
            withClosedTaskField
        }?: {
            processTypeId?: number;
            level?: number;
            history?: boolean;
            processIds?: number[];
            withClosedTask?: boolean;
            withClosedTaskField?: boolean;
            rootOnly?: boolean;
        } = {}
    ): Promise<SafeResult<TaskDto[], Error>>;

    /**
     *
     * @param {number|number[]} userIds
     * @param {number|number[]} taskLinkTypeIds
     * @param {number} taskToId
     * @param {number} withTaskFromClosed
     * @param {number} withTaskToClosed
     * @param {number} taskFromUserId
     * @param {number} taskToUserId
     * @param {number} taskLinkTypeIds
     * @param {number}
     * @return {Promise<SafeResult<TaskLinkDto[], Error>>}
     */
    async getTaskLinks({
        userIds,
        taskLinkTypeIds,
        taskFromId,
        taskToId,
        withTaskFromClosed,
        withTaskToClosed,
        taskFromUserId,
        taskToUserId
    }: {
        userIds?: number[];
        taskLinkTypeIds?: number[];
        taskFromId?: number;
        taskToId?: number;
        withTaskFromClosed?: number;
        withTaskToClosed?: boolean;
        taskFromUserId?: number;
        taskToUserId?: number;
    }): Promise<SafeResult<TaskLinkDto[], Error>>;

    /**
     *
     * @param {number|number[]} taskId
     * @return {Promise<SafeResult<TaskDto, Error>>}
     */
    getTaskById(taskId: number): Promise<SafeResult<TaskDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/
     * @description Получение списка связей целей с возможностью передачей массивов для параметров task_user_id_from, task_user_id_to, task_id_from и task_id_to.
     *
     * @param {Object} params
     * @param {number|number[]} params.userIds - Массив идентификаторов пользователей
     * @param {number|number[]} [params.taskLinkTypeIds] - Массив идентификаторов типов ссылки на цели
     * @param {number|number[]} [params.taskFromId] - Массив идентификаторов начальной цели
     * @param {number|number[]} [params.taskToId] - Массив идентификаторов конечной цели
     * @param {boolean} [params.withTaskFromClosed] - false - в результате получим связи только с открытыми начальными целями, true - будем получать связи даже с закрытими начальными целями
     * @param {boolean} [params.withTaskToClosed] - false - в результате получим связи только с открытыми конечными целями, true - будем получать связи даже с закрытими конечными целями
     * @param {number|number[]} [params.taskFromUserId] - Массив идентификаторов пользователей начальной цели
     * @param {number|number[]} [params.taskToUserId] - Массив идентификаторов пользователей конечной цели
     * @param {number} [params.taskLinkId] - Идентификатор связи целей
     * @return {Promise<SafeResult<TaskLinkDto[], Error>>}
     */
    async getTaskLinksByFilter({
        userIds,
        taskLinkTypeIds,
        taskFromId,
        taskToId,
        withTaskFromClosed,
        withTaskToClosed,
        taskFromUserId,
        taskToUserId,
        taskLinkId
    }: {
        userIds?: number[];
        taskLinkTypeIds?: number[];
        taskFromId?: number;
        taskToId?: number;
        withTaskFromClosed?: number;
        withTaskToClosed?: boolean;
        taskFromUserId?: number;
        taskToUserId?: number;
        taskLinkId?: number;
    }): Promise<SafeResult<TaskLinkDto[], Error>>;

    /**
     * Изменение связи цели
     *
     * @param {number} linkId
     * @param {number} task_id_from
     * @param {number} task_link_type_id
     * @param {number} task_id_to
     * @param {string}date_from
     * @param {string} date_to
     * @return {Promise<SafeResult<Number, Error>>}
     */
    async updateTaskLink(
        linkId,
        { task_id_from, task_link_type_id, task_id_to, date_from, date_to }
    ): Promise<SafeResult<Number, Error>>;

    /**
     * Получение списка типов связей
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/getTaskLinkTypeByIds
     *
     * @param {number} linkTypeId
     * @return {Promise<SafeResult<TaskLinkTypeDto[], Error>>}
     */
    async getTaskLinkTypes(linkTypeId): Promise<SafeResult<TaskLinkTypeDto[], Error>>;

    /**
     * Создание связи цели
     *
     * @param {number} task_id_from
     * @param {number} task_link_type_id
     * @param {number} task_id_to
     * @param {string}date_from
     * @param {string} date_to
     * @return {Promise<SafeResult<Number, Error>>}
     */
    async createTaskLink({
        task_id_from,
        task_link_type_id,
        task_id_to,
        date_from,
        date_to
    }): Promise<SafeResult<Number, Error>>;

    /**
     *
     * @param {number} id
     * @return {Promise<SafeResult<TaskLinkDto, Error>>}
     */
    async getTaskLinkById(id: number): Promise<SafeResult<TaskLinkDto, Error>>;

    /**
     *
     * @param {string|number} taskId
     *
     * @param {number} type type id
     * @param {number} user user id
     * @param {Record<string, string>[]} [fields]
     * @param {string} [comment]
     * @param {number} [parent] parent id
     * @param {number} [status]
     * @return {Promise<SafeResult<number, Error>>}
     */
    async replaceTask(
        taskId,
        { fields, comment, parent, type, user, status }: TaskMutateInput
    ): Promise<SafeResult<TaskDto, Error>>;

    /**
     *
     * @param {string|number} taskId
     *
     * @param {Record<string, string>[]} fields
     * @param {string} [comment]
     * @param {number} [parent] parent id
     * @param {number} [type] type id
     * @param {number} [user] user id
     * @param {number} [status]
     * @return {Promise<SafeResult<number, Error>>}
     */
    async updateTask(
        taskId,
        { fields, comment, parent, type, user, status }: TaskMutateInput
    ): Promise<SafeResult<TaskDto, Error>>;

    /**
     * @param {number} processId process id
     * @param {number} type type id
     * @param {number} user user id
     * @param {Record<string, string>[]} [fields]
     * @param {string} [comment]
     * @param {number} [parent] parent id
     * @param {number} [status]
     * @return {Promise<SafeResult<number, Error>>}
     */
    async createTask(
        processId: number | string,
        { fields, comment, parent, type, user, status }: TaskMutateInput
    ): Promise<SafeResult<TaskDto, Error>>;

    /**
     *
     * @param {number} taskId
     * @param {number[]|number} processIds
     * @return {Promise<SafeResult<TaskConditionsDto[], Error>>}
     */
    async getTaskConditions(
        taskId: number,
        {
            processIds
        }?: {
            processIds?: number[] | number;
        }
    ): Promise<SafeResult<TaskConditionsDto, Error>>;

    /**
     *
     * @param {number} processId
     * @return {Promise<SafeResult<ProcessDto, Error>>}
     */
    async getProcessById({ processId }: { processId: number }): Promise<SafeResult<ProcessDto, Error>>;

    /**
     *
     * @return {Promise<SafeResult<ProcessDto[], Error>>}
     */
    async getProcess(): Promise<SafeResult<ProcessDto[], Error>>;

    /**
     *
     * @return {Promise<SafeResult<ProcessTypeDto[], Error>>}
     */
    async getProcessTypes(): Promise<SafeResult<ProcessTypeDto[], Error>>;

    /**
     *
     * @return {Promise<SafeResult<ProcessStageTypeDto[], Error>>}
     */
    async getProcessStageTypes(): Promise<SafeResult<ProcessStageTypeDto[], Error>>;

    /**
     * @description Создание процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/createProcessNew
     *
     * @param {string} name
     * @param {string} params
     * @param {number} type_id
     * @param {number} is_startable
     * @param {string} date_to
     * @param {string} date_block
     * @param {string} date_end
     * @param {string} date_start
     * @param {string} date_end_confirm
     * @param {string} date_start_confirm
     * @return {Promise<SafeResult<number, Error>>}
     */
    async createProcess({
        name,
        params,
        type_id,
        is_startable,
        date_to,
        date_block,
        date_end,
        date_start,
        date_end_confirm,
        date_start_confirm
    }: {
        name?: string;
        params?: string;
        type_id?: number;
        is_startable?: number;
        date_to?: string;
        date_block?: string;
        date_end?: string;
        date_start?: string;
        date_end_confirm?: string;
        date_start_confirm?: string;
    }): Promise<SafeResult<number, Error>>;

    /**
     * @description Создание этапа процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/createProcessStage
     *
     * @param {string} params
     * @param {number} process_id
     * @param {number} stage_type_id
     * @param {string} date_to
     * @param {string} date_start
     * @param {string} date_end
     * @param {string} date_start_confirm
     * @param {string} date_end_confirm
     * @return {Promise<SafeResult<ProcessStageDto, Error>>}
     */
    createProcessStage({
        params,
        process_id,
        stage_type_id,
        date_to,
        date_start,
        date_end,
        date_start_confirm,
        date_end_confirm
    }: {
        params?: string;
        process_id?: number;
        stage_type_id?: number;
        date_to?: string;
        date_start?: string;
        date_end?: string;
        date_start_confirm?: string;
        date_end_confirm?: string;
    }): Promise<SafeResult<ProcessStageDto, Error>>;

    /**
     * @description Изменение процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/updateProcessNew
     *
     * @param {number} processId
     * @param {string} name
     * @param {string} params
     * @param {number} type_id
     * @param {number} is_startable
     * @param {string} date_to
     * @param {string} date_block
     * @param {string} date_start_confirm
     * @param {string} date_end_confirm
     * @param {string} date_start
     * @param {string} date_end
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    async updateProcess(
        processId: number,
        {
            name,
            params,
            type_id,
            is_startable,
            date_to,
            date_block,
            date_start_confirm,
            date_end_confirm,
            date_start,
            date_end
        }: {
            name?: string;
            params?: string;
            type_id?: number;
            is_startable?: number;
            date_to?: string;
            date_block?: string;
            date_start_confirm?: string;
            date_end_confirm?: string;
            date_start?: string;
            date_end?: string;
        }
    ): Promise<SafeResult<boolean, Error>>;

    /**
     * @description Обновление этапа процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/updateProcessStage
     *
     * @param {number} processStageId
     * @param {string} params
     * @param {number} process_id
     * @param {number} stage_type_id
     * @param {string} date_to
     * @param {string} date_start
     * @param {string} date_end
     * @param {string} date_start_confirm
     * @param {string} date_end_confirm
     * @return {Promise<SafeResult<ProcessStageDto, Error>>}
     */
    updateProcessStage(
        processStageId: number,
        {
            params,
            process_id,
            stage_type_id,
            date_to,
            date_start,
            date_end,
            date_start_confirm,
            date_end_confirm
        }: {
            params?: string;
            process_id?: number;
            stage_type_id?: number;
            date_to?: string;
            date_start?: string;
            date_end?: string;
            date_start_confirm?: string;
            date_end_confirm?: string;
        }
    ): Promise<SafeResult<ProcessStageDto, Error>>;

    /**
     * Retrieves tasks by filter
     *
     * @param {TaskFilterInput} filter
     * @return {Promise<SafeResult<TaskDto[], Error>>} result
     */
    async getTasksByFilter({
        taskIds,
        taskTypeIds,
        userIds,
        parentIds,
        processId,
        processTypeId,
        taskFieldTypeId,
        taskFieldValue,
        taskField,
        rootId
    }: TaskFilterInput): Promise<SafeResult<TaskDto[], Error>>;

    /**
     * Retrieves process-task bindings by filter
     *
     * @param {import("./types").ProcessTaskBindingFilterInput} filter
     * @return {Promise<SafeResult<ProcessTaskBindingDto[], Error>>} result
     */
    async getProcessTaskBindingsByFilter({
        taskId,
        processId
    }: ProcessTaskBindingFilterInput): Promise<SafeResult<ProcessTaskBindingDto[], Error>>;

    /**
     * Получение типа задачи `TaskTypeDto` по id
     *
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/getTaskType
     * @return {Promise<SafeResult<TaskTypeDto, Error>>}
     */
    async getTaskTypeById(taskTypeId): Promise<SafeResult<TaskTypeDto, Error>>;

    /**
     * @description Метод загрузки файла на сервер.
     *
     * @param {Object} taskParams
     * @param {number} taskParams.taskId
     * @param {number} taskParams.taskTypeFieldId
     * @param {Object} formData
     *
     * @return {Promise<SafeResult<Object, Error>>}
     */
    uploadFile(
        {
            taskId,
            taskTypeFieldId
        }: {
            taskId: number;
            taskTypeFieldId: number;
        } = {},
        formData: Object
    ): Promise<SafeResult<Object, Error>>;

    /**
     **
     * @description Удаление цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/deleteTask
     *
     * @param {number} taskId task id
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    deleteTask(taskId: number): Promise<SafeResult<boolean, Error>>;

    /**
     **
     * @description Удаление целей по массиву идентификаторов
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/deleteTask
     *
     * @param {number[]} taskIds task ids
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    deleteTasks(taskIds: number[]): Promise<SafeResult<boolean, Error>>;

    /**
     * @descriptionМетод получения файла
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/file/downloadFile
     *
     * @param {number} taskFieldId
     * @return {Promise<SafeResult<Object, Error>>}
     */
    downloadFileByTaskFieldId(taskFieldId): Promise<SafeResult<Object, Error>>;

    /**
     * @description Метод массового изменения статуса целей/задач
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/statusChangeBulk
     *
     * @param {Object} params
     * @param {number[]|number} params.userIds - Массив идентификаторов пользователей для фильтрации
     * @param {number[]|number} params.taskTypeIds - Массив идентификаторов типов цели для фильтрации
     * @param {number[]} [params.statusIds] - Массив идентификаторовтекущих статусов для фильтрации
     * @param {number[]} [params.processIds] - Массив идентификаторов процессов для фильтрации
     * @param {number[]|number} targetStatusId - Массив идентификаторов новых статусов для обновления
     *
     * @return {Promise<SafeResult<Object, Error>>}
     */
    updateTasksStatuses(
        {
            userIds,
            taskTypeIds,
            statusIds,
            processIds
        }: {
            userIds: number[];
            taskTypeIds: number[];
            statusIds?: number[] | null;
            processIds?: number[] | null;
        },
        targetStatusId: number | number[]
    ): Promise<SafeResult<Object, Error>>;

    /**
     * @description Изменение целей
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/updateTask
     *
     * @param { TaskBatchUpdateInput[] } tasks
     * @return {Promise<SafeResult<number[], Error>>}
     */
    updateTasks(tasks: TaskBatchUpdateInput[]): Promise<SafeResult<number[], Error>>;

    /**
     *
     * @param {number} processId
     * @param {Object} [filters]
     * @param {string} [filters.externalId]
     * @param {string} [filters.dateStartStart]
     * @param {string} [filters.dateStartEnd]
     * @param {string} [filters.dateEndStart]
     * @param {string} [filters.dateEndEnd]
     * @param {Object} [options]
     * @param {boolean} [options.withClosed]
     * @return {Promise<SafeResult<ProcessStageDto[], Error>>}
     */
    getProcessStagesByFilter(
        processId: number,
        {
            externalId,
            dateStartStart,
            dateStartEnd,
            dateEndStart,
            dateEndEnd
        }?: {
            externalId?: string;
            dateStartStart?: string;
            dateStartEnd?: string;
            dateEndStart?: string;
            dateEndEnd?: string;
        },
        { withClosed }?: { withClosed?: boolean }
    ): Promise<SafeResult<ProcessStageDto[], Error>>;

    /**
     * @description поиск типа таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/taskTypeFind
     *
     * @param {number[]} taskTypeIds
     * @param {Object} [filters]
     * @param {number} filters.parentId
     * @param {boolean} filters.useParentFilter - флаг, который отвечает за передачу параметра parentId
     * @return {Promise<SafeResult<TaskTypeDto[], Error>>}
     */
    getTaskTypesByIds(
        taskTypeIds: number[],
        { parentId, useParentFilter }?: { parentId?: number; useParentFilter?: boolean }
    ): Promise<SafeResult<TaskTypeDto[], Error>>;

    /**
     * @description Получение информации о модулях
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/module/getModuleAll
     *
     * @return {Promise<SafeResult<ModuleDto[], Error>>}
     */
    getModules(): Promise<SafeResult<ModuleDto[], Error>>;

    /**
     * @description Получение информации о типах доступа
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/access_type/getAccessType
     *
     * @return {Promise<SafeResult<AccessTypeDto[], Error>>}
     */
    getAccessTypes(): Promise<SafeResult<AccessTypeDto[], Error>>;

    /**
     * @description Получение информации о типах пользователя
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/user_type/getUserTypeAll
     *
     * @return {Promise<SafeResult<UserTypeDto[], Error>>}
     */
    getUserTypes(): Promise<SafeResult<UserTypeDto[], Error>>;

    /**
     * @description Получение информации о группах полей таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_group/getTaskTypeFieldGroupAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldGroupDto[], Error>>}
     */
    getTaskTypeFieldGroups(): Promise<SafeResult<TaskTypeFieldGroupDto[], Error>>;

    /**
     * @description Получение информации о типах полей таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_type/getTaskTypeFieldTypeAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>}
     */
    getTaskTypeFieldTypes(): Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>;

    /**
     * @description Создание типа цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/createTaskType
     *
     * @param {TaskTypeInputDto} taskType
     *
     * @return {Promise<SafeResult<number, Error>>}
     */
    createTaskType(taskType: TaskTypeInputDto): Promise<SafeResult<number, Error>>;

    /**
     * @description Изменение типа цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/updateTaskType
     *
     * @param {number} id
     * @param {TaskTypeInputDto} taskType
     *
     * @return {Promise<SafeResult<number, Error>>}
     */
    updateTaskType(id: number, taskType: TaskTypeInputDto): Promise<SafeResult<number, Error>>;

    /**
     * @description Получение всех связей компонентов и полей типа таска (цели)
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component_task_type_field/getAllComponentTaskTypeField
     *
     *
     * @return {Promise<SafeResult<ComponentTaskTypeFieldDto[], Error>>}
     */
    getComponentTaskTypeFields(): Promise<SafeResult<ComponentTaskTypeFieldDto[], Error>>;

    /**
     * @description Удаление типов целей по массиву идентификаторов
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/deleteTask
     *
     * @param {number|string} id
     * @return {Promise<SafeResult<Object, Error>>}
     */
    deleteTaskType(id: number | string): Promise<SafeResult<Object, Error>>;

    competence: {
        /**
         * @description Добавление и отображение комментария к уровню развития компетенции
         * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/BFF/getOrCreateTaskFieldCommentForBff
         *
         * @param {number} taskId - Идентификатор задачи
         * @param {Object} options - Объект с данными комментария
         * @param {string} options.comment - Текст комментария
         * @param {boolean} options.commentHidden - Флаг скрытости комментария
         *
         * @returns {Promise<SafeResult<CompetenceCommentDto, Error>>}
         */
        addCompetenceComment(taskId: number, {
            comment,
            commentHidden
        }: {
            comment: string;
            commentHidden: boolean;
        }): Promise<SafeResult<CompetenceCommentDto, Error>>;
    }
}
