import { ApiClientMethod } from '@goodt-common/api';

export const ServiceAction = {
    TASK_TREES_GET: {
        url: 'task/trees',
        resultTransformer: (result) => result.flatMap(({ tree }) => tree),
        options: {
            method: ApiClientMethod.POST,
            // use caching for `POST` method
            cache: true,
            paramsSerializer: (params) => new URLSearchParams(params)
        }
    },
    TASK_CONDITIONS_GET: { url: 'task/conditions' },
    TASK_LINKLIST_GET: {
        url: 'task/linklist/array',
        options: {
            paramsSerializer: (params) => new URLSearchParams(params)
        }
    },
    TASK_LINK_UPDATE: {
        url: 'task/linkupdate',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_LINK_TYPE: {
        url: 'task/linktype'
    },
    TASK_INFO_GET: { url: 'task/info' },
    TASK_TYPE_GET: { url: 'tasktype/:id' },
    TASK_REPLACE: { url: '/task/update/:id', options: { method: ApiClientMethod.PUT } },
    TASK_CREATE: { url: '/task/update', options: { method: ApiClientMethod.POST } },
    TASK_UPDATE: { url: '/task/update', options: { method: ApiClientMethod.POST } },
    TASK_UPDATE_PUT: { url: '/task/update', options: { method: ApiClientMethod.PUT } },
    TASK_STATUS_UPDATE: {
        url: 'task/statuschange',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_DELETE: {
        url: 'task/delete',
        options: {
            method: ApiClientMethod.POST
        }
    },
    DELETE_LINK: {
        url: 'task/linkdelete/:id',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_FIND: {
        url: 'task/find',
        options: {
            method: ApiClientMethod.POST,
            // use caching for `POST` method
            cache: true
        }
    },
    TASK_HISTORY_GET: { url: 'task/history' },
    PROCESS_TASK_BINDINGS_GET: {
        url: 'processtask/find'
    },
    PROCESS_GET_BY_ID: {
        url: 'process/:id'
    },
    PROCESSES_GET_BY_FILTER: {
        url: 'process'
    },
    PROCESS_GET_TYPES: {
        url: 'process/type'
    },
    PROCESS_CREATE: {
        url: 'process',
        options: {
            method: ApiClientMethod.POST
        }
    },
    PROCESS_UPDATE: {
        url: 'process/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    PROCESS_DELETE: {
        url: 'process/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    PROCESS_STAGE_GET_BY_ID: {
        url: 'process/stage/:id'
    },
    PROCESS_STAGE_GET_TYPES: {
        url: 'process/stage_type'
    },
    PROCESS_STAGE_GET: {
        url: 'process/stage'
    },
    PROCESS_STAGE_CREATE: {
        url: 'process/stage',
        options: {
            method: ApiClientMethod.POST
        }
    },
    PROCESS_STAGE_UPDATE: {
        url: 'process/stage/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    PROCESS_STAGE_DELETE: {
        url: 'process/stage/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    FILE_UPLOAD_POST: {
        url: 'file/upload',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'Content-Type': 'multipart/form-data'
            }
        }
    },
    FILE_DOWNLOAD_GET: {
        url: 'file/download/:taskFieldId',
        options: {
            responseType: 'blob',
            // eslint-disable-next-line no-restricted-syntax
            transformResponse: [
                (data, headers) => ({
                    headers,
                    data
                })
            ]
        }
    },
    TASK_STATUS_CHANGE_BULK_POST: {
        url: 'task/statuschangebulk',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_FIND_POST: {
        url: 'tasktype/find',
        options: {
            method: ApiClientMethod.POST
        }
    },
    MODULE_GET: {
        url: 'module'
    },
    ACCESS_TYPE_GET: {
        url: 'accesstype'
    },
    USER_TYPE_GET: {
        url: 'usertype'
    },
    TASK_TYPE_FIELD_GROUP_GET: {
        url: 'tasktypefieldgroup'
    },
    TASK_TYPE_FIELD_TYPE_GET: {
        url: 'tasktypefieldtype'
    },
    TASK_TYPE_UPDATE_POST: {
        url: 'tasktype/update',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_UPDATE_PUT: {
        url: 'tasktype/update',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    TASK_TYPE_FIELD_DELETE_POST: {
        url: 'tasktypefield/delete',
        options: {
            method: ApiClientMethod.POST
        }
    },
    COMPONENT_TASK_TYPE_FIELD_GET: {
        url: 'componenttasktypefield'
    },
    TASK_TYPE_DELETE_POST: {
        url: 'tasktype/delete',
        options: {
            method: ApiClientMethod.POST
        }
    },
    BFF_COMPETENCE_ADD_COMMENT_POST: {
        url: 'bff/competence/addcomment',
        options: {
            method: ApiClientMethod.POST
        }
    }
};
