import { BaseApiService } from '@goodt-common/api';
import { SafeResult } from '@goodt-common/utils';
import {
    TaskDto,
    UserTaskTreeDto,
    TaskLinkDto,
    TaskMutateInput,
    TaskConditionsDto,
    ProcessDto,
    ProcessTypeDto,
    ProcessStageTypeDto,
    ProcessTaskBindingDto,
    TaskLinkTypeDto,
    TaskTypeDto,
    ProcessStageDto,
    TaskBatchUpdateInput,
    ModuleDto,
    AccessTypeDto,
    UserTypeDto,
    TaskTypeFieldGroupDto,
    TaskTypeFieldTypeDto,
    ComponentTaskTypeFieldDto,
    TaskTypeInputDto,
    TaskTypeParentPermissionInput,
    TaskCreateInputDto,
    TaskAvailableStatusDto,
    ComponentFieldDto,
    ComponentFieldShortDto,
    ComponentFieldInheritanceDto,
    OperationResultDto,
    TaskFieldInfoDto,
    ConditionGroupDto,
    TaskTypeFieldFloatConfigurationDto,
    ConditionDto,
    ConditionInput,
    ConditionKindDto,
    ComparisonSignDto,
    ConditionModifierKindDto,
    ConditionModifierKindConditionKindDto,
    ConditionModifierDto,
    TaskTypeRoleDto,
    TaskTypeRolePermissionDto,
    TaskTypeRolePermissionFieldRestrictionDto,
    MemberDto,
    ProcessMemberDto,
    StatusDto,
    StatusInput,
    StatusChangeRuleDto,
    ProcessStageGroupDto,
    SystemStatusDto,
    TaskTypeFieldDictionaryConfigurationDto,
    ScaleDto,
    DictionaryServiceDto,
    DictionaryEntityInfoDto,
    TypeDictionaryInput,
    BasicDataTypeDto,
    TaskTypeFieldDto,
    TaskTypeFieldDictionaryConfigurationInput,
    TaskTypeFieldDictionaryConfigurationUpdateInput,
    CustomDictionaryDto,
    CustomDictionaryInput,
    CustomDictionaryColumnDto,
    CustomDictionaryColumnInput,
    CustomDictionaryColumnRowInput,
    CustomDictionaryColumnRowDto,
    CustomDictionaryColumnRowsPage,
    CustomDictionaryFilterInput,
    ProcessInput,
    DictionaryMetaDataDto,
    TaskTypeFieldInheritanceValueDto,
    MemberGroupDto,
    TaskRawDataDto,
    TaskTypeParentPermissionDto,
    EvaluationScaleDto,
    RoleInfoDto
} from './dto';

import {
    CustomDictionaryColumnRowsFilterInput,
    CustomDictionaryColumnRowsOptionsInput,
    CustomDictionaryColumnsFilterInput,
    ProcessInfosFilterInput,
    ProcessTaskBindingFilterInput,
    TaskStatusUpdateInput,
    TaskFilterInput,
    TaskRawDataInput,
    MemberGroupInput,
    StatusChangeRuleInput
} from './type';

export class TaskSettingsApiService extends BaseApiService {
    /**
     * Получение списка сущностей "пользовательское дерево задач" для списка заданных идентификаторов
     * пользователей и заданного типа задачи
     *
     * @param {number|number[]} userIds - Массив идентификаторов пользователей
     * @param {number} typeId - Идентификатор типа цели
     * @param {Object} [options={}]
     * @param {number} options.processTypeId - Идентификатор типа процесса
     * @param {number} options.level - Идентификатор уровня
     * @param {boolean} options.history - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {number[]} options.processIds - Массив идентификаторов процессов
     * @param {boolean} options.withClosedTask - Этот флаг устанавливает следующее: если true - то выведутся все цели, если false - выведутся только незавершённые цели
     * @param {boolean} options.withClosedTaskField - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {boolean} options.rootOnly - Этот флаг устанавливает следующее: если true - то выведутся только рутовые цели, если false - выведутся все имеющиеся цели
     * @return {Promise<SafeResult<UserTaskTreeDto[], Error>>}
     */
    getUserTaskTrees(
        userIds: number | number[],
        typeId: number,
        {
            processTypeId,
            level,
            history,
            processIds,
            withClosedTask,
            withClosedTaskField,
            rootOnly
        }?: {
            processTypeId?: number;
            level?: number;
            history?: boolean;
            processIds?: number[];
            withClosedTask?: boolean;
            withClosedTaskField?: boolean;
            rootOnly?: boolean;
        } = {}
    ): Promise<SafeResult<UserTaskTreeDto[], Error>>;

    /**
     * Получение списка сущностей "задача" (одного "дерева" задач) для заданного пользователя
     * и заданного типа задачи
     *
     * @param {number} userId - - Идентификатор пользователя
     * @param {number} typeId  - Идентификатор типа цели
     * @param {Object} [options={}]
     * @param {number} options.processTypeId - Идентификатор типа процесса
     * @param {number} options.level - Идентификатор уровня
     * @param {boolean} options.history - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {number[]} options.processIds - Массив идентификаторов процессов
     * @param {boolean} options.withClosedTask - Этот флаг устанавливает следующее: если true - то выведутся все цели, если false - выведутся только незавершённые цели
     * @param {boolean} options.withClosedTaskField - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {boolean} options.rootOnly - Этот флаг устанавливает следующее: если true - то выведутся только рутовые цели, если false - выведутся все имеющиеся цели
     * @return {Promise<SafeResult<TaskDto[], Error>>}
     */
    getTaskTree(
        userId: number,
        typeId: number,
        {
            processTypeId,
            level,
            history,
            processIds,
            withClosedTask,
            withClosedTaskField
        }?: {
            processTypeId?: number;
            level?: number;
            history?: boolean;
            processIds?: number[];
            withClosedTask?: boolean;
            withClosedTaskField?: boolean;
            rootOnly?: boolean;
        } = {}
    ): Promise<SafeResult<TaskDto[], Error>>;

    /**
     *
     * @param {number|number[]} userIds
     * @param {number|number[]} taskLinkTypeIds
     * @param {number} taskToId
     * @param {number} withTaskFromClosed
     * @param {number} withTaskToClosed
     * @param {number} taskFromUserId
     * @param {number} taskToUserId
     * @param {number} taskLinkTypeIds
     * @param {number}
     * @return {Promise<SafeResult<TaskLinkDto[], Error>>}
     */
    async getTaskLinks({
        userIds,
        taskLinkTypeIds,
        taskFromId,
        taskToId,
        withTaskFromClosed,
        withTaskToClosed,
        taskFromUserId,
        taskToUserId
    }: {
        userIds?: number[];
        taskLinkTypeIds?: number[];
        taskFromId?: number;
        taskToId?: number;
        withTaskFromClosed?: number;
        withTaskToClosed?: boolean;
        taskFromUserId?: number;
        taskToUserId?: number;
    }): Promise<SafeResult<TaskLinkDto[], Error>>;

    /**
     *
     * @param {number|number[]} taskId
     * @return {Promise<SafeResult<TaskDto, Error>>}
     */
    getTaskById(taskId: number): Promise<SafeResult<TaskDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/
     * @description Получение списка связей целей с возможностью передачей массивов для параметров task_user_id_from, task_user_id_to, task_id_from и task_id_to.
     *
     * @param {Object} params
     * @param {number|number[]} params.userIds - Массив идентификаторов пользователей
     * @param {number|number[]} [params.taskLinkTypeIds] - Массив идентификаторов типов ссылки на цели
     * @param {number|number[]} [params.taskFromId] - Массив идентификаторов начальной цели
     * @param {number|number[]} [params.taskToId] - Массив идентификаторов конечной цели
     * @param {boolean} [params.withTaskFromClosed] - false - в результате получим связи только с открытыми начальными целями, true - будем получать связи даже с закрытими начальными целями
     * @param {boolean} [params.withTaskToClosed] - false - в результате получим связи только с открытыми конечными целями, true - будем получать связи даже с закрытими конечными целями
     * @param {number|number[]} [params.taskFromUserId] - Массив идентификаторов пользователей начальной цели
     * @param {number|number[]} [params.taskToUserId] - Массив идентификаторов пользователей конечной цели
     * @param {number} [params.taskLinkId] - Идентификатор связи целей
     * @return {Promise<SafeResult<TaskLinkDto[], Error>>}
     */
    async getTaskLinksByFilter({
        userIds,
        taskLinkTypeIds,
        taskFromId,
        taskToId,
        withTaskFromClosed,
        withTaskToClosed,
        taskFromUserId,
        taskToUserId,
        taskLinkId
    }: {
        userIds?: number[];
        taskLinkTypeIds?: number[];
        taskFromId?: number;
        taskToId?: number;
        withTaskFromClosed?: number;
        withTaskToClosed?: boolean;
        taskFromUserId?: number;
        taskToUserId?: number;
        taskLinkId?: number;
    }): Promise<SafeResult<TaskLinkDto[], Error>>;

    /**
     * Изменение связи цели
     *
     * @param {number} linkId
     * @param {number} task_id_from
     * @param {number} task_link_type_id
     * @param {number} task_id_to
     * @param {string}date_from
     * @param {string} date_to
     * @return {Promise<SafeResult<Number, Error>>}
     */
    async updateTaskLink(
        linkId,
        { task_id_from, task_link_type_id, task_id_to, date_from, date_to }
    ): Promise<SafeResult<Number, Error>>;

    /**
     * Получение списка типов связей
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/getTaskLinkTypeByIds
     *
     * @param {number} linkTypeId
     * @return {Promise<SafeResult<TaskLinkTypeDto[], Error>>}
     */
    async getTaskLinkTypes(linkTypeId): Promise<SafeResult<TaskLinkTypeDto[], Error>>;

    /**
     * Создание связи цели
     *
     * @param {number} task_id_from
     * @param {number} task_link_type_id
     * @param {number} task_id_to
     * @param {string}date_from
     * @param {string} date_to
     * @return {Promise<SafeResult<Number, Error>>}
     */
    async createTaskLink({
        task_id_from,
        task_link_type_id,
        task_id_to,
        date_from,
        date_to
    }): Promise<SafeResult<Number, Error>>;

    /**
     *
     * @param {number} id
     * @return {Promise<SafeResult<TaskLinkDto, Error>>}
     */
    async getTaskLinkById(id: number): Promise<SafeResult<TaskLinkDto, Error>>;

    /**
     *
     * @param {string|number} taskId
     *
     * @param {number} type type id
     * @param {number} user user id
     * @param {Record<string, string>[]} [fields]
     * @param {string} [comment]
     * @param {number} [parent] parent id
     * @param {number} [status]
     * @return {Promise<SafeResult<number, Error>>}
     */
    async replaceTask(
        taskId,
        { fields, comment, parent, type, user, status }: TaskMutateInput
    ): Promise<SafeResult<TaskDto, Error>>;

    /**
     *
     * @param {string|number} taskId
     *
     * @param {Record<string, string>[]} fields
     * @param {string} [comment]
     * @param {number} [parent] parent id
     * @param {number} [type] type id
     * @param {number} [user] user id
     * @param {number} [status]
     * @return {Promise<SafeResult<number, Error>>}
     */
    async updateTask(
        taskId,
        { fields, comment, parent, type, user, status }: TaskMutateInput
    ): Promise<SafeResult<TaskDto, Error>>;

    /**
     **
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/createTask
     * @description Создание цели
     *
     * @param {number|string} processId process id
     *
     * @param {TaskCreateInputDto} task
     * @param {number|string} taskTypeRoleId
     * @return {Promise<SafeResult<number, Error>>}
     */
    async createTask(
        processId: number | string,
        task: TaskCreateInputDto,
        { taskTypeRoleId }?: { taskTypeRoleId: number | string }
    ): Promise<SafeResult<number, Error>>;

    /**
     *
     * @param {number} taskId
     * @param {number[]|number} processIds
     * @return {Promise<SafeResult<TaskConditionsDto[], Error>>}
     */
    async getTaskConditions(
        taskId: number,
        {
            processIds
        }?: {
            processIds?: number[] | number;
        }
    ): Promise<SafeResult<TaskConditionsDto, Error>>;

    /**
     *
     * @param {number} processId
     * @return {Promise<SafeResult<ProcessDto, Error>>}
     */
    async getProcessById({ processId }: { processId: number }): Promise<SafeResult<ProcessDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/getProcessListNew
     * @description НОВЫЙ МЕТОД!!! Получение информации о всех процессах
     *
     * @param {import("./type").ProcessInfosFilterInput} filter
     * @return {Promise<SafeResult<ProcessInfoDto[], Error>>}
     */
    async getProcessInfos({
        typeCode,
        externalId,
        date,
        stageDate
    }: ProcessInfosFilterInput): Promise<SafeResult<ProcessInfoDto[], Error>>;

    /**
     *
     * @return {Promise<SafeResult<ProcessDto[], Error>>}
     */
    async getProcess(): Promise<SafeResult<ProcessDto[], Error>>;

    /**
     *
     * @return {Promise<SafeResult<ProcessTypeDto[], Error>>}
     */
    async getProcessTypes(): Promise<SafeResult<ProcessTypeDto[], Error>>;

    /**
     *
     * @return {Promise<SafeResult<ProcessStageTypeDto[], Error>>}
     */
    async getProcessStageTypes(): Promise<SafeResult<ProcessStageTypeDto[], Error>>;

    /**
     * @description Создание процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/createProcessNew
     *
     * @param {string} name
     * @param {string} params
     * @param {number} is_startable
     * @param {string} date_to
     * @param {string} date_block
     * @param {string} date_end
     * @param {string} date_start
     * @param {string} date_end_confirm
     * @param {string} date_start_confirm
     * @param {string} type_code
     * @return {Promise<SafeResult<number, Error>>}
     */
    async createProcess({
        name,
        params,
        is_startable,
        date_to,
        date_block,
        date_end,
        date_start,
        date_end_confirm,
        date_start_confirm,
        type_code
    }: {
        name?: string;
        params?: string;
        type_id?: number;
        is_startable?: number;
        date_to?: string;
        date_block?: string;
        date_end?: string;
        date_start?: string;
        date_end_confirm?: string;
        date_start_confirm?: string;
        type_code?: string;
    }): Promise<SafeResult<number, Error>>;

    /**
     * @description Создание этапа процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/createProcessStage
     *
     * @param {ProcessStageInput} processStage
     * @return {Promise<SafeResult<ProcessStageDto, Error>>}
     */
    createProcessStage(processStage: ProcessStageInput): Promise<SafeResult<ProcessStageDto, Error>>;

    /**
     * @description Изменение процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/updateProcessNew
     *
     * @param {number} processId
     * @param {ProcessInput} process
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    async updateProcess(processId: number, process: ProcessInput): Promise<SafeResult<boolean, Error>>;

    /**
     * @description Обновление этапа процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/updateProcessStage
     *
     * @param {number} processStageId
     * @param {ProcessStageInput} processStage
     *
     * @return {Promise<SafeResult<ProcessStageDto, Error>>}
     */
    updateProcessStage(
        processStageId: number,
        processStage: ProcessStageInput
    ): Promise<SafeResult<ProcessStageDto, Error>>;

    /**
     * Find tasks (exactly filter tasks)
     *
     * @param {import("./type").TaskFilterInput} filter
     * @param {Object} options
     * @param {number} options.taskTypeRoleId - ИД связь типа таска и роли
     * @param {number} options.page
     * @param {number} options.size
     * @return {Promise<SafeResult<TaskDto[], Error>>} result
     */
    async getTasksByFilter(
        {
            taskIds,
            taskTypeIds,
            userIds,
            parentIds,
            processId,
            processTypeId,
            taskFieldTypeId,
            taskFieldValue,
            taskField,
            rootId,
            taskTypeRoleId
        }: TaskFilterInput,
        { taskTypeRoleId, page, size }?: { taskTypeRoleId: number; page: number; size: number }
    ): Promise<SafeResult<TaskDto[], Error>>;

    /**
     * Retrieves process-task bindings by filter
     *
     * @param {import("./type").ProcessTaskBindingFilterInput} filter
     * @return {Promise<SafeResult<ProcessTaskBindingDto[], Error>>} result
     */
    async getProcessTaskBindingsByFilter({
        taskId,
        processId
    }: ProcessTaskBindingFilterInput): Promise<SafeResult<ProcessTaskBindingDto[], Error>>;

    /**
     * Получение типа задачи `TaskTypeDto` по id
     *
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/getTaskType
     * @return {Promise<SafeResult<TaskTypeDto, Error>>}
     */
    async getTaskTypeById(taskTypeId): Promise<SafeResult<TaskTypeDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/getAllTaskType
     * @description Получение списка типов целей (тасков)
     *
     *
     * @return {Promise<SafeResult<TaskTypeDto[], Error>>}
     */
    async getTaskTypes(): Promise<SafeResult<TaskTypeDto[], Error>>;

    /**
     * @description Метод загрузки файла на сервер.
     *
     * @param {Object} taskParams
     * @param {number} taskParams.taskId
     * @param {number} taskParams.taskTypeFieldId
     * @param {Object} formData
     *
     * @return {Promise<SafeResult<Object, Error>>}
     */
    uploadFile(
        {
            taskId,
            taskTypeFieldId
        }: {
            taskId: number;
            taskTypeFieldId: number;
        } = {},
        formData: Object
    ): Promise<SafeResult<Object, Error>>;

    /**
     **
     * @description Удаление цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/deleteTask
     *
     * @param {number} taskId task id
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    deleteTask(taskId: number): Promise<SafeResult<boolean, Error>>;

    /**
     **
     * @description Удаление целей по массиву идентификаторов
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/deleteTask
     *
     * @param {number[]} taskIds task ids
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    deleteTasks(taskIds: number[]): Promise<SafeResult<boolean, Error>>;

    /**
     * @descriptionМетод получения файла
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/file/downloadFile
     *
     * @param {number} taskFieldId
     * @return {Promise<SafeResult<Object, Error>>}
     */
    downloadFileByTaskFieldId(taskFieldId): Promise<SafeResult<Object, Error>>;

    /**
     * @description Метод массового изменения статуса целей/задач
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/statusChangeBulk
     *
     * @param {Object} params
     * @param {number[]|number} params.userIds - Массив идентификаторов пользователей для фильтрации
     * @param {number[]|number} params.taskTypeIds - Массив идентификаторов типов цели для фильтрации
     * @param {number[]} [params.statusIds] - Массив идентификаторовтекущих статусов для фильтрации
     * @param {number[]} [params.processIds] - Массив идентификаторов процессов для фильтрации
     * @param {number[]} [params.taskIds] - Массив идентификаторов задач для фильтрации
     * @param {number[]|number} targetStatusId - Массив идентификаторов новых статусов для обновления
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    updateTasksStatuses(
        {
            userIds,
            taskTypeIds,
            statusIds,
            processIds,
            taskIds
        }: {
            userIds: number[];
            taskTypeIds: number[];
            statusIds?: number[] | null;
            processIds?: number[] | null;
            taskIds?: number[] | null;
        },
        targetStatusId: number | number[]
    ): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @description Изменение целей
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/updateTask
     *
     * @param { TaskBatchUpdateInput[] } tasks
     * @param { Object } options
     * @param { number | string } options.taskTypeRoleId
     * @return {Promise<SafeResult<number[], Error>>}
     */
    updateTasks(
        tasks: TaskBatchUpdateInput[],
        { taskTypeRoleId }?: { taskTypeRoleId: number | string }
    ): Promise<SafeResult<number[], Error>>;

    /**
     *
     * @param {number} processId
     * @param {Object} [filters]
     * @param {string} [filters.externalId]
     * @param {string} [filters.dateStartStart]
     * @param {string} [filters.dateStartEnd]
     * @param {string} [filters.dateEndStart]
     * @param {string} [filters.dateEndEnd]
     * @param {Object} [options]
     * @param {boolean} [options.withClosed]
     * @return {Promise<SafeResult<ProcessStageDto[], Error>>}
     */
    getProcessStagesByFilter(
        processId: number,
        {
            externalId,
            dateStartStart,
            dateStartEnd,
            dateEndStart,
            dateEndEnd
        }?: {
            externalId?: string;
            dateStartStart?: string;
            dateStartEnd?: string;
            dateEndStart?: string;
            dateEndEnd?: string;
        },
        { withClosed }?: { withClosed?: boolean }
    ): Promise<SafeResult<ProcessStageDto[], Error>>;

    /**
     * @description поиск типа таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/taskTypeFind
     *
     * @param {number[]} taskTypeIds
     * @param {Object} [filters]
     * @param {number} filters.parentId
     * @param {boolean} filters.useParentFilter - флаг, который отвечает за передачу параметра parentId
     * @return {Promise<SafeResult<TaskTypeDto[], Error>>}
     */
    getTaskTypesByIds(
        taskTypeIds: number[],
        { parentId, useParentFilter }?: { parentId?: number; useParentFilter?: boolean }
    ): Promise<SafeResult<TaskTypeDto[], Error>>;

    /**
     * @description Получение информации о модулях
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/module/getModuleAll
     *
     * @return {Promise<SafeResult<ModuleDto[], Error>>}
     */
    getModules(): Promise<SafeResult<ModuleDto[], Error>>;

    /**
     * @description Получение информации о типах доступа
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/access_type/getAccessType
     *
     * @return {Promise<SafeResult<AccessTypeDto[], Error>>}
     */
    getAccessTypes(): Promise<SafeResult<AccessTypeDto[], Error>>;

    /**
     * @description Получение информации о типах пользователя
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/user_type/getUserTypeAll
     *
     * @return {Promise<SafeResult<UserTypeDto[], Error>>}
     */
    getUserTypes(): Promise<SafeResult<UserTypeDto[], Error>>;

    /**
     * @description Получение информации о группах полей таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_group/getTaskTypeFieldGroupAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldGroupDto[], Error>>}
     */
    getTaskTypeFieldGroups(): Promise<SafeResult<TaskTypeFieldGroupDto[], Error>>;

    /**
     * @description Получение информации о типах полей таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_type/getTaskTypeFieldTypeAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>}
     */
    getTaskTypeFieldTypes(): Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>;

    /**
     * @description Создание типа цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/createTaskType
     *
     * @param {TaskTypeInputDto} taskType
     *
     * @return {Promise<SafeResult<number, Error>>}
     */
    createTaskType(taskType: TaskTypeInputDto): Promise<SafeResult<number, Error>>;

    /**
     * @description Изменение типа цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/updateTaskType
     *
     * @param {number} id
     * @param {TaskTypeInputDto} taskType
     *
     * @return {Promise<SafeResult<number, Error>>}
     */
    updateTaskType(id: number, taskType: TaskTypeInputDto): Promise<SafeResult<number, Error>>;

    /**
     * @description Получение всех связей компонентов и полей типа таска (цели)
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component_task_type_field/getAllComponentTaskTypeField
     *
     *
     * @return {Promise<SafeResult<ComponentTaskTypeFieldDto[], Error>>}
     */
    getComponentTaskTypeFields(): Promise<SafeResult<ComponentTaskTypeFieldDto[], Error>>;

    /**
     * @description Удаление типов целей по массиву идентификаторов
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/deleteTask
     *
     * @param {number|string} id
     * @return {Promise<SafeResult<Object, Error>>}
     */
    deleteTaskType(id: number | string): Promise<SafeResult<Object, Error>>;

    /**
     * @description Получение информации о типах полей таска
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_type/getTaskTypeFieldTypeAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>}
     */
    getFieldTypes(): Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>;

    /**
     * @description Получение информации о компонентах
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component/getAll
     *
     * @return {Promise<SafeResult<ComponentDto[], Error>>}
     */
    getFieldComponents(): Promise<SafeResult<ComponentDto[], Error>>;

    /**
     * @description Метод создания иерархической подчиненности типов тасков
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_parent_permission/create
     *
     * @param {TaskTypeParentPermissionInput} data - Объект с данными для создания разрешения
     * @param {number} data.taskTypeParentId - Идентификатор родительского типа задач
     * @param {number} data.taskTypeId - Идентификатор типа задачи
     *
     * @return {Promise<SafeResult<TaskTypeParentPermission, Error>>}
     */
    createTaskTypeParentPermission(data: {
        taskTypeParentId: number;
        taskTypeId: number;
    }): Promise<SafeResult<TaskTypeParentPermission, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_parent_permission/delete_1
     * @description Метод удаления иерархической подчиненности типов тасков
     *
     * @param {number} parentTaskTypeId
     * @param {number} childTaskTypeId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeParentPermission({
        parentTaskTypeId,
        childTaskTypeId
    }: {
        parentTaskTypeId: number;
        childTaskTypeId: number;
    }): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @description Метод получения доступных для перехода статусов
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/statusList
     *
     * @param {number|string} taskId - ИД таска
     * @param {Object} [options]
     * @param {boolean} [options.withConditionGroups] - Если false - не раскрывать поле condition_groups (пустой массив). Если true - раскрывать
     * @param {boolean} [options.taskTypeRoleId] - Уникальный идентификатор роли типа задачи
     *
     * @return {Promise<SafeResult<TaskAvailableStatusDto[], Error>>}
     */
    getTaskAvailableStatuses(
        taskId: number,
        { withConditionGroups, taskTypeRoleId }?: { withConditionGroups: boolean; taskTypeRoleId: number }
    ): Promise<SafeResult<TaskAvailableStatusDto[], Error>>;

    /**
     * @description Получение информации о всех полях всех данных из таблицы component_field
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-controller/getAllComponentFieldDto
     *
     * @return {Promise<SafeResult<ComponentFieldDto[], Error>>}
     */
    getComponentFields(): Promise<SafeResult<ComponentFieldDto[], Error>>;

    /**
     * @description Создание информации о полях компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-controller/createComponentField
     *
     * @param {ComponentFieldShortDto} componentField
     *
     * @return {Promise<SafeResult<ComponentFieldDto[], Error>>}
     */
    createComponentField(componentField: ComponentFieldShortDto): Promise<SafeResult<ComponentFieldDto[], Error>>;

    /**
     * @description Предоставление информации о наследовании полей компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-inheritance-controller/create_1
     *
     * @param {number} componentFieldIdFrom
     * @param {number} componentFieldIdTo
     *
     * @return {Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>}
     */
    createComponentFieldInheritance({
        componentFieldIdFrom,
        componentFieldIdTo
    }: {
        componentFieldIdFrom: number;
        componentFieldIdTo: number;
    }): Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>;

    /**
     * @description Удаление информации о наследовании полей компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-inheritance-controller/delete
     *
     * @param {number} componentFieldIdFrom - id поля, из которого наследуется значение
     * @param {number} componentFieldIdTo - id поля, из которого наследуется значение
     *
     * @return {Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>}
     */
    deleteComponentFieldInheritance({
        componentFieldIdFrom,
        componentFieldIdTo
    }: {
        componentFieldIdFrom: number;
        componentFieldIdTo: number;
    }): Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>;

    /**
     * @description Получение информации о наследовании полей компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-inheritance-controller/findComponentFieldInheritance
     *
     * @param {number|string} [componentFieldIdFrom] - id поля, из которого наследуется значение
     * @param {number|string} [componentFieldIdTo] - id поля, из которого наследуется значение
     *
     * @return {Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>}
     */
    getComponentFieldInheritance({
        componentFieldIdFrom,
        componentFieldIdTo
    }?: {
        componentFieldIdFrom: number | string;
        componentFieldIdTo: number | string;
    }): Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/taskStatusChange
     * @description Изменение статуса цели и отправка уведомления владельцу цели либо его руководителю
     *
     * @param {number} taskId task id
     * @param {import("./type").TaskStatusUpdateInput} input
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    async updateTaskStatus(
        taskId: number,
        { statusChangeRuleId, ids, comment }: TaskStatusUpdateInput
    ): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @description Получение всех TaskTypeRole
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllTaskTypeRole
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto[], Error>>}
     */
    getTaskTypeRoles(): Promise<SafeResult<TaskTypeRoleDto[], Error>>;

    /**
     * @description Получение TaskTypeRole
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getTaskTypeRole
     *
     * @param {number|string} taskTypeRoleId
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto[], Error>>}
     */
    getTaskTypeRoleById(taskTypeRoleId: number | string): Promise<SafeResult<TaskTypeRoleDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/createTaskTypeRole
     * @description Создание TaskTypeRole
     *
     * @param {TaskTypeRoleInput} taskTypeRole
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto, Error>>}
     */
    createTaskTypeRole(taskTypeRole: TaskTypeRoleInput): Promise<SafeResult<TaskTypeRoleDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/updateTaskTypeRole
     * @description Обновление TaskTypeRole
     *
     * @param {number} taskTypeRoleId
     * @param {TaskTypeRoleInput} taskTypeRole
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto, Error>>}
     */
    updateTaskTypeRole(
        taskTypeRoleId: number,
        taskTypeRole: TaskTypeRoleInput
    ): Promise<SafeResult<TaskTypeRoleDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/deleteTaskTypeRole
     * @description Удаление TaskTypeRole
     *
     * @param {number} taskTypeRoleId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeRole(taskTypeRoleId: number): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/dictionary/getInfo
     * @description Получение данных справочника Info
     *
     * @param {number[]} taskFieldIds
     *
     * @return {Promise<SafeResult<TaskFieldInfoDto[], Error>>}
     */
    getDictionaryInfo({ taskFieldIds }): Promise<SafeResult<TaskFieldInfoDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/dictionary/getList
     * @description Получение данных справочника List
     *
     * @param {number | string} taskId
     * @param {number[] | string[]} taskTypeFieldId
     *
     * @return {Promise<SafeResult<Object[], Error>>}
     */
    getDictionaries({
        taskId,
        taskTypeFieldIds
    }: {
        taskId: number | string;
        taskTypeFieldIds: number[] | string[];
    }): Promise<SafeResult<Object[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findCondition
     * @description Получение информации об условиях
     *
     * @return {Promise<SafeResult<ConditionDto[], Error>>}
     */
    getConditions(): Promise<SafeResult<ConditionDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionModifierByConditionId
     * @description Получение информации о модификаторах условий. Если condition_id = null - возвращаются все модификаторы, иначе - возвращается список доступных модификаторов для выбранного условия
     *
     * @param {number|string} conditionId
     * @return {Promise<SafeResult<ConditionModifierDto[], Error>>}
     */
    getConditionModifiers({
        conditionId
    }: {
        conditionId: number | string;
    }): Promise<SafeResult<ConditionModifierDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionGroup
     * @description Получение информации о группах условий
     *
     * @return {Promise<SafeResult<ConditionGroupDto[], Error>>}
     */
    getConditionGroups(): Promise<SafeResult<ConditionGroupDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/createConditionGroup
     * @description Создание группы условия
     *
     * @param {ConditionGroupInput} conditionGroup
     * @return {Promise<SafeResult<ConditionGroupDto, Error>>}
     */
    createConditionGroup(conditionGroup: ConditionGroupInput): Promise<SafeResult<ConditionGroupDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/updateConditionGroup
     * @description Обновление группы условия
     *
     * @param {number} conditionGroupId
     *
     * @param {ConditionGroupInput} conditionGroup
     *
     * @return {Promise<SafeResult<ConditionGroupDto, Error>>}
     */
    updateConditionGroup(
        conditionGroupId: number,
        conditionGroup: ConditionGroupInput
    ): Promise<SafeResult<ConditionGroupDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/deleteConditionGroup
     * @description Удаление группы условия
     *
     * @param {number | string} id
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteConditionGroup(id: number | string): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/createCondition
     * @description Создание условия
     *
     * @param {ConditionInput} condition
     *
     * @return {Promise<SafeResult<ConditionDto, Error>>}
     */
    createCondition(condition: ConditionInput): Promise<SafeResult<ConditionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/updateCondition
     * @description Обновление условия
     *
     * @param {number} conditionId
     * @param {ConditionInput} condition
     *
     * @return {Promise<SafeResult<ConditionDto, Error>>}
     */
    updateCondition(conditionId: number, condition: ConditionInput): Promise<SafeResult<ConditionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/createConditionModifier
     * @description Создание модификатора условия
     *
     * @param {ConditionModifierInput} conditionModifier
     *
     * @return {Promise<SafeResult<ConditionModifierDto, Error>>}
     */
    createConditionModifier(
        conditionModifier: ConditionModifierInput
    ): Promise<SafeResult<ConditionModifierDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/updateConditionModifier
     * @description Обновление модификатора условия
     *
     * @param {number} conditionModifierId
     * @param {ConditionModifierInput} conditionModifier
     *
     * @return {Promise<SafeResult<ConditionModifierDto, Error>>}
     */
    updateConditionModifier(
        conditionModifierId: number,
        conditionModifier: ConditionModifierInput
    ): Promise<SafeResult<ConditionModifierDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/deleteConditionModifier
     * @description Удаление модификатора условия
     *
     * @param {number} conditionModifierId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteConditionModifier(conditionModifierId: number): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/findProcessStageTask
     * @description Получение информации о связях этапа процесса и цели
     *
     * @param {number | string} processStageId
     * @param {number[] | string[]} taskIds
     *
     * @return {Promise<SafeResult<ProcessTaskBindingDto[], Error>>}
     */
    getProcessStageTaskBindings({
        processStageId,
        taskIds
    }: {
        processStageId: number | string;
        taskIds: number[] | string[];
    }): Promise<SafeResult<ProcessTaskBindingDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_float_configuration/getAllTaskTypeFieldFloatConfiguration
     * @description Получение всех TaskTypeFieldFloatConfiguration
     *
     * @return {Promise<SafeResult<TaskTypeFieldFloatConfigurationDto[], Error>>}
     */
    getTaskTypeFieldFloatConfigurations(): Promise<SafeResult<TaskTypeFieldFloatConfigurationDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_float_configuration/createTaskTypeFieldFloatConfiguration
     * @description Создание TaskTypeFieldFloatConfiguration
     *
     * @param {TaskTypeFieldFloatConfigurationInput} configuration
     * @return {Promise<SafeResult<TaskTypeFieldFloatConfigurationDto, Error>>}
     */
    createTaskTypeFieldFloatConfiguration(
        configuration: TaskTypeFieldFloatConfigurationInput
    ): Promise<SafeResult<TaskTypeFieldFloatConfigurationDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_float_configuration/updateTaskTypeFieldFloatConfiguration
     * Обновление TaskTypeFieldFloatConfiguration
     *
     * @param {number | string} configurationId
     * @param {TaskTypeFieldFloatConfigurationInput} configuration
     *
     * @return {Promise<SafeResult<TaskTypeFieldFloatConfigurationDto, Error>>}
     */
    updateTaskTypeFieldFloatConfiguration(
        configurationId: number | string,
        configuration: TaskTypeFieldFloatConfigurationInput
    ): Promise<SafeResult<TaskTypeFieldFloatConfigurationDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/deleteStatusChangeRuleConditionGroup
     * @description Удаление StatusChangeRuleConditionGroup
     *
     * @param {number | string} configurationId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeFieldFloatConfiguration(configurationId): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionKindByConditionId
     * @description Получение вида состояния (condition kind). Если conditionKindId = null - возвращаются все виды состояний, иначе - возвращается список доступных видов состояний для выбранного условия
     *
     * @param {string} conditionKindCode
     *
     * @return {Promise<SafeResult<ConditionKindDto, Error>>}
     */
    getConditionKinds({
        conditionKindCode
    }?: {
        conditionKindCode: string;
    }): Promise<SafeResult<ConditionKindDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findComparisonSignById
     * @description Получение сравнения подписи (comparison sign). Если comparisonSignId = null - возвращаются все сравнения подписи, иначе - возвращается список доступных сравнений подписей для выбранного условия
     *
     * @param {string} [comparisonSignCode]
     *
     * @return {Promise<SafeResult<ComparisonSignDto[], Error>>}
     */
    getComparisonSigns({
        comparisonSignCode
    }?: {
        comparisonSignCode: string;
    }): Promise<SafeResult<ComparisonSignDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionModifierKindByConditionId
     * @description Получение вида модификатора состояния (condition modifier kind). Если conditionModifierKindId = null - возвращаются все виды модификаторов состояний, иначе - возвращается список доступных видов модификаторов состояний для выбранного условия
     *
     * @param {string} [conditionModifierKindCode]
     *
     * @return {Promise<SafeResult<ConditionModifierKindDto[], Error>>}
     */
    getConditionModifierKinds({
        conditionModifierKindCode
    }?: {
        conditionModifierKindCode: string;
    }): Promise<SafeResult<ConditionModifierKindDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionModifierKindConditionKindById
     * @description Получение модификатора условия вида условия (condition modifier kind condition kind). Если conditionModifierKindConditionKindId = null - возвращаются все модификаторы условия вида условия, иначе - возвращается список доступных модификаторов условия вида условия для выбранного условия
     *
     * @param {string} conditionModifierKindCode
     * @param {string} conditionKindCode
     *
     * @return {Promise<SafeResult<ConditionModifierKindConditionKindDto[], Error>>}
     */
    getConditionModifierKindConditionKinds({
        conditionModifierKindCode,
        conditionKindCode
    }?: {
        conditionModifierKindCode: string;
        conditionKindCode: string;
    }): Promise<SafeResult<ConditionModifierKindConditionKindDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllTaskTypeRolePermission
     * @description Получение всех TaskTypeRolePermission
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionDto[], Error>>}
     */
    getTaskTypeRolePermissions(): Promise<SafeResult<TaskTypeRolePermissionDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/createTaskTypeRolePermission
     * @description Создание TaskTypeRolePermission
     *
     * @param {TaskTypeRolePermissionInput} taskTypeRolePermission
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionDto, Error>>}
     */
    createTaskTypeRolePermission(
        taskTypeRolePermission: TaskTypeRolePermissionInput
    ): Promise<SafeResult<TaskTypeRolePermissionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/updateTaskTypeRolePermission
     * @description Обновление TaskTypeRolePermission
     *
     * @param {number} taskTypeRolePermissionId
     * @param {TaskTypeRolePermissionInput} taskTypeRolePermission
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionDto, Error>>}
     */
    updateTaskTypeRolePermission(
        taskTypeRolePermissionId: number,
        taskTypeRolePermission: TaskTypeRolePermissionInput
    ): Promise<SafeResult<TaskTypeRolePermissionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/deleteTaskTypeRolePermission
     * @description Удаление TaskTypeRolePermission
     *
     * @param {number} taskTypeRolePermissionId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeRolePermission(taskTypeRolePermissionId: number): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_role_permission_field_restriction/createTaskTypeRolePermissionFieldRestriction
     * @description Получение всех ограничений к полям таска
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto[], Error>>}
     */
    getTaskTypeRolePermissionFieldRestrictions(): Promise<
        SafeResult<TaskTypeRolePermissionFieldRestrictionDto[], Error>
    >;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/
     * @description Создание ограничений к полям таска
     *
     * @param {TaskTypeRolePermissionFieldRestrictionInput} fieldRestriction
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto, Error>>}
     */
    createTaskTypeRolePermissionFieldRestriction(
        fieldRestriction: TaskTypeRolePermissionFieldRestrictionInput
    ): Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_role_permission_field_restriction/updateTaskTypeRolePermissionFieldRestriction
     * @description Изменение ограничений к полям таска
     *
     * @param {number} fieldRestrictionId
     * @param {TaskTypeRolePermissionFieldRestrictionInput} fieldRestriction
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto, Error>>}
     */
    updateTaskTypeRolePermissionFieldRestriction(
        fieldRestrictionId: number,
        fieldRestriction: TaskTypeRolePermissionFieldRestrictionInput
    ): Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_role_permission_field_restriction/deleteTaskTypeRolePermissionFieldRestriction
     * @description Удаление ограничений к полям таска
     *
     * @param {number} fieldRestrictionId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeRolePermissionFieldRestriction(fieldRestrictionId): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/createEvaluationTasks
     * @description Создание показателей
     *
     * @param {EvaluationTaskInput} task
     *
     * @return {Promise<SafeResult<Array, Error>>}
     */
    createTaskWithEvaluation(task: EvaluationTaskInput): Promise<SafeResult<Array, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/member/memberExcludeUpdate
     * @description По переданному массиву ИД member изменяется поле is_exclude на переданное значение
     *
     * @param {number[]} ids - member ids
     * @param {boolean} isExclude
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    updateMemberExclude(
        ids: number[],
        { isExclude }: { isExclude: boolean }
    ): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/member/create_1
     * @description Создание участника
     *
     * @param {MemberInput} member
     * @return {Promise<SafeResult<MemberDto, Error>>}
     */
    createMember(member: MemberInput): Promise<SafeResult<MemberDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/getProcessMembers
     * @description Получение данных о process_stage и member_group
     *
     * @param {number} processId
     * @param {number} userTypeId
     *
     * @return {Promise<SafeResult<ProcessMemberDto[], Error>>}
     */
    getProcessMembers({
        processId,
        userTypeId
    }: {
        processId: number;
        userTypeId: number;
    }): Promise<SafeResult<ProcessMemberDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/getAllStatus
     * @description Получение информации о статусах
     *
     * @return {Promise<SafeResult<StatusDto[], Error>>}
     */
    getStatuses(): Promise<SafeResult<StatusDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/createStatus
     * @description Создание статуса
     *
     * @param {StatusInput} status
     *
     * @return {Promise<SafeResult<StatusDto, Error>>}
     */
    createStatus(status: StatusInput): Promise<SafeResult<StatusDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/updateStatus
     * @description Обновление статуса
     *
     * @param {number} id
     * @param {StatusInput} status
     *
     * @return {Promise<SafeResult<StatusDto, Error>>}
     */
    updateStatus(id: number, status: StatusInput): Promise<SafeResult<StatusDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/deleteStatus
     * @description Удаление статуса
     *
     * @param {number} id
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteStatus(id: number): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/getStatusById
     * @description Получение информации о статусе
     *
     * @return {Promise<SafeResult<StatusDto, Error>>}
     */
    getStatusById(id: number): Promise<SafeResult<StatusDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process_stage_group/getProcessStageGroup
     * @description Получение ProcessStageGroup
     *
     * @param {number} id
     *
     * @return {Promise<SafeResult<ProcessStageGroupDto, Error>>}
     */
    getProcessStageGroupById(id: number): Promise<SafeResult<ProcessStageGroupDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllStatusChangeRule
     * @description Получение всех StatusChangeRule
     *
     * @return {Promise<SafeResult<StatusChangeRuleDto[], Error>>}
     */
    getStatusChangeRules(): Promise<SafeResult<ProcessStageGroupDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getStatusChangeRule
     * @description Получение StatusChangeRule
     *
     * @return {Promise<SafeResult<StatusChangeRuleDto, Error>>}
     */
    getStatusChangeRuleById(id: number): Promise<SafeResult<ProcessStageGroupDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/createStatusChangeRule
     * @description Создание StatusChangeRule
     *
     * @param {StatusChangeRuleInput} rule
     * @return {Promise<SafeResult<StatusChangeRuleDto, Error>>}
     */
    createStatusChangeRule(rule: StatusChangeRuleInput): Promise<SafeResult<StatusChangeRuleDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/updateStatusChangeRule
     * @description Обновление StatusChangeRule
     *
     * @param {number | string} id
     * @param {StatusChangeRuleInput} rule
     *
     * @return {Promise<SafeResult<StatusChangeRuleDto, Error>>}
     */
    updateStatusChangeRule(
        id: number | string,
        rule: StatusChangeRuleInput
    ): Promise<SafeResult<StatusChangeRuleDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/deleteStatusChangeRule
     * @description Удаление StatusChangeRule
     *
     * @param {number} id
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteStatusChangeRule(id: number): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/system_status/getAllSystemStatus
     * @description Получение всех SystemStatus
     *
     * @return {Promise<SafeResult<SystemStatusDto, Error>>}
     */
    getSystemStatuses(): Promise<SafeResult<SystemStatusDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/getAllTaskTypeFieldDictionaryConfiguration
     * @description Получение всех TaskTypeFieldDictionaryConfiguration
     *
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto[], Error>>}
     */
    getTaskTypeFieldDictionaryConfigurations(): Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/createTaskTypeFieldDictionaryConfiguration
     * @description Создание TaskTypeFieldDictionaryConfiguration
     *
     * @param {TaskTypeFieldDictionaryConfigurationInput} taskTypeFieldDictionaryConfiguration
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto, Error>>}
     */
    createTaskTypeFieldDictionaryConfiguration(
        taskTypeFieldDictionaryConfiguration: TaskTypeFieldDictionaryConfigurationInput
    ): Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/updateTaskTypeFieldDictionaryConfiguration
     * @description Обновление TaskTypeFieldDictionaryConfiguration
     *
     * @param {number} taskTypeFieldId
     * @param {TaskTypeFieldDictionaryConfigurationUpdateInput} taskTypeFieldDictionaryConfiguration
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto, Error>>}
     */
    updateTaskTypeFieldDictionaryConfiguration(
        { taskTypeFieldId }: { taskTypeFieldId: number },
        taskTypeFieldDictionaryConfiguration: TaskTypeFieldDictionaryConfigurationUpdateInput
    ): Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/deleteTaskTypeFieldDictionaryConfiguration
     * @description Удаление TaskTypeFieldDictionaryConfiguration
     *
     * @param {number} taskTypeFieldId
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeFieldDictionaryConfiguration({
        taskTypeFieldId
    }: {
        taskTypeFieldId: number;
    }): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/findTaskTypeFieldDictionaryConfiguration
     * @description Поиск TaskTypeFieldDictionaryConfiguration
     *
     * @param {number[]|string[]} taskTypeFieldIds
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto[], Error>>}
     */
    getTaskTypeFieldDictionaryConfigurationsByIds({
        taskTypeFieldIds
    }: {
        taskTypeFieldIds: number[] | string[];
    }): Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/scale/findActualScale
     * @description Получение информации об актуальных scale
     *
     * @return {Promise<SafeResult<ScaleDto[], Error>>}
     */
    getScales(): Promise<SafeResult<ScaleDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/getTypeDictionaryServices
     * @description Получение всех сервисов справочников
     *
     * @return {Promise<SafeResult<DictionaryServiceDto[], Error>>}
     */
    getTypeDictionaryServices(): Promise<SafeResult<DictionaryServiceDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/getTypeDictionaryEntity
     * @description Получение сущности справочника по идентификатору
     *
     * @param {number} id
     * @return {Promise<SafeResult<DictionaryEntityInfoDto, Error>>}
     */
    getTypeDictionaryById(id: number): Promise<SafeResult<DictionaryEntityInfoDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/getTypeDictionaryEntities
     * @description Получение списка всех справочников
     *
     * @return {Promise<SafeResult<DictionaryEntityInfoDto[], Error>>}
     */
    getTypeDictionaries(): Promise<SafeResult<DictionaryEntityInfoDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/createTypeDictionaryEntity
     * @description Создание сущности справочника
     *
     * @param {TypeDictionaryInput} typeDictionary
     * @return {Promise<SafeResult<string, Error>>}
     */
    createTypeDictionary(typeDictionary: TypeDictionaryInput): Promise<SafeResult<string, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/patchTypeDictionaryEntity
     * @description Изменение сущности справочника
     *
     * @param {number} id
     * @param {TypeDictionaryInput} typeDictionary
     * @return {Promise<SafeResult<DictionaryEntityInfoDto, Error>>}
     */
    updateTypeDictionary(
        id: number,
        typeDictionary: TypeDictionaryInput
    ): Promise<SafeResult<DictionaryEntityInfoDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/deleteTypeDictionaryEntity
     * @description Удаление сущности справочника
     *
     * @param {number} id
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTypeDictionary(id: number): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/basic_data_type/fetch
     * @description Получение информации о базовых типах данных
     *
     * @return {Promise<SafeResult<BasicDataTypeDto[], Error>>}
     */
    getBasicDataTypes(): Promise<SafeResult<BasicDataTypeDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field/getAllTaskTypeField
     * @description Получение списка типов полей цели (таска)
     *
     * @param {number[]} [taskTypeIds]
     * @return {Promise<SafeResult<TaskTypeFieldDto[], Error>>}
     */
    getTaskTypeFields({ taskTypeIds }?: { taskTypeIds: number[] }): Promise<SafeResult<TaskTypeFieldDto[], Error>>;

    /**
     * @description Закрытие полей типа цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field/closeTaskTypeField
     *
     * @param {number[]} ids
     * @return {Promise<SafeResult<number, Error>>}
     */
    deleteTaskTypeField(ids: number[]): Promise<SafeResult<number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/getCustomDictionaryByName
     * @description Получение информации о кастомном справочнике по названию справочника.
     *
     * @param {CustomDictionaryFilterInput} name
     * @return {Promise<SafeResult<CustomDictionaryDto[], Error>>}
     */
    getCustomDictionaries({ name }: CustomDictionaryFilterInput): Promise<SafeResult<CustomDictionaryDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/createCustomDictionary_1
     * @description Создание кастомного справочника
     *
     * @param {CustomDictionaryInput} customDictionary
     * @return {Promise<SafeResult<number, Error>>}
     */
    createCustomDictionary(customDictionary: CustomDictionaryInput): Promise<SafeResult<number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/getCustomDictionaryColumns
     * @description Получение информации о полях справочника по идентификатору справочника.
     *
     * @param {import("./type").CustomDictionaryColumnsFilterInput} tableId
     * @return {Promise<SafeResult<CustomDictionaryColumnDto[], Error>>}
     */
    getCustomDictionaryColumns({
        tableId
    }: CustomDictionaryColumnsFilterInput): Promise<SafeResult<CustomDictionaryColumnDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/createCustomDictionary
     * @description Добавление поля кастомного справочника
     *
     * @param {import("./type").CustomDictionaryColumnsFilterInput} tableId
     * @param {CustomDictionaryColumnInput} customDictionaryColumn
     * @return {Promise<SafeResult<number, Error>>}
     */
    createCustomDictionaryColumn(
        { tableId }: CustomDictionaryColumnsFilterInput,
        customDictionaryColumn: CustomDictionaryColumnInput
    ): Promise<SafeResult<number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/patchCustomDictionaryColumn
     * @description Изменение поля кастомного справочника
     *
     * @param {number} id
     * @param {CustomDictionaryColumnInput} customDictionaryColumn
     * @return {Promise<SafeResult<CustomDictionaryColumnDto, Error>>}
     */
    updateCustomDictionaryColumn(
        id: number,
        customDictionaryColumn: CustomDictionaryColumnInput
    ): Promise<SafeResult<CustomDictionaryColumnDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/deleteCustomDictionaryColumn
     * @description Удаление поля кастомного справочника
     *
     * @param {number} id
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteCustomDictionaryColumn(id: number): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/getCustomDictionaryColumnRows
     * @description Получение данных справочника
     *
     * @param {import("./type").CustomDictionaryColumnRowsFilterInput} filter
     * @param {import("./type").CustomDictionaryColumnRowsOptionsInput} options
     * @return {Promise<SafeResult<CustomDictionaryColumnRowsPage, Error>>}
     */
    getCustomDictionaryColumnRowsByFilter(
        { tableId, tableName, columnIds, columnNames }?: CustomDictionaryColumnRowsFilterInput,
        { page, size, sort }?: CustomDictionaryColumnRowsOptionsInput
    ): Promise<SafeResult<CustomDictionaryColumnRowsPage, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/insertCustomDictionaryData
     * @description Добавление данных кастомного справочника
     *
     * @param {CustomDictionaryColumnRowInput[]} customDictionaryColumnRows
     * @return {Promise<SafeResult<CustomDictionaryColumnRowDto[], Error>>}
     */
    createCustomDictionaryColumnRows(
        customDictionaryColumnRows: CustomDictionaryColumnRowInput[]
    ): Promise<SafeResult<CustomDictionaryColumnRowDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/patchCustomDictionaryData
     * @description Изменение данных кастомного справочника
     *
     * @param {CustomDictionaryColumnRowInput[]} customDictionaryColumnRows
     * @return {Promise<SafeResult<CustomDictionaryColumnRowDto[], Error>>}
     */
    updateCustomDictionaryColumnRows(
        customDictionaryColumnRows: CustomDictionaryColumnRowInput[]
    ): Promise<SafeResult<CustomDictionaryColumnRowDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/deleteCustomDictionaryData
     * @description Удаление данных кастомного справочника
     *
     * @param {number[]} customDictionaryColumnRowsIds
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteCustomDictionaryColumnRows(
        customDictionaryColumnRowsIds: number[]
    ): Promise<SafeResult<OperationResultDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/dictionary/getMetadata
     * @description Получение базовой информации о сервисе (версия, профиль, используемая БД и сервер авторизации)
     *
     * @param {number | string | number[] | string[]} taskTypeFieldIds - Массив ИД типа филда
     *
     * @return {Promise<SafeResult<DictionaryMetaDataDto[], Error>>}
     */
    getDictionaryMetaData(
        taskTypeFieldIds: number | string | number[] | string[]
    ): Promise<SafeResult<DictionaryMetaDataDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/createTaskAndCheckKpiDuplicate
     * @description Создание цели с проверкой на существование в БД актуального филда с component_field.code="id kpi"
     *
     * @param {TaskCreateInputDto} task
     *
     * @param {Object} [queryParams]
     * @param {number | string} [queryParams.processId]
     * @param {number | string} [queryParams.taskTypeRoleId]
     *
     * @return {Promise<SafeResult<Number, Error>>}
     */
    createTaskWithoutKpiDuplicates(
        task: TaskCreateInputDto,
        { processId, taskTypeRoleId }?: { processId?: number | string; taskTypeRoleId?: number | string }
    ): Promise<SafeResult<Number, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field/taskTypeFieldInheritanceValue
     * @description Метод поиска наследуемых значений у филда
     *
     * @param {number | string} taskTypeId
     * @param {number | string} baseTaskId
     *
     * @return {Promise<SafeResult<TaskTypeFieldInheritanceValueDto[], Error>>}
     */
    getTaskTypeFieldInheritanceValues({
        taskTypeId,
        baseTaskId
    }: {
        taskTypeId: number | string;
        baseTaskId: number | string;
    }): Promise<SafeResult<TaskTypeFieldInheritanceValueDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/evaluateIndexes
     * @description Метод оценки показателя
     *
     * @param {number | string} processStageId
     *
     * @return {Promise<SafeResult<void, Error>>}
     */
    evaluateProcessStageEvaluationTasks(processStageId: number | string): Promise<SafeResult<void, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/member_group/createMemberGroup_1
     * @description Создание MemberGroup
     *
     * @param {MemberGroupInput} memberGroup
     *
     * @return {Promise<SafeResult<MemberGroupDto, Error>>}
     */
    createMemberGroup(memberGroup: MemberGroupInput): Promise<SafeResult<MemberGroupDto, Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html#/task/taskDataLoad
     * @description Создание целей из массива
     *
     * @param {TaskRawDataInput[]} tasks
     *
     * @return {Promise<SafeResult<TaskRawDataDto[], Error>>}
     */
    createTasks(tasks: TaskRawDataInput[]): Promise<SafeResult<TaskRawDataDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_parent_permission/get
     * @description Метод чтения иерархической подчиненности типов тасков
     *
     * @param {number | string} [parentTaskTypeId]
     * @param {number | string} [childTaskTypeId]
     *
     * @return {Promise<SafeResult<TaskTypeParentPermissionDto[], Error>>}
     */
    getTaskTypeParentPermissions({
        parentTaskTypeId,
        childTaskTypeId
    }?: {
        parentTaskTypeId?: number | string;
        childTaskTypeId?: number | string;
    }): Promise<SafeResult<TaskTypeParentPermissionDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/evaluation_scale/findActualEvaluationScale
     * @description Получение информации об актуальных evaluation_scale
     *
     * @return {Promise<SafeResult<EvaluationScaleDto[], Error>>}
     */
    getEvaluationScales(): Promise<SafeResult<EvaluationScaleDto[], Error>>;

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllRole
     * @description Получение всех Role
     *
     * @return {Promise<SafeResult<RoleInfoDto[], Error>>}
     */
    getRoles(): Promise<SafeResult<RoleInfoDto[], Error>>;
}
