/* eslint-disable camelcase */

import { buildRequest, BaseApiService, processRequestResult } from '@goodt-common/api';
import {
    TaskConditionsDto,
    TaskDto,
    TaskHistoryResultDto,
    TaskLinkDto,
    TaskLinkTypeDto,
    TaskTypeDto,
    UserTaskTreeDto,
    ProcessDto,
    ProcessInfoDto,
    ProcessStageShortDto,
    ProcessStageDto,
    ProcessTypeDto,
    ProcessStageTypeDto,
    ProcessTaskBindingDto,
    TaskBatchUpdateInput,
    ModuleDto,
    AccessTypeDto,
    UserTypeDto,
    TaskTypeFieldGroupDto,
    TaskTypeFieldTypeDto,
    ComponentTaskTypeFieldDto,
    ComponentDto,
    TaskTypeParentPermissionDto,
    TaskTypeParentPermissionInput,
    TaskCreateInputDto,
    TaskAvailableStatusDto,
    ComponentFieldDto,
    ComponentFieldShortDto,
    ComponentFieldInheritanceDto,
    OperationResultDto,
    TaskTypeRoleDto,
    TaskFieldInfoDto,
    ConditionDto,
    ConditionModifierDto,
    ConditionGroupDto,
    TaskTypeFieldFloatConfigurationDto,
    DictionaryDto,
    ConditionKindDto,
    ComparisonSignDto,
    ConditionModifierKindDto,
    ConditionModifierKindConditionKindDto,
    TaskTypeRolePermissionDto,
    TaskTypeRolePermissionFieldRestrictionDto,
    MemberDto,
    ProcessMemberDto,
    StatusDto,
    ProcessStageGroupDto,
    StatusChangeRuleDto,
    SystemStatusDto,
    TaskTypeFieldDictionaryConfigurationDto,
    ScaleDto,
    DictionaryServiceDto,
    DictionaryEntityInfoDto,
    TypeDictionaryInput,
    BasicDataTypeDto,
    TaskTypeFieldDto,
    CustomDictionaryDto,
    CustomDictionaryColumnDto,
    CustomDictionaryColumnRowDto,
    CustomDictionaryColumnRowsPage,
    DictionaryMetaDataDto,
    TaskTypeFieldInheritanceValueDto,
    MemberGroupDto,
    TaskRawDataDto,
    EvaluationScaleDto,
    RoleInfoDto
} from './dto';
import { ServiceAction } from './config';

/**
 * @typedef {import('@goodt-common/utils').ISafeResult} SafeResult
 */
/**
 *
 */
export class TaskSettingsApiService extends BaseApiService {
    /**
     *
     * @param {IApiServiceRequestOptions} request
     * @param [DtoConstructor]
     * @param [processOptions]
     * @return {Promise<SafeResult<*, Error>>}
     */
    async request(request, DtoConstructor, processOptions) {
        return processRequestResult(await super.request(buildRequest(request)), DtoConstructor, processOptions);
    }

    /**
     * Получение списка сущностей "пользовательское дерево задач" для списка заданных идентификаторов
     * пользователей и заданного типа задачи
     *
     * @param {number|number[]} userIds - Массив идентификаторов пользователей
     * @param {number} typeId - Идентификатор типа цели
     * @param {Object} [options={}]
     * @param {number} options.processTypeId - Идентификатор типа процесса
     * @param {number} options.level - Идентификатор уровня
     * @param {boolean} options.history - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {number[]} options.processIds - Массив идентификаторов процессов
     * @param {boolean} options.withClosedTask - Этот флаг устанавливает следующее: если true - то выведутся все цели, если false - выведутся только незавершённые цели
     * @param {boolean} options.withClosedTaskField - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {boolean} options.rootOnly - Этот флаг устанавливает следующее: если true - то выведутся только рутовые цели, если false - выведутся все имеющиеся цели
     * @return {Promise<SafeResult<UserTaskTreeDto[], Error>>}
     */

    getUserTaskTrees(
        userIds,
        typeId,
        { processTypeId, level, history, processIds, withClosedTask, withClosedTaskField, rootOnly } = {}
    ) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_TREES_GET,
            queryParams: {
                ...(typeId != null && { type: typeId }),
                ...(userIds !=null && { users: [userIds].flat().filter((id) => id != null) }),
                ...(processTypeId != null && { process_type: processTypeId }),
                ...(level != null && { level }),
                ...(history != null && { history }),
                ...(processIds != null && { process_id: [processIds].flat().filter(id => id != null) }),
                ...(withClosedTask != null && { with_closed_task: withClosedTask }),
                ...(withClosedTaskField != null && { with_closed_task_field: withClosedTaskField }),
                ...(rootOnly != null && { root_only: rootOnly }),
            }
        }, UserTaskTreeDto);
    }

    /**
     * Получение списка сущностей "задача" (одного "дерева" задач) для заданного пользователя
     * и заданного типа задачи
     *
     * @param {number} userId - - Идентификатор пользователя
     * @param {number} typeId  - Идентификатор типа цели
     * @param {Object} [options={}]
     * @param {number} options.processTypeId - Идентификатор типа процесса
     * @param {number} options.level - Идентификатор уровня
     * @param {boolean} options.history - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {number[]} options.processIds - Массив идентификаторов процессов
     * @param {boolean} options.withClosedTask - Этот флаг устанавливает следующее: если true - то выведутся все цели, если false - выведутся только незавершённые цели
     * @param {boolean} options.withClosedTaskField - Этот флаг устанавливает следующее: если true - то выведутся все поля цели, если false - выведутся только незавершённые поля цели
     * @param {boolean} options.rootOnly - Этот флаг устанавливает следующее: если true - то выведутся только рутовые цели, если false - выведутся все имеющиеся цели
     * @return {Promise<SafeResult<TaskDto[], Error>>}
     */
    async getTaskTree(
        userId,
        typeId,
        { processTypeId, level, history, processIds, withClosedTask, withClosedTaskField, rootOnly } = {}
    ) {
        return this.request(
            {
                action: ServiceAction.TASK_TREES_GET,
                queryParams: {
                    ...(typeId != null && { type: typeId }),
                    ...(userId != null && { users: [userId].flat().filter((id) => id != null) }),
                    ...(processTypeId != null && { process_type: processTypeId }),
                    ...(level != null && { level }),
                    ...(history != null && { history }),
                    ...(processIds != null && { process_id: [processIds].flat().filter((id) => id != null) }),
                    ...(withClosedTask != null && { with_closed_task: withClosedTask }),
                    ...(withClosedTaskField != null && { with_closed_task_field: withClosedTaskField }),
                    ...(rootOnly != null && { root_only: rootOnly })
                }
            },
            TaskDto,
            { resultTransformer: ServiceAction.TASK_TREES_GET.resultTransformer }
        );
    }

    /**
     *
     * @param {number|number[]} [userIds]
     * @param {number|number[]} [taskLinkTypeIds]
     * @param {number} [taskFromId]
     * @param {number} [taskToId]
     * @param {boolean} [withTaskFromClosed]
     * @param {boolean} [withTaskToClosed]
     * @param {number} [taskFromUserId]
     * @param {number} [taskToUserId]
     * @return {Promise<SafeResult<TaskLinkDto[], Error>>}
     */
    async getTaskLinks({
        userIds,
        taskLinkTypeIds,
        taskFromId,
        taskToId,
        withTaskFromClosed,
        withTaskToClosed,
        taskFromUserId,
        taskToUserId
    }) {
        // prettier-ignore
        return this.getTaskLinksByFilter({
            userIds,
            taskFromId,
            taskToId,
            withTaskFromClosed,
            withTaskToClosed,
            taskFromUserId,
            taskToUserId,
            taskLinkTypeIds
        });
    }

    /**
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/
     * @description Получение списка связей целей с возможностью передачей массивов для параметров task_user_id_from, task_user_id_to, task_id_from и task_id_to.
     *
     * @param {Object} params
     * @param {number|number[]} params.userIds - Массив идентификаторов пользователей
     * @param {number|number[]} [params.taskLinkTypeIds] - Массив идентификаторов типов ссылки на цели
     * @param {number|number[]} [params.taskFromId] - Массив идентификаторов начальной цели
     * @param {number|number[]} [params.taskToId] - Массив идентификаторов конечной цели
     * @param {boolean} [params.withTaskFromClosed=false] - false - в результате получим связи только с открытыми начальными целями, true - будем получать связи даже с закрытими начальными целями
     * @param {boolean} [params.withTaskToClosed=false] - false - в результате получим связи только с открытыми конечными целями, true - будем получать связи даже с закрытими конечными целями
     * @param {number|number[]} [params.taskFromUserId] - Массив идентификаторов пользователей начальной цели
     * @param {number|number[]} [params.taskToUserId] - Массив идентификаторов пользователей конечной цели
     * @param {number} [params.taskLinkId] - Идентификатор связи целей
     * @return {Promise<SafeResult<TaskLinkDto[], Error>>}
     */
    async getTaskLinksByFilter({
        userIds,
        taskLinkTypeIds,
        taskFromId,
        taskToId,
        withTaskFromClosed,
        withTaskToClosed,
        taskFromUserId,
        taskToUserId,
        taskLinkId
    }) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_LINKLIST_GET,
            params: {
                ...(userIds && { users: [userIds].flat().filter((id) => id != null) }),
                ...(taskLinkTypeIds && { task_link_type_id: [taskLinkTypeIds].flat().filter((id) => id != null) }),
                ...(taskFromId && { task_id_from: [taskFromId].flat().filter((id) => id != null) }),
                ...(taskToId && { task_id_to: [taskToId].flat().filter((id) => id != null) }),
                ...(withTaskFromClosed != null && { task_with_closed_from: withTaskFromClosed }),
                ...(withTaskToClosed != null && { task_with_closed_to: withTaskToClosed }),
                ...(taskFromUserId && { task_user_id_from: [taskFromUserId].flat().filter((id) => id != null) }),
                ...(taskToUserId && { task_user_id_to: [taskToUserId].flat().filter((id) => id != null) }),
                ...(taskLinkId && { id: [taskLinkId].flat().filter((id) => id != null) }),
            }
        }, TaskLinkDto);
    }

    /**
     * Изменение связи цели
     *
     * @param {number} linkId
     * @param {number} task_id_from
     * @param {number} task_link_type_id
     * @param {number} task_id_to
     * @param {string} date_from
     * @param {string} date_to
     * @return {Promise<SafeResult<Number, Error>>}
     */
    async updateTaskLink(linkId, { task_id_from, task_link_type_id, task_id_to, date_from, date_to }) {
        return this.request(
            {
                action: ServiceAction.TASK_LINK_UPDATE,
                params: {
                    id: linkId,
                    task_id_from,
                    task_link_type_id,
                    task_id_to,
                    date_from,
                    date_to
                }
            },
            Number
        );
    }

    /**
     * Получение списка типов связей
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/getTaskLinkTypeByIds
     *
     * @param {number} linkTypeId
     * @return {Promise<SafeResult<TaskLinkTypeDto[], Error>>}
     */
    async getTaskLinkTypes(linkTypeId) {
        return this.request(
            {
                action: ServiceAction.TASK_LINK_TYPE,
                params: {
                    id: linkTypeId
                }
            },
            TaskLinkTypeDto
        );
    }

    /**
     * Создание связи цели
     *
     * @param {number} task_id_from
     * @param {number} task_link_type_id
     * @param {number} task_id_to
     * @param {string}date_from
     * @param {string} date_to
     * @return {Promise<SafeResult<Number, Error>>}
     */
    async createTaskLink({ task_id_from, task_link_type_id, task_id_to, date_from, date_to }) {
        return this.request(
            {
                action: ServiceAction.TASK_LINK_UPDATE,
                params: {
                    task_id_from,
                    task_link_type_id,
                    task_id_to,
                    date_from,
                    date_to
                }
            },
            Number
        );
    }

    /**
     *
     * @param {number} id
     * @return {Promise<SafeResult<TaskLinkDto, Error>>}
     */
    async getTaskLinkById(id) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_LINKLIST_GET,
            params: {
                id
            }
        }, TaskLinkDto, {
            resultTransformer: (taskLinks) => taskLinks[0]
        });
    }

    /**
     * Получение сущности "задача" по её идентификатору
     *
     * @param {number} taskId
     * @return {Promise<SafeResult<TaskDto, Error>>}
     */
    async getTaskById(taskId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_INFO_GET,
            params: {
                id: taskId
            }
        }, TaskDto);
    }

    /**
     *
     * @param {number} taskId
     *
     * @param {number} type type id
     * @param {number} user user id
     * @param {Record<string, string>[]} [fields]
     * @param {string} [comment]
     * @param {number} [parent] parent id
     * @param {number} [status]
     * @param {number|string} [taskTypeRoleId]
     * @return {Promise<SafeResult<number, Error>>}
     */
    async replaceTask(taskId, { fields, comment, parent, type, user, status }, { taskTypeRoleId } = {}) {
        return this.request(
            {
                action: ServiceAction.TASK_REPLACE,
                params: { id: taskId, parent, type, user, status, fields, comment },
                pathParams: { id: taskId },
                queryParams: { task_type_role_id: taskTypeRoleId }
            },
            Number
        );
    }

    /**
     *
     * @param {number} taskId
     *
     * @param {Record<string, string>[]} [fields]
     * @param {string} [comment]
     * @param {number} [parent] parent id
     * @param {number} [type] type id
     * @param {number} [user] user id
     * @param {number} [status]
     * @return {Promise<SafeResult<number, Error>>}
     */
    async updateTask(taskId, { fields, comment, parent, type, user, status }) {
        return this.request(
            {
                action: ServiceAction.TASK_UPDATE,
                params: { id: taskId, parent, type, user, status, fields, comment }
            },
            Number
        );
    }

    /**
     **
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/createTask
     * @description Создание цели
     *
     * @param {number|string} processId process id
     *
     * @param {TaskCreateInputDto} task
     * @param {number|string} taskTypeRoleId
     * @return {Promise<SafeResult<number, Error>>}
     */
    async createTask(processId, task, { taskTypeRoleId } = {}) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_CREATE,
            queryParams: { process_id: processId, task_type_role_id: taskTypeRoleId},
            params: task
        }, Number);
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/taskStatusChange
     * @description Изменение статуса цели и отправка уведомления владельцу цели либо его руководителю
     *
     * @param {number} taskId task id
     * @param {import("./type").TaskStatusUpdateInput} input
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    async updateTaskStatus(taskId, { statusChangeRuleId, ids, comment }) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_STATUS_UPDATE,
            params: {
                task_id: taskId,
                comment,
                status_change_rule_id: statusChangeRuleId,
                task_ids: ids
            }
        }, OperationResultDto);
    }

    /**
     **
     * @description Удаление цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/deleteTask
     *
     * @param {number} taskId task id
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    async deleteTask(taskId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_DELETE,
            queryParams: {
                // eslint-disable-next-line no-restricted-syntax
                id: [taskId]
            }
        }, Boolean);
    }

    /**
     **
     * @description Удаление целей по массиву идентификаторов
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/deleteTask
     *
     * @param {number[]} taskIds task ids
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    async deleteTasks(taskIds) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_DELETE,
            queryParams: {
                id: taskIds
            }
        }, Boolean);
    }

    /**
     *
     * @param {number} taskLinkId
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    async deleteTaskLink(taskLinkId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.DELETE_LINK,
            pathParams: { id: taskLinkId }
        }, Boolean);
    }

    /**
     * Task History
     *
     * @param {number} tasksId
     * @return {Promise<SafeResult<TaskHistoryResultDto, Error>>}
     */
    async getTaskHistory(tasksId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_HISTORY_GET,
            params: {
                id: tasksId
            }
        }, TaskHistoryResultDto);
    }

    /**
     * Find tasks (exactly filter tasks)
     *
     * @param {import("./type").TaskFilterInput} filter
     * @param {Object} options
     * @param {number} options.taskTypeRoleId - ИД связь типа таска и роли
     * @param {number} options.page
     * @param {number} options.size
     * @return {Promise<SafeResult<TaskDto[], Error>>} result
     */
    async getTasksByFilter(
        {
            taskIds,
            taskTypeIds,
            userIds,
            parentIds,
            processId,
            processTypeId,
            taskFieldTypeId,
            taskFieldValue,
            taskField = {},
            rootId
        },
        { taskTypeRoleId, page, size } = {}
    ) {
        // eslint-disable-next-line no-underscore-dangle
        const _taskFieldTypeId = taskField.type_id ?? taskFieldTypeId;
        // eslint-disable-next-line no-underscore-dangle
        const _taskFieldValue = taskField.value ?? taskFieldValue;
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_FIND,
            queryParams: {
                ...(taskTypeRoleId != null && {task_type_role_id: taskTypeRoleId}),
                ...(page != null && { page }),
                ...(size != null && { size }),
            },
            params: {
                ...(taskIds && { ids: taskIds }),
                ...(userIds && { users: userIds }),
                ...(taskTypeIds && { task_type: taskTypeIds }),
                ...(processTypeId && { process_type_id: processTypeId }),
                ...(parentIds && { parent_id: parentIds }),
                ...(processId && { process_id: processId }),
                ...(_taskFieldTypeId && { task_field_type_id: _taskFieldTypeId }),
                ...(_taskFieldValue && { task_field_value: _taskFieldValue }),
                ...(rootId && { root_id: rootId }),
            }
        }, TaskDto);
    }

    /**
     * Retrieves process-task bindings by filter
     *
     * @param {import("./type").ProcessTaskBindingFilterInput} filter
     * @return {Promise<SafeResult<ProcessTaskBindingDto[], Error>>} result
     */
    async getProcessTaskBindingsByFilter({ taskId, processId }) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_TASK_BINDINGS_GET,
            params: {
                task_id: taskId,
                process_id: processId
            }
        }, ProcessTaskBindingDto);
    }

    /**
     *
     * @param {number} taskId
     * @param {number[]|number} processIds
     * @return {Promise<SafeResult<TaskConditionsDto[], Error>>}
     */
    async getTaskConditions(taskId, { processIds } = {}) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_CONDITIONS_GET,
            params: {
                id: taskId,
                process_id: [processIds].flat().filter((id) => id != null)
            }
        }, TaskConditionsDto);
    }

    /**
     *
     * @param {number|string} processId
     * @return {Promise<SafeResult<*, Error>|SafeResult<any, Error>|*>}
     */
    async getProcessById(processId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_GET_BY_ID,
            pathParams: {
                id: processId
            }
        }, ProcessDto);
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/getProcessListNew
     * @description НОВЫЙ МЕТОД!!! Получение информации о всех процессах
     *
     * @param {import("./type").ProcessInfosFilterInput} filter
     * @return {Promise<SafeResult<ProcessInfoDto[], Error>>}
     */
    async getProcessInfos({ typeCode, externalId, date, stageDate } = {}) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESSES_GET_BY_FILTER,
            params: {
                type_code: typeCode,
                external_id: externalId,
                date,
                stage_date: stageDate
            }
        }, ProcessInfoDto);
    }

    /**
     *
     * @param {number} typeId
     * @param {string} date
     * @return {Promise<SafeResult<ProcessDto[], Error>>}
     */
    async getProcesses({ typeId, date } = {}) {
        const resultTransformer = (processInfos) => processInfos.map(({ process }) => process);

        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESSES_GET_BY_FILTER,
            params: {
                type_id: typeId,
                date
            }
        }, ProcessDto, { resultTransformer });
    }

    /**
     * @param {number} processTypeId
     * @param {string} processDate
     * @return {Promise<SafeResult<ProcessStageShortDto[], Error>>}
     */
    async getProcessStages({ processTypeId, processDate } = {}) {
        const resultTransformer = (processInfos) =>
            processInfos.flatMap(({ process_stages: processStages }) => processStages);

        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESSES_GET_BY_FILTER,
            params: {
                type_id: processTypeId,
                date: processDate
            }
        }, ProcessStageShortDto, { resultTransformer });
    }

    /**
     * @description Создание процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/createProcessNew
     *
     * @param {string} name
     * @param {string} params
     * @param {number} is_startable
     * @param {string} date_to
     * @param {string} date_block
     * @param {string} date_end
     * @param {string} date_start
     * @param {string} date_end_confirm
     * @param {string} date_start_confirm
     * @param {string} type_code
     * @return {Promise<SafeResult<number, Error>>}
     */
    async createProcess({
        name,
        params,
        is_startable,
        date_to,
        date_block,
        date_end,
        date_start,
        date_end_confirm,
        date_start_confirm,
        type_code
    }) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_CREATE,
            params: {
                name,
                params,
                is_startable,
                date_to,
                date_block,
                date_end,
                date_start,
                date_end_confirm,
                date_start_confirm,
                type_code
            }
        }, Number);
    }

    /**
     * @description Изменение процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/updateProcessNew
     *
     * @param {number} processId
     * @param {ProcessInput} process
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    async updateProcess(processId, process) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_UPDATE,
            pathParams: {
                id: processId
            },
            params: process
        }, Boolean);
    }

    /**
     **
     * @param {number} processId
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    deleteProcess(processId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_DELETE,
            pathParams: {
                id: processId
            }
        }, Boolean);
    }

    /**
     * @param {number} processStageId
     * @return {Promise<SafeResult<ProcessStageDto, Error>>}
     */
    async getProcessStageById(processStageId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_STAGE_GET_BY_ID,
            pathParams: {
                id: processStageId
            }
        }, ProcessStageDto);
    }

    /**
     * @description Создание этапа процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/createProcessStage
     *
     * @param {ProcessStageInput} processStage
     * @return {Promise<SafeResult<ProcessStageDto, Error>>}
     */
    createProcessStage(processStage) {
        return this.request(
            {
                action: ServiceAction.PROCESS_STAGE_CREATE,
                params: processStage
            },
            ProcessStageDto
        );
    }

    /**
     * @description Обновление этапа процесса
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/updateProcessStage
     *
     * @param {number} processStageId
     * @param {ProcessStageInput} processStage
     *
     * @return {Promise<SafeResult<ProcessStageDto, Error>>}
     */
    updateProcessStage(processStageId, processStage) {
        return this.request(
            {
                action: ServiceAction.PROCESS_STAGE_UPDATE,
                pathParams: {
                    id: processStageId
                },
                params: processStage
            },
            ProcessStageDto
        );
    }

    /**
     **
     * @param {number} processStageId
     * @return {Promise<SafeResult<boolean, Error>>}
     */
    deleteProcessStage(processStageId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_STAGE_DELETE,
            pathParams: {
                id: processStageId
            }
        }, Boolean);
    }

    /**
     *
     * @return {Promise<SafeResult<ProcessTypeDto[], Error>>}
     */
    async getProcessTypes() {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_GET_TYPES
        }, ProcessTypeDto);
    }

    /**
     *
     * @return {Promise<SafeResult<ProcessStageTypeDto[], Error>>}
     */
    async getProcessStageTypes() {
        // prettier-ignore
        return this.request({
            action: ServiceAction.PROCESS_STAGE_GET_TYPES
        }, ProcessStageTypeDto);
    }

    /**
     * Получение типа задачи `TaskTypeDto` по id
     *
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/getTaskType
     * @return {Promise<SafeResult<TaskTypeDto, Error>>}
     */
    async getTaskTypeById(taskTypeId) {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_TYPE_GET,
            pathParams: {
                id: taskTypeId
            }
        }, TaskTypeDto);
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/getAllTaskType
     * @description Получение списка типов целей (тасков)
     *
     *
     * @return {Promise<SafeResult<TaskTypeDto[], Error>>}
     */
    async getTaskTypes() {
        // prettier-ignore
        return this.request({
            action: ServiceAction.TASK_TYPE_ALL_GET,
        }, TaskTypeDto);
    }

    /**
     * @description Метод загрузки файла на сервер.
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/file/uploadFile
     *
     * @param {Object} taskParams
     * @param {number} taskParams.taskId
     * @param {number} taskParams.taskTypeFieldId
     * @param {Object} formData
     *
     * @return {Promise<SafeResult<Object, Error>>}
     */
    uploadFile({ taskId, taskTypeFieldId }, formData) {
        return this.request(
            {
                action: ServiceAction.FILE_UPLOAD_POST,
                queryParams: {
                    task_id: taskId,
                    task_type_field_id: taskTypeFieldId
                },
                params: formData
            },
            Object
        );
    }

    /**
     * @descriptionМетод получения файла
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/file/downloadFile
     *
     * @param {number} taskFieldId
     * @return {Promise<SafeResult<Object, Error>>}
     */
    downloadFileByTaskFieldId(taskFieldId) {
        return this.request(
            {
                action: ServiceAction.FILE_DOWNLOAD_GET,
                pathParams: {
                    taskFieldId
                }
            },
            Object
        );
    }

    /**
     * @description Метод массового изменения статуса целей/задач
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/statusChangeBulk
     *
     * @param {Object} params
     * @param {number[]|number} params.userIds - Массив идентификаторов пользователей для фильтрации
     * @param {number[]|number} params.taskTypeIds - Массив идентификаторов типов цели для фильтрации
     * @param {number[]} [params.statusIds] - Массив идентификаторовтекущих статусов для фильтрации
     * @param {number[]} [params.processIds] - Массив идентификаторов процессов для фильтрации
     * @param {number[]} [params.taskIds] - Массив идентификаторов задач для фильтрации
     * @param {number[]|number} targetStatusId - Массив идентификаторов новых статусов для обновления
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    updateTasksStatuses({ userIds, taskTypeIds, statusIds, processIds, taskIds }, targetStatusId) {
        return this.request(
            {
                action: ServiceAction.TASK_STATUS_CHANGE_BULK_POST,
                params: {
                    users: [userIds].flat(),
                    task_type: [taskTypeIds].flat(),
                    current_status: [statusIds].flat(),
                    process_id: [processIds].flat(),
                    task_ids: [taskIds].flat(),
                    status: [targetStatusId].flat()
                }
            },
            OperationResultDto
        );
    }

    /**
     * @description Изменение целей
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/updateTask
     *
     * @param { TaskBatchUpdateInput[] } tasks
     * @param { Object } options
     * @param { number | string } options.taskTypeRoleId
     * @return {Promise<SafeResult<number[], Error>>}
     */
    updateTasks(tasks, { taskTypeRoleId } = {}) {
        return this.request(
            {
                action: ServiceAction.TASK_UPDATE_PUT,
                queryParams: {
                    task_type_role_id: taskTypeRoleId
                },
                params: tasks
            },
            Number
        );
    }

    /**
     *
     * @param {number} processId
     * @param {Object} [filters]
     * @param {string} [filters.externalId]
     * @param {string} [filters.dateStartStart]
     * @param {string} [filters.dateStartEnd]
     * @param {string} [filters.dateEndStart]
     * @param {string} [filters.dateEndEnd]
     * @param {Object} [options]
     * @param {boolean} [options.withClosed]
     * @return {Promise<SafeResult<ProcessStageDto[], Error>>}
     */
    getProcessStagesByFilter(
        processId,
        { externalId, dateStartStart, dateStartEnd, dateEndStart, dateEndEnd } = {},
        { withClosed } = {}
    ) {
        return this.request(
            {
                action: ServiceAction.PROCESS_STAGE_GET,
                params: {
                    process_id: processId,
                    external_id: externalId,
                    date_start_start: dateStartStart,
                    date_start_end: dateStartEnd,
                    date_end_start: dateEndStart,
                    date_end_end: dateEndEnd,
                    with_closed: withClosed
                }
            },
            ProcessStageDto
        );
    }

    /**
     * @description поиск типа таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/taskTypeFind
     *
     * @param {number[]} taskTypeIds
     * @param {Object} [filters]
     * @param {number} filters.parentId
     * @param {boolean} filters.useParentFilter - флаг, который отвечает за передачу параметра parentId
     * @return {Promise<SafeResult<TaskTypeDto[], Error>>}
     */
    getTaskTypesByIds(taskTypeIds, { parentId, useParentFilter = true } = {}) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIND_POST,
                queryParams: {
                    parent_id: useParentFilter === true ? parentId : -1
                },
                params: taskTypeIds
            },
            TaskTypeDto
        );
    }

    /**
     * @description Получение информации о модулях
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/module/getModuleAll
     *
     * @return {Promise<SafeResult<ModuleDto[], Error>>}
     */
    getModules() {
        return this.request(
            {
                action: ServiceAction.MODULE_GET
            },
            ModuleDto
        );
    }

    /**
     * @description Получение информации о типах доступа
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/access_type/getAccessType
     *
     * @return {Promise<SafeResult<AccessTypeDto[], Error>>}
     */
    getAccessTypes() {
        return this.request(
            {
                action: ServiceAction.ACCESS_TYPE_GET
            },
            AccessTypeDto
        );
    }

    /**
     * @description Получение информации о типах пользователя
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/user_type/getUserTypeAll
     *
     * @return {Promise<SafeResult<UserTypeDto[], Error>>}
     */
    getUserTypes() {
        return this.request(
            {
                action: ServiceAction.USER_TYPE_GET
            },
            UserTypeDto
        );
    }

    /**
     * @description Получение информации о группах полей таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_group/getTaskTypeFieldGroupAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldGroupDto[], Error>>}
     */
    getTaskTypeFieldGroups() {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_GROUP_GET
            },
            TaskTypeFieldGroupDto
        );
    }

    /**
     * @description Получение информации о типах полей таска
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_type/getTaskTypeFieldTypeAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>}
     */
    getTaskTypeFieldTypes() {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_TYPE_GET
            },
            TaskTypeFieldTypeDto
        );
    }

    /**
     * @description Создание типа цели
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type/createTaskType
     *
     * @param {TaskTypeInputDto} taskType
     *
     * @return {Promise<SafeResult<number, Error>>}
     */
    createTaskType(taskType) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_UPDATE_POST,
                params: taskType
            },
            TaskTypeDto
        );
    }

    /**
     * @description Изменение типа цели
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/updateTasks
     *
     * @param {number} id
     * @param {TaskTypeInputDto} taskType
     *
     * @return {Promise<SafeResult<number, Error>>}
     */
    updateTaskType(id, taskType) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_UPDATE_PUT,
                params: { id, ...taskType }
            },
            TaskTypeDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field/getAllTaskTypeField
     * @description Получение списка типов полей цели (таска)
     *
     * @param {number[]} [taskTypeIds]
     * @return {Promise<SafeResult<TaskTypeFieldDto[], Error>>}
     */
    getTaskTypeFields({ taskTypeIds } = {}) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_GET,
                queryParams: {
                    task_type_id: taskTypeIds
                }
            },
            TaskTypeFieldDto
        );
    }

    /**
     * @description Закрытие полей типа цели
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field/closeTaskTypeField
     *
     * @param {number[]} ids
     *
     * @return {Promise<SafeResult<number, Error>>}
     */
    deleteTaskTypeField(ids) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_DELETE_POST,
                queryParams: {
                    id: ids
                }
            },
            Number
        );
    }

    /**
     * @description Получение всех связей компонентов и полей типа таска (цели)
     * @link https://goodt-dev.goodt.me:8487/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component_task_type_field/getAllComponentTaskTypeField
     *
     *
     * @return {Promise<SafeResult<ComponentTaskTypeFieldDto[], Error>>}
     */
    getComponentTaskTypeFields() {
        return this.request(
            {
                action: ServiceAction.COMPONENT_TASK_TYPE_FIELD_GET
            },
            ComponentTaskTypeFieldDto
        );
    }

    /**
     * @description Удаление типов целей по массиву идентификаторов

     * @param {number|string} id
     * @return {Promise<SafeResult<Object, Error>>}
     */
    deleteTaskType(id) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_DELETE_POST,
                queryParams: {
                    id
                }
            },
            Object
        );
    }

    /**
     * @description Получение информации о типах полей таска
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_type/getTaskTypeFieldTypeAll
     *
     * @return {Promise<SafeResult<TaskTypeFieldTypeDto[], Error>>}
     */
    getFieldTypes() {
        return this.request(
            {
                action: ServiceAction.FIELD_TYPE_GET
            },
            TaskTypeFieldTypeDto
        );
    }

    /**
     * @description Получение информации о компонентах
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component/getAll
     *
     * @return {Promise<SafeResult<ComponentDto[], Error>>}
     */
    getFieldComponents() {
        return this.request(
            {
                action: ServiceAction.FIELD_COMPONENT_GET
            },
            ComponentDto
        );
    }

    /**
     * @description Метод создания иерархической подчиненности типов тасков
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_parent_permission/create
     *
     * @param {TaskTypeParentPermissionInput} data - Объект с данными для создания разрешения
     * @param {number} data.taskTypeParentId - Идентификатор родительского типа задач
     * @param {number} data.taskTypeId - Идентификатор типа задачи
     *
     * @return {Promise<SafeResult<TaskTypeParentPermissionDto, Error>>}
     */
    createTaskTypeParentPermission({ taskTypeParentId, taskTypeId }) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_PARENT_PERMISSION_CREATE_POST,
                params: {
                    task_type_id_parent: taskTypeParentId,
                    task_type_id_child: taskTypeId
                }
            },
            TaskTypeParentPermissionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_parent_permission/delete_1
     * @description Метод удаления иерархической подчиненности типов тасков
     *
     * @param {number} parentTaskTypeId
     * @param {number} childTaskTypeId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeParentPermission({ parentTaskTypeId, childTaskTypeId }) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_PARENT_PERMISSION_DELETE,
                params: {
                    task_type_id_parent: parentTaskTypeId,
                    task_type_id_child: childTaskTypeId
                }
            },
            OperationResultDto
        );
    }

    /**
     * @description Метод получения доступных для перехода статусов
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/statusList
     *
     * @param {number|string} taskId - ИД таска
     * @param {Object} [options]
     * @param {boolean} [options.withConditionGroups] - Если false - не раскрывать поле condition_groups (пустой массив). Если true - раскрывать
     * @param {boolean} [options.taskTypeRoleId] - Уникальный идентификатор роли типа задачи
     *
     * @return {Promise<SafeResult<TaskAvailableStatusDto[], Error>>}
     */
    getTaskAvailableStatuses(taskId, { withConditionGroups = false, taskTypeRoleId } = {}) {
        return this.request(
            {
                action: ServiceAction.TASK_STATUS_LIST_GET,
                params: {
                    task_id: taskId,
                    with_condition_groups: withConditionGroups,
                    ...(taskTypeRoleId != null && { task_type_role_id: taskTypeRoleId })
                }
            },
            TaskAvailableStatusDto
        );
    }

    /**
     * @description Получение информации о всех полях всех данных из таблицы component_field
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-controller/getAllComponentFieldDto
     *
     * @return {Promise<SafeResult<ComponentFieldDto[], Error>>}
     */
    getComponentFields() {
        return this.request(
            {
                action: ServiceAction.COMPONENT_FIELD_GET
            },
            ComponentFieldDto
        );
    }

    /**
     * @description Создание информации о полях компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-controller/createComponentField
     *
     * @param {ComponentFieldShortDto} componentField
     *
     * @return {Promise<SafeResult<ComponentFieldDto[], Error>>}
     */
    createComponentField(componentField) {
        return this.request(
            {
                action: ServiceAction.COMPONENT_FIELD_CREATE_POST,
                params: componentField
            },
            ComponentFieldDto
        );
    }

    /**
     * @description Предоставление информации о наследовании полей компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-inheritance-controller/create_1
     *
     * @param {number} componentFieldIdFrom
     * @param {number} componentFieldIdTo
     *
     * @return {Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>}
     */
    createComponentFieldInheritance({ componentFieldIdFrom, componentFieldIdTo }) {
        return this.request(
            {
                action: ServiceAction.COMPONENT_FIELD_INHERITANCE_CREATE_POST,
                params: {
                    component_field_from: componentFieldIdFrom,
                    component_field_to: componentFieldIdTo
                }
            },
            ComponentFieldInheritanceDto
        );
    }

    /**
     * @description Удаление информации о наследовании полей компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-inheritance-controller/delete
     *
     * @param {number} componentFieldIdFrom - id поля, из которого наследуется значение
     * @param {number} componentFieldIdTo - id поля, из которого наследуется значение
     *
     * @return {Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>}
     */
    deleteComponentFieldInheritance({ componentFieldIdFrom, componentFieldIdTo }) {
        return this.request(
            {
                action: ServiceAction.COMPONENT_FIELD_INHERITANCE_DELETE_POST,
                pathParams: {
                    from: componentFieldIdFrom,
                    to: componentFieldIdTo
                },
                params: {
                    component_field_id_from: componentFieldIdFrom,
                    component_field_id_to: componentFieldIdTo
                }
            },
            ComponentFieldInheritanceDto
        );
    }

    /**
     * @description Получение информации о наследовании полей компонента
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/component-field-inheritance-controller/findComponentFieldInheritance
     *
     * @param {number|string} [componentFieldIdFrom] - id поля, из которого наследуется значение
     * @param {number|string} [componentFieldIdTo] - id поля, из которого наследуется значение
     *
     * @return {Promise<SafeResult<ComponentFieldInheritanceDto[], Error>>}
     */
    getComponentFieldInheritance({ componentFieldIdFrom, componentFieldIdTo } = {}) {
        return this.request(
            {
                action: ServiceAction.COMPONENT_FIELD_INHERITANCE_GET,
                params: {
                    component_field_id_from: componentFieldIdFrom,
                    component_field_id_to: componentFieldIdTo
                }
            },
            ComponentFieldInheritanceDto
        );
    }

    /**
     * @description Получение всех TaskTypeRole
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllTaskTypeRole
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto[], Error>>}
     */
    getTaskTypeRoles() {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_GET
            },
            TaskTypeRoleDto
        );
    }

    /**
     * @description Получение TaskTypeRole
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getTaskTypeRole
     *
     * @param {number|string} taskTypeRoleId
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto[], Error>>}
     */
    getTaskTypeRoleById(taskTypeRoleId) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE__BY_ID_GET,
                pathParams: {
                    id: taskTypeRoleId
                }
            },
            TaskTypeRoleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/createTaskTypeRole
     * @description Создание TaskTypeRole
     *
     * @param {TaskTypeRoleInput} taskTypeRole
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto, Error>>}
     */
    createTaskTypeRole(taskTypeRole) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_POST,
                params: taskTypeRole
            },
            TaskTypeRoleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/updateTaskTypeRole
     * @description Обновление TaskTypeRole
     *
     * @param {number} taskTypeRoleId
     * @param {TaskTypeRoleInput} taskTypeRole
     *
     * @return {Promise<SafeResult<TaskTypeRoleDto, Error>>}
     */
    updateTaskTypeRole(taskTypeRoleId, taskTypeRole) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PUT,
                pathParams: {
                    id: taskTypeRoleId
                },
                params: taskTypeRole
            },
            TaskTypeRoleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/deleteTaskTypeRole
     * @description Удаление TaskTypeRole
     *
     * @param {number} taskTypeRoleId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeRole(taskTypeRoleId) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_DELETE,
                pathParams: {
                    id: taskTypeRoleId
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/dictionary/getInfo
     * @description Получение данных справочника Info
     *
     * @param {number[]} taskFieldIds
     *
     * @return {Promise<SafeResult<TaskFieldInfoDto[], Error>>}
     */
    getDictionaryInfo(taskFieldIds) {
        return this.request(
            {
                action: ServiceAction.DICTIONARY_INFO_GET,
                params: {
                    task_field_ids: taskFieldIds
                }
            },
            TaskFieldInfoDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/dictionary/getList
     * @description Получение данных справочника List
     *
     * @param {number | string} taskId
     * @param {number[] | string[]} taskTypeFieldId
     *
     * @return {Promise<SafeResult<Object[], Error>>}
     */
    getDictionaries({ taskId, taskTypeFieldIds }) {
        return this.request(
            {
                action: ServiceAction.DICTIONARY_LIST_GET,
                params: {
                    task_type_field_ids: taskTypeFieldIds,
                    task_id: taskId
                }
            },
            DictionaryDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findCondition
     * @description Получение информации об условиях
     *
     * @return {Promise<SafeResult<ConditionDto[], Error>>}
     */
    getConditions() {
        return this.request(
            {
                action: ServiceAction.CONDITION_GET
            },
            ConditionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionModifierByConditionId
     * @description Получение информации о модификаторах условий. Если condition_id = null - возвращаются все модификаторы, иначе - возвращается список доступных модификаторов для выбранного условия
     *
     * @param {number|string} conditionId
     * @return {Promise<SafeResult<ConditionModifierDto[], Error>>}
     */
    getConditionModifiers({ conditionId }) {
        return this.request(
            {
                action: ServiceAction.CONDITION_MODIFIER_GET,
                params: {
                    condition_id: conditionId
                }
            },
            ConditionModifierDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionGroup
     * @description Получение информации о группах условий
     *
     * @return {Promise<SafeResult<ConditionGroupDto[], Error>>}
     */
    getConditionGroups() {
        return this.request(
            {
                action: ServiceAction.CONDITION_GROUP_GET
            },
            ConditionGroupDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/createConditionGroup
     * @description Создание группы условия
     *
     * @param {ConditionGroupInput} conditionGroup
     * @return {Promise<SafeResult<ConditionGroupDto, Error>>}
     */
    createConditionGroup(conditionGroup) {
        return this.request(
            {
                action: ServiceAction.CONDITION_GROUP_POST,
                params: conditionGroup
            },
            ConditionGroupDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/updateConditionGroup
     * @description Обновление группы условия
     *
     * @param {number} conditionGroupId
     *
     * @param {ConditionGroupInput} conditionGroup
     *
     * @return {Promise<SafeResult<ConditionGroupDto, Error>>}
     */
    updateConditionGroup(conditionGroupId, conditionGroup) {
        return this.request(
            {
                action: ServiceAction.CONDITION_GROUP_PUT,
                pathParams: {
                    id: conditionGroupId
                },
                params: conditionGroup
            },
            ConditionGroupDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/deleteConditionGroup
     * @description Удаление группы условия
     *
     * @param {number | string} id
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteConditionGroup(id) {
        return this.request(
            {
                action: ServiceAction.CONDITION_GROUP_DELETE,
                pathParams: {
                    id
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/createCondition
     * @description Создание условия
     *
     * @param {ConditionInput} condition
     *
     * @return {Promise<SafeResult<ConditionDto, Error>>}
     */
    createCondition(condition) {
        return this.request(
            {
                action: ServiceAction.CONDITION_POST,
                params: condition
            },
            ConditionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/updateCondition
     * @description Обновление условия
     *
     * @param {number} conditionId
     * @param {ConditionInput} condition
     *
     * @return {Promise<SafeResult<ConditionDto, Error>>}
     */
    updateCondition(conditionId, condition) {
        return this.request(
            {
                action: ServiceAction.CONDITION_PUT,
                pathParams: {
                    id: conditionId
                },
                params: condition
            },
            ConditionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/createConditionModifier
     * @description Создание модификатора условия
     *
     * @param {ConditionModifierInput} conditionModifier
     *
     * @return {Promise<SafeResult<ConditionModifierDto, Error>>}
     */
    createConditionModifier(conditionModifier) {
        return this.request(
            {
                action: ServiceAction.CONDITION_MODIFIER_POST,
                params: conditionModifier
            },
            ConditionModifierDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/updateConditionModifier
     * @description Обновление модификатора условия
     *
     * @param {number} conditionModifierId
     * @param {ConditionModifierInput} conditionModifier
     *
     * @return {Promise<SafeResult<ConditionModifierDto, Error>>}
     */
    updateConditionModifier(conditionModifierId, conditionModifier) {
        return this.request(
            {
                action: ServiceAction.CONDITION_MODIFIER_PUT,
                pathParams: {
                    id: conditionModifierId
                },
                params: conditionModifier
            },
            ConditionModifierDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/deleteConditionModifier
     * @description Удаление модификатора условия
     *
     * @param {number} conditionModifierId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteConditionModifier(conditionModifierId) {
        return this.request(
            {
                action: ServiceAction.CONDITION_MODIFIER_DELETE,
                pathParams: {
                    id: conditionModifierId
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/findProcessStageTask
     * @description Получение информации о связях этапа процесса и цели
     *
     * @param {number | string} processStageId
     * @param {number[] | string[]} taskIds
     *
     * @return {Promise<SafeResult<ProcessTaskBindingDto[], Error>>}
     */
    getProcessStageTaskBindings({ processStageId, taskIds }) {
        return this.request(
            {
                action: ServiceAction.PROCESS_STAGE_TASK_FIND_GET,
                params: {
                    process_stage_id: processStageId,
                    task_ids: taskIds
                }
            },
            ProcessTaskBindingDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_float_configuration/getAllTaskTypeFieldFloatConfiguration
     * @description Получение всех TaskTypeFieldFloatConfiguration
     *
     * @return {Promise<SafeResult<TaskTypeFieldFloatConfigurationDto[], Error>>}
     */
    getTaskTypeFieldFloatConfigurations() {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_FLOAT_CONFIGURATION_GET
            },
            TaskTypeFieldFloatConfigurationDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_float_configuration/createTaskTypeFieldFloatConfiguration
     * @description Создание TaskTypeFieldFloatConfiguration
     *
     * @param {TaskTypeFieldFloatConfigurationInput} configuration
     * @return {Promise<SafeResult<TaskTypeFieldFloatConfigurationDto, Error>>}
     */
    createTaskTypeFieldFloatConfiguration(configuration) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_FLOAT_CONFIGURATION_POST,
                params: configuration
            },
            TaskTypeFieldFloatConfigurationDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_float_configuration/updateTaskTypeFieldFloatConfiguration
     * @description Обновление TaskTypeFieldFloatConfiguration
     *
     * @param {number | string} configurationId
     * @param {TaskTypeFieldFloatConfigurationInput} configuration
     *
     * @return {Promise<SafeResult<TaskTypeFieldFloatConfigurationDto, Error>>}
     */
    updateTaskTypeFieldFloatConfiguration(configurationId, configuration) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_FLOAT_CONFIGURATION_POST,
                params: configuration,
                pathParams: {
                    id: configurationId
                }
            },
            TaskTypeFieldFloatConfigurationDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/deleteStatusChangeRuleConditionGroup
     * @description Удаление StatusChangeRuleConditionGroup
     *
     * @param {number | string} configurationId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeFieldFloatConfiguration(configurationId) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_FLOAT_CONFIGURATION_DELETE,
                pathParams: {
                    id: configurationId
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionKindByConditionId
     * @description Получение вида состояния (condition kind). Если conditionKindId = null - возвращаются все виды состояний, иначе - возвращается список доступных видов состояний для выбранного условия
     *
     * @param {string} [conditionKindCode]
     *
     * @return {Promise<SafeResult<ConditionKindDto[], Error>>}
     */
    getConditionKinds({ conditionKindCode } = {}) {
        return this.request(
            {
                action: ServiceAction.CONDITION_KIND_GET,
                params: {
                    conditionKindCode
                }
            },
            ConditionKindDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findComparisonSignById
     * @description Получение сравнения подписи (comparison sign). Если comparisonSignId = null - возвращаются все сравнения подписи, иначе - возвращается список доступных сравнений подписей для выбранного условия
     *
     * @param {string} [comparisonSignCode]
     *
     * @return {Promise<SafeResult<ComparisonSignDto[], Error>>}
     */
    getComparisonSigns({ comparisonSignCode } = {}) {
        return this.request(
            {
                action: ServiceAction.COMPARISON_SIGN_GET,
                params: {
                    comparisonSignCode
                }
            },
            ComparisonSignDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionModifierKindByConditionId
     * @description Получение вида модификатора состояния (condition modifier kind). Если conditionModifierKindId = null - возвращаются все виды модификаторов состояний, иначе - возвращается список доступных видов модификаторов состояний для выбранного условия
     *
     * @param {string} [conditionModifierKindCode]
     *
     * @return {Promise<SafeResult<ConditionModifierKindDto[], Error>>}
     */
    getConditionModifierKinds({ conditionModifierKindCode } = {}) {
        return this.request(
            {
                action: ServiceAction.CONDITION_MODIFIER_KIND_GET,
                params: {
                    conditionModifierKindCode
                }
            },
            ConditionModifierKindDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/condition/findConditionModifierKindConditionKindById
     * @description Получение модификатора условия вида условия (condition modifier kind condition kind). Если conditionModifierKindConditionKindId = null - возвращаются все модификаторы условия вида условия, иначе - возвращается список доступных модификаторов условия вида условия для выбранного условия
     *
     * @param {string} conditionModifierKindCode
     * @param {string} conditionKindCode
     *
     * @return {Promise<SafeResult<ConditionModifierKindConditionKindDto[], Error>>}
     */
    getConditionModifierKindConditionKinds({ conditionModifierKindCode, conditionKindCode } = {}) {
        return this.request(
            {
                action: ServiceAction.CONDITION_MODIFIER_KIND_CONDITION_KIND_GET,
                params: {
                    conditionModifierKindCode,
                    conditionKindCode
                }
            },
            ConditionModifierKindConditionKindDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllTaskTypeRolePermission
     * @description Получение всех TaskTypeRolePermission
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionDto[], Error>>}
     */
    getTaskTypeRolePermissions() {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_GET
            },
            TaskTypeRolePermissionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/createTaskTypeRolePermission
     * @description Создание TaskTypeRolePermission
     *
     * @param {TaskTypeRolePermissionInput} taskTypeRolePermission
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionDto, Error>>}
     */
    createTaskTypeRolePermission(taskTypeRolePermission) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_POST,
                params: taskTypeRolePermission
            },
            TaskTypeRolePermissionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/updateTaskTypeRolePermission
     * @description Обновление TaskTypeRolePermission
     *
     * @param {number} taskTypeRolePermissionId
     * @param {TaskTypeRolePermissionInput} taskTypeRolePermission
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionDto, Error>>}
     */
    updateTaskTypeRolePermission(taskTypeRolePermissionId, taskTypeRolePermission) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_PUT,
                pathParams: {
                    id: taskTypeRolePermissionId
                },
                params: taskTypeRolePermission
            },
            TaskTypeRolePermissionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/deleteTaskTypeRolePermission
     * @description Удаление TaskTypeRolePermission
     *
     * @param {number} taskTypeRolePermissionId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeRolePermission(taskTypeRolePermissionId) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_DELETE,
                pathParams: {
                    id: taskTypeRolePermissionId
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_role_permission_field_restriction/createTaskTypeRolePermissionFieldRestriction
     * @description Получение всех ограничений к полям таска
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto[], Error>>}
     */
    getTaskTypeRolePermissionFieldRestrictions() {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_GET
            },
            TaskTypeRolePermissionFieldRestrictionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/
     * @description Создание ограничений к полям таска
     *
     * @param {TaskTypeRolePermissionFieldRestrictionInput} fieldRestriction
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto, Error>>}
     */
    createTaskTypeRolePermissionFieldRestriction(fieldRestriction) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_POST,
                params: fieldRestriction
            },
            TaskTypeRolePermissionFieldRestrictionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_role_permission_field_restriction/updateTaskTypeRolePermissionFieldRestriction
     * @description Изменение ограничений к полям таска
     *
     * @param {number} fieldRestrictionId
     * @param {TaskTypeRolePermissionFieldRestrictionInput} fieldRestriction
     *
     * @return {Promise<SafeResult<TaskTypeRolePermissionFieldRestrictionDto, Error>>}
     */
    updateTaskTypeRolePermissionFieldRestriction(fieldRestrictionId, fieldRestriction) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_PUT,
                pathParams: {
                    id: fieldRestrictionId
                },
                params: fieldRestriction
            },
            TaskTypeRolePermissionFieldRestrictionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_role_permission_field_restriction/deleteTaskTypeRolePermissionFieldRestriction
     * @description Удаление ограничений к полям таска
     *
     * @param {number} fieldRestrictionId
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeRolePermissionFieldRestriction(fieldRestrictionId) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_DELETE,
                pathParams: {
                    id: fieldRestrictionId
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/createEvaluationTasks
     * @description Создание показателей
     *
     * @param {EvaluationTaskInput} task
     *
     * @return {Promise<SafeResult<Array, Error>>}
     */
    createTaskWithEvaluation(task) {
        return this.request(
            {
                action: ServiceAction.BFF_TASK_EVALUATION_UPDATE_POST,
                params: task
            },
            Array
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/member/memberExcludeUpdate
     * @description По переданному массиву ИД member изменяется поле is_exclude на переданное значение
     *
     * @param {number[]} ids - member ids
     * @param {boolean} isExclude
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    updateMemberExclude(ids, { isExclude }) {
        return this.request(
            {
                action: ServiceAction.MEMBER_EXCLUDE_UPDATE_PUT,
                params: {
                    ids,
                    is_exclude: isExclude
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/member/create_1
     * @description Создание участника
     *
     * @param {MemberInput} member
     * @return {Promise<SafeResult<MemberDto, Error>>}
     */
    createMember(member) {
        return this.request(
            {
                action: ServiceAction.MEMBER_POST,
                params: member
            },
            MemberDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process/getProcessMembers
     * @description Получение данных о process_stage и member_group
     *
     * @param {number} processId
     * @param {number} userTypeId
     *
     * @return {Promise<SafeResult<ProcessMemberDto[], Error>>}
     */
    getProcessMembers({ processId, userTypeId }) {
        return this.request(
            {
                action: ServiceAction.PROCESS_MEMBERS_GET,
                params: {
                    process_id: processId,
                    user_type_id: userTypeId
                }
            },
            ProcessMemberDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/getAllStatus
     * @description Получение информации о статусах
     *
     * @return {Promise<SafeResult<StatusDto[], Error>>}
     */
    getStatuses() {
        return this.request(
            {
                action: ServiceAction.STATUS_GET
            },
            StatusDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/createStatus
     * @description Создание статуса
     *
     * @param {StatusInput} status
     *
     * @return {Promise<SafeResult<StatusDto, Error>>}
     */
    createStatus(status) {
        return this.request(
            {
                action: ServiceAction.STATUS_POST,
                params: status
            },
            StatusDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/updateStatus
     * @description Обновление статуса
     *
     * @param {number} id
     * @param {StatusInput} status
     *
     * @return {Promise<SafeResult<StatusDto, Error>>}
     */
    updateStatus(id, status) {
        return this.request(
            {
                action: ServiceAction.STATUS_PUT,
                pathParams: {
                    id
                },
                params: status
            },
            StatusDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/deleteStatus
     * @description Удаление статуса
     *
     * @param {number} id
     *
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteStatus(id) {
        return this.request(
            {
                action: ServiceAction.STATUS_DELETE,
                pathParams: {
                    id
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/status/getStatusById
     * @description Получение информации о статусе
     *
     * @return {Promise<SafeResult<StatusDto, Error>>}
     */
    getStatusById(id) {
        return this.request(
            {
                action: ServiceAction.STATUS_BY_ID_GET,
                pathParams: {
                    id
                }
            },
            StatusDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/process_stage_group/getProcessStageGroup
     * @description Получение ProcessStageGroup
     *
     * @param {number} id
     *
     * @return {Promise<SafeResult<ProcessStageGroupDto, Error>>}
     */
    getProcessStageGroupById(id) {
        return this.request(
            {
                action: ServiceAction.PROCESS_STAGE_GROUP_BY_ID_GET,
                pathParams: {
                    id
                }
            },
            ProcessStageGroupDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllStatusChangeRule
     * @description Получение всех StatusChangeRule
     *
     * @return {Promise<SafeResult<StatusChangeRuleDto[], Error>>}
     */
    getStatusChangeRules() {
        return this.request(
            {
                action: ServiceAction.STATUS_CHANGE_RULE_GET
            },
            StatusChangeRuleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getStatusChangeRule
     * @description Получение StatusChangeRule
     *
     * @return {Promise<SafeResult<StatusChangeRuleDto, Error>>}
     */
    getStatusChangeRuleById(id) {
        return this.request(
            {
                action: ServiceAction.STATUS_CHANGE_RULE_BY_ID_GET,
                pathParams: {
                    id
                }
            },
            StatusChangeRuleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/createStatusChangeRule
     * @description Создание StatusChangeRule
     *
     * @param {StatusChangeRuleInput} rule
     * @return {Promise<SafeResult<StatusChangeRuleDto, Error>>}
     */
    createStatusChangeRule(rule) {
        return this.request(
            {
                action: ServiceAction.STATUS_CHANGE_RULE_POST,
                params: rule
            },
            StatusChangeRuleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/updateStatusChangeRule
     * @description Обновление StatusChangeRule
     *
     * @param {number | string} id
     * @param {StatusChangeRuleInput} rule
     *
     * @return {Promise<SafeResult<StatusChangeRuleDto, Error>>}
     */
    updateStatusChangeRule(id, rule) {
        return this.request(
            {
                action: ServiceAction.STATUS_CHANGE_RULE_PUT,
                pathParams: {
                    id
                },
                params: rule
            },
            StatusChangeRuleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/deleteStatusChangeRule
     * @description Удаление StatusChangeRule
     *
     * @param {number} id
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteStatusChangeRule(id) {
        return this.request(
            {
                action: ServiceAction.STATUS_CHANGE_RULE_DELETE,
                pathParams: {
                    id
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/system_status/getAllSystemStatus
     * @description Получение всех SystemStatus
     *
     * @return {Promise<SafeResult<SystemStatusDto, Error>>}
     */
    getSystemStatuses() {
        return this.request(
            {
                action: ServiceAction.SYSTEM_STATUS_GET
            },
            SystemStatusDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/getAllTaskTypeFieldDictionaryConfiguration
     * @description Получение всех TaskTypeFieldDictionaryConfiguration
     *
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto[], Error>>}
     */
    getTaskTypeFieldDictionaryConfigurations() {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_GET
            },
            TaskTypeFieldDictionaryConfigurationDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/createTaskTypeFieldDictionaryConfiguration
     * @description Создание TaskTypeFieldDictionaryConfiguration
     *
     * @param {TaskTypeFieldDictionaryConfigurationInput} taskTypeFieldDictionaryConfiguration
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto, Error>>}
     */
    createTaskTypeFieldDictionaryConfiguration(taskTypeFieldDictionaryConfiguration) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_CREATE,
                params: taskTypeFieldDictionaryConfiguration
            },
            TaskTypeFieldDictionaryConfigurationDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/updateTaskTypeFieldDictionaryConfiguration
     * @description Обновление TaskTypeFieldDictionaryConfiguration
     *
     * @param {number} taskTypeFieldId
     * @param {TaskTypeFieldDictionaryConfigurationUpdateInput} taskTypeFieldDictionaryConfiguration
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto, Error>>}
     */
    updateTaskTypeFieldDictionaryConfiguration({ taskTypeFieldId }, taskTypeFieldDictionaryConfiguration) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_UPDATE,
                pathParams: {
                    task_type_field_id: taskTypeFieldId
                },
                params: taskTypeFieldDictionaryConfiguration
            },
            TaskTypeFieldDictionaryConfigurationDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/deleteTaskTypeFieldDictionaryConfiguration
     * @description Удаление TaskTypeFieldDictionaryConfiguration
     *
     * @param {number} taskTypeFieldId
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTaskTypeFieldDictionaryConfiguration({ taskTypeFieldId }) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_DELETE,
                pathParams: {
                    task_type_field_id: taskTypeFieldId
                }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field_dictionary_configuration/findTaskTypeFieldDictionaryConfiguration
     * @description Поиск TaskTypeFieldDictionaryConfiguration
     *
     * @param {number[]|string[]} taskTypeFieldIds
     * @return {Promise<SafeResult<TaskTypeFieldDictionaryConfigurationDto[], Error>>}
     */
    getTaskTypeFieldDictionaryConfigurationsByIds({ taskTypeFieldIds }) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_FIND_POST,
                queryParams: {
                    taskTypeFieldId: taskTypeFieldIds
                }
            },
            TaskTypeFieldDictionaryConfigurationDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/scale/findActualScale
     * @description Получение информации об актуальных scale
     *
     * @return {Promise<SafeResult<ScaleDto[], Error>>}
     */
    getScales() {
        return this.request(
            {
                action: ServiceAction.SCALE_GET
            },
            ScaleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/getTypeDictionaryServices
     * @description Получение всех сервисов справочников
     *
     * @return {Promise<SafeResult<DictionaryServiceDto[], Error>>}
     */
    getTypeDictionaryServices() {
        return this.request(
            {
                action: ServiceAction.TYPE_DICTIONARY_SERVICES_GET
            },
            DictionaryServiceDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/getTypeDictionaryEntity
     * @description Получение сущности справочника по идентификатору
     *
     * @param {number} id
     * @return {Promise<SafeResult<DictionaryEntityInfoDto, Error>>}
     */
    getTypeDictionaryById(id) {
        return this.request(
            {
                action: ServiceAction.TYPE_DICTIONARY_BY_ID_GET,
                pathParams: {
                    id
                }
            },
            DictionaryEntityInfoDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/getTypeDictionaryEntities
     * @description Получение списка всех справочников
     *
     * @return {Promise<SafeResult<DictionaryEntityInfoDto[], Error>>}
     */
    getTypeDictionaries() {
        return this.request(
            {
                action: ServiceAction.TYPE_DICTIONARY_GET
            },
            DictionaryEntityInfoDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/createTypeDictionaryEntity
     * @description Создание сущности справочника
     *
     * @param {TypeDictionaryInput} typeDictionary
     * @return {Promise<SafeResult<string, Error>>}
     */
    createTypeDictionary(typeDictionary) {
        return this.request(
            {
                action: ServiceAction.TYPE_DICTIONARY_CREATE,
                params: typeDictionary
            },
            String
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/patchTypeDictionaryEntity
     * @description Изменение сущности справочника
     *
     * @param {number} id
     * @param {TypeDictionaryInput} typeDictionary
     * @return {Promise<SafeResult<DictionaryEntityInfoDto, Error>>}
     */
    updateTypeDictionary(id, typeDictionary) {
        return this.request(
            {
                action: ServiceAction.TYPE_DICTIONARY_UPDATE,
                params: {
                    id,
                    ...typeDictionary
                },
                pathParams: { id }
            },
            DictionaryEntityInfoDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/typedictionary/deleteTypeDictionaryEntity
     * @description Удаление сущности справочника
     *
     * @param {number} id
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteTypeDictionary(id) {
        return this.request(
            {
                action: ServiceAction.TYPE_DICTIONARY_DELETE,
                pathParams: { id }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/basic_data_type/fetch
     * @description Получение информации о базовых типах данных
     *
     * @return {Promise<SafeResult<BasicDataTypeDto[], Error>>}
     */
    getBasicDataTypes() {
        return this.request(
            {
                action: ServiceAction.BASIC_DATA_TYPE_GET
            },
            BasicDataTypeDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/getCustomDictionaryByName
     * @description Получение информации о кастомном справочнике по названию справочника.
     *
     * @param {CustomDictionaryFilterInput} name
     * @return {Promise<SafeResult<CustomDictionaryDto[], Error>>}
     */
    getCustomDictionaries({ name }) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_GET,
                queryParams: { name }
            },
            CustomDictionaryDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/createCustomDictionary_1
     * @description Создание кастомного справочника
     *
     * @param {CustomDictionaryInput} customDictionary
     * @return {Promise<SafeResult<number, Error>>}
     */
    createCustomDictionary(customDictionary) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_CREATE,
                params: customDictionary
            },
            Number
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/getCustomDictionaryColumns
     * @description Получение информации о полях справочника по идентификатору справочника.
     *
     * @param {import("./type").CustomDictionaryColumnsFilterInput} tableId
     * @return {Promise<SafeResult<CustomDictionaryColumnDto[], Error>>}
     */
    getCustomDictionaryColumns({ tableId }) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_COLUMN_GET,
                queryParams: {
                    table_id: tableId
                }
            },
            CustomDictionaryColumnDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/createCustomDictionary
     * @description Добавление поля кастомного справочника
     *
     * @param {import("./type").CustomDictionaryColumnsFilterInput} tableId
     * @param {CustomDictionaryColumnInput} customDictionaryColumn
     * @return {Promise<SafeResult<number, Error>>}
     */
    createCustomDictionaryColumn({ tableId }, customDictionaryColumn) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_COLUMN_CREATE,
                queryParams: { table_id: tableId },
                params: customDictionaryColumn
            },
            Number
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/patchCustomDictionaryColumn
     * @description Изменение поля кастомного справочника
     *
     * @param {number} id
     * @param {CustomDictionaryColumnInput} customDictionaryColumn
     * @return {Promise<SafeResult<CustomDictionaryColumnDto, Error>>}
     */
    updateCustomDictionaryColumn(id, customDictionaryColumn) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_COLUMN_UPDATE,
                pathParams: { id },
                params: customDictionaryColumn
            },
            CustomDictionaryColumnDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/deleteCustomDictionaryColumn
     * @description Удаление поля кастомного справочника
     *
     * @param {number} id
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteCustomDictionaryColumn(id) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_COLUMN_DELETE,
                pathParams: { id }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/getCustomDictionaryColumnRows
     * @description Получение данных справочника
     *
     * @param {import("./type").CustomDictionaryColumnRowsFilterInput} filter
     * @param {import("./type").CustomDictionaryColumnRowsOptionsInput} options
     * @return {Promise<SafeResult<CustomDictionaryColumnRowsPage, Error>>}
     */
    getCustomDictionaryColumnRowsByFilter(
        { tableId, tableName, columnIds, columnNames } = {},
        { page, size, sort } = {}
    ) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_DATA_GET,
                params: {
                    ...(tableId && { table_id: tableId }),
                    ...(tableName && { table_name: tableName }),
                    ...(columnIds && { column_ids: columnIds }),
                    ...(columnNames && { column_names: columnNames }),
                    ...(page != null && { page }),
                    ...(size != null && { size }),
                    ...(sort != null && { sort })
                }
            },
            CustomDictionaryColumnRowsPage
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/insertCustomDictionaryData
     * @description Добавление данных кастомного справочника
     *
     * @param {CustomDictionaryColumnRowInput[]} customDictionaryColumnRows
     * @return {Promise<SafeResult<CustomDictionaryColumnRowDto[], Error>>}
     */
    createCustomDictionaryColumnRows(customDictionaryColumnRows) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_DATA_CREATE,
                params: customDictionaryColumnRows
            },
            CustomDictionaryColumnRowDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/patchCustomDictionaryData
     * @description Изменение данных кастомного справочника
     *
     * @param {CustomDictionaryColumnRowInput[]} customDictionaryColumnRows
     * @return {Promise<SafeResult<CustomDictionaryColumnRowDto[], Error>>}
     */
    updateCustomDictionaryColumnRows(customDictionaryColumnRows) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_DATA_UPDATE,
                params: customDictionaryColumnRows
            },
            CustomDictionaryColumnRowDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/customdictionary/deleteCustomDictionaryData
     * @description Удаление данных кастомного справочника
     *
     * @param {number[]} customDictionaryColumnRowsIds
     * @return {Promise<SafeResult<OperationResultDto, Error>>}
     */
    deleteCustomDictionaryColumnRows(customDictionaryColumnRowsIds) {
        return this.request(
            {
                action: ServiceAction.CUSTOM_DICTIONARY_DATA_DELETE,
                queryParams: { ids: customDictionaryColumnRowsIds }
            },
            OperationResultDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/dictionary/getMetadata
     * @description Получение базовой информации о сервисе (версия, профиль, используемая БД и сервер авторизации)
     *
     * @param {number[] | string[]} taskTypeFieldIds
     *
     * @return {Promise<SafeResult<DictionaryMetaDataDto[], Error>>}
     */
    getDictionaryMetaData(taskTypeFieldIds) {
        return this.request(
            {
                action: ServiceAction.DICTIONARY_META_DATA_GET,
                params: {
                    taskTypeFieldId: taskTypeFieldIds
                }
            },
            DictionaryMetaDataDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/createTaskAndCheckKpiDuplicate
     * @description Создание цели с проверкой на существование в БД актуального филда с component_field.code="id kpi"
     *
     * @param {TaskCreateInputDto} task
     *
     * @param {Object} [queryParams]
     * @param {number | string} [queryParams.processId]
     * @param {number | string} [queryParams.taskTypeRoleId]
     *
     * @return {Promise<SafeResult<Number, Error>>}
     */
    createTaskWithoutKpiDuplicates(task, { processId, taskTypeRoleId } = {}) {
        return this.request(
            {
                action: ServiceAction.TASK_UPDATE_CHECK_KPI_DUPLICATE_POST,
                params: task,
                queryParams: {
                    process_id: processId,
                    task_type_role_id: taskTypeRoleId
                }
            },
            Number
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_field/taskTypeFieldInheritanceValue
     * @description Метод поиска наследуемых значений у филда
     *
     * @param {number|string} taskTypeId
     * @param {number|string} baseTaskId
     *
     * @return {Promise<SafeResult<TaskTypeFieldInheritanceValueDto[], Error>>}
     */
    getTaskTypeFieldInheritanceValues({ taskTypeId, baseTaskId }) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_FIELD_INHERITANCE_VALUE_GET,
                params: {
                    taskTypeId,
                    baseTaskId
                }
            },
            TaskTypeFieldInheritanceValueDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task/evaluateIndexes
     * @description Метод оценки показателя
     *
     * @param {number | string} processStageId
     *
     * @return {Promise<SafeResult<void, Error>>}
     */
    evaluateProcessStageEvaluationTasks(processStageId) {
        return this.request({
            action: ServiceAction.BFF_TASK_EVALUATE_INDEXES_POST,
            queryParams: {
                process_stage_id: processStageId
            }
        });
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/member_group/createMemberGroup_1
     * @description Создание MemberGroup
     *
     * @param {MemberGroupInput} memberGroup
     *
     * @return {Promise<SafeResult<MemberGroupDto, Error>>}
     */
    createMemberGroup(memberGroup) {
        return this.request(
            {
                action: ServiceAction.MEMBER_GROUP_POST,
                params: memberGroup
            },
            MemberGroupDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html#/task/taskDataLoad
     * @description Создание целей из массива
     *
     * @param {TaskRawDataInput[]} tasks
     *
     * @return {Promise<SafeResult<TaskRawDataDto[], Error>>}
     */
    createTasks(tasks) {
        return this.request(
            {
                action: ServiceAction.TASK_LOAD_DATA_POST,
                params: tasks
            },
            TaskRawDataDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/task_type_parent_permission/get
     * @description Метод чтения иерархической подчиненности типов тасков
     *
     * @param {number | string} [parentTaskTypeId]
     * @param {number | string} [childTaskTypeId]
     *
     * @return {Promise<SafeResult<TaskTypeParentPermissionDto[], Error>>}
     */
    getTaskTypeParentPermissions({ parentTaskTypeId, childTaskTypeId } = {}) {
        return this.request(
            {
                action: ServiceAction.TASK_TYPE_PARENT_PERMISSION_GET,
                params: {
                    parent_id: parentTaskTypeId,
                    child_id: childTaskTypeId
                }
            },
            TaskTypeParentPermissionDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/evaluation_scale/findActualEvaluationScale
     * @description Получение информации об актуальных evaluation_scale
     *
     * @return {Promise<SafeResult<EvaluationScaleDto[], Error>>}
     */
    getEvaluationScales() {
        return this.request(
            {
                action: ServiceAction.EVALUATION_SCALE_GET
            },
            EvaluationScaleDto
        );
    }

    /**
     * @link https://goodt-dev.goodt.me:8488/swagger-ui/index.html?configUrl=/v3/api-docs/swagger-config#/role/getAllRole
     * @description Получение всех Role
     *
     * @return {Promise<SafeResult<RoleInfoDto[], Error>>}
     */
    getRoles() {
        return this.request(
            {
                action: ServiceAction.ROLE_GET
            },
            RoleInfoDto
        );
    }
}
