import { ApiClientMethod } from '@goodt-common/api';

export const ServiceAction = {
    TASK_TREES_GET: {
        url: 'task/trees',
        resultTransformer: (result) => result.flatMap(({ tree }) => tree),
        options: {
            method: ApiClientMethod.POST,
            // use caching for `POST` method
            cache: true,
            paramsSerializer: (params) => new URLSearchParams(params)
        }
    },
    TASK_CONDITIONS_GET: { url: 'task/conditions' },
    TASK_LINKLIST_GET: {
        url: 'task/linklist/array',
        options: {
            paramsSerializer: (params) => new URLSearchParams(params)
        }
    },
    TASK_LINK_UPDATE: {
        url: 'task/linkupdate',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_LINK_TYPE: {
        url: 'task/linktype'
    },
    TASK_INFO_GET: { url: 'task/info' },
    TASK_TYPE_ALL_GET: { url: 'tasktype' },
    TASK_TYPE_GET: { url: 'tasktype/:id' },
    TASK_REPLACE: { url: '/task/update/:id', options: { method: ApiClientMethod.PUT } },
    TASK_CREATE: { url: '/task/update', options: { method: ApiClientMethod.POST } },
    TASK_UPDATE: { url: '/task/update', options: { method: ApiClientMethod.POST } },
    TASK_UPDATE_PUT: { url: '/task/update', options: { method: ApiClientMethod.PUT } },
    TASK_STATUS_UPDATE: {
        url: 'task/statuschange',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_DELETE: {
        url: 'task/delete',
        options: {
            method: ApiClientMethod.POST
        }
    },
    DELETE_LINK: {
        url: 'task/linkdelete/:id',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_FIND: {
        url: 'task/find',
        options: {
            method: ApiClientMethod.POST,
            // use caching for `POST` method
            cache: true
        }
    },
    TASK_HISTORY_GET: { url: 'task/history' },
    PROCESS_TASK_BINDINGS_GET: {
        url: 'processtask/find'
    },
    PROCESS_GET_BY_ID: {
        url: 'process/:id'
    },
    PROCESSES_GET_BY_FILTER: {
        url: 'process'
    },
    PROCESS_GET_TYPES: {
        url: 'process/type'
    },
    PROCESS_CREATE: {
        url: 'process',
        options: {
            method: ApiClientMethod.POST
        }
    },
    PROCESS_UPDATE: {
        url: 'process/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    PROCESS_DELETE: {
        url: 'process/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    PROCESS_STAGE_GET_BY_ID: {
        url: 'process/stage/:id'
    },
    PROCESS_STAGE_GET_TYPES: {
        url: 'process/stage_type'
    },
    PROCESS_STAGE_GET: {
        url: 'process/stage'
    },
    PROCESS_STAGE_CREATE: {
        url: 'process/stage',
        options: {
            method: ApiClientMethod.POST
        }
    },
    PROCESS_STAGE_UPDATE: {
        url: 'process/stage/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    PROCESS_STAGE_DELETE: {
        url: 'process/stage/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    FILE_UPLOAD_POST: {
        url: 'file/upload',
        options: {
            method: ApiClientMethod.POST,
            headers: {
                'Content-Type': 'multipart/form-data'
            }
        }
    },
    FILE_DOWNLOAD_GET: {
        url: 'file/download/:taskFieldId',
        options: {
            responseType: 'blob',
            // eslint-disable-next-line no-restricted-syntax
            transformResponse: [
                (data, headers) => ({
                    headers,
                    data
                })
            ]
        }
    },
    TASK_STATUS_CHANGE_BULK_POST: {
        url: 'task/statuschangebulk',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_FIND_POST: {
        url: 'tasktype/find',
        options: {
            method: ApiClientMethod.POST
        }
    },
    MODULE_GET: {
        url: 'module'
    },
    ACCESS_TYPE_GET: {
        url: 'accesstype'
    },
    USER_TYPE_GET: {
        url: 'usertype'
    },
    TASK_TYPE_FIELD_GROUP_GET: {
        url: 'tasktypefieldgroup'
    },
    TASK_TYPE_FIELD_TYPE_GET: {
        url: 'tasktypefieldtype'
    },
    TASK_TYPE_UPDATE_POST: {
        url: 'tasktype/update',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_UPDATE_PUT: {
        url: 'tasktype/update',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    TASK_TYPE_FIELD_GET: {
        url: 'tasktypefield'
    },
    TASK_TYPE_FIELD_DELETE_POST: {
        url: 'tasktypefield/delete',
        options: {
            method: ApiClientMethod.POST
        }
    },
    COMPONENT_TASK_TYPE_FIELD_GET: {
        url: 'componenttasktypefield'
    },
    TASK_TYPE_DELETE_POST: {
        url: 'tasktype/delete',
        options: {
            method: ApiClientMethod.POST
        }
    },
    BFF_COMPETENCE_ADD_COMMENT_POST: {
        url: 'bff/competence/addcomment',
        options: {
            method: ApiClientMethod.POST
        }
    },
    FIELD_TYPE_GET: {
        url: 'fieldtype'
    },
    FIELD_COMPONENT_GET: {
        url: 'component'
    },
    TASK_TYPE_PARENT_PERMISSION_GET: {
        url: 'tasktypeparentpermission'
    },
    TASK_TYPE_PARENT_PERMISSION_CREATE_POST: {
        url: 'tasktypeparentpermission/create',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_PARENT_PERMISSION_DELETE: {
        url: 'tasktypeparentpermission',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    TASK_STATUS_LIST_GET: {
        url: 'task/status/list'
    },
    COMPONENT_FIELD_GET: {
        url: 'componentfield'
    },
    COMPONENT_FIELD_CREATE_POST: {
        url: 'componentfield/create',
        options: {
            method: ApiClientMethod.POST
        }
    },
    COMPONENT_FIELD_INHERITANCE_GET: {
        url: 'componentfieldinheritance'
    },
    COMPONENT_FIELD_INHERITANCE_CREATE_POST: {
        url: 'componentfieldinheritance/create',
        options: {
            method: ApiClientMethod.POST
        }
    },
    COMPONENT_FIELD_INHERITANCE_DELETE_POST: {
        url: 'componentfieldinheritance/delete/:from/:to',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_ROLE_GET: {
        url: 'tasktyperole',
        options: {
            method: ApiClientMethod.GET
        }
    },
    TASK_TYPE_ROLE__BY_ID_GET: {
        url: 'tasktyperole/:id',
        options: {
            method: ApiClientMethod.GET
        }
    },
    TASK_TYPE_ROLE_POST: {
        url: 'tasktyperole',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_ROLE_PUT: {
        url: 'tasktyperole/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    TASK_TYPE_ROLE_DELETE: {
        url: 'tasktyperole/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    DICTIONARY_INFO_GET: {
        url: 'dictionary/info'
    },
    DICTIONARY_LIST_GET: {
        url: 'dictionary/list'
    },
    CONDITION_GET: {
        url: 'condition'
    },
    CONDITION_POST: {
        url: 'condition',
        options: {
            method: ApiClientMethod.POST
        }
    },
    CONDITION_PUT: {
        url: 'condition/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    CONDITION_MODIFIER_GET: {
        url: 'conditionmodifier'
    },
    CONDITION_MODIFIER_POST: {
        url: 'conditionmodifier',
        options: {
            method: ApiClientMethod.POST
        }
    },
    CONDITION_MODIFIER_PUT: {
        url: 'conditionmodifier/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    CONDITION_MODIFIER_DELETE: {
        url: 'conditionmodifier/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    CONDITION_GROUP_GET: {
        url: 'conditiongroup'
    },
    CONDITION_GROUP_POST: {
        url: 'conditiongroup',
        options: {
            method: ApiClientMethod.POST
        }
    },
    CONDITION_GROUP_PUT: {
        url: 'conditiongroup/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    CONDITION_GROUP_DELETE: {
        url: 'condition/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    PROCESS_STAGE_TASK_FIND_GET: {
        url: 'processstagetask/find'
    },
    TASK_TYPE_FIELD_FLOAT_CONFIGURATION_GET: {
        url: 'task-type-field-float-configuration'
    },
    TASK_TYPE_FIELD_FLOAT_CONFIGURATION_POST: {
        url: 'task-type-field-float-configuration',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_FIELD_FLOAT_CONFIGURATION_PUT: {
        url: 'task-type-field-float-configuration/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    TASK_TYPE_FIELD_FLOAT_CONFIGURATION_DELETE: {
        url: 'task-type-field-float-configuration/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    CONDITION_KIND_GET: {
        url: 'condition-kind'
    },
    COMPARISON_SIGN_GET: {
        url: 'comparison-sign'
    },
    CONDITION_MODIFIER_KIND_GET: {
        url: 'condition-modifier-kind'
    },
    CONDITION_MODIFIER_KIND_CONDITION_KIND_GET: {
        url: 'condition-modifier-kind-condition-kind'
    },
    TASK_TYPE_ROLE_PERMISSION_GET: {
        url: 'tasktyperolepermission'
    },
    TASK_TYPE_ROLE_PERMISSION_POST: {
        url: 'tasktyperolepermission',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_ROLE_PERMISSION_PUT: {
        url: 'tasktyperolepermission/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    TASK_TYPE_ROLE_PERMISSION_DELETE: {
        url: 'tasktyperolepermission/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_GET: {
        url: 'tasktyperolepermissionfieldrestriction'
    },
    TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_POST: {
        url: 'tasktyperolepermissionfieldrestriction',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_PUT: {
        url: 'tasktyperolepermissionfieldrestriction/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    TASK_TYPE_ROLE_PERMISSION_FIELD_RESTRICTION_DELETE: {
        url: 'tasktyperolepermissionfieldrestriction/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    BFF_TASK_EVALUATION_UPDATE_POST: {
        url: 'bff/task-evaluation-update',
        options: {
            method: ApiClientMethod.POST
        }
    },
    MEMBER_EXCLUDE_UPDATE_PUT: {
        url: 'member/exclude-update',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    MEMBER_POST: {
        url: 'member',
        options: {
            method: ApiClientMethod.POST
        }
    },
    PROCESS_MEMBERS_GET: {
        url: 'process/members'
    },
    STATUS_GET: {
        url: 'status'
    },
    STATUS_POST: {
        url: 'status',
        options: {
            method: ApiClientMethod.POST
        }
    },
    STATUS_PUT: {
        url: 'status/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    STATUS_DELETE: {
        url: 'status/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    STATUS_BY_ID_GET: {
        url: 'status/:id'
    },
    PROCESS_STAGE_GROUP_BY_ID_GET: {
        url: 'process-stage-group/:id'
    },
    STATUS_CHANGE_RULE_GET: {
        url: 'statuschangerule'
    },
    STATUS_CHANGE_RULE_BY_ID_GET: {
        url: 'statuschangerule/:id'
    },
    STATUS_CHANGE_RULE_POST: {
        url: 'statuschangerule',
        options: {
            method: ApiClientMethod.POST
        }
    },
    STATUS_CHANGE_RULE_DELETE: {
        url: 'statuschangerule/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    STATUS_CHANGE_RULE_PUT: {
        url: 'statuschangerule/:id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    SYSTEM_STATUS_GET: {
        url: 'system-status'
    },
    TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_GET: {
        url: 'tasktypefielddictionaryconfiguration'
    },
    TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_CREATE: {
        url: 'tasktypefielddictionaryconfiguration',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_UPDATE: {
        url: 'tasktypefielddictionaryconfiguration/:task_type_field_id',
        options: {
            method: ApiClientMethod.PUT
        }
    },
    TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_FIND_POST: {
        url: 'task-type-field-dictionary-configuration/find',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_FIELD_DICTIONARY_CONFIGURATION_DELETE: {
        url: 'tasktypefielddictionaryconfiguration/:task_type_field_id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    SCALE_GET: {
        url: 'scale'
    },
    TYPE_DICTIONARY_SERVICES_GET: {
        url: 'typedictionary/services'
    },
    TYPE_DICTIONARY_BY_ID_GET: {
        url: 'typedictionary/:id'
    },
    TYPE_DICTIONARY_GET: {
        url: 'typedictionary'
    },
    TYPE_DICTIONARY_CREATE: {
        url: 'typedictionary',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TYPE_DICTIONARY_UPDATE: {
        url: 'typedictionary/:id',
        options: {
            method: ApiClientMethod.PATCH
        }
    },
    TYPE_DICTIONARY_DELETE: {
        url: 'typedictionary/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    BASIC_DATA_TYPE_GET: {
        url: 'basicdatatype'
    },
    CUSTOM_DICTIONARY_GET: {
        url: 'customdictionary'
    },
    CUSTOM_DICTIONARY_CREATE: {
        url: 'customdictionary',
        options: {
            method: ApiClientMethod.POST
        }
    },
    CUSTOM_DICTIONARY_COLUMN_GET: {
        url: 'customdictionarycolumn'
    },
    CUSTOM_DICTIONARY_COLUMN_CREATE: {
        url: 'customdictionarycolumn',
        options: {
            method: ApiClientMethod.POST
        }
    },
    CUSTOM_DICTIONARY_COLUMN_UPDATE: {
        url: 'customdictionarycolumn/:id',
        options: {
            method: ApiClientMethod.PATCH
        }
    },
    CUSTOM_DICTIONARY_COLUMN_DELETE: {
        url: 'customdictionarycolumn/:id',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    CUSTOM_DICTIONARY_DATA_GET: {
        url: 'customdictionary/data'
    },
    CUSTOM_DICTIONARY_DATA_CREATE: {
        url: 'customdictionary/data',
        options: {
            method: ApiClientMethod.POST
        }
    },
    CUSTOM_DICTIONARY_DATA_UPDATE: {
        url: 'customdictionary/data',
        options: {
            method: ApiClientMethod.PATCH
        }
    },
    CUSTOM_DICTIONARY_DATA_DELETE: {
        url: 'customdictionary/data',
        options: {
            method: ApiClientMethod.DELETE
        }
    },
    DICTIONARY_META_DATA_GET: {
        url: 'dictionary/metadata'
    },
    TASK_UPDATE_CHECK_KPI_DUPLICATE_POST: {
        url: 'task/update/check-kpi-duplicate',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_TYPE_FIELD_INHERITANCE_VALUE_GET: {
        url: 'task-type-field/inheritance-value'
    },
    BFF_TASK_EVALUATE_INDEXES_POST: {
        url: 'bff/task-evaluate-indexes',
        options: {
            method: ApiClientMethod.POST
        }
    },
    MEMBER_GROUP_POST: {
        url: 'member-group',
        options: {
            method: ApiClientMethod.POST
        }
    },
    TASK_LOAD_DATA_POST: {
        url: 'task/loaddata',
        options: {
            method: ApiClientMethod.POST
        }
    },
    EVALUATION_SCALE_GET: {
        url: 'evaluation-scale'
    },
    ROLE_GET: {
        url: 'role'
    }
};
