import { BaseDto } from '@goodt-common/infra';
import { ITaskDto } from './type';

export class UserTaskTreeDto extends BaseDto {}
export class TaskDto extends BaseDto implements ITaskDto {}
export class TaskRawExtendedDto extends BaseDto {}
export class TaskLinkDto extends BaseDto {}
export class TaskTypeDto extends BaseDto {
    id: number;
    name: string;
    component: ComponentDto;
    access_type: AccessTypeDto;
    user_type: UserTypeDto;
    task_type_fields: TaskTypeFieldDto;
    description: string;
    date_from: string;
    date_to: string;
    task_type_parent_permission: any;
    parent_id: number;
}
export class ModuleDto extends BaseDto {
    code: string;
    name: string;
    description: string;
    is_adminable: number;
}
export class AccessTypeDto extends BaseDto {
    id: number;
    name: string;
}
export class UserTypeDto extends BaseDto {
    id: number;
    name: string;
}
export class TaskTypeFieldDto extends BaseDto {
    id: number;
    name: string;
    params: string;
    description: string;
    index: number;
    is_required: number;
    date_from: string;
    date_to: string;
    is_hidden: boolean;
    is_final: boolean;
    is_system: boolean;
    task_type_field_group: TaskTypeFieldGroupDto;
    component_field: ComponentFieldDto;
    field_type_code: string;
}
export class TaskTypeFieldGroupDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    index: number;
}
export class DictionaryServiceDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    base_uri: string;
    is_using_auth_token: boolean;
}
export class DictionaryEntityInfoDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    dictionary_service: DictionaryServiceDto;
    dictionary_service_endpoint_uri: string;
    key_basic_data_type_code: string;
    key_field_name: string;
    value_basic_data_type_code: string;
    value_field_name: string;
}
export class TaskTypeFieldDictionaryConfigurationDto extends BaseDto {
    task_type_field: TaskFieldTypeDto;
    dictionary_entity_list: DictionaryEntityInfoDto;
    dictionary_entity_info: DictionaryEntityInfoDto;
    is_multiselect: boolean;
    is_readonly: boolean;
}
export class TaskTypeFieldTypeDto extends BaseDto {}
export class ComponentTaskTypeFieldDto extends BaseDto {}
export class CompetenceCommentDto extends BaseDto {}
export class ComponentFieldShortDto extends BaseDto {
    id: number;
    code: string;
    name: string;
    description: string;
    component_id: number;
    field_type_code: string;
    is_required: boolean;
}
export class ComponentDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    module: ModuleDto;
    date_from: string;
    date_to: string;
    component_field: ComponentFieldShortDto[];
}
export class TaskTypeParentPermissionDto extends BaseDto {
    taskTypeParent: string;
    taskTypeChild: string;
}

export class TaskHistoryResultDto extends BaseDto {
    task_history: TaskDto[];
    field_history: Record<string, TaskFieldDto[]>;
}

type TaskConditionCheckDto = {
    name: string;
    success: boolean;
};

export class TaskConditionsDto extends BaseDto {
    name: string;
    isRequired: boolean;
    conditions: TaskConditionCheckDto[];
    is_required: boolean;
}

export class ProcessDto extends BaseDto {}
export class ProcessStageShortDto extends BaseDto {}

export class ProcessInfoDto extends BaseDto {
    process: ProcessDto;
    process_stages: ProcessStageShortDto[];
}

export class ProcessStageDto extends BaseDto {}

export class ProcessTypeDto extends BaseDto {}
export class ProcessStageTypeDto extends BaseDto {}
export class ProcessTaskBindingDto extends BaseDto {
    process: ProcessDto;
    task: TaskRawExtendedDto;
}
export class CustomDictionaryDto extends BaseDto {
    id: number;
    name: string;
    description: string;
}

type Table = {
    id: number;
    name: string;
    description: string;
};

export class CustomDictionaryColumnDto extends BaseDto {
    id: number;
    index: number;
    name: string;
    description: string;
    basic_data_type_code: string;
    table: Table;
}

export class CustomDictionaryColumnRowsPage extends BaseDto {
    content: CustomDictionaryColumnRowDto[];
    empty: boolean;
    first: boolean;
    last: boolean;
    number: number;
    numberOfElements: number;
    pageable: Pageable;
    size: number;
    sort: Sort;
    totalElements: number;
    totalPages: number;
}

type Sort = {
    empty: boolean;
    unsorted: boolean;
    sorted: boolean;
};

type Pageable = {
    offset: number;
    pageNumber: number;
    pageSize: number;
    paged: boolean;
    sort: Sort;
    unpaged: boolean;
};

class CustomDictionaryColumnRow extends BaseDto {
    id: number;
    index: number;
    value: string;
    column_id: number;
}

export class CustomDictionaryColumnRowDto extends BaseDto {
    id: number;
    index: number;
    value: string;
}

// Input classes
export type TypeDictionaryInput = {
    name: string;
    description: string;
    dictionary_service: number;
    dictionary_service_endpoint_uri: string;
    key_basic_data_type_code: string;
    key_field_name: string;
    value_basic_data_type_code: string;
    value_field_name: string;
};

export type CustomDictionaryFilterInput = Pick<CustomDictionaryDto, 'name'>;

export type TaskTypeFieldDictionaryConfigurationInput = {
    task_type_field_id: number;
    dictionary_entity_list: number;
    dictionary_entity_info: number;
    is_multiselect: boolean;
    is_readonly: boolean;
};
export type TaskTypeFieldDictionaryConfigurationUpdateInput = Omit<
    TaskTypeFieldDictionaryConfigurationInput,
    'task_type_field_id'
>;

export type CustomDictionaryInput = {
    name: string;
    description: string;
};

export type CustomDictionaryColumnInput = Omit<CustomDictionaryColumnDto, 'id' | 'table'>;

export type CustomDictionaryColumnRowInput = Omit<CustomDictionaryColumnRow, 'id'>;

export class TaskFieldTaskInput {
    type: number;
    value: any;
}

export class TaskMutateInput {
    id?: number;
    type: number;
    user: number;
    fields?: TaskFieldTaskInput[];
    comment: string;
    parent?: number;
    status?: number;
}

export type ProcessMutateInput = {};

export class TaskMutateTaskFieldInput {
    type: {
        id: number;
    };
    value: any;
}

export class TaskBatchUpdateInput {
    fields: TaskMutateTaskFieldInput[];
    comment: string;
    id: number;
    parent: number;
}

export class TaskTypeFieldInputDto {
    name: string;
    params: string;
    description: string;
    is_required: number;
    index: number;
    type_field_type: number;
    type_field_group: number;
    component_id: number;
}

export class TaskTypeInputDto {
    name: string;
    parent: number;
    description: string;
    module: number;
    access_type: number;
    user_type: number;
    task_type_fields: TaskTypeFieldInputDto;
}

export class TaskFieldTypeInputDto {
    value: any;
    type: {
        id: number;
    };
}

export class TaskCreateInputDto {
    parent: number;
    type: number;
    user: number;
    comment: string;
    fields: TaskMutateTaskFieldInput[];
    count: number;
    user_type: number;
    base_task: number;
}

export class ConditionCheckDto extends BaseDto {
    result: boolean;
    condition_id: number;
    condition_name: string;
}

export class ConditionGroupCheckDto extends BaseDto {
    conditions: ConditionCheckDto[];
    result: boolean;
    condition_group_id: number;
    condition_group_name: string;
}

export class CanbanLevelDto extends BaseDto {
    id: number;
    index: number;
}

export class StatusNameDto extends BaseDto {
    name: string;
    code: string;
}

export class SystemStatusDto extends BaseDto {
    id: number;
    name: string;
    description: string;
}

export class StatusDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    system_status: SystemStatusDto;
    status_names: StatusNameDto[];
    canban_level: CanbanLevelDto;
}

export class StatusChangeRuleDto extends BaseDto {
    id: number;
    description: string;
    task_type_role_id: number;
    status_from: StatusDto;
    status_to: StatusDto;
    is_commentable: boolean;
    is_comment_required: boolean;
}

export class TaskAvailableStatusDto extends BaseDto {
    result: boolean;
    status_change_rule: StatusChangeRuleDto;
    condition_groups: ConditionGroupCheckDto;
}

export class ComponentFieldDto extends BaseDto {
    id: number;
    code: string;
    name: string;
    description: string;
    component: ComponentDto;
    component_id: number;
    field_type_code: string;
    is_required: boolean;
}

export class ComponentFieldInheritanceDto extends BaseDto {
    component_field_from: ComponentFieldDto;
    component_field_to: ComponentFieldDto;
}

export class OperationResultDto extends BaseDto {
    result: any;
    message: string;
}

export class RoleInfoDto extends BaseDto {
    id: number;
    name: string;
    is_assignable: boolean;
}

export class TaskTypeRoleDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    index: number;
    role: RoleInfoDto;
    task_type: TaskTypeDto;
    count_min: number;
    count_max: number;
    count_recommend: number;
    is_auto_assign: boolean;
    assign_task_type_id: number;
    assign_system_status_id: number;
}

export class TaskFieldInfoDto extends BaseDto {
    id: number;
    info: any;
}

export class ConditionGroupDto extends BaseDto {
    id: number;
    name: string;
    description: string;
    date_from: string;
    date_to: string;
}

export class ConditionDto extends BaseDto {
    id: number;
    group: ConditionGroupDto;
    name: string;
    description: string;
    value: string;
    kind_code: string;
    comparison_sign_code: string;
}

export class ConditionModifierDto extends BaseDto {
    id: number;
    condition: ConditionDto;
    name: string;
    description: string;
    value: string;
    kind_code: string;
    comparison_sign_code: string;
}

export type ConditionInput = {
    name: string;
    description: string;
    value: string;
    group_id: number;
    kind_code: string;
    comparison_sign_code: string;
};

export type ConditionModifierInput = {
    name: string;
    description: string;
    value: string;
    condition_id: number;
    kind_code: string;
    comparison_sign_code: string;
};

export class TaskTypeFieldFloatConfigurationDto extends BaseDto {
    taskTypeFieldId: number;
    taskTypeFieldFloatTypeCode: string;
    valueMin: number;
    valueMax: number;
    isUnsigned: boolean;
}

export type TaskTypeFieldFloatConfigurationInput = {
    taskTypeFieldId: number;
    taskTypeFieldFloatTypeCode: string;
    valueMin: number;
    valueMax: number;
    isUnsigned: boolean;
};

export class DictionaryDto extends BaseDto {}

export type ConditionGroupInput = {
    name: string;
    description: string;
};

export class ConditionKindDto extends BaseDto {
    code: string;
    name: string;
    description: string;
}

export class ComparisonSignDto extends BaseDto {
    code: string;
    name: string;
}

export class BasicDataTypeDto extends BaseDto {
    code: string;
    name: string;
}

export class ConditionModifierKindDto extends BaseDto {
    code: string;
    name: string;
    description: string;
}

export class ConditionModifierKindConditionKindDto extends BaseDto {
    condition_modifier_kind: ConditionModifierKindDto;
    condition_kind: ConditionKindDto;
}

export type TaskTypeRoleInput = {
    name: string;
    description: string;
    index: number;
    task_type_id: number;
    role_id: number;
    count_min: number;
    count_max: number;
    count_recommend: number;
    is_auto_assign: boolean;
    assign_task_type_id: number;
    assign_system_status_id: number;
};

export class TaskTypeRolePermissionDto extends BaseDto {
    id: number;
    name: string;
    status: StatusDto;
    task_type_role_id: number;
    is_readable: boolean;
    is_writeable: boolean;
}

export type TaskTypeRolePermissionInput = {
    name: string;
    status_id: number;
    task_type_role_id: number;
    is_readable: boolean;
    is_writeable: boolean;
};

export class TaskFieldTypeDto extends BaseDto {
    id: number;
    name: string;
    params: string;
    description: string;
    index: number;
    is_required: number;
    task_type_field_group: TaskTypeFieldGroupDto;
    date_from: string;
    date_to: string;
    is_hidden: boolean;
    is_final: boolean;
    is_system: boolean;
    component_field: ComponentFieldDto;
    field_type_code: string;
}

export class TaskTypeRolePermissionFieldRestrictionDto extends BaseDto {
    id: number;
    comment: string;
    isReadRestricted: boolean;
    isWriteRestricted: boolean;
    taskTypeRolePermission: TaskTypeRolePermissionDto;
    taskFieldType: TaskFieldTypeDto;
}

export type TaskTypeRolePermissionFieldRestrictionInput = {
    comment: string;
    is_read_restricted: boolean;
    is_write_restricted: boolean;
    task_type_role_permission_id: number;
    task_type_field_id: number;
};

export type ProcessInput = {
    name: string;
    params: string;
    type_code: string;
    is_startable: number;
    date_to: string;
    date_start_confirm: string;
    date_end_confirm: string;
    date_block: string;
    date_start: string;
    date_end: string;
    external_id: string;
};

export type ProcessStageInput = {
    params: string;
    process_id: number;
    date_start_confirm: string;
    date_to: string;
    date_end_confirm: string;
    date_start: string;
    date_end: string;
    external_id: string;
    group_id: number;
    member_group_id: number;
    stage_type_id: string;
};

export type EvaluationTaskInput = {
    processId: number;
    taskTypeId: number;
    userId: number;
    componentId: number;
    baseTaskId: number;
    fields: TaskFieldTypeInputDto[];
};

export class MemberTypeDto extends BaseDto {
    code: string;
    name: string;
}

export class MemberGroupDto extends BaseDto {
    id: number;
    dateFrom: string;
    dateTo: string;
    name: string;
    description: string;
}

export class MemberDto extends BaseDto {
    id: number;
    date_from: string;
    date_to: string;
    member_group: MemberGroupDto;
    member_type: MemberGroupDto;
    value_id: number;
    is_exclude: boolean;
}

export type MemberInput = {
    member_group_id: number;
    member_type_code: string;
    value_ids: number[];
    is_exclude: boolean;
};

export class ProcessMemberDto extends BaseDto {
    process_stage_id: number;
    member_group_name: string;
    member_group_id: number;
    member_group_description: string;
    user_ids: number[];
}

export type StatusInput = {
    name: string;
    description: string;
    index: number;
    system_status_id: number;
    canban_level_id: number;
};

export class ProcessStageGroupDto extends BaseDto {
    id: number;
    name: string;
    description: string;
}

export class ScaleDto extends BaseDto {
    id: number;
    dateFrom: string;
    dateTo: string;
}

export class TaskTypeFieldDictionaryListParameterDto extends BaseDto {
    id: number;
    task_type_field: TaskFieldTypeDto;
    query_parameter_name: string;
    query_parameter_value_task_type_field: TaskFieldTypeDto;
    is_skippable_on_null: boolean;
}

export class TaskTypeFieldDictionaryColumnWithoutTaskTypeFieldDto extends BaseDto {
    id: number;
    index: number;
    dictionary_field_title: string;
    dictionary_field_name: string;
    dictionary_field_position_code: string;
    is_enabled: boolean;
}

export class TypeDictionaryEntityWithoutDictionaryServiceDto extends BaseDto {
    name: string;
    description: string;
    key_basic_data_type_code: string;
    key_field_name: string;
    value_basic_data_type_code: string;
    value_field_name: string;
}

export class TypeDictionaryInfoWithTaskTypeFieldDictionaryListParameterDto extends BaseDto {
    entity: TypeDictionaryEntityWithoutDictionaryServiceDto;
    task_type_field: TaskFieldTypeDto;
    dictionary_column_list: TaskTypeFieldDictionaryColumnWithoutTaskTypeFieldDto[];
    task_type_field_dictionary_list_parameter: TaskTypeFieldDictionaryListParameterDto[];
}

export class TypeDictionaryInfoDto extends BaseDto {
    entity: TypeDictionaryEntityWithoutDictionaryServiceDto;
    task_type_field: TaskFieldTypeDto;
    dictionary_column_list: TaskTypeFieldDictionaryColumnWithoutTaskTypeFieldDto[];
}

export class DictionaryMetaDataDto extends BaseDto {
    list: TypeDictionaryInfoWithTaskTypeFieldDictionaryListParameterDto;
    info: TypeDictionaryInfoDto;
}

export class TaskTypeFieldInheritanceValueDto extends BaseDto {
    taskTypeFieldId: number;
    taskFieldValue: string;
}

export class TaskRawDataDto extends BaseDto {
    id: number;
    parent_id: number;
    type_id: number;
    user_id: number;
}

export class FormulaDto extends BaseDto {
    id: number;
    formula: string;
}

export class EvaluationScaleDto extends BaseDto {
    id: number;
    formula: FormulaDto;
    value: number;
    scale: ScaleDto;
    lower_bound: number;
    upper_bound: number;
    date_from: string;
    date_to: string;
}
