import { ConstManager } from '@goodt-wcore/managers';
import { ApiServiceOptionsSchema } from '@goodt-common/api';
import { LifetimeType, ContainerValueType } from '@goodt-common/service-container';
import {
    OrgStructureApiServiceName,
    OrgStructureApiServiceSymbol,
    OrgStructureApiService
} from './OrgStructureApiService';
import {
    TaskSettingsApiServiceName,
    TaskSettingsApiServiceSymbol,
    TaskSettingsApiService
} from './TaskSettingsApiService/v1';
import {
    LearningCourseApiServiceName,
    LearningCourseApiServiceSymbol,
    LearningCourseApiService
} from './LearningCourseApiService';
import { RostalentApiServiceName, RostalentApiServiceSymbol, RostalentApiService } from './RostalentApiService';
import { FileUploadApiServiceName, FileUploadApiServiceSymbol, FileUploadApiService } from './FileUploadApiService';
import { TaskOrgApiServiceName, TaskOrgApiServiceSymbol, TaskOrgApiService } from './TaskOrgApiService';

// prettier-ignore
const createFactory = (ApiService) =>
    (options) => {
        const { baseURL, ...restOptions } = options;
        const apiBaseURL = ConstManager.instance.getConstValue(baseURL);
        // eslint-disable-next-line goodt-rules/deprecate-member-expression
        return new ApiService({ options: { apiBaseURL, ...restOptions} });
    };

export const ServiceProviderSetupConfigs = [
    {
        id: OrgStructureApiServiceSymbol,
        // eslint-disable-next-line goodt-rules/deprecate-member-expression
        value: createFactory(OrgStructureApiService),
        config: {
            type: ContainerValueType.FACTORY,
            lifetime: LifetimeType.TRANSIENT
        },
        meta: {
            name: OrgStructureApiServiceName,
            schema: ApiServiceOptionsSchema
        }
    },
    {
        id: TaskSettingsApiServiceSymbol,
        // eslint-disable-next-line goodt-rules/deprecate-member-expression
        value: createFactory(TaskSettingsApiService),
        config: {
            type: ContainerValueType.FACTORY,
            lifetime: LifetimeType.TRANSIENT
        },
        meta: {
            name: TaskSettingsApiServiceName,
            schema: ApiServiceOptionsSchema
        }
    },
    {
        id: LearningCourseApiServiceSymbol,
        // eslint-disable-next-line goodt-rules/deprecate-member-expression
        value: createFactory(LearningCourseApiService),
        config: {
            type: ContainerValueType.FACTORY,
            lifetime: LifetimeType.TRANSIENT
        },
        meta: {
            name: LearningCourseApiServiceName,
            schema: ApiServiceOptionsSchema
        }
    },
    {
        id: FileUploadApiServiceSymbol,
        // eslint-disable-next-line goodt-rules/deprecate-member-expression
        value: createFactory(FileUploadApiService),
        config: {
            type: ContainerValueType.FACTORY,
            lifetime: LifetimeType.TRANSIENT
        },
        meta: {
            name: FileUploadApiServiceName,
            schema: ApiServiceOptionsSchema
        }
    },
    {
        id: TaskOrgApiServiceSymbol,
        // eslint-disable-next-line goodt-rules/deprecate-member-expression
        value: createFactory(TaskOrgApiService),
        config: {
            type: ContainerValueType.FACTORY,
            lifetime: LifetimeType.TRANSIENT
        },
        meta: {
            name: TaskOrgApiServiceName,
            schema: ApiServiceOptionsSchema
        }
    },
    {
        id: RostalentApiServiceSymbol,
        value: createFactory(RostalentApiService),
        config: {
            type: ContainerValueType.FACTORY,
            lifetime: LifetimeType.TRANSIENT
        },
        meta: {
            name: RostalentApiServiceName,
            schema: ApiServiceOptionsSchema
        }
    }
];
