Example using <mark>header</mark> <mark>icon-\*</mark> slots

```vue
<template>
    <div class="pad-l5">
        <ui-collapse v-bind="props">
            <template #header="{ toggle }">
                <h3 class="last cursor-pointer" @click="toggle">My header</h3>
            </template>
            <div>Lorem ipsum dolor sit amet consectetur adipisicing elit. Dignissimos, natus.</div>
        </ui-collapse>
    </div>
</template>
<script>
import UiCollapse from './Collapse.vue';

export default {
    components: { UiCollapse },
    data() {
        return {
            props: {
                visible: true,
                icon: true,
            },
        };
    },
};
</script>
```

Example using <mark>heading</mark> slot

```vue
<template>
    <div class="pad-l5">
        <ui-collapse class="ui-collapse-custom" v-bind="props">
            <template #heading="{ isOpen, toggle }">
                <div
                    class="ui-collapse-custom-heading pad-v-3 pad-h-5 cursor-pointer u-select-none pos-rel"
                    :class="{ 'color-primary': isOpen, 'bg-primary-focus': isOpen }"
                    @click="toggle"
                >
                    <div class="row row-collapse">
                        <div class="col col-vmid">My header</div>
                        <div class="col col-auto col-vmid">
                            <div class="icon w-auto pull-left">
                                <i
                                    class="mdi mdi-chevron-right"
                                    :class="{ 'mdi-rotate-90': isOpen }"
                                ></i>
                            </div>
                        </div>
                    </div>
                </div>
            </template>
            <div class="pad-5">
                <p>Lorem ipsum dolor sit amet consectetur adipisicing elit. Dignissimos, natus.</p>
                <p>Lorem ipsum dolor sit amet consectetur adipisicing elit. Dignissimos, natus.</p>
                <p>Lorem ipsum dolor sit amet consectetur adipisicing elit. Dignissimos, natus.</p>
                <p>Lorem ipsum dolor sit amet consectetur adipisicing elit. Dignissimos, natus.</p>
                <p class="last">
                    Lorem ipsum dolor sit amet consectetur adipisicing elit. Dignissimos, natus.
                </p>
            </div>
        </ui-collapse>
    </div>
</template>
<style lang="less" scoped>
.ui-collapse-custom {
    overflow: hidden;
    border-radius: var(--border-radius);
    border: 1px solid var(--color-grey-light);
}
.ui-collapse-custom-heading {
    transition: all 0.5s ease;
}
</style>
<script>
import UiCollapse from './Collapse.vue';

export default {
    components: { UiCollapse },
    data() {
        return {
            props: {},
        };
    },
};
</script>
```
