```vue
<template>
    <div class="pad-l5">
        <ui-file-selector v-bind="props" @change="onFileSelect">
            <div class="btn btn-primary btn-small">select file</div>
        </ui-file-selector>
        <pre>{{ files }}</pre>
    </div>
</template>
<script>
import UiFileSelector from './FileSelector.vue';

export default {
    components: { UiFileSelector },
    data() {
        return {
            files: [],
            props: {
                multiple: false,
                accept: '',
            },
        };
    },
    methods: {
        onFileSelect(files) {
            this.files = files.map(({ name, type, size }) => ({ name, type, size }));
        },
    },
};
</script>
```

Advanced demo: multiple image selection with preview

```vue
<template>
    <div class="pad-l5">
        <div class="d-flex block">
            <ui-file-selector ref="file-selector" v-bind="props" @change="onFileSelect">
                <div class="btn btn-primary btn-small">
                    <template v-if="files.length">images selected: ({{ files.length }})</template>
                    <template v-else>select images</template>
                </div>
            </ui-file-selector>
            <div class="btn btn-outline btn-small mar-h-3" v-if="files.length" @click="resetFiles">
                reset
            </div>
        </div>
        <table class="table table-vmid w-6-12">
            <tr v-for="meta in filesMeta" :key="meta.name">
                <td class="table-w-auto">
                    <ui-image :src="meta.preview" style="display:block; width:2rem">
                        <div><i class="preloader"></i></div>
                    </ui-image>
                </td>
                <td>{{ meta.name }}</td>
                <td>
                    <small>({{ meta.size }}kb)</small>
                </td>
            </tr>
        </table>
    </div>
</template>
<script>
import UiFileSelector from './FileSelector.vue';
import UiImage from './Image.vue';

// b -> kb util
const toKb = n => Math.round((n / 1024) * 10) / 10;

export default {
    components: { UiFileSelector, UiImage },
    data() {
        return {
            files: [],
            props: {
                multiple: true,
                accept: 'image/png,image/jpeg,image/gif',
            },
        };
    },
    computed: {
        filesMeta() {
            return this.files.map(file => {
                const { name, type, size } = file;
                return {
                    name,
                    type,
                    size: toKb(size),
                    preview: file,
                };
            });
        },
    },
    methods: {
        resetFiles() {
            this.files = [];
        },
        onFileSelect(files) {
            this.files = files;
        },
    },
};
</script>
```
