```vue
<template>
    <div class="pad-l5">
        <div class="tile">
            <ui-grid class="tile-body" v-bind="props">
                <template #avatar="{ style }">
                    <img
                        class="avatar avatar-3 round"
                        src="https://picsum.photos/150/150"
                        :style="style"
                    />
                </template>
                <template #info="{ style }">
                    <div :style="style">
                        <div class="text-bold">John Wick</div>
                        <div class="text-xsmall">john.wick@site.com</div>
                    </div>
                </template>
                <template #status="{ style }">
                    <div class="text-xsmall color-green" :style="style">online</div>
                </template>
            </ui-grid>
        </div>
    </div>
</template>
<script>
import UiGrid from './Grid.vue';

export default {
    components: { UiGrid },
    data() {
        return {
            props: {
                areas: [['avatar', 'info', 'status']],
                cols: ['auto', '1fr', 'auto'],
                rows: ['1fr'],
                gap: ['1rem'],
            },
        };
    },
};
</script>
```

Using wrapper element

```vue
<template>
    <div class="pad-l5">
        <div class="tile">
            <ui-grid class="tile-body" v-bind="props">
                <template #avatar>
                    <img class="avatar avatar-3 round" src="https://picsum.photos/150/150" />
                </template>
                <template #info>
                    <div class="text-bold">John Wick</div>
                    <div class="text-xsmall">john.wick@site.com</div>
                </template>
                <template #status>
                    <div class="text-xsmall color-green">online</div>
                </template>
            </ui-grid>
        </div>
    </div>
</template>
<script>
import UiGrid from './Grid.vue';

export default {
    components: { UiGrid },
    data() {
        return {
            props: {
                areas: [['avatar', 'info', 'status']],
                cols: ['auto', '1fr', 'auto'],
                rows: ['1fr'],
                gap: ['1rem'],
                wrapTag: 'div',
            },
        };
    },
};
</script>
```

```vue
<template>
    <div class="pad-l5">
        <ui-grid v-bind="props">
            <template v-for="name in areaNames" v-slot:[name]="{ style }">
                <div class="box" :style="style">
                    <code>{{ name }}</code>
                </div>
            </template>
        </ui-grid>
    </div>
</template>
<script>
import UiGrid from './Grid.vue';

export default {
    components: { UiGrid },
    data() {
        return {
            props: {
                areas: [
                    ['area1', 'area3', 'area5'],
                    ['area1', 'area4', 'area5'],
                    ['area1', 'area2', 'area2'],
                ],
                cols: ['auto', '1fr', 'auto'],
                rows: ['1fr'],
                gap: ['1rem'],
            },
        };
    },
    computed: {
        areaNames() {
            return [...new Set(this.props.areas.flat())];
        },
    },
};
</script>
<style scopped>
.box {
    padding: 1rem;
    background: #eee;
}
</style>
```
