Simple example

```vue
<template>
    <div class="pad-l5">
        <p>value: {{ model }}</p>
        <input-autocomplete class="w-6-12" v-model="model" v-bind="props"></input-autocomplete>
    </div>
</template>
<script>
export default {
    data() {
        return {
            model: '',
            props: {
                options: [
                    'angular',
                    'aurelia',
                    'backbone',
                    'ember',
                    'meteor',
                    'react',
                    'riot',
                    'stencil',
                    'svelte',
                    'vue',
                ],
                placeholder: 'New tag here',
            },
        };
    },
};
</script>
```

Advanced example. Async filtering, debounce, slots

```vue
<template>
    <div class="pad-l5">
        <p>value: {{ model }}</p>
        <input-autocomplete class="w-6-12" v-model="model" v-bind="props">
            <template #loading>
                <mark>loading</mark>
            </template>
            <template #input="{ id, value, inputBinds, inputEvents }">
                <input
                    class="w-100"
                    :id="id"
                    type="text"
                    :value="value"
                    v-bind="inputBinds"
                    v-on="inputEvents"
                    style="border:none; outline:none"
                />
            </template>
            <template #dropdown-header>
                <div class="pad-3">header</div>
            </template>
            <template #noresults>
                <div class="pad-3 text-muted">Nothing found :(</div>
            </template>
            <template #option="{ option, optionIndex, valueLocal, selectOption, cursorIndex }">
                <li
                    :class="{ 'bg-yellow': optionIndex == cursorIndex }"
                    @click="selectOption(option)"
                >
                    <div v-html="option.replace(valueLocal, '<b>' + valueLocal + '</b>')"></div>
                </li>
            </template>
            <template #dropdown-footer>
                <div class="pad-3">footer</div>
            </template>
        </input-autocomplete>
    </div>
</template>
<script>
// fake api
const api = {
    autocomplete(query) {
        return new Promise(resolve => {
            setTimeout(() => {
                let arr = [
                    'angular',
                    'aurelia',
                    'backbone',
                    'ember',
                    'meteor',
                    'react',
                    'riot',
                    'stencil',
                    'svelte',
                    'vue',
                ].filter(item => item.indexOf(query) === 0);
                resolve(arr);
            }, 500);
        });
    },
};
export default {
    data() {
        return {
            model: '',
            props: {
                options: [],
                placeholder: 'New tag here (min 1 letter)',
                minLength: 1,
                filter: api.autocomplete,
                filterDebounce: 250,
            },
        };
    },
};
</script>
```
