Simple example

```vue
<template>
    <div class="pad-l5">
        <p>value: {{ model }}</p>
        <div class="p">
            <label>
                <input
                    class="checkbox checkbox-small"
                    type="checkbox"
                    v-model="props.datepicker.range"
                /><i></i>
                <span class="pad-left-2 v-mid">range</span>
            </label>
        </div>
        <input-date-picker class="w-6-12" v-model="model" v-bind="props"></input-date-picker>
    </div>
</template>
<script>
export default {
    data() {
        return {
            model: '',
            props: {
                placeholder: 'Pick dates',
                datepicker: {
                    range: false,
                },
            },
        };
    },
};
</script>
```

Advanced example. Custom format, slots etc

```vue
<template>
    <div class="pad-l5">
        <p>value: {{ model }}</p>
        <p>
            <input-date-picker class="w-6-12" v-model="model" v-bind="props" v-on="events">
                <template #clear="{ clear }">
                    <b class="text-xsmall cursor-pointer color-red mar-h-2" @click="clear">clear</b>
                </template>
                <template #icon="{ toggle }">
                    <b class="text-xsmall cursor-pointer" @click="toggle">DP</b>
                </template>
                <template #dp-left>
                    <div class="mar-l1">
                        <p v-for="n in offsets" :key="n">
                            <span
                                class="btn btn-small d-flex"
                                :class="[offset == n ? 'btn-primary' : 'btn-ghost']"
                                @click="setOffset(n)"
                            >
                                {{ n }} d
                            </span>
                        </p>
                    </div>
                </template>
            </input-date-picker>
        </p>
        <pre style="height:8rem">{{ log }}</pre>
    </div>
</template>
<script>
let dayjs = window.dayjs;
dayjs.locale(window.dayjs_locale_ru);
dayjs.extend(window.dayjs_plugin_customParseFormat);

let format = 'DD MMM YYYY';

export default {
    data() {
        return {
            log: '',
            offset: 0,
            offsets: [3, 7, 14],
            model: [],
            props: {
                placeholder: 'Pick a date',
                toDate(str) {
                    return str ? dayjs(str, format).toDate() : null;
                },
                toValue(date) {
                    return dayjs(date).format(format);
                },
                datepicker: {
                    range: true,
                },
            },
            events: {
                clear: this.onClear,
                'set-date': this.onSetDate,
            },
        };
    },
    methods: {
        onClear() {
            this.log = `event:clear\n` + this.log;
        },
        onSetDate(d) {
            let { toValue } = this.props;
            this.log = `event:set-date ${d}\n` + this.log;
            if (this.offset) {
                let d2 = dayjs(d)
                    .add(this.offset, 'd')
                    .toDate();
                this.model = [toValue(d), toValue(d2)];
            }
        },
        setOffset(n) {
            this.offset = this.offset == n ? 0 : n;
        },
    },
};
</script>
```
