Simple example

```vue
<template>
    <div class="pad-l5">
        <ui-pagination v-bind="props" @select="n => (props.page = n)"></ui-pagination>
    </div>
</template>
<script>
import UiPagination from './Pagination.vue';

export default {
    components: { UiPagination },
    data() {
        return {
            props: {
                page: 1,
                pages: 25,
            },
        };
    },
};
</script>
```

Advance example. Slots, sync

```vue
<template>
    <div class="pad-l5">
        <ui-pagination :page.sync="props.page" :pages="props.pages">
            <template #before="{ page, prev }">
                <div class="btn btn-inline" :class="{ disabled: page <= 1 }" @click="prev">
                    prev
                </div>
            </template>
            <template #default="{ page, currentPage, index, selectPage }">
                <div
                    class="pad-2 text-center cursor-pointer"
                    @click="selectPage(page)"
                    style="width:3em"
                >
                    <template v-if="page">
                        <div class="d-block" :class="[page == currentPage ? 'mark' : 'code']">
                            {{ page }}
                        </div>
                    </template>
                    <template v-else>...</template>
                </div>
            </template>
            <template #after="{ page, pages, next }">
                <div class="btn btn-inline" :class="{ disabled: page >= pages }" @click="next">
                    next
                </div>
            </template>
        </ui-pagination>
    </div>
</template>
<script>
import UiPagination from './Pagination.vue';

export default {
    components: { UiPagination },
    data() {
        return {
            props: {
                page: 1,
                pages: 25,
            },
        };
    },
};
</script>
```
