import { ConstManager } from '@goodt-wcore/managers';
import { ApiCacheServiceProvider, IApiCacheService } from './ApiCacheServiceProvider';

type UrlInfoType = {
    url: string;
    enabled: false;
};

export function processUrlWithConstants(constName: string): string;

export class ApiCacheManager {
    /**
     * Cache service instance
     * @private
     */
    private _cacheService: IApiCacheService;

    /**
     * Cache service provider
     * @private
     */
    private _cacheServiceProvider: ApiCacheServiceProvider;

    /**
     * @type {ConstManager}
     * @private
     */
    private _constManager: ConstManager

    /**
     * @type { Map<string, UrlInfoType>}
     */
    private _cachingUrlsMap: Map<string, UrlInfoType>;

    /**
     * @type {UrlInfoType[]}
     */
    readonly cachingUrls: UrlInfoType[];

    /**
     * Caching is enabled
     * @type {boolean}
     */
    isEnabled: boolean;

    /**
     * Cache service cache lifetime
     */
    cacheLifetime: number = 1000;

    /**
     * Cache service is enable lifetime
     */
    routeLifetime: number = 10000;

    /**
     *
     * @param {ConstManager} constManager
     * @param {import('@goodt/editor-common').ApiCacheServiceProvider} cacheServiceProvider
     */
    constructor({ constManager, cacheServiceProvider }: { constManager: ConstManager, cacheServiceProvider: ApiCacheServiceProvider });

    /**
     *
     * @param {string} cacheServiceId
     * @return {Promise<void>}
     */
    async init({ cacheServiceId }?: { cacheServiceId?: string }): Promise<void>;

    /**
     *
     * @param {string} cacheServiceId
     */
    setCacheServiceById(cacheServiceId: string);

    /**
     *
     * @param {boolean} isDebugMode
     */
    setDebugMode(isDebugMode: boolean);

    /**
     *
     * @param {boolean} enabled
     * @param {Array} urls
     */
    setConfig({ enabled, urls }: { enabled: boolean, urls: UrlInfoType });

    /**
     *
     * @param {boolean} isEnabled
     */
    setupUrlsInCacheService(isEnabled: boolean);

    /**
     *
     */
    clearUrlsInCacheService();

    /**
     */
    clearCache();

    /**
     * @param {boolean} isEnabled
     */
    toggle(isEnabled: boolean);

    /**
     * @param {{ url: string, enabled: boolean }[]} urlInfos
     */
    setUrls(urlInfos: UrlInfoType[])

    /**
     *
     * @param {string} url
     * @param {boolean} enabled
     * @param {Record<string, any>} options
     * @return {void}
     */
    addUrl(url: string, { enabled, ...options }: Omit<UrlInfoType, 'url'>);

    /**
     *
     * @param {string} url
     * @return {void}
     */
    removeUrl(url: string);

    /**
     * @return {void}
     */
    save();

    /**
     * Enables cache service for specified timeout/lifetime, then disable it
     *
     * @param {number} lifetime
     */
    startCacheServiceLifecycle(lifetime: number = this.routeLifetime);
}
