import {
    IProjectDataProvider,
    IProjectDataProviderConnection,
    IProjectDataProviderConnector
} from '@goodt-wcore/core/dremio';

export interface IProject {
    meta: IProjectMeta;
    data: IProjectData;
}

export interface IProjectMeta {
    id: string;
    title: string;
    description: string;
    type: string;
    tags: string[];
    preview: string;
    slug: string;
    folder_id: string;
    is_owner: boolean;
    is_shared_group: boolean;
    can_shared_group_edit: boolean;
}

export type IProjectConsts = Record<string, string> | IProjectConstGroup[];

export interface IProjectData {
    authAdapter: IProjectAuthAdapter;
    routes: IProjectRoute[];
    pages: IProjectPageMeta;
    services: IProjectService[];
    constants: IProjectConsts;
    dataProviders: IProjectDataProvider[];
}

export interface IProjectAuthAdapter {
    name: string;
    config: object;
}

export interface IProjectConstGroup {
    name: string;
    hash: Record<string, string>;
}

export interface IProjectRoute {
    id: string;
    title: string;
    name: string;
    pageId: string;
    slug: string;
    enabled: boolean;
    popup: boolean;
    meta: IProjectRouteMeta;
}

export interface IProjectRouteMeta {
    popupCloseEvent: boolean;
}

export interface IProjectPageMeta {
    id: string;
    title: string;
    templatePageId: string;
    isTemplate: boolean;
}

export interface IProjectPageData {
    id: string;
    content: IProjectPageElem[];
}

export interface IProjectPageElem {
    id: string;
    pid: string;
    name: string;
    type: string;
    props: object;
    children: IProjectPageElem[];
    visible: boolean;
}

export interface IProjectService {
    id: string;
    options: object;
}

export { IProjectDataProvider, IProjectDataProviderConnection, IProjectDataProviderConnector };
