import Config from '@goodt/editor-common/utils/Config';
import Const from '@goodt/editor-common/utils/Const';
import { getEditorSettingsPropFromStorage } from '@goodt/editor-common/utils/common';
import * as AssetsCacheServiceWorkerClient from './AssetsCacheServiceWorkerClient';

let workerApiPromise = null;

const hashObject = (str) => Array.from(JSON.stringify(decodeURIComponent(str)))
    .reduce((s, c) => Math.imul(31, s) + c.charCodeAt(0) | 0, 0);

export const init = async ({ authUrl = './worker.html', isDebug, redirectUrl } = {}) => {
    if (workerApiPromise != null) {
        return workerApiPromise;
    }

    if (authUrl == null) {
        throw new Error('"authUrl" param is required');
    }

    await Config.init();
    const { version, date } = Config.report;
    const { assets: { cache: cacheAssetsFromConfig = false } = {} } = Config.data;

    const cacheAssets = getEditorSettingsPropFromStorage(Const.EDITOR_SETTINGS_CACHE_ASSETS_KEY) ?? cacheAssetsFromConfig;

    const appVersion = `${version}_${date}`;
    const workerConfigVersion = hashObject(Config.worker);

    workerApiPromise = new Promise((resolve) => {
        const el = document.createElement('iframe');
        el.src = authUrl;
        el.style.cssText = 'position: absolute; left: -100%; top: 0; width: 1px; height: 1px; visibility: hidden;';
        el.onload = ({ target }) => {
            resolve(target.contentWindow.$api);
        };
        document.body.append(el);

    }).then(async (clientApi) => {
        const AssetsCacheApi = AssetsCacheServiceWorkerClient.use();
        const cacheAssetsWorkerQuery = AssetsCacheServiceWorkerClient.buildWorkerQueryParams({ appVersion, cacheAssets });

        await clientApi.init({ isDebug, workerConfigVersion, redirectUrl }, { workerQuery: cacheAssetsWorkerQuery });
        return { ...clientApi, cache: AssetsCacheApi };
    });

    return workerApiPromise;
};
