import mergeWith from 'lodash/mergeWith';

const { NODE_ENV } = process.env;
const UID = Math.random().toString(16).slice(2);

const merge = (object, source) => {
    return mergeWith(object, source, (_, srcValue) => (Array.isArray(srcValue) ? srcValue : undefined));
};

const Config = {
    data: null,
    report: null,
    worker: null,
    rev: 'n/a',
    isStandaloneMode: window.location.pathname.includes('/editor/player/') === false,
    init,
    merge
};
const loadJson = (filePath) => {
    return new Promise((resolve) =>
        fetch(`${filePath}.json?${UID}`)
            .then((response) => response.json())
            .then(resolve)
            .catch(() => resolve({}))
    );
};

async function init() {
    // eslint-disable-next-line no-return-assign
    return (this._promise ??= (async () => {
        const [ envConfig, envLocalConfig, rev, report, worker, widgetsMap ] = await Promise.all([
            loadJson(`config/${NODE_ENV}`),
            loadJson(`config/${NODE_ENV}.local`),
            loadJson('revision'),
            loadJson('report'),
            loadJson('config/worker'),
            loadJson('config/widgets.map')
        ]);
        const data = mergeWith(envConfig, envLocalConfig, (_, srcValue) =>
            Array.isArray(srcValue) ? srcValue : undefined
        );
        Object.assign(Config, { data, rev, report, worker, widgetsMap });

        return data;
    })());
}

export default Config;
