import Vue from 'vue';
import Const from './Const';
import * as Managers from '@goodt-wcore/managers';
import { importDebugStuffToWindow, getEditorSettingsPropFromStorage, setEditorSettingsPropToStorage, createDebugLogger } from './common';


let LOG_LABEL = 'EDITOR';
let LOG_STYLE = 'background:#1b73e8;font-weight:bold;border-radius:999px;padding: 1px 5px;';

const consoleLogOriginal = window.console.log;
let consoleLogDebug = createDebugLogger({ logLabel: LOG_LABEL, logStyle: LOG_STYLE });

export const setup = ({ logLabel, logStyle }) => {
    if (typeof logLabel === 'string') {
        LOG_LABEL = logLabel;
    }
    if (typeof logStyle === 'string') {
        LOG_STYLE = logStyle;
    }
    consoleLogDebug = createDebugLogger({ logLabel: LOG_LABEL, logStyle: LOG_STYLE });
}


const toggleConsoleLogger = (isDebugMode) => {
    window.console.log = isDebugMode ? consoleLogDebug : consoleLogOriginal;
};

/**
 * Try read isDeveloperMode from Local Storage or resolve from process.env or global defined variable __VUE_PROD_DEVTOOLS__
 * @type {boolean}
 */
export let isDeveloperMode = getEditorSettingsPropFromStorage(Const.EDITOR_SETTINGS_DEV_MODE_KEY) ?? (process.env.NODE_ENV === 'development' || !!__VUE_PROD_DEVTOOLS__);

/**
 */
export const setDebugMode = (isDebugMode = isDeveloperMode) => {
    isDeveloperMode = isDebugMode;
    toggleConsoleLogger(isDebugMode);
    consoleLogDebug(`setting "isDebugMode": isDebugMode = ${isDebugMode}`);

    Vue.config.productionTip = false;

    importDebugStuffToWindow({
        isDebugMode
    });

    Vue.config.silent = !isDebugMode;
    Vue.config.performance = isDebugMode;
    Vue.config.devtools = isDebugMode || !!__VUE_PROD_DEVTOOLS__;
    if (isDebugMode) {
        window.$core = { Managers };
    }
};

importDebugStuffToWindow({
    isDebugMode: isDeveloperMode,
    setDebugMode,
    setDeveloperMode: (isEnabled) => {
        setEditorSettingsPropToStorage(Const.EDITOR_SETTINGS_DEV_MODE_KEY, isEnabled);
        setDebugMode(isEnabled);
    }
});

export default isDeveloperMode;
