import Const from './Const';
import { usePersistentStorage } from '@goodt-wcore/utils';

const { getItem, setItem } = usePersistentStorage();

export const importDebugStuffToWindow = (record, scope) => {
    window.__GOODT__ = {
        ...window.__GOODT__,
        ...scope ? { [scope]: record } : record
    };
};

export const getEditorSettingsPropFromStorage = (editorSettingsProp) => {
    try {
        let { [editorSettingsProp]: value = null } = JSON.parse(getItem(Const.LOCALSTORAGE_KEY_EDITOR_SETTINGS) ?? '{}');
        return value;
    } catch (e) {
        return null;
    }
};

export const setEditorSettingsPropToStorage = (editorSettingsProp, editorSettingsPropValue) => {
    try {
        const editorSettings = JSON.parse(getItem(Const.LOCALSTORAGE_KEY_EDITOR_SETTINGS) ?? '{}');
        setItem(Const.LOCALSTORAGE_KEY_EDITOR_SETTINGS, JSON.stringify({
            ...editorSettings,
            [editorSettingsProp]: editorSettingsPropValue
        }));
    } catch (e) {
    }
};

const filterLabelArgs = (args, isLabelArg = true) => {
    return args.filter((value) => {
        const { label } = value ?? {};
        return [ null, undefined, '' ].includes(label) === !isLabelArg;
    });
};

const consoleLogOriginal = window.console.log;

export const createDebugLogger = ({ logLabel, logStyle }) =>
    (...args) => {
        const { labels, styles } = filterLabelArgs(args, true).reduce((acc, {
            label,
            style = ''
        }) => {
            const { labels, styles } = acc;
            labels.push(`%c${label}`);
            styles.push(logStyle.concat(';', style));
            return {
                labels,
                styles
            };
        }, {
            labels: [ `%c${logLabel}` ],
            styles: [ logStyle ]
        });
        const nonLabelArgs = filterLabelArgs(args, false);

        consoleLogOriginal(labels.join(''), ...styles, ...nonLabelArgs);
    };
