/**
 * @typedef {Object} AuthAdapter
 * @property {String} name
 * @property {Object} config
 */
/**
 * @typedef {Object} AppSession
 * @property {Boolean} authenticated
 * @property {Object} profile
 * @property {Array} permissions
 */
import { AuthManager } from '@goodt-wcore/managers';
import Const from '@/utils/Const';

let initWAuthManagerTimeoutId = null;

export const AppSession = ({ authenticated = false, profile = {}, permissions = [] }) => ({
    authenticated,
    profile,
    permissions
});

export const getWAuthManagerSession = (adapter = AuthManager.instance.adapter) => {
    return Promise.all([adapter.getUserProfile(), adapter.getUserPermissions()]).then(([profile, permissions]) =>
        AppSession({ authenticated: adapter.authenticated, profile, permissions })
    );
};

export const getWAuthManagerAdapter = (authManager = AuthManager.instance) => authManager.adapter;

/**
 * Inits authManager
 * @param {AuthAdapter} adapter
 * @param {AuthManager} authManager
 * @return {Promise.<AppSession>}
 */
export const initWAuthManager = (adapter, authManager = AuthManager.instance) => {
    if (!adapter) {
        authManager.destroy();
        return Promise.resolve(AppSession({}));
    } else {
        return new Promise((resolve, reject) => {
            if (initWAuthManagerTimeoutId) {
                clearTimeout(initWAuthManagerTimeoutId);
            }
            initWAuthManagerTimeoutId = setTimeout(() => {
                console.warn('WAuthManagerInstance.init timeout');
                resolve(AppSession({}));
            }, Const.PLAYER_AUTH_MANAGER_INIT_TIMEOUT_DELAY);
            authManager
                .init(adapter.name, adapter.config)
                .then(() => {
                    clearTimeout(initWAuthManagerTimeoutId);
                    let adapter = authManager.adapter;
                    if (adapter.authenticated) {
                        getWAuthManagerSession().then((session) => resolve(session));
                    } else {
                        resolve(AppSession({}));
                    }
                })
                .catch((e) => {
                    console.warn(e);
                    clearTimeout(initWAuthManagerTimeoutId);
                    resolve(AppSession({}));
                });
        });
    }
};
