const buildFormFields = (schema) =>
    Object.entries(schema).reduce(
        (acc, [key, { type, validation }]) => ({
            ...acc,
            [key]: {
                type,
                validation,
                touched: false,
                touchedError: false,
                error: ''
            }
        }),
        {}
    );

const buildForm = (schema) => ({
    fields: buildFormFields(schema),
    hasErrors: false,
    touched: false,
    isFirstChange: true
});

export const useForm = ({ schema, model, immediate = true }) => ({
    data: () => ({
        form: buildForm(schema)
    }),
    computed: {
        $modelStr() {
            return JSON.stringify(this[model]);
        }
    },
    created() {
        this.$watch(
            () => JSON.stringify(this[model]),
            (newModelStr, oldModelStr) => {
                const oldModel = JSON.parse(oldModelStr || null);
                const newModel = JSON.parse(newModelStr || null);
                this.$modelChanged(newModel, oldModel);
            },
            { immediate }
        );
    },
    methods: {
        $setSchema(newSchema) {
            this.form = buildForm(newSchema);
            this.$modelChanged(this[model], this[model]);
        },
        $modelChanged(newModel, oldModel) {
            const { form } = this;

            if (newModel == null) {
                return;
            }
            if (!form.isFirstChange) {
                const diffKeys = Object.keys(newModel).filter(
                    (key) => oldModel == null || oldModel[key] !== newModel[key]
                );
                diffKeys.forEach((key) => {
                    const formField = form.fields[key];
                    if (formField == null) {
                        return;
                    }
                    formField.touched = true;
                });
                form.touched = true;
            }
            Object.entries(form.fields).forEach(([key, formField]) => {
                formField.error = formField.validation.bind(this)(newModel[key]);
                formField.touchedError = formField.error !== '' && formField.touched;
            });
            form.hasErrors = Object.values(form.fields).some(({ error }) => error !== '');
            form.isFirstChange = false;
        }
    }
});
