const getCaretIndex = () => {
    if (window.getSelection && window.getSelection().getRangeAt) {
        const range = window.getSelection().getRangeAt(0);
        const selectedObj = window.getSelection();
        const childNodes = selectedObj.anchorNode.parentNode.childNodes;
        let rangeCount = 0;

        for (let i = 0; i < childNodes.length; i++) {
            if (childNodes[i] == selectedObj.anchorNode) {
                break;
            }
            if (childNodes[i].outerHTML) rangeCount += childNodes[i].outerHTML.length;
            else if (childNodes[i].nodeType == 3) {
                rangeCount += childNodes[i].textContent.length;
            }
        }
        return range.startOffset + rangeCount;
    }
    return -1;
};

const getRowIndex = () => {
    const sel = document.getSelection();
    const node = sel.anchorNode;
    const text = node.textContent.slice(0, sel.focusOffset);
    return text.split('\n').length - 1;
};

const SyntaxRules = {
    css: {
        literal: [/(['"][^'"]+['"])/g, (s, e) => `${s}$1${e}`],
        var: [/(--\w[\w_-]{0,})/g, (s, e) => `${s}$1${e}`],
        prop: [/([\w][\w-]+)(\s*:\s*)([\w\W]+?;)/g, (s, e) => `${s}$1${e}$2$3`],
        digit: [/((\b\d+\b)|(\b\d+\w{2,3}\b)|(#[0-9a-f]{3,8})|(u\+[0-9a-f-]+))/gi, (s, e) => `${s}$1${e}`],
        rule: [/^(\s*.+?)({)/gm, (s, e) => `${s}$1${e}$2`],
        func: [/([\w]+?)(\()/g, (s, e) => `${s}$1${e}$2`],
        comment: [/(\/\*[\s\S]*?\*\/)/g, (s, e) => `${s}$1${e}`]
    }
};

export { getCaretIndex, getRowIndex, SyntaxRules };
