import uid from 'uuid/v1';
import Const from '@/utils/Const';

export default {
    /**
     * @param {import('@goodt/editor-common').IProjectMeta} meta
     * @param {import('@goodt/editor-common').IProjectData} data
     * @returns {import('@goodt/editor-common').IProject}
     */
    appInfo(meta, data) {
        return {
            meta,
            data
        };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectMeta}
     */
    appMeta({
        id = '',
        title = '',
        description = '',
        type = '',
        tags = [],
        preview = '',
        slug = '',
        folder_id = null,
        is_owner = true,
        is_shared_group = false
    }) {
        return {
            id,
            title,
            description,
            type,
            tags,
            preview,
            slug,
            folder_id,
            is_owner,
            is_shared_group
        };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectData}
     */
    appData() {
        return {
            authAdapter: null,
            constants: {},
            routes: [],
            pages: [],
            services: [],
            dataProviders: []
        };
    },
    /**
     * @param {string} type
     * @returns {import('@goodt/editor-common').IProjectData}
     */
    appDataByType(type) {
        const isTemplate = type === Const.APP_TYPE_TEMPLATE;
        const page = this.pageMeta({ title: 'index', isTemplate });
        const route = this.route({ title: page.title, name: page.title, pageId: page.id, slug: '/' });
        return {
            ...this.appData(),
            routes: [route],
            pages: [page]
        };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectPageMeta}
     */
    pageMeta({ id = uid(), title = '', templatePageId = '', isTemplate = false }) {
        return {
            id,
            title,
            templatePageId,
            isTemplate
        };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectPageData}
     */
    pageData({ id, isTemplate = false }) {
        const root = this.elem({ type: Const.ELEM_TYPE_ROOT });
        if (isTemplate) {
            root.children = [this.elem({ pid: root.id, type: Const.ELEM_TYPE_TEMPLATE_CONTENT })];
        }
        return {
            id,
            content: [root]
        };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectRoute}
     */
    route({ id = uid(), title = '', name = '', pageId = '', slug = '', enabled = true, popup = false, meta = {} }) {
        return {
            id,
            title,
            name,
            pageId,
            slug,
            enabled,
            popup,
            meta
        };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectPageElem}
     */
    elem({ id = uid(), pid = null, type = '', props = {}, children = [], visible = true }) {
        return {
            id,
            pid,
            type,
            props,
            children,
            visible
        };
    },
    /**
     * @param {object} options
     * @returns {{ name:string, value:string, group:string }}
     */
    const({ name = '', value = null, group = '' }) {
        return {
            name,
            value,
            group
        };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectConstGroup}
     */
    constGroup({ name = '', hash = {} }) {
        return { name, hash };
    },
    /**
     * @param {object} options
     * @returns {import('@goodt/editor-common').IProjectAuthAdapter}
     */
    authAdapter({ name = '', config = {} }) {
        return { name, config };
    },
    /**
     * @param {import('@goodt/editor-common').IProjectDataProvider} options
     * @returns {import('@goodt/editor-common').IProjectDataProvider}
     */
    dataProvider({
        id = '',
        name = '',
        description = '',
        connector = null,
        connection = null,
        isDefault = false
    } = {}) {
        return { id, name, description, connector, connection, isDefault };
    },
    /**
     * @returns {string}
     */
    uid() {
        return uid();
    }
};
