// core-level configuring/bootstrapping
import '@goodt-wcore/core/boot';
// env-level configuring/bootstrapping
import './bootstrap';

import VueI18n from 'vue-i18n';

import router from './router';
import vuex from './store';
import i18nConfig from '@/lang';

import { AppConfigConstMap } from '@/constants';
import isDeveloperMode from '@/utils/DevMode';
import { importDebugStuffToWindow, Config } from '@goodt/editor-common/utils';

import { useDevtools } from '@goodt-common/plugins';
import * as ServiceWorkerClient from '@goodt/editor-common/sw/clients/ServiceWorkerClient';

import packageJson from '../package.json';

(async () => {
    const workerApi = await ServiceWorkerClient.init({
        isDebug: isDeveloperMode
    });

    // start loading assets after ServiceWorker registration to decide if caching required
    import('@mdi/font/css/materialdesignicons.min.css');
    import('@mdi/light-font/css/materialdesignicons-light.min.css');
    import('goodt-framework-css/dist/all.css');
    import('@goodt/postcss-config/tailwind.pcss');
    import('./assets/css/style.less');

    const [{ Application }, { default: AppComponent }] = await Promise.all([
        import('@/app/index'),
        import('./App.vue')
    ]);

    const App = new Application({
        router,
        vuex,
        i18n: new VueI18n(i18nConfig),
        workerApi
    });

    const { version: APP_VERSION } = packageJson;
    App.init(
        AppComponent,
        {
            data: () => ({
                isEditorMode: true
            })
        },
        {
            ConstMap: AppConfigConstMap,
            version: APP_VERSION
        }
    ).then(({ vueApp }) => {
        useDevtools(vueApp);
        const { data, rev, report, worker, widgetsMap, isStandaloneMode } = Config;
        importDebugStuffToWindow({ config: data, rev, report, worker, widgetsMap, isStandaloneMode });
        importDebugStuffToWindow(workerApi, 'workerApi');
    });
})();
