import Service from './Service';

/**
 * @typedef {object} IConnector
 * @property {string} id
 * @property {string} name
 * @property {string} description
 * @property {string} url
 * @property {string} data_url
 * @property {string} is_owner
 */

const responseHandler = ({ data }) => data;

export class ConnectorService extends Service {
    /**
     * @param {{ onlyActive:boolean }} options
     * @return {Promise.<IConnector[], Error>}
     */
    list({ onlyActive = true } = {}) {
        return this.transport.request('dataconnector', { only_closed: !onlyActive }, responseHandler);
    }

    /**
     * @param {IConnector} connector
     * @return {Promise.<IConnector, Error}
     */
    create(connector) {
        return this.transport.request('dataconnector/', connector, responseHandler, 'post');
    }

    /**
     * @param {IConnector} connector
     * @return {Promise.<IConnector, Error}
     */
    update(connector) {
        const { id } = connector;
        return this.transport.request(`dataconnector/${id}`, connector, responseHandler, 'put');
    }

    /**
     * @param {string} connectorId
     * @return {Promise}
     */
    delete(connectorId) {
        return this.transport.request(`dataconnector/${connectorId}`, {}, responseHandler, 'delete');
    }

    /**
     * @param {string} connectorId
     * @return {Promise}
     */
    restore(connectorId) {
        return this.transport.request(`dataconnector/${connectorId}/restore`, {}, responseHandler, 'post');
    }
}

/**
 * @param {IConnector} options
 * @return {IConnector}
 */
export const IConnectorFactory = ({
    id = null,
    name = '',
    description = '',
    url = '',
    data_url = '',
    is_owner = true
} = {}) => ({ id, name, description, url, data_url, is_owner });
