import Service from './Service';

export default class FolderService extends Service {
    /**
     * Возвращает список папок @see FolderEntity.folder()
     * @param {String} type
     * @param {Number} [parent_id=null]
     * @param {Number|Number[]} [id=null]
     * @return {Promise} ~ FolderEntity.folder[]
     */
    foldersList({ type, parent_id = null, id = null }) {
        const params = {
            type
        };
        
        if (parent_id != null) {
            params.parent_id = parent_id;
        }
        if (id != null) {
            params.id = id;
        }
        
        return this.transport.request('folder', params, response => response.data);
    }
    /**
     * Создает папку
     * @param {object} folder
     * @return {Promise} data ~ id
     */
    folderCreate(folder) {
        const params = { ...folder };
        
        return this.transport.request(
            'folder',
            params,
            response => response.data.id,
            'post'
        );
    }
    /**
     * Обновляет папку
     * @param {object} folder
     * @return {Promise} data ~ id
     */
    folderUpdate({ id, parent_id = null, ...meta }) {
        const params = { ...meta };
       
        if (parent_id != null) {
            params.parent_id = parent_id;
        }
        
        return this.transport.request(
            `folder/${id}`,
            params,
            response => response.data.id,
            'put'
        );
    }
    /**
     * Удаляет папку
     * @param {String} id   id папки
     * @return {Promise} ~ data boolean
     */
    folderDelete(id) {
        return this.transport.request(
            `folder/${id}`,
            {},
            response => response.data.result == 1,
            'delete'
        );
    }
    /**
     * Добавляет шаринг папки для группы
     * @param {String} id   id папки
     * @return {Promise}
     */
    folderShareGroup(id) {
        return this.transport.request(
            `folder/${id}/sharegroup`,
            {},
            response => response.data,
            'put'
        );
    }
    /**
     * Удаляет шаринг папки для группы
     * @param {String} id   id папки
     * @return {Promise}
     */
    folderUnshareGroup(id) {
        return this.transport.request(
            `folder/${id}/unsharegroup`,
            {},
            response => response.data,
            'put'
        );
    }
}
