import Vue from 'vue';
import Vuex from 'vuex';
import { SessionExpiredError } from '@/services/errors';
import EditorMutations from '@/store/modules/editor/mutations';
import * as modules from './modules';
import Mutations from './mutations';
import { NAMESPACES } from './constants';

Vue.use(Vuex);

export const handleApiError = (promise, reject, commit) => {
    promise.catch((error) => {
        commit(Mutations.SET_API_ERROR, error, { root: true });
        if (error instanceof SessionExpiredError) {
            commit(`${NAMESPACES.EDITOR}/${EditorMutations.SET_EDITOR_SESSION}`, false);
        }
        reject(error);
    });
};

export default new Vuex.Store({
    modules: {
        [NAMESPACES.APP]: modules.moduleApp,
        [NAMESPACES.EDITOR]: modules.moduleEditor
    },
    state: {
        apiError: null,
        tools: {},
        locale: '',
        version: '',
        init: false,
        loading: true,
        debugModeEnabled: false,
        previewModeEnabled: false
    },
    mutations: {
        [Mutations.SET_API_ERROR](state, val) {
            state.apiError = val;
        },
        [Mutations.SET_TOOLS](state, val) {
            state.tools = val;
        },
        [Mutations.SET_LOCALE](state, val) {
            state.locale = val;
        },
        [Mutations.SET_INIT](state, val) {
            state.init = val;
        },
        [Mutations.SET_VERSION](state, version) {
            state.version = version;
        },
        [Mutations.SET_LOADING](state, val) {
            state.loading = val;
        },
        [Mutations.SET_DEBUG_MODE_ENABLED](state, val) {
            state.debugModeEnabled = val;
        },
        [Mutations.SET_PREVIEW_MODE_ENABLED](state, val) {
            state.previewModeEnabled = val;
        }
    },
    actions: {},
    getters: {}
});
