import Mutations from './mutations';
import Actions from './actions';
import Const from '@/utils/Const';
import Vue from 'vue';
import { handleApiError } from '@/store';
import { useKeycloakCustom } from '@/services/KeycloakAuth';

export default {
    namespaced: true,
    state: () => ({
        editorSettings: {
            canvasMinWidth: 1920,
            canvasMinHeight: 1080,
            layersExpandOnChildSelect: true,
            isDeveloperMode: false
        },
        editorSession: {
            authenticated: false
        }
    }),
    mutations: {
        [Mutations.SET_EDITOR_SETTINGS](state, val) {
            state.editorSettings = { ...state.editorSettings, ...val };
        },
        [Mutations.SET_EDITOR_SESSION](state, isAuthenticated) {
            Vue.set(state.editorSession, 'authenticated', isAuthenticated);
        }
    },
    actions: {
        [Actions.LOAD_EDITOR_SETTINGS]({ commit, rootState }) {
            let settings = localStorage.getItem(Const.LOCALSTORAGE_KEY_EDITOR_SETTINGS) || {};
            try {
                let { version, ...otherSettings } = JSON.parse(settings);
                settings = version == rootState.version ? otherSettings : {};
            } catch (e) {
                settings = {};
            }
            commit(Mutations.SET_EDITOR_SETTINGS, settings);
        },
        [Actions.SET_EDITOR_SETTINGS]({ commit, state, rootState }, settings) {
            try {
                commit(Mutations.SET_EDITOR_SETTINGS, settings);
                let settingsAll = { ...state.editorSettings, version: rootState.version };
                localStorage.setItem(Const.LOCALSTORAGE_KEY_EDITOR_SETTINGS, JSON.stringify(settingsAll));
            } catch (e) {}
        },
        [Actions.AUTH_INIT]({ commit }) {
            return new Promise(async (resolve, reject) => {
                const promise = (await useKeycloakCustom())
                    .token()
                    .then(({ details }) => {
                        const isAuthorized = details.token != null;
                        commit(Mutations.SET_EDITOR_SESSION, isAuthorized);
                    })
                    .catch(() => {
                        commit(Mutations.SET_EDITOR_SESSION, false);
                    })
                    .finally(resolve);
            });
        }
    }
};
