const domNodeToVue = (el, vueRefProp = '__vue__') => {
    while (el) {
        if (el[vueRefProp]) {
            return el[vueRefProp];
        } else if (el.parentNode) {
            el = el.parentNode;
        } else {
            return null;
        }
    }
    return null;
};
const domNodeToElem = (el) => domNodeToVue(el, '__elem__');
const domNodeIndex = (el) => {
    return Array.from(el.parentNode.children).indexOf(el);
};
const domRectIntersects = (r, x, y) => {
    return x >= r.x && x <= r.x + r.width && y >= r.y && y <= r.y + r.height;
};
const domRectIntersectionRel = (r, x, y) => {
    const o = {
        x: (x - r.x) / r.width,
        y: (y - r.y) / r.height
    };
    o.x = o.x < 0 || o.x > 1 ? -1 : o.x;
    o.y = o.y < 0 || o.y > 1 ? -1 : o.y;
    return o;
};

const domIsNodeInViewport = (el) => {
    const rect = el.getBoundingClientRect();
    return (
        rect.top >= 0 &&
        rect.left >= 0 &&
        rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
        rect.right <= (window.innerWidth || document.documentElement.clientWidth)
    );
};

/**
 * @param {Element} target
 * @param {Event|string} type
 * @param {(e:Event) => void} listener
 * @param {AddEventListenerOptions} options
 * @returns
 */
const domEvent = (target, type, listener, options) => {
    target.addEventListener(type, listener, options);
    return () => target.removeEventListener(type, listener, options);
};

export {
    domNodeToVue,
    domNodeToElem,
    domNodeIndex,
    domRectIntersects,
    domRectIntersectionRel,
    domIsNodeInViewport,
    domEvent
};
