const BooleanVariablesPrefixes = [
    'is',
    'are',
    'may',
    'can',
    'has',
    'have',
    'should',
    'could',
    'with',
    'if',
    'not',
    'whether',
    'when',
    'use'
];

const ExcludedArrayExpressions = [
    'inject',
    'watchStore',
    'subscribe',
    'event',
    'handler',
    'when',
    'include',
    'exclude',
    'data',
    'type',
    'transformRequest',
    'children',
    'list',
    'List',
    '.+s',
    '.+ed'
];

const BOOLEAN_VARIABLES_PREFIXES_RE_LIST = `^(${BooleanVariablesPrefixes.join('|')})`;
const EXCLUDED_ARRAY_EXPRESSIONS_RE_LIST = `^(${ExcludedArrayExpressions.join('|')})$`;

module.exports = [
    'error',
    {
        selector: `Property[key.name='apiBaseURL'][value.type='FunctionExpression']`,
        message: `"apiBaseURL" FunctionExpression type declaration is deprecated. Use string declaration "{ apiBaseURL: 'prop.url}" instead.`
    },
    {
        selector: `CallExpression[callee.property.name='listen'] Literal[value='state-change']`,
        message: `Method ".listen('state-change', ...)" is deprecated. Use "watchStore" instead.`
    },
    {
        selector: `CallExpression[callee.property.name='trigger'] Literal[value='state-change']`,
        message: `Method ".trigger('state-change')" is deprecated. Use "watchStore" instead.`
    },
    {
        selector: `Identifier[name='divisionteam']`,
        message: `Name "divisionteam" is legacy. Use "divisionTeamId" instead.`
    },
    {
        selector: `Identifier[name='teamdivision']`,
        message: `Name "teamdivision" is legacy. Use "divisionTeamId" instead.`
    },
    {
        selector: `IfStatement UnaryExpression[operator='!'][argument.type=/Identifier/][argument.name!=/${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}/]`,
        message: `Using "!" with not Boolean type variables in conditions is deprecated. Use "== null" operator instead.`
    },
    {
        selector: `IfStatement UnaryExpression[operator='!'][argument.type=/MemberExpression/][argument.property.name!=/${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}/]`,
        message: `Using "!" with not Boolean type property in conditions is deprecated. Use "== null" operator instead.`
    },
    {
        selector:
            `IfStatement UnaryExpression[operator='!'][argument.type=/CallExpression/]` +
            `[argument.callee.property.name!=/includes|some|every|${BooleanVariablesPrefixes.join('|')}/]`,
        message: `Using "!" operator with not Boolean type expression call result in conditions is deprecated. Use "== null" operator instead.`
    },
    {
        selector: `UnaryExpression[operator='+'] Identifier`,
        message: `Using "+" to Number type casting is deprecated. Use clear "Number(value)" type casting instead.`
    },
    {
        selector: `ImportDeclaration[source.value='portal-vue'] Identifier[name=/Portal/]`,
        message: `Do not use "import { Portal } from 'portal-vue'" use "import { Portal as UiPortal } from '@goodt-wcore/components'" instead `
    },
    {
        selector: `ImportDeclaration[source.value='goodteditor-ui'] Identifier[name='Popup']`,
        message: `Do not use "import { Popup } from 'goodteditor-ui'" use "import { Popup as UiPopup } from '@goodt-wcore/components'" instead `
    },
    {
        selector: `ImportDeclaration[source.value='@goodt-common/mixins'] Identifier[name='useApiServiceMixin']`,
        message: `Do not use "import { useApiServiceMixin } from '@goodt-common/mixins'" use "import { useApiServiceMixin } from '@goodt-common/api'" instead `
    },
    {
        selector: `ImportDeclaration[source.value='@goodt-wcore/mixins'] Identifier[name='useDremio']`,
        message: `Do not use "import { useDremio } from '@goodt-wcore/mixins'" use "import { mixin as DremioMixin } from '@goodt-common/dremio'" instead `
    },
    {
        selector: `ImportDeclaration[source.value='@goodt-wcore/panels'] Identifier[name=/DremioPanel/]`,
        message: `Do not use "import { DremioPanelAsync } from '@goodt-wcore/panels'" use "import { DremioPanelAsync } from '@goodt-common/dremio-panels'" instead `
    },
    {
        selector: `ImportDeclaration[source.value='@goodt-wcore/dremio']`,
        message: `Package '@goodt-wcore/dremio' does not exist use '@goodt-common/dremio' instead`
    },
    {
        selector: `ImportDeclaration[source.value='@goodt-wcore/net']`,
        message: `Package '@goodt-wcore/net' does not exist use '@goodt-common/net' instead`
    },
    {
        selector: `ImportDeclaration[source.value='@goodt-common/utils/number']`,
        message: `Do not use '@goodt-common/utils/number' use '@goodt-common/utils-number' instead`
    },
    {
        selector: `ImportDeclaration[source.value=/src/]`,
        message: `Import path could not contain "/src/" part. Rewrite import without using "/src/". `
    },
    {
        selector: `ImportDeclaration[source.value=/^([a-z]|@[a-z-]+[^a-z-])[a-z-]+[^a-z-]/]`,
        message: `Import should contain only package name. No extra file or folder access after "/" package name is allowed". (not allowed  "lodash/isEqual", "@goodt-wcore/core/dremio")`
    },
    {
        selector: `VariableDeclarator[id.name=/^[A-Z_]+$/][init.type=/ObjectExpression|ArrayExpression/]`,
        message: `Use PascalCase for object or array constant names. `
    },
    {
        selector: `MemberExpression[property] MemberExpression[property.name='find']`,
        message: `Accessing property after using ".find()" is not allowed. Use next line object prop accessing. `
    },
    {
        selector: `VariableDeclarator[id.name!=/${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}/][init.type=/LogicalExpression/][init.operator!='??'][init.operator!='||']`,
        message: `Variable is potentially of Boolean type and its name should starts with one of prefixes "${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}". `
    },
    {
        selector: `VariableDeclarator[id.name!=/${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}/][init.operator=/>|>=|<|<=|==|===|!=|!==/]`,
        message: `Variable is potentially of Boolean type and its name should starts with one of prefixes "${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}". `
    },
    {
        selector: `VariableDeclarator[id.name!=/${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}/][init.callee.property.name=/some|every|includes/]`,
        message: `Variable name should starts with one of prefixes "${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}". `
    },
    {
        selector: `Property[key.name!=/${EXCLUDED_ARRAY_EXPRESSIONS_RE_LIST}/][value.type=/ArrayExpression/]`,
        message: `Property name should ends with "*s" or "*ed" due to array type. Example: "filtered", "employees". `
    },
    {
        // prettier-ignore
        selector: `VariableDeclarator[id.name!=/^.+(s|ed)$/][init.type=/ArrayExpression/]`,
        message: `Variable name should ends with "*s" or "*ed" due to array type. Example: "filtered", "employees". `
    },
    {
        selector: `Property[key.name!=/^.+(s|ed)$/][init.callee.property.name=/map|filter/]`,
        message: `Property name should ends with "*s" or "*ed" due to array type. Example: "filtered", "employees". `
    },
    {
        // prettier-ignore
        selector: `VariableDeclarator[id.name!=/^.+(s|ed)$/][init.callee.property.name=/map|filter/]`,
        message: `Variable name should ends with "*s" or "*ed" due to array type. Example: "filtered", "employees". `
    },
    {
        selector: `IfStatement[test.type='Identifier'] > Identifier[name!=/${BOOLEAN_VARIABLES_PREFIXES_RE_LIST}/]`,
        message: `Using if statement with not boolean variables in conditions deprecated. Use "!= null" or "== null" condition instead.`
    },
    {
        selector: `Property[key.name='watchStore'] Property[key.name='when'][value.raw='true']`,
        message: `Using "when: true" option is deprecated. Use "all: true" instead. `
    }
];
