const { dasherize, underscore } = require('inflection');
const { createBemClassBuilder } = require('posthtml-bemify');
const buildBemClassList = createBemClassBuilder();

const STATIC_MODIFIER_VALUE_RE = /['"]/;
const MAP_MODIFIER_RE = new RegExp("\\s*'?(?<key>[^':{};,\\s]+)'?\\s*:?\\s*(?<value>[^:}{;,]+)?[\\s]*", 'g');
const MAP_MODIFIER_RE_STATIC = new RegExp('^[a-z-0-9]+$', 'g');
const MAP_MODIFIER_RE_DYNAMIC = new RegExp('^\\[([a-z-0-9]+)\\]$');

const STATIC_CLASS = 'class';
const DYNAMIC_CLASS = ':class';

const uniqueClassesList = (args) => {
    return [...new Set(args.filter(Boolean).flatMap((x) => x.split(' ')))].join(' ');
};

// prettier-ignore
const buildTagDescriptorClassMap = ({ b, e, m }) => {
    const staticClasses = buildBemClassList(b, e, null).split(' ');
    // prettier-ignore
    const modifiersDescriptor = m?.length === 1 ? m.pop() : '';

    // prettier-ignore
    // process dynamic ~m="{ isActive }"
    const modifiersPairs = [...modifiersDescriptor.matchAll(MAP_MODIFIER_RE)]
        .map(({ groups: { key: modifier, value } }) => [dasherize(underscore(modifier)), value ?? modifier])
        .map(([modifier, value]) => {
            const isConst = STATIC_MODIFIER_VALUE_RE.test(value);
            // prettier-ignore
            const modifierValue = isConst
                ? value.replace(STATIC_MODIFIER_VALUE_RE, '')
                : null;
            if (MAP_MODIFIER_RE_DYNAMIC.test(modifier)) {
                const [, key] = MAP_MODIFIER_RE_DYNAMIC.exec(modifier);
                // eslint-disable-next-line no-param-reassign
                modifier = ['${', key , '}'].join('');
            };

            return staticClasses
                .flatMap((tagClass) => [buildBemClassList(tagClass, null, modifier, modifierValue), isConst ? null : value]);
        });

    // prettier-ignore
    // add static modifier ~m="active"
    staticClasses.push(
        ...[...modifiersDescriptor.matchAll(MAP_MODIFIER_RE_STATIC)]
            .flatMap((modifier) => staticClasses
                .map((tagClass) => buildBemClassList(tagClass, null, modifier))
            )
    );

    // prettier-ignore
    // process static ~m="active"
    const dynamicClassesMap = modifiersPairs.length > 0
        ? [ '{ ',
            modifiersPairs
                .reduce(
                    (acc, [dynamicClass, vmPropName]) => {
                        const classPairRecord = dynamicClass.includes('${')
                            // if dynamic class name, wrap with template literal
                            ? ['[`', dynamicClass, '`]', ':', `Boolean(${vmPropName})`].join('')
                            // if static class name build string
                            : `'${dynamicClass}': Boolean(${vmPropName})`;
                        return acc.concat(classPairRecord);
                    },
                    []
                )
                .join(', '),
            ' }'
          ].join('')
        : null;

    return {
        dynamicClassesMap,
        staticClasses
    };
};

/**
 *
 * @param node
 * @param b
 * @param e
 * @param m
 */
const nodeVisitor = (node, { b, e, m }) => {
    const { staticClasses, dynamicClassesMap } = buildTagDescriptorClassMap({ b, e, m });
    node.attrs[STATIC_CLASS] = uniqueClassesList([node.attrs[STATIC_CLASS], staticClasses.join(' ')]);
    if (dynamicClassesMap != null) {
        node.attrs[DYNAMIC_CLASS] = dynamicClassesMap;
    }
};

module.exports = {
    buildTagDescriptorClassMap,
    nodeVisitor
};
