const express = require('express');
const { join } = require('path');
const { createProxyMiddleware } = require('http-proxy-middleware');

const BASE_DIR = process.cwd();
const PLATFORM_CONFIG_PATH = 'sandbox/config/platform.json';

let config = {};
try {
    config = require(join(BASE_DIR, PLATFORM_CONFIG_PATH));
} catch {
    throw new Error(`Unable to load config "${PLATFORM_CONFIG_PATH}"`);
}

const HOST = config.host?.split(':')[0] ?? "localhost";
const PORT = config.host?.split(':')[1] ?? 3000;

const app = express();
// app.get("/local/", (req, res, next) => {
//     res.sendFile(path.resolve(__dirname, ));
// });

const buildProxyOptions = (origin, target) => ({
    target,
    changeOrigin: true,
    pathRewrite: {
        [`^${origin}`]: '/',
    },
});

Object.entries(config.widgets).forEach(([ key, options ]) => {
    const originPath = `${config.platform.remotesUrl}${key}/`;
    const proxyOptions = buildProxyOptions(originPath, options.url);
    app.use(createProxyMiddleware(originPath, proxyOptions));
});

app.use('/', createProxyMiddleware(buildProxyOptions('/', config.platform.url)));

app.listen(PORT, HOST, () => {
    console.log(`Sandbox started at http://${HOST}:${PORT}`)
});