import '@goodt-wcore/root/src/boot';
import Vue from 'vue';

import VueI18n from 'vue-i18n';
import { useDevtools } from '@goodt-common/plugins';
import { componentFactory, configPublicPath } from '@root/sandbox/config.js';

import { Sandbox, Config, initGlobalErrorHandle } from './components';
import { setDebugMode } from './debug';

import('@goodt/postcss-config/tailwind.pcss');
import('goodt-framework-css');

import('@mdi/font/css/materialdesignicons.css');
import('@mdi/light-font/css/materialdesignicons-light.css');

// plugins install
Vue.use(VueI18n);

const i18n = new VueI18n({
    locale: 'ru', // set locale
    messages: {} // set locale messages
});

const init = async () => {
    const configInstance = new Config({ configPublicPath });
    const config = await configInstance.load();

    const isDebugMode = config.emulator.isDebugMode ?? true;
    const isEditorMode = config.emulator.isEditorMode ?? true;
    setDebugMode(isDebugMode);

    const vueApp = new Vue({
        i18n,
        provide() {
            return {
                $errorManager: this.$errorManager,
                $errorService: this.$errorService
            };
        },
        beforeCreate() {
            const { errorService, errorManager } = initGlobalErrorHandle();
            this.$errorService = errorService;
            this.$errorManager = errorManager;
        },
        data: {
            // eslint-disable-next-line vue/no-unused-properties
            isEditorMode,
            configInstance
        },
        sandbox: {
            componentFactory,
            configPublicPath
        },
        render(h) {
            // pseudo tags to force sandbox re-create
            return h(this.isEditorMode ? 'main' : 'section', [h(Sandbox)]);
        }
    }).$mount('#app');

    return { vueApp };
};

init().then(({ vueApp }) => {
    useDevtools(vueApp);
});
