import { FETCH_DATA_EVENT_PROP_NAME, FetchDataEventProp } from './constants';

/**
 * @return {Promise<any>}
 */
const FetchDataEventPanelAsync = () => import('./FetchDataEventPanel.vue');

/**
 * factory returns fetchDataEventMixin
 *
 * @param {{ methodName: string }} options - mixin options
 * @return {import('./useFetchDataEventMixin').IFetchDataEventMixin}
 */
export const useFetchDataEventMixin = (options = { methodName: '' }) => ({
    data: () => ({
        descriptor: {
            props: {
                [FETCH_DATA_EVENT_PROP_NAME]: { ...FetchDataEventProp }
            }
        }
    }),
    watchEditor: {
        [`props.${FETCH_DATA_EVENT_PROP_NAME}`]: {
            handler(value) {
                this.disposeFetchDataEventPropWatcher?.();
                this.disposeFetchDataEventPropWatcher = null;

                if (value !== '') {
                    this.listenFetchDataEvent(value);
                }
            }
        }
    },

    constructed() {
        if (this.resolvePanelsOriginal == null) {
            this.resolvePanelsOriginal = this.resolvePanels.bind(this);
            this.resolvePanels = () => [...this.resolvePanelsOriginal(), FetchDataEventPanelAsync];
        }
    },
    created() {
        const { [FETCH_DATA_EVENT_PROP_NAME]: fetchDataEvent } = this.props;
        if ([null, undefined, ''].includes(fetchDataEvent) === false) {
            this.listenFetchDataEvent(fetchDataEvent);
        }
    },
    methods: {
        /**
         * @param {string} event - name of the event
         */
        listenFetchDataEvent(event) {
            this.disposeFetchDataEventPropWatcher = this.$eventListen(event, () => {
                this[options.methodName]?.();
            });
        }
    }
});
