import { InfrastructureError } from '@goodt-wcore/errors';

/**
 * Enum ошибок транспорта
 *
 * @readonly
 * @enum number
 */
export enum HttpTransportErrorCode {
    FORBIDDEN = 403,
    NOT_FOUND = 404,
    UNAUTHORIZED = 401,
    INTERNAL_SERVER_ERROR = 500,
    BAD_REQUEST = 400,
    INTERNAL = 0
}

export type THttpTransportErrorCode = `${HttpTransportErrorCode}`;

export type Reason = Record<string, any> | Error | undefined;

/**
 * Класс-исключение транспортного уровня для запросов к api
 * @class ApiHttpClientError
 */
export class HttpTransportError extends InfrastructureError {
    static Code: typeof HttpTransportErrorCode = HttpTransportErrorCode;

    /**
     *
     * @param {string} [message]
     * @param {THttpTransportErrorCode} [code]
     * @param {*} [data]
     * @param {Reason} [reason]
     * @constructs Service
     */
    constructor(message?: string, { code, data, reason }?: { code?: string; data?: any; reason?: Reason });

    /**
     * @private
     * @type {THttpTransportErrorCode}
     */
    private _code: THttpTransportErrorCode = HttpTransportErrorCode.INTERNAL;

    /**
     * @private
     * @type {*}
     */
    private _data: any;

    /**
     * Ошибка вызвавшая exception
     * @private
     * @type {Reason}
     */
    private _reason: Reason;

    /**
     * Данные пришедшие в ответе в
     * @public
     * @readonly
     * @type {*}
     */
    public readonly data: any;

    /**
     * HTTP status code
     * @public
     * @readonly
     * @type {number}
     */
    public readonly code: THttpTransportErrorCode;

    /**
     * Дополнительная информация о причине ошибки
     * @public
     * @readonly
     * @type {Reason}
     */
    public readonly reason: Reason;
}

export { HttpTransportError as default };
