import { InfrastructureError } from '@goodt-wcore/errors';

/**
 * Enum ошибок апи-сервиса
 *
 * @readonly
 * @enum string
 */
export const ApiHttpClientErrorCode: Readonly<{
    FORBIDDEN: 403;
    NOT_FOUND: 404;
    UNAUTHORIZED: 401;
    INTERNAL_SERVER_ERROR: 500;
    BAD_REQUEST: 400;
    INTERNAL: 0;
}>;

/**
 * Enum ошибок апи-сервиса
 */
export type TApiHttpClientErrorCode = typeof ApiHttpClientErrorCode[keyof typeof ApiHttpClientErrorCode];
/**
 * Класс-исключение транспортного уровня для запросов к api
 * @class ApiHttpClientError
 */
export class ApiHttpClientError extends InfrastructureError {
    static Code: typeof ApiHttpClientErrorCode = ApiHttpClientErrorCode;

    /**
     * @type {string}
     */
    name: string;
    /**
     *
     * @param {string} [message]
     * @param {TApiHttpClientErrorCode} [code]
     * @param {*} [data]
     * @param {null | Error | string | Record<string, any>} [reason]
     * @constructs Service
     */
    constructor(
        message?: string,
        {
            code,
            data,
            reason
        }?: { code?: TApiHttpClientErrorCode; data?: any; reason?: null | Error | string | Record<string, any> }
    );
    /**
     * @private
     * @type {TApiHttpClientErrorCode}
     */
    private _code: TApiHttpClientErrorCode;

    /**
     * @private
     * @member {*}
     */
    private _data: any;
    /**
     * Ошибка вызвавшая exception
     * @private
     * @member {null | Error | string | Record<string, any>}
     */
    private _reason: null | Error | string | Record<string, any>;
    /**
     * Данные пришедшие в ответе в
     * @public
     * @readonly
     * @member {*} Service_data
     */
    public get data(): any;
    /**
     * HTTP status code
     * @public
     * @readonly
     * @member {TApiHttpClientErrorCode} Service_code
     */
    public get code(): TApiHttpClientErrorCode;
    /**
     * Дополнительная информация о причине ошибки
     * @public
     * @readonly
     * @member {Object} Service_reason
     */
    public get reason(): null | Error | string | Record<string, any>;
}

export { ApiHttpClientError as default };
