import { InfrastructureError } from '@goodt-wcore/errors';

/**
 * Enum ошибок апи-сервиса
 *
 * @readonly
 * @enum string
 */
export enum ApiServiceErrorCodeEnum {
    INTERNAL = 'internal',
    VALIDATION = 'validation',
    FORBIDDEN = 'forbidden',
    NOT_FOUND = 'not_found',
    UNAUTHORIZED = 'unauthorized',
    UNKNOWN = 'unknown'
}
export type TApiServiceErrorCode = `${ApiServiceErrorCodeEnum}`;

/**
 * Enum ошибок апи-сервиса
 *
 * @readonly
 * @enum string
 */
export const ApiServiceErrorCode: typeof ApiServiceErrorCodeEnum;

export type Reason = Record<string, any> | Error | undefined;

/**
 * Класс-исключение транспортного уровня для запросов к api
 * @class ApiServiceError
 */
export class ApiServiceError extends InfrastructureError {
    /**
     *
     */
    static Code: typeof ApiServiceErrorCode = ApiServiceErrorCode;

    /**
     *
     * @param {string} [message]
     * @param {TApiServiceErrorCode} [code]
     * @param {*} [data]
     * @param {Reason} [reason]
     * @constructs Service
     */
    constructor(
        message?: string,
        { code, data, reason }?: { code?: TApiServiceErrorCode; data?: any; reason?: Reason }
    );

    /**
     * @private
     * @type {TApiServiceErrorCode}
     */
    private _code: TApiServiceErrorCode;

    /**
     * @private
     * @type {*}
     */
    private _data: any;

    /**
     * Ошибка вызвавшая exception
     * @private
     * @type {Reason}
     */
    private _reason: Reason;

    /**
     * Данные пришедшие в ответе в
     * @public
     * @readonly
     * @type {*} Service_data
     */
    public data: any;

    /**
     * HTTP status code
     * @public
     * @readonly
     * @type {TApiServiceErrorCode} ApiServiceError#code
     */
    public code: TApiServiceErrorCode;

    /**
     * Дополнительная информация о причине ошибки
     * @public
     * @readonly
     * @type {Reason} ApiServiceError#reason
     */
    public reason: Reason;
}

export { ApiServiceError as default };
