/**
 * converts recursively passed value if it contains a css-variable to its computed value
 * @param {*} option
 * @param {CSSStyleDeclaration} computedStyle
 * @return {*}
 */
export const convertCssVarToComputedValue = (option, computedStyle) => {
    const extractCssVarValue = (cssVar) =>
        computedStyle.getPropertyValue(cssVar.substring(4, cssVar.length - 1)) || cssVar;
    
    if (Array.isArray(option)) {
        return option.map((item) => convertCssVarToComputedValue(item, computedStyle));
    }
    
    if (typeof option === 'object' && option != null) {
        return Object.entries(option).reduce(
            (acc, [key, value]) => ({
                ...acc,
                [key]: convertCssVarToComputedValue(value, computedStyle)
            }),
            {}
        );
    }
    
    if (/^var\(--/.test(option)) {
        return extractCssVarValue(option);
    }
    
    return option;
};
