import NumberFormat from './number-format';
import { NumberFormatPatternConstructorOptions, NumberFormatPattern } from './number-format-pattern';

export interface NumberFormatOptions {
    locale?: string;
}

/**
 * Format number as currency value
 * @param {number} number
 * @param {NumberFormatPatternConstructorOptions} [pattern]
 * @param {NumberFormatOptions} [options]
 * @return {string}
 */
export const formatCurrency: (
    number: any,
    { digits, unit, modifiers }?: NumberFormatPatternConstructorOptions,
    { locale }?: NumberFormatOptions
) => string;

/**
 * Format number as a decimal number
 * @param {number} number
 * @param {NumberFormatPatternConstructorOptions} [pattern]
 * @param {NumberFormatOptions} [options]
 * @return {string}
 */
export const formatDecimal: (
    number: any,
    { digits, unit, modifiers }?: NumberFormatPatternConstructorOptions,
    { locale }?: NumberFormatOptions
) => string;

/**
 * Format number according using defined format
 * @param {number} number
 * @param {string|NumberFormat} format
 * @param {NumberFormatOptions} [options={}]
 * @return {string}
 */
export const formatNumber: (number: number, format: string | NumberFormat, options: NumberFormatOptions = {}) => string;

export { NumberFormat, NumberFormatPattern };
