import NumberFormatPattern from './number-format-pattern';

export type TypeEnum = Readonly<{ CURRENCY: 'c'; DECIMAL: 'd' }>;
export type NumberFormatType = TypeEnum['CURRENCY'] | TypeEnum['DECIMAL'];

export type StyleEnum = Readonly<{ CURRENCY: 'currency'; PERCENT: 'percent'; DECIMAL: 'decimal' }>;
export type CurrencyDisplayEnum = Readonly<{ CODE: 'code' }>;
export type NotationEnum = Readonly<{ COMPACT: 'compact'; STANDARD: 'standard' }>;

export default class NumberFormat {
    public pattern: NumberFormatPattern;
    public type: NumberFormatType;

    static Type: TypeEnum;
    static Style: StyleEnum;
    static Notation: NotationEnum;
    static CurrencyDisplay: CurrencyDisplayEnum;

    /**
     * @param {{ pattern?: NumberFormatPattern, type?: NumberFormatType }} options
     */
    constructor({ pattern, type }?: { pattern?: NumberFormatPattern; type?: NumberFormatType });

    /**
     * @return {string}
     */
    toString(): string;

    /**
     * @param {string} formatString
     * @return {NumberFormat}
     */
    static fromString(formatString: string): NumberFormat;
}
