import { CSS_VARS_DEFAULT_PREFIX } from './config';
import { CssVarsMapping } from './types';

/**
 * Generates css-vars-style def
 *
 * @param {Record<string, string>} cssVars
 * @param {string} [prefix=CSS_VARS_DEFAULT_PREFIX]
 * @return {Record<string, string>}
 */
export function buildCssVarsStyle(
    cssVars: Record<string, string>,
    prefix?: string = CSS_VARS_DEFAULT_PREFIX
): Record<string, string>;

/**
 * Build css-vars name-value hash map object by mapping on props
 *
 */
export function buildCssVarsMap<P = Record<string, any>>(
    cssVarsMapping: CssVarsMapping<P>,
    props: P
): Map<string, string | null>;

/**
 * Build css-vars hash map object from css var to prop mapping
 *
 * @param {Record<string, string|[string, string]|function(): string>} cssVarsMapping
 * @param {Record<string, any>} props
 * @return {Record<string, string>}
 */
export function buildCssVars<P = Record<string, any>>(cssVarsMapping: CssVarsMapping, props: P): Record<string, string>;
