import { IElemInstance } from '@goodt-wcore/core/Elem';

export type WatchStoreStrategyEnum = {
    ANY: 'any';
    ALL: 'all';
    ALL_VARS: 'all_vars';
};

export type WatchStoreStrategy = WatchStoreStrategyEnum['ALL'] | WatchStoreStrategyEnum['ANY'] | WatchStoreStrategyEnum['ALL_VARS'];

export type WatchStoreHandler<TVarList> =
    | ((values?: any[], state?: { [key in TVarList]: number | string | boolean | null | undefined }) => void)
    | string;

export type WatchStoreHandlerConditionFunction = (values: any[]) => boolean;

export type WatchStoreHandlerCondition =
    | WatchStoreHandlerConditionFunction
    | WatchStoreHandlerConditionFunction[]
    | string
    | boolean;

export interface IWatchStoreDefinition<TVarList = string[]> {
    id?: string;
    vars?: TVarList | null;
    all?: boolean;
    when?: WatchStoreHandlerCondition;
    handler: WatchStoreHandler;
}

declare global {
    WatchStoreDefinition = IWatchStoreDefinition;
}

declare module 'vue/types/options' {
    import Vue from 'vue';

    interface ComponentOptions<V extends Vue> {
        watchStore?: IWatchStoreDefinition[];
    }
}

type WatchDispose = () => void;

export function createStoreWatcher(
    vm: IElemInstance,
    definition: WatchStoreDefinition,
    watchOptions: {
        immediate?: boolean;
        deep?: boolean;
    }
): WatchDispose;

export function watchStore<TVarList = string[]>({
    handler,
    vars,
    all,
    when
}: {
    vars?: TVarList | null;
    all?: boolean;
    when?: WatchStoreHandlerCondition;
    handler: WatchStoreHandler<TVarList>;
}): ReturnType<typeof createStoreWatcher>;

type WatchStoreFunction = () => WatchDispose;

/**
 * Automatically creates '$storeState' watchers defined in the '#WATCH_STORE_COMPONENT_OPTION_NAME' block of the target 'vm'
 * @param {IElemInstance} vm  target component
 * @return {{ $watchStore: WatchDispose, disposals: WatchDispose[] }} array of watcher disposal functions
 */
export function useWatchStore(vm: ElemInstance): {
    $watchStore: typeof watchStore;
    disposals: WatchDispose[];
}[];
