const StoreOperationType = {
    READ: 'listen',
    WRITE: 'trigger'
}

export const StoreOperation = {
    // eslint-disable-next-line no-restricted-syntax
    ALL: [StoreOperationType.READ, StoreOperationType.WRITE],
    // eslint-disable-next-line no-restricted-syntax
    READ: [StoreOperationType.READ],
    // eslint-disable-next-line no-restricted-syntax
    WRITE: [StoreOperationType.WRITE]
};

const VARS_PROP_KEY = 'varAliases';

const resolveVarNames = (vm, operationType) =>
    Object.entries(vm.props[VARS_PROP_KEY])
        .filter(([, { [operationType]: operation }]) => operation != null)
        .map(([varAlias]) => varAlias);

export const createElemStoreMeta = (vm) => ({
    get vars() {
        return {
            get read() {
                return resolveVarNames(vm, StoreOperationType.READ);
            },
            get write() {
                return resolveVarNames(vm, StoreOperationType.WRITE);
            },
            get readMap() {
                return this.read.reduce((acc, varAlias) => ({
                    ...acc,
                    [varAlias]: vm.props[VARS_PROP_KEY][varAlias][StoreOperationType.READ]
                }), {});
            },
            get writeMap() {
                return this.write.reduce((acc, varAlias) => ({
                    ...acc,
                    [varAlias]: vm.props[VARS_PROP_KEY][varAlias][StoreOperationType.WRITE]
                }), {});
            }
        };
    }
});

export const createPanelStoreMeta = (vm) => ({
    setVar({ varAlias, storeVar = varAlias, operation = StoreOperation.ALL }) {
        // eslint-disable-next-line id-length
        operation.forEach((op) => {
            // eslint-disable-next-line no-param-reassign
            vm.props[VARS_PROP_KEY][varAlias] = {
                ...vm.props[VARS_PROP_KEY][varAlias],
                [op]: storeVar
            };
        });
        // eslint-disable-next-line no-param-reassign
    },
    deleteVar({ varAlias, operation = StoreOperation.ALL }) {
        operation.forEach((_operation) => {
            const { [VARS_PROP_KEY]: varAliases } = vm.props;
            if (varAliases[varAlias] == null) {
                return;
            }
            // eslint-disable-next-line no-underscore-dangle
            delete varAliases[varAlias][_operation];
            if (Object.keys(varAliases[varAlias]).length === 0) {
                delete varAliases[varAlias];
            }
        });
    },
    saveVars() {
        vm.propChanged('varAliases');
    },
    ...createElemStoreMeta(vm)
});



/**
 * @type {{ $storeMeta: ReturnType<typeof $storeMeta> }}
 */
export const InjectedTypesDefinitions = undefined;
