export class BaseError extends Error {
    isCancel: boolean;

    captureStackTrace(context: any): void;
}

/**
 * Any core functionality-related error
 */
export class CoreError extends BaseError {
    /**
     * @param {string} [message]
     * @param {null | Error | string | Record<string, any>} [reason]
     * @constructs CoreError
     */
    constructor(message?: string, { reason }?: { reason?: null | Error | string | Record<string, any> });
}
/**
 * Any core functionality-related warning
 */
export class CoreWarning extends SilentError {
    constructor(message, { reason }: { reason: Record<string, any> })

    reason: Record<string, any>;
}

export class WidgetPresentableError extends PresentableError {}
export class SilentError extends Error {}


export class PresentableError extends SilentError {}

export class RequestCancel extends SilentError {
    public isCancel: boolean;
}

/**
 *
 */
export class ExtendedInfoError extends BaseError {
    /**
     *
     * @param {string} [message]
     * @param {string} [code]
     * @param {*} [data]
     * @param {null | Error | string | Record<string, any>} [reason]
     * @constructs InfrastructureError
     */
    constructor(
        message?: string,
        {
            code,
            data,
            reason
        }?: { code?: number | string; data?: any; reason?: null | Error | string | Record<string, any> }
    );

    /**
     * @private
     * @type {number | string}
     */
    private _code: number | string;

    /**
     * @private
     * @type {*}
     */
    private _data: any;

    /**
     * Ошибка вызвавшая exception
     *
     * @private
     * @type {null | Error | string | Record<string, any>}
     */
    private _reason: null | Error | string | Record<string, any>;

    /**
     * @type {string}
     */
    public scope: string;

    /**
     * Данные пришедшие в ответе в
     *
     * @public
     * @readonly
     * @type {*}
     */
    public get data(): any;

    /**
     * HTTP status code
     *
     * @public
     * @readonly
     * @type {number | string}
     */
    public get code(): TApiHttpClientErrorCode;

    /**
     * Дополнительная информация о причине ошибки
     *
     * @public
     * @readonly
     * @type {null | Error | string | Record<string, any>}
     */
    public get reason(): null | Error | string | Record<string, any>;
}

export class InfrastructureError extends ExtendedInfoError {
}
export class WidgetDebugMessage extends ExtendedInfoError {
    type: 'error' | 'warning' | 'info'
}

