export class PopupManager {
    private _isOpenResolver: () => boolean;

    /**
     * @return {PopupManager}
     */
    public static instance: PopupManager;

    public isOpen: boolean;

    setIsOpenResolver(resolver: () => boolean);

    /**
     * @param {any} [data]
     * @return {Promise<any>}
     */
    open(data?: any): Promise<any>;

    /**
     * @param {any} [data]
     * @return {Promise<any>}
     */
    close(data?: any): Promise<any>;

    /**
     * Registers open() observer (used by the env)
     *
     * @param {({ pageId: string })} handler  open handler invoked by @see open()
     * @return {() => void}                 dispose function to unregister observer
     */
    onOpen(handler: ({ resolve, ...rest }: { resolve: (...args: any[]) => void, rest?: Record<string, any> }) => void): () => void;

    /**
     * Registers close() observer (used by the env)
     *
     * @param {()} handler     close handler invoked by @see close()
     * @return {() => void}   dispose function to unregister observer
     */
    onClose(handler: ({ resolve, ...rest }: { resolve: (...args: any[]) => void, rest?: Record<string, any> }) => void): () => void;
}
