export interface NavigateOptions {
    path: string;
    query?: Record<string, null | undefined | string | number | boolean>;
}

export class Route implements NavigateOptions {
    path: string;
    query?: Record<string, null | undefined | string | number | boolean>;
}

export interface RouteObject extends Required<NavigateOptions> {
    readonly meta: Record<string, any>;
}

type NavigateHandler = ({ path, query }: NavigateOptions) => {};
type RouteHandler = ({ path, query }: NavigateOptions) => {};
type RouteStringifier = ({ path, query }: NavigateOptions, baseUrl = string) => {};

export class RouteManager {
    /**
     * @private
     */
    public static routeStringifier: RouteStringifier;

    /**
     * @private
     * @type {RouteHandler[]}
     */
    private _routeHandlers = [];

    /**
     * @return {RouteManager}
     */
    public static instance: RouteManager;

    /**
     * Returns the current route
     * @return {RouteObject} route
     */
    public route: RouteObject;

    /**
     * Sets the current route
     * @param {RouteObject} route                       new route
     * @param {boolean} [isInvokeRouteHandlers=true]      if true will invoke route handlers
     */
    setRoute(route: RouteObject, isInvokeRouteHandlers = true);

    /**
     *
     */
    setRouteStringifier(routeStringifier: RouteStringifier);

    /**
     * Requests a route change by path
     *
     * @param {NavigateOptions} options
     */
    // eslint-disable-next-line class-methods-use-this
    navigate({ path, query = {} }: NavigateOptions);

    /**
     * Registers navigate() observer (used by the env)
     *
     * @param {NavigateHandler} handler     navigate handler invoked by @see navigate()
     * @return {Function}                   dispose function to unregister observer
     */
    // eslint-disable-next-line class-methods-use-this
    onNavigate(handler: NavigateHandler): () => {};

    /**
     * Adds a route handler
     * @param {RouteHandler} handler
     */
    addRouteHandler(handler: RouteHandler);

    /**
     * Removes a route handler
     * @param {RouteHandler} handler
     */
    removeRouteHandler(handler: RouteHandler);

    /**
     * @return {string|*}
     */
    buildRouteString(...args: Parameters<RouteStringifier>): string;
}

export { RouteManager as default }