import { ValueObject } from './ValueObject';

export type CommitHandler = (statePartial: Record<string, any>) => any;
export type StoreElemState<T = any> = Record<string, T>;
export type StoreGlobalState = Record<string, ValueObject>;

/**
 * Reactive state holder symbol identifier
 */
declare const stateManagerObservable: unique symbol;
/**
 * Store
 */
export declare class Store {
    private _commitHandlers: any[];
    /**
     * Returns the current state
     *
     * @return {Record<string, any>}
     */

    readonly state: StoreGlobalState;
    /**
     * Merges the 'statePartial' object to the current state
     *
     * @param {Record<string, unknown>} statePartial      state change obj
     * @param {{ isInvokeCommitHandlers?: boolean, context?: any }} options    if true will invoked
     */

    commit(
        statePartial: StoreGlobalState,
        { isInvokeCommitHandlers = true, context }: { isInvokeCommitHandlers?: boolean; context?: any }
    );

    /**
     * Replaces the state with the 'newState'
     *
     * @param {Record<string, any>} newState
     */
    replace(newState: StoreGlobalState);
    /**
     * Adds a commit handler
     *
     * @param {CommitHandler} handler
     */

    addCommitHandler(handler: CommitHandler): void;
    /**
     * Removes a commit handler
     *
     * @param {CommitHandler} handler
     */

    removeCommitHandler(handler: CommitHandler): void;
    /**
     * @callback CommitHandler
     * @param {Record<string, any>} statePartial
     */

    /** @type {CommitHandler[]} */
    [stateManagerObservable]: CommitHandler[];
}


export const store: Store = undefined;

/**
 * Store factory method
 *
 * @return {Store}
 */
export function createStore(): Store;
