export { IWatchStoreDefinition, ValueObjectMeta } from './managers';

declare global {
    import { PropOptions } from 'vue';

    export interface ElemPropDef extends PropOptions {
        type: String | Boolean | Number | Object | Array | Function;
        default?: String | Boolean | Number | Object | Array | Function;
        enum?: string[];
        options?: { value: unknown; label: string }[] | Record<string, any>;
        hasConst?: boolean;
        label?: String | Record<string, string>,
        hint?: String | Record<string, string>,
        factory?: ((...args: IArguments) => any) | Record<string, (...args: IArguments) => any>
    }

    export type ElemVarDef = {
        description?: string;
        sortIndex?: number;
    }

    export type ElemVarAliasDef = {
        listen?: string,
        trigger?: string,
        meta?: ValueObjectMeta
    }

    export type ElemRecordPropsDefinition<T> = {
        readonly [K in keyof T]: ElemPropDef<T[K]>;
    };

    export type ElemRecordVarsDefinition = {
        readonly [K as string]?: ElemVarDef;
    };

    export type ElemDescriptorEventsDefinition = {
        readonly [K as string]?: {
            listen?: string;
            trigger?: string;
        };
    };


    export interface ElemDescriptor<P extends Record<string, ElemPropDef>, V extends Record<string, ElemVarDef>> {
        readonly props?: ElemRecordPropsDefinition<P>;
        readonly vars?: ElemRecordVarsDefinition<V>;
        readonly events?: ElemDescriptorEventsDefinition;
    }
}
