import { ComponentOptions } from 'vue/types/options';
import Vue from 'vue';

export type WhenCondition = string | (() => boolean);

interface IWatchWhen {
    resolveWatch({ context }: { context: Vue }): ComponentOptions<Vue>['watch'];
}

/**
 * Helper function to wrap `watch` section with condition
 *
 * @param {ComponentOptions['watch']} watch
 * @param {WhenCondition} when
 * @return {IWatchWhen}
 */
export function watchWhen(watch: ComponentOptions<Vue>['watch'], when?: WhenCondition): IWatchWhen;

/**
 *
 * @param {string} name
 * @param {WhenCondition} when
 * @return {{created(): void, beforeCreate(): void}}
 */
export function useWatchWhenMixin({ name = 'watch', when = () => true }: { name: string; when: WhenCondition } = {}): {
    created(): void;
    beforeCreate(): void;
};

export function shouldWatch(when: IWatchWhen, context: Vue): boolean;