import { Server as HttpServer } from 'http'
import { Server, ServerOptions } from 'socket.io'
import { createAppHandlers } from './management/index.ts'
import { ClientEvents, ServerEvents } from './events.ts'
import { ClientEventEnum } from './utils.ts'

export const createApp = (
    httpServer: HttpServer,
    serverOptions: Partial<ServerOptions> = {}
    ): Server<ClientEvents, ServerEvents> => {
    const io = new Server<ClientEvents, ServerEvents>(httpServer, serverOptions);


    io.on('connection', (socket) => {
        const { handshake, joinApp, leaveApp, disconnect } = createAppHandlers(socket);

        socket.on(ClientEventEnum.HANDSHAKE, handshake);
        socket.on(ClientEventEnum.APP_JOIN, joinApp);
        socket.on(ClientEventEnum.APP_LEAVE, leaveApp);
        socket.on(ClientEventEnum.DISCONNECT, disconnect);
    })

    return io;
}
