import { ValidationErrorItem } from 'joi';
import { ServerEventEnum, ClientEventEnum } from './utils.ts'
import { appId, user, token } from './management/index.ts'

interface Error {
    error: string;
    errorDetails?: ValidationErrorItem[];
}

interface Success<T> {
    data: T;
}

export type Response<T> = Error | Success<T>;

export interface ClientEvents {
    [ClientEventEnum.HANDSHAKE]: (token: token, callback: (res: Response<boolean>) => void) => void;
    [ClientEventEnum.APP_JOIN]: (
        appId: appId,
        user: Omit<user, 'id' | 'name' | 'hasModeratorRole'>,
        callback: (res: Response<Record<string, user>>) => void
    ) => void;
    [ClientEventEnum.APP_LEAVE]: (appId: appId, callback: (res: Response<boolean>) => void) => void;
    [ClientEventEnum.DISCONNECT]: () => void;
}

export interface ServerEvents {
    [ServerEventEnum.APP_JOINED]: (userMap: Record<string, user>, user: user) => void;
    [ServerEventEnum.APP_LEFT]: (userMap: Record<string, user>, user: user) => void;
}
