// core-level configuring/bootstrapping
import 'goodt-wcore/boot.wmf';
// env-level configuring/bootstrapping
import './bootstrap';
import isDeveloperMode from '@/utils/DevMode';
import { importDebugStuffToWindow } from '@goodt/editor-common/utils/common';

import VueI18n from 'vue-i18n';
import { store as vuex } from '@/store';

import { ServiceWorkerClient } from '@/services';

import { useDevtools } from '@goodt-common/plugins';

const i18n = new VueI18n({
    messages: {}
});

(async () => {
    const workerApi = await ServiceWorkerClient.init({
        isDebug: isDeveloperMode
    });

    // start loading assets after ServiceWorker registration to decide if caching required
    import('@mdi/font/css/materialdesignicons.min.css');
    import('@mdi/light-font/css/materialdesignicons-light.min.css');
    import('@/assets/style.less');
    import('@goodt/postcss-config/tailwind.pcss');

    const [{ Application }, { default: AppComponent }] = await Promise.all([
        import('./core'),
        import('./App.vue')
    ]);

    new Application({
        vuex,
        i18n,
        workerApi
    })
        .init(AppComponent, {
            data: () => ({
                isEditorMode: false
            })
        })
        .then(({ vueApp }) => {
            useDevtools(vueApp);
            importDebugStuffToWindow(workerApi, 'workerApi');
        });
})();
