import PageRenderer from '@/core/PageRenderer';

/**
 * @typedef {object} PageEntity
 * @property {string} id
 * @property {string} title
 * @property {boolean} isTemplate
 * @property {string} templatePageId
 * @property {PageElemEntity[]} content
 */
/**
 * @typedef {object} PageElemEntity
 * @property {string} id
 * @property {string} type
 * @property {object} props
 * @property {PageElemEntity[]} children
 */

/**
 * @typedef {object} ElemInfo
 * @property {string} id            id
 * @property {string} type          type
 * @property {object} props         props
 * @property {import('vue/types/options').AsyncComponentFactory} component     component def
 * @property {ElemInfo[]} children  children
 */
export default {
    functional: true,
    name: 'Page',
    props: {
        page: { type: Object, default: null },
        template: { type: Object, default: null }
    },
    render(h, { props: { page, template }, parent: { $route } }) {
        const pageRenderer = new PageRenderer({ h });
        if (page == null) {
            const { page: routePage, template: routeTemplate } = $route.meta;
            return pageRenderer.render({ template: routeTemplate, page: routePage });
        }
        return pageRenderer.render({ template, page });
    }
};
