import { createRenderFactory } from '@goodt-wcore/render';
import ElemRegistry from './ElemRegistry';
import PageRendererRegistry from './PageRenderRegistry';
import RenderTreeBuilder from './RenderTreeBuilder';

/**
 * @typedef {object} PageEntity
 * @property {string} id
 * @property {string} title
 * @property {boolean} isTemplate
 * @property {string} templatePageId
 * @property {PageElemEntity[]} content
 */
/**
 * @typedef {object} PageElemEntity
 * @property {string} id
 * @property {string} type
 * @property {object} props
 * @property {PageElemEntity[]} children
 */
/**
 * @typedef {object} ElemInfo
 * @property {string} id            id
 * @property {string} type          type
 * @property {object} props         props
 * @property {import('vue/types/options').AsyncComponentFactory} component     component def
 * @property {ElemInfo[]} children  children
 */

class PageRenderer {
    _createElement;

    constructor({ h, pageRendererRegistry = PageRendererRegistry }) {
        this._createElement = h;
        this._pageRendererRegistry = pageRendererRegistry;
    }

    _createRenderFactory({ page, template }) {
        const renderTreeBuilder = new RenderTreeBuilder({ registry: ElemRegistry });
        const renderTree = renderTreeBuilder.build({ page, template });
        const renderFn = createRenderFactory(this._createElement, renderTree);

        return renderFn;
    }

    render({ template, page }) {
        const pageId = page.id || template.id;
        let pageRenderFactory = this._pageRendererRegistry.get(pageId);

        if (pageRenderFactory === undefined) {
            pageRenderFactory = this._createRenderFactory({ template, page });
            this._pageRendererRegistry.set(pageId, pageRenderFactory);
        }

        return pageRenderFactory();
    }
}

export { PageRenderer, PageRenderer as default };
