import { CoreError } from '@goodt-wcore/errors';

/**
 * @typedef {object} RouteMonitorOptions
 * @property {string} url
 * @property {() => string?} getToken
 */

/**
 * @typedef {import('../utils/log').Log} LogRecord
 */
export class RouteMonitor {
    /**
     * @param {RouteMonitorOptions} options
     */
    constructor(options) {
        this.options = options;
    }

    /**
     * Log a record
     * @param {LogRecord} record    log record
     */
    log(record) {
        const { url, getToken } = this.options;
        const request = {
            method: 'POST',
            cache: 'no-cache',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify(record)
        };
        if (getToken != null) {
            request.headers.Authorization = `Bearer ${getToken()}`;
        }
        try {
            fetch(url, request);
        } catch (error) {
            throw new CoreError('Log was not sent', { reason: error })
        }
    }
}

/**
 * @param {RouteMonitorOptions} options
 * @return {RouteMonitor}
 */
export const useRouteMonitor = (options) => new RouteMonitor(options);
