import { Config } from '@/utils';

const log = (...rest) =>
    console.log({ label: 'SW.CLIENT' }, ...rest);

const hashObject = (str) => Array.from(JSON.stringify(decodeURIComponent(str)))
    .reduce((s, c) => Math.imul(31, s) + c.charCodeAt(0) | 0, 0);


const serviceWorkerRegistrationHandler = (registration) => {
    return new Promise((resolve) => {
        const onStateChange = ({ target }, { onSuccess } = {}) => {
            const isActivated = target.state === 'activated';
            const { controller } = navigator.serviceWorker;

            if (controller != null) {
                onSuccess && onSuccess();
                return;
            }
            if (isActivated && !controller) {
                // https://web.dev/service-worker-lifecycle/#shift-reload
                if (window.parent) {
                    window.parent.location.reload();
                } else {
                    location.reload();
                }
            }
        };
        const worker = registration.installing || registration.waiting || registration.active;
        worker.onstatechange = onStateChange;
        onStateChange({ target: worker }, { onSuccess: resolve });
    });
};

const useHostAppServiceWorker = async ({ isDebug }) => {
    const { auth: { url: authUrl = null, redirectUrl = null } = {} } = Config.data;
    const { init } = await import ('@goodt/editor-common/sw/clients/ServiceWorkerClient');

    return await init({ isDebug, authUrl, redirectUrl });
};

const useSelfAppServiceWorker = async ({ isDebug }) => {
    const { version, date } = Config.report;
    const { auth: {} = {}, assets: { cache: cacheAssets = false } = {} } = Config.data;

    const urlParams = new URLSearchParams({
        debug: isDebug ? 1 : 0,
        appVersion: `${version}_${date}`,
        // to force re-registration on config updated
        workerConfigVersion: hashObject(Config.worker),
        cacheAssets: cacheAssets ? 1 : 0
    });

    const registration = await navigator.serviceWorker
        .register(`./worker.js?${urlParams.toString()}`);

    await serviceWorkerRegistrationHandler(registration);

    const { use: useAssetsCacheServiceApi } = await import('@goodt/editor-common/sw/clients/AssetsCacheServiceWorkerClient');
    return useAssetsCacheServiceApi();
 };
/**
 *
 * @return {Promise<unknown>}
 */
export const init = async ({ isDebug }) => {
    await Config.init();
    const { isStandaloneMode } = Config;
    log({ label: `INFO` }, { isStandaloneMode });
    return isStandaloneMode ? useSelfAppServiceWorker({ isDebug }) : useHostAppServiceWorker({ isDebug });
};
