import Config from './Config';

export class NetworkAuthError extends Error {}

/**
 * @param {string} url
 * @param {RequestInit} options
 * @return {Promise}
 */
const fetchAsset = (url, options = { method: 'GET' }) => {
    // eslint-disable-next-line
    const { baseURL = '' } = Config.data.assets ?? {};
    const optionsDefault = { credentials: 'include' };
    const targetURL = baseURL === '' ? url : [baseURL, url].join('/');
    return fetch(targetURL, { ...optionsDefault, ...options }).then((response) => {
        if (response.status === 401 || response.status === 403) {
            throw new NetworkAuthError('Unauthorized');
        }
        return response;
    });
};

/**
 * Fetch text asset (alias for fetch().text())
 * @param {string} url
 * @return {Promise.<string>}
 */
export const fetchText = (url) => fetchAsset(url).then((response) => response.text());

/**
 * Fetch json asset (alias for fetch().json())
 * @param {string} url
 * @return {Promise.<string>}
 */
export const fetchJson = (url) => fetchAsset(url).then((response) => response.json());
