/**
 * @typedef {Object} Log
 * @property {string} cid
 * @property {string} time
 * @property {string} browser
 * @property {string} baseUrl
 * @property {width: number, height: number} clientResolution
 * @property {string} previousPage
 * @property {string} page
 * @property {string} pageTitle
 * @property {string} message
 * @property {string} [userType]
 * @property {string} [userName]
 * @property {string[]} [userId]
 * @property {string[]} [userGroups]
 */

/**
 * @param {import('vue-router').Route}                                      to
 * @param {import('vue-router').Route}                                      from
 * @param {import('@goodt-wcore/managers/AuthManager').AdapterInfo}         adapter
 * @param {string}                                                          cid - client unique identifier
 * @return {Log}
 */
export const createLog = async ({ to, from, adapter, cid }) => {
    const { navigator, screen, location } = window;
    const { fullPath: previousPage } = from;
    const { fullPath: page, meta } = to;
    const log = {
        cid,
        time: new Date().toISOString(),
        browser: navigator.userAgent,
        baseURL: location.href,
        clientResolution: {
            width: screen.width,
            height: screen.height
        },
        previousPage,
        page,
        pageTitle: meta.page.title,
        event: 'Route changed',
        message: `The route was changed from '${previousPage}' to '${page}'`
    };
    
    if (adapter == null) {
        return log;
    }
    
    const { authenticated = false } = adapter;
    if (authenticated === false) {
        return log;
    }
    
    const profile = await adapter.getUserProfile();
    const { username = '', attributes = {} } = profile;
    const { employee_id = [], groups = [] } = attributes;
    
    log.userType = authenticated ? 'authorized' : 'unauthorized';
    log.userName = username;
    log.userId = employee_id;
    log.userGroups = groups;
    return log;
}
