// eslint-disable no-magic-numbers
import panels, { LabelMap } from './panels';
import { ImageFormat } from './const';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({
    MAKE_JPEG: 'make-jpeg',
    MAKE_PNG: 'make-png',
    MAKE_WEBP: 'make-webp',
    MAKE_PDF: 'make-pdf',
    SEND_PDF: 'send-pdf'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        height: {
            default: 100
        },
        heightUnit: {
            default: '%'
        },
        grid: {
            type: Object,
            default() {
                return {
                    areas: [
                        ['.', '.'],
                        ['.', '.']
                    ],
                    places: {},
                    rows: ['1fr', '1fr'],
                    cols: ['1fr', '1fr'],
                    gap: {
                        row: '1.5rem',
                        col: '1.5rem'
                    }
                };
            }
        },
        screenshotMode: {
            type: Object,
            default: () => ({
                isEnabled: false,
                withDate: true,
                formatMap: Object.values(ImageFormat).reduce(
                    (acc, format) => ({
                        ...acc,
                        [format]: {
                            event: format,
                            title: format
                        }
                    }),
                    {}
                )
            }),
            label: LabelMap.screenshotMode
        },
        events: {
            type: Object,
            default: () => ({
                [Events.SEND_PDF]: Events.SEND_PDF
            }),
            label: {
                [`events.${Events.SEND_PDF}`]: 'Событие выгрузки в pdf'
            }
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    events: {
        [Events.SEND_PDF]: ['trigger'],
        [Events.MAKE_PDF]: ['listen'],
        [Events.MAKE_JPEG]: {
            listen: 'screenshotMode.formatMap.jpeg.event'
        },
        [Events.MAKE_PNG]: {
            listen: 'screenshotMode.formatMap.png.event'
        },
        [Events.MAKE_WEBP]: {
            listen: 'screenshotMode.formatMap.webp.event'
        }
    }
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: (type, vm) => vm.areaNames.length > 0,
    slotNames: ({ areaNames }) => areaNames,
    cssVars: {
        gap: ({ grid }) => `${grid.gap.row} ${grid.gap.col}`,
        'template-columns': ({ grid }) => grid.cols.join(' '),
        'template-rows': ({ grid }) => grid.rows.join(' '),
        'template-areas': ({ grid }) => grid.areas.map((arr) => `"${arr.join(' ')}"`).join(' ')
    }
};

export default descriptor;
