// eslint-disable no-magic-numbers
/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        height: {
            default: 100
        },
        heightUnit: {
            default: '%'
        },
        grid: {
            type: Object,
            default() {
                return {
                    areas: [
                        ['.', '.'],
                        ['.', '.']
                    ],
                    rows: ['1fr', '1fr'],
                    cols: ['1fr', '1fr'],
                    gap: {
                        row: '1.5rem',
                        col: '1.5rem'
                    }
                };
            }
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    cssVars: {
        gap: ({ grid }) => `${grid.gap.row} ${grid.gap.col}`,
        'template-columns': ({ grid }) => grid.cols.join(' '),
        'template-rows': ({ grid }) => grid.rows.join(' '),
        'template-areas': ({ grid }) => grid.areas.map((arr) => `"${arr.join(' ')}"`).join(' ')
    }
});

export default descriptor;
