/* eslint-disable no-restricted-syntax */
import panels from './panels';
import { LayerFactory } from './constants';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({
    /*
    OPEN: 'open',
    CLOSE: 'close'
    */
});

/**
 * @typedef {object}        LayerItem
 * @property {string}       name
 * @property {boolean}      isVisible
 * @property {string}       [width]
 * @property {string}       [height]
 * @property {string}       [position]
 */

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        layers: {
            type: Array,
            default: () => [],
            /**
             * @return {LayerItem}
             */
            factory: LayerFactory
        },
        position: {
            type: String,
            default: 'pos-rel'
        },
        height: {
            type: String,
            default: '100'
        },
        heightUnit: {
            type: String,
            default: '%'
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: true,
    slotNames: ({ props }) => props.layers.map(({ name }) => name)
};

export default descriptor;
