import { TimeUnitsType } from './constants';

/** @type {import('./defs').DAction} */

/**
 * @return {DAction}
 */
export const actionFactory = () => ({
    socketMessage: null,
    shouldRunOnTimer: true,
    refreshTimeout: null,
    events: [],
    filters: {}
});

/**
 * @param {string} timeString
 * @return {number}
 */
export const parseTimeString = (timeString) => {
    const MINUTES_IN_HOUR = 60;
    const SECONDS_IN_MINUTE = 60;
    const MILLISECONDS_IN_SECOND = 1000;
    const timeConverterMap = {
        [TimeUnitsType.HOUR]: (hours) => timeConverterMap[TimeUnitsType.MIN](hours * MINUTES_IN_HOUR),
        [TimeUnitsType.MIN]: (minutes) => timeConverterMap[TimeUnitsType.SEC](minutes * SECONDS_IN_MINUTE),
        [TimeUnitsType.SEC]: (seconds) => seconds * MILLISECONDS_IN_SECOND
    };
    const withUnitRegExp = /^(-?[\d.]*)(\D+)$/i;
    const [_, value, unit] = timeString.match(withUnitRegExp);
    return timeConverterMap[unit](value);
};

/**
 * @param {Record<string, string>} data
 * @return {Record<string, any>}
 */
export const buildDataToCommit = (data) =>
    Object.entries(data).reduce((acc, [key, value]) => {
        try {
            return { ...acc, [key]: JSON.parse(value.replace(/'/g, '"')) };
        } catch (e) {
            return { ...acc, [key]: value };
        }
    }, {});
