/**
 * @typedef {Readonly<{ PNG: string, JPEG: string, WEBP: string, PDF: string }>} ScreenshotFormat
 */

/**
 * @typedef {Object} Title
 * @property {string} text                      The text of the title
 * @property {string} color                     The color of the title
 * @property {string} fontSize                  The font size of the title
 * @property {string} fontWeight                The font weight of the title
 * @property {string} fontFamily                The font family of the title
 * @property {string} offset                    The offset of the title from the icon
 */

/**
 * @typedef {Object} Icon
 * @property {string} name                      The name of the icon
 * @property {string} color                     The color of the icon
 * @property {string} size                      The size of the icon
 */

/**
 * @typedef {Object} MenuItem
 * @property {string} name                                  The name of the menu item
 * @property {ScreenshotFormat|string} event                The name of the triggered event
 * @property {boolean} isVisible                            Whether the menu item is visible
 * @property {Title & {offset: string}} title               The title of the menu item
 * @property {Icon} icon                                    The icon of the menu item
 */

/**
 * @typedef {Object} MenuButton
 * @property {'start'|'center'|'end'} position              The menu button position
 * @property {Title} title                                  The title of the menu button
 * @property {Icon} icon                                    The icon of the menu button
 */

/**
 * @enum {string}
 * @type {ScreenshotFormat}
 */
export const ScreenshotFormat = Object.freeze({
    PNG: 'png',
    JPEG: 'jpeg',
    WEBP: 'webp',
    PDF: 'pdf'
});

/**
 * @param {string} menuItemName                         The name of the menu item
 * @param {ScreenshotFormat|string} [event='']          The name of the triggered event
 * @param {string} [iconName='']                        The name of the icon
 * @return {MenuItem}
 */
export const menuItemFactory = (menuItemName, event = '', iconName = '') => ({
    name: menuItemName,
    event,
    isVisible: true,
    title: {
        text: menuItemName,
        color: null,
        fontSize: null,
        fontWeight: null,
        fontFamily: null,
        offset: null
    },
    icon: {
        name: iconName,
        color: null,
        size: null
    }
});

export const MENU_ITEM_NAME_PREFIX = 'Пункт ';

/**
 * @return {MenuButton}
 */
export const menuButtonStyleFactory = () => ({
    title: {
        text: '',
        color: null,
        fontSize: null,
        fontWeight: null,
        fontFamily: null
    },
    icon: {
        name: 'camera',
        size: null,
        color: null
    }
});

export const TriggerOn = Object.freeze({
    CLICK: 'click',
    HOVER: 'hover'
});

export const PageOrientation = Object.freeze({
    LANDSCAPE: 'landscape',
    PORTRAIT: 'portrait'
});

export const IMAGE_FORMAT = 'JPEG';
export const A4_HEIGHT = 297;
export const A4_WIDTH = 210;
export const PAGE_X_OFFSET = 10;
export const PAGE_Y_OFFSET = 10;
