/* eslint-disable no-restricted-syntax */
import panels, { LabelMap } from './panels';
import { ScreenshotFormat, menuItemFactory, menuButtonStyleFactory, TriggerOn } from './constants';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({
    MAKE_JPEG: 'make-jpeg',
    MAKE_PNG: 'make-png',
    MAKE_WEBP: 'make-webp',
    MAKE_PDF: 'make-pdf',
    SEND_PDF: 'send-pdf'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        menu: {
            type: Object,
            default: () => ({
                isAlwaysOpen: true,
                dropdownPosition: 'bottom',
                triggerOn: TriggerOn.CLICK,
                gapBetweenItems: null,
                hoveredItemStyle: {
                    textColor: null,
                    iconColor: null,
                    bgColor: null
                }
            }),
            label: LabelMap.menu
        },
        menuItems: {
            type: Array,
            default: () => [
                menuItemFactory(ScreenshotFormat.PNG, ScreenshotFormat.PNG, 'file-png-box'),
                menuItemFactory(ScreenshotFormat.JPEG, ScreenshotFormat.JPEG, 'file-jpg-box'),
                menuItemFactory(ScreenshotFormat.WEBP, ScreenshotFormat.WEBP, 'web'),
                menuItemFactory(ScreenshotFormat.PDF, ScreenshotFormat.PDF, 'file-pdf-box')
            ],
            factory: menuItemFactory,
            label: LabelMap.menuItems
        },
        menuButton: {
            type: Object,
            default: () => ({
                position: 'start',
                defaultStyle: menuButtonStyleFactory(),
                activeStyle: menuButtonStyleFactory()
            }),
            label: LabelMap.menuButton
        },
        events: {
            type: Object,
            default: () => ({
                [Events.SEND_PDF]: Events.SEND_PDF
            }),
            label: {
                [`events.${Events.SEND_PDF}`]: 'Событие выгрузки в pdf'
            }
        },
        height: {
            type: String,
            default: '100'
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    events: {
        [Events.SEND_PDF]: ['listen']
    }
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: false,
    cssVars
};

export default descriptor;
