import panels from './panels';
import { cssVars } from './css-vars';

export const Events = Object.freeze({
    UPDATE: 'update'
});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({
    TASK_ID: 'task Id',
    EMPLOYEE_ID: 'employee id'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Array,
            default: () => []
        },
        rostalentApiUrl: {
            type: String,
            default: 'https://goodt-dev.goodt.me:8486',
            hasConst: true
        },
        taskSettingsApiUrl: {
            type: String,
            default: 'https://goodt-dev.goodt.me:8487',
            hasConst: true
        },
        format: {
            type: String,
            default: '1||/d'
        },
        modeApi: {
            type: Boolean,
            default: false
        },
        mergeDatasets: {
            type: Boolean,
            default: false
        },
        competenceCatalogIds: {
            type: String,
            default: '1.0, 2.0, 3.0'
        },
        taskTypeFieldId: {
            type: Number,
            default: 225
        },
        events: {
            type: Object,
            default: () => ({
                [Events.UPDATE]: 'update'
            })
        },
        hoverLine: {
            type: Object,
            default: () => ({
                show: true,
                stroke: '#999999',
                strokeWidth: '1px'
            })
        },
        dremioSettings: {
            type: Array
        },
        diagramSettings: {
            type: Object,
            default: () => ({
                width: 760,
                height: 640,
                centerX: 370,
                centerY: 300,
                radius: 48,
                circleRadius: 6,
                multiplierCircleRadius: 2,
                dropShadow: '0px 0px 1px #00000029',
                circleStroke: '#999999',
                circleFill: '#ffffff',
                circleStrokeWidth: '1px'
            })
        },
        segmentValues: {
            type: Object,
            default: () => ({
                fontFamily: 'Roboto',
                fontSize: '0.75rem',
                fontWeight: '500',
                offsetX: 0,
                offsetY: 0,
                styles: []
            })
        },
        segmentTitles: {
            type: Object,
            default: () => ({
                width: 24,
                fontFamily: 'Roboto',
                fontSize: '0.75rem',
                fontWeight: '500',
                dyTSpan: 16,
                fill: '#666666',
                titleOffset: 1.5,
                offsetX: 0,
                offsetY: 0,
                styles: []
            })
        },
        segmentLineSettings: {
            type: Object,
            default: () => ({
                strokeWidth: '1px',
                stroke: '#666666',
                strokeDashWidth: 4,
                strokeSpaceWidth: 4
            })
        },
        tooltipSettings: {
            type: Object,
            default: () => ({
                show: false,
                borderRadius: '4px',
                offsetY: 0,
                styles: []
            })
        },
        metrics: {
            type: Array,
            default: () => []
        },
        numberOfLaps: {
            type: Number,
            default: 5
        },
        showSegmentsByMetrics: {
            type: Boolean,
            default: false
        },
        tooltipMetric: {
            type: Object,
            default: () => ({
                factMetric: null,
                planMetric: null
            }),
            label: {
                'tooltipMetric.factMetric': 'Фактическое значение тултипа',
                'tooltipMetric.planMetric': 'Плановое значение тултипа'
            }
        }
    },
    events: {
        [Events.UPDATE]: {
            listen: `events['${Events.UPDATE}']`
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    cssVars
};

export default descriptor;
