export const resolveCoordinatesForSegmentLines = (sector, circlesLength, circleRadius, centerX, centerY) => {
    const angle = Math.PI * 2 * sector;
    const radius = circleRadius * circlesLength;
    const xCoordinate = Math.sin(angle) * radius + centerX;
    const yCoordinate = -Math.cos(angle) * radius + centerY;
    return { xCoordinate2: xCoordinate, yCoordinate2: yCoordinate };
};

export const resolveCoordinatesForSegmentTitles = (
    sector,
    circlesLength,
    circleRadius,
    centerX,
    centerY,
    titleOffset
) => {
    const angle = Math.PI * 2 * sector;
    const radius = circleRadius * (circlesLength + titleOffset);
    const xCoordinate = Math.sin(angle) * radius + centerX;
    const yCoordinate = -Math.cos(angle) * radius + centerY;
    return { xCoordinate, yCoordinate };
};

export const resolveCoordinatesForSegmentValues = (sector, circleRadius, centerX, centerY) => {
    const angle = Math.PI * 2 * sector;
    const radius = circleRadius / 2;
    const xCoordinate = Math.sin(angle) * radius + centerX;
    const yCoordinate = -Math.cos(angle) * radius + centerY;
    return { xCoordinate, yCoordinate };
};

export const resolveCoordinatesForCircles = (sector, circleRadius, centerX, centerY) => {
    const angle = Math.PI * 2 * sector;
    const xCoordinate = Math.sin(angle) * circleRadius + centerX;
    const yCoordinate = -Math.cos(angle) * circleRadius + centerY;
    return { x: xCoordinate, y: yCoordinate };
};

export const resolveCoordinatesForLineByCircles = (sector, circleRadius, centerX, centerY) => {
    const angle = Math.PI * 2 * sector;
    const xCoordinate = Math.sin(angle) * circleRadius + centerX;
    const yCoordinate = -Math.cos(angle) * circleRadius + centerY;
    return { x: xCoordinate, y: yCoordinate };
};

export const resolveTextAnchorForTitle = (i, segments) => {
    const value = i / segments;
    const middleIndex = Math.ceil(segments / 2);
    if (middleIndex === i) {
        return 'middle';
    }

    return value > 0.5 ? 'end' : 'start';
};

export const hexToRgb = (hex, a) => {
    const result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
    const rColor = parseInt(result[1], 16);
    const gColor = parseInt(result[2], 16);
    const bColor = parseInt(result[3], 16);

    return result
        ? `rgb(
        ${(1 - a) * 255 + a * rColor},
        ${(1 - a) * 255 + a * gColor},
        ${(1 - a) * 255 + a * bColor}`
        : null;
};
