import {
    DEFAULT_HEIGHT_WORKER_IMG,
    DEFAULT_ROW_COUNT_IN_PAGINATION,
    DEFAULT_TABLE_ROW_HEIGHT,
    DEFAULT_WIDTH_WORKER_IMG,
    DEFAULT_WIDTH_WORKER_RENDER
} from './utils/constants';

export const WeekNames = ['Пн', 'Вт', 'Ср', 'Чт', 'Пт', 'Сб', 'Вс'];
export const MonthShortNames = ['Янв', 'Фев', 'Мар', 'Апр', 'Май', 'Июн', 'Июл', 'Авг', 'Сен', 'Окт', 'Ноя', 'Дек'];
export const MonthFullNames = [
    'Январь',
    'Февраль',
    'Март',
    'Апрель',
    'Май',
    'Июнь',
    'Июль',
    'Август',
    'Сентябрь',
    'Октябрь',
    'Ноябрь',
    'Декабрь'
];
export const FilterFormatNames = {
    WEEK_MONTH_YEAR: 'weekMonthYear',
    WEEK: 'week',
    MONTH: 'month',
    YEAR: 'year'
};
export const GlobalFilters = [
    {
        name: 'Неделя',
        type: FilterFormatNames.WEEK
    },
    {
        name: 'Месяц',
        type: FilterFormatNames.MONTH
    },
    {
        name: 'Год',
        type: FilterFormatNames.YEAR
    }
];

export const TemplateNames = {
    TIME_RENDER: 'TIME_RENDER',
    DOUBLE_VALUE_WITH_ICON_RENDER: 'DOUBLE_VALUE_WITH_ICON_RENDER'
};

export const FiltersStylesOptions = {
    titleSlotStyles: [],
    filtersSlotStyles: [],
    additionalFiltersSlotStyles: []
};

/**
 *
 * @type {{WORKDAY: string, SHORTDAY: string, WEEKEND: string, WEEKDAY: string}}
 * 0 - Рабочий день
 * 1 - Нерабочий день
 * 2 - Сокращённый рабочий день
 * 4 - Рабочий день
 */
export const DayType = {
    WEEKDAY: '0',
    WEEKEND: '1',
    SHORTDAY: '2',
    WORKDAY: '4'
};

export const ShowCurrentDateSettings = {
    enabled: false,
    showDate: true
};

export const CurrentDateStyle = {
    color: '#C8102E'
};

export const SearchIcon = {
    fontSize: '16',
    fontSizeUnit: 'px',
    top: '5.5px',
    color: '#000000'
};

export const TableStyle = {
    height: DEFAULT_TABLE_ROW_HEIGHT,
    widthWorker: DEFAULT_WIDTH_WORKER_RENDER
};

export const SearchStyle = {
    color: '#333333',
    backgroundColor: '#F4F4F9',
    fontSize: '14',
    fontSizeUnit: 'px',
    placeholder: 'Поиск работника',
    colorPlaceholder: '#1f1f1f'
};

export const TooltipStyle = {
    color: 'rgb(255, 255, 255)',
    backgroundColor: 'rgba(50, 50, 50, 0.7)',
    fontSize: '14',
    fontSizeUnit: 'px'
};

export const HeadStyle = {
    color: 'rgba(0, 0, 0, 0.4)',
    fontSize: '14',
    fontSizeUnit: 'px',
    fontFamily: 'Roboto'
};

export const MetricsId = {
    metrics: 'employee_id'
};

export const ImageSettings = {
    metrics: 'ajnj',
    width: DEFAULT_WIDTH_WORKER_IMG,
    height: DEFAULT_HEIGHT_WORKER_IMG
};

export const NameSettings = {
    metrics: 'person_name',
    fontSize: '16',
    fontSizeUnit: 'px',
    fontFamily: 'Roboto',
    color: '#333333'
};

export const JobSettings = {
    metrics: 'job_title_short_name',
    fontSize: '14',
    fontSizeUnit: 'px',
    fontFamily: 'Roboto',
    color: '#00000099'
};

export const DateSettings = {
    metricsForGlobalFormat: 'date_from',
    metricsStart: 'date_from',
    metricsEnd: 'date_to',
    additionalMetricsStart: null,
    additionalMetricsEnd: null,
    fontSize: '16',
    fontSizeUnit: 'px',
    fontFamily: 'Roboto',
    color: '#009688'
};

export const IconSettings = {
    metrics: null,
    fontSize: '20',
    fontSizeUnit: 'px',
    color: '#ffffff'
};

export const Pagination = {
    show: false,
    useDefault: false,
    showArrows: false,
    rowCount: DEFAULT_ROW_COUNT_IN_PAGINATION,
    fontSize: '14',
    fontFamily: 'Roboto',
    color: '#C8102E',
    activeColor: '#FFFFFF',
    background: '#FFFFFF',
    activeBackground: '#C8102E',
    borderColor: '#C8102E'
};

export const FilterStyle = {
    fontWeight: '600',
    boxShadow: '0 0.0625rem 0.25rem #00000029',
    fontSize: '0.75rem',
    color: 'rgba(0, 0, 0, 0.6)',
    colorActive: 'rgba(0, 0, 0, 1)'
};

export const DefaultValueSettings = {
    enabled: false,
    format: null,
    week: null,
    month: new Date().getMonth(),
    year: new Date().getFullYear(),
    isCurrentDate: false
};

export const PopupSettings = {
    usePopup: false,
    taskId: null,
    employeeId: null,
    courseName: null,
    title: null,
    icon: null,
    color: null,
    status: null,
    colorFactStatus: null,
    dateFrom: null,
    dateTo: null,
    submitStatusId: null,
    cancelStatusId: null,
    submitButtonText: 'Согласовать',
    cancelButtonText: 'Отклонить',
    classroom: null,
    time: null,
    type: null
};

export const TooltipSettings = {
    isEnabled: false,
    metric: null
};

export const ProductionCalendarSettings = {
    isEnabled: false,
    weekendColor: 'rgba(0,0,0,.1)',
    shortdayColor: '#d4e0eb'
};

export const AdditionalBarSettings = {
    isEnabled: false,
    shouldUseColorFromStatus: false,
    periodYearColor: '#99D5CF',
    periodMonthColor: '#FFD699',
    periodWeekColor: '#ffa299',
    heightPeriod: '80',
    verticalAlign: 'center'
};

export const CounterSettings = {
    isEnabled: false,
    color: '#000',
    fontFamily: '',
    fontSize: '14px',
    fontWeight: '500',
    marginRight: '4px',
    prefix: {
        text: '',
        color: '#000',
        fontFamily: '',
        fontWeight: '500',
        fontSize: '14px',
        marginRight: '4px',
        icon: '',
        iconColor: '#000'
    },
    postfix: {
        text: '',
        color: '#000',
        fontSize: '14px',
        fontFamily: '',
        fontWeight: '500',
        marginLeft: '4px'
    }
};
