import { cssVars } from './css-vars';
import {
    AdditionalBarSettings,
    CounterSettings,
    CurrentDateStyle,
    DateSettings,
    DefaultValueSettings,
    FiltersStylesOptions,
    FilterStyle,
    HeadStyle,
    IconSettings,
    ImageSettings,
    JobSettings,
    MetricsId,
    NameSettings,
    Pagination,
    PopupSettings,
    ProductionCalendarSettings,
    SearchIcon,
    SearchStyle,
    ShowCurrentDateSettings,
    TableStyle,
    TooltipSettings,
    TooltipStyle
} from './config';

export const Vars = Object.freeze({
    CURRENT_FILTER_SETTINGS: 'current filter settings',
    TRIGGERED_YEAR_METRIC: 'triggered year metric',
    TRIGGERED_MONTH_METRIC: 'triggered month metric',
    CONFLICT_DATE: 'conflict date',
    CONFLICT_ROW_IDS: 'conflict row ids',
    CONFLICT_MONTH: 'conflict month'
});

export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        orgStructureApiUrl: {
            type: String,
            default: 'https://goodt-dev.goodt.me:8480',
            hasConst: true
        },
        taskSettingsApiUrl: {
            type: String,
            default: 'https://goodt-dev.goodt.me:8487',
            hasConst: true
        },
        isDayOffApiUrl: {
            type: String,
            default: 'https://isdayoff.ru',
            hasConst: true
        },
        enableFilters: {
            type: Boolean,
            default: false
        },
        enableGlobalFilters: {
            type: Boolean,
            default: true
        },
        showCurrentDate: {
            type: Object,
            default: () => ShowCurrentDateSettings
        },
        currentDateStyle: {
            type: Object,
            default: () => CurrentDateStyle
        },
        searchIcon: {
            type: Object,
            default: () => SearchIcon
        },
        styleTable: {
            type: Object,
            default: () => TableStyle
        },
        styleSearch: {
            type: Object,
            default: () => SearchStyle
        },
        tooltipShow: {
            type: Boolean,
            default: true
        },
        tooltipStyle: {
            type: Object,
            default: () => TooltipStyle
        },
        headStyle: {
            type: Object,
            default: () => HeadStyle
        },
        metricsId: {
            type: Object,
            default: () => MetricsId
        },
        metricsImg: {
            type: Object,
            default: () => ImageSettings
        },
        metricsName: {
            type: Object,
            default: () => NameSettings
        },
        metricsJob: {
            type: Object,
            default: () => JobSettings
        },
        metricsYear: {
            type: String,
            default: 'year'
        },
        metricsDate: {
            type: Object,
            default: () => DateSettings
        },
        metricsIcon: {
            type: Object,
            default: () => IconSettings
        },
        pagination: {
            type: Object,
            default: () => Pagination
        },
        additionalBarSettings: {
            type: Object,
            default: () => AdditionalBarSettings
        },
        format: {
            type: String,
            default: 'year'
        },
        periodYearColor: {
            type: String,
            default: '#99D5CF'
        },
        periodMonthColor: {
            type: String,
            default: '#FFD699'
        },
        showFullMonthNames: {
            type: Boolean,
            default: false
        },
        periodWeekColor: {
            type: String,
            default: '#ffa299'
        },
        heightPeriod: {
            type: String,
            default: '80'
        },
        periodVerticalOffset: {
            type: Number,
            default: 10
        },
        periodHorizontalOffset: {
            type: Number,
            default: 4
        },
        minWidthWidget: {
            type: String,
            default: '80rem'
        },
        rowBackgroundColorHover: {
            type: String,
            default: 'rgba(200, 245, 237, .35)'
        },
        triggerEvent: {
            type: String,
            default: ''
        },
        filterStyles: {
            type: Object,
            default: () => FilterStyle
        },
        defaultValue: {
            type: Object,
            default: () => DefaultValueSettings
        },
        popupUrl: {
            type: String,
            default: ''
        },
        popupCourseUrl: {
            type: String,
            default: ''
        },
        popupMetrics: {
            type: Object,
            default: () => PopupSettings
        },
        useColorsFromStatus: {
            type: Boolean,
            default: true
        },
        conflictPopupUrl: {
            type: String,
            default: ''
        },
        filtersStyles: {
            type: Object,
            default: () => FiltersStylesOptions
        },
        showSolidLine: {
            type: Boolean,
            default: false
        },
        shouldHideConflicts: {
            type: Boolean,
            default: false
        },
        shouldPinTableRow: {
            type: Boolean,
            default: false
        },
        tooltip: {
            type: Object,
            default: () => TooltipSettings
        },
        productionCalendarSettings: {
            type: Object,
            default: () => ProductionCalendarSettings
        },
        shouldFilterRowsByDates: {
            type: Boolean,
            default: false
        },
        counter: {
            type: Object,
            default: () => CounterSettings
        },
        shouldShowValueByFilter: {
            type: Boolean,
            default: false
        },
        conflictMetric: {
            type: String,
            default: null
        },
        shouldShowAllChildInRow: {
            type: Boolean,
            default: false
        },
        isMainBarOnFront: {
            type: Boolean,
            default: false
        },
        isShowPopupFooterBtn: {
            type: Boolean,
            default: false
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    cssVars,
    slotNames: ['table', 'title', 'filters', 'default'],
    isChildAllowed: true
};
