import {
    getAllDaysUpToMonth,
    getNumberDayInWeek,
    getVacationDays,
    getWeekNumber,
    isCurrentDay
} from '../utils/date-utils';
import { HOUR, MICROTIME_MINUTE, WEEK } from '../utils/constants';
import { resolveBackgroundColor } from '../utils/utils';

export const receiveTimeInfo = ({ start, end }) => {
    const startVacation = new Date(start);
    const endVacation = new Date(end);
    const startVacationYear = startVacation.getFullYear();
    const startVacationMonth = startVacation.getMonth();
    const startVacationWeek = getWeekNumber(start);
    const endVacationDate = endVacation.getDate();
    const startVacationDate = startVacation.getDate();
    const endVacationYear = endVacation.getFullYear();
    const endVacationMonth = endVacation.getMonth();
    const endVacationWeek = getWeekNumber(end);
    return {
        startVacation,
        endVacation,
        startVacationYear,
        startVacationMonth,
        startVacationWeek,
        startVacationDate,
        endVacationYear,
        endVacationMonth,
        endVacationWeek,
        endVacationDate
    };
};

export const calcVacationDays = ({ workers, dateMetrics }) =>
    workers.reduce((acc, worker) => acc + getVacationDays({ worker, dateMetrics }), 0);

export const resolveWeekTimeline = ({
    year,
    week,
    startVacationYear,
    endVacationYear,
    width,
    periodHorizontalOffset,
    defaultValues,
    startVacationWeek,
    endVacationWeek,
    startWeekDayOfYear,
    endWeekDayOfYear,
    startVacationDayOfYear,
    endVacationDayOfYear
}) => {
    const cellWidth = width / WEEK;

    // --|*|--
    if (year > startVacationYear && year < endVacationYear) {
        return {
            ...defaultValues,
            width: `${width - 2 * periodHorizontalOffset}px`,
            left: `${periodHorizontalOffset}px`
        };
    }

    if (year === startVacationYear && year === endVacationYear) {
        // --|*|--
        if (startVacationWeek < week && endVacationWeek > week) {
            return {
                ...defaultValues,
                width: `${width - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }

        // *|--|--
        if (startVacationWeek === week && week < endVacationWeek) {
            return {
                ...defaultValues,
                width: `${(endWeekDayOfYear - startVacationDayOfYear + 1) * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${(startVacationDayOfYear - startWeekDayOfYear) * cellWidth + periodHorizontalOffset}px`
            };
        }

        // --|--|*
        if (startVacationWeek < week && week === endVacationWeek) {
            return {
                ...defaultValues,
                width: `${(endVacationDayOfYear - startWeekDayOfYear + 1) * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }

        // |-*-|
        if (startVacationWeek === endVacationWeek && startVacationWeek === week) {
            return {
                ...defaultValues,
                width: `${
                    (endVacationDayOfYear - startVacationDayOfYear + 1) * cellWidth - 2 * periodHorizontalOffset
                }px`,
                left: `${(startVacationDayOfYear - startWeekDayOfYear) * cellWidth + periodHorizontalOffset}px`
            };
        }
    }

    // *|--|--
    if (year === startVacationYear && year < endVacationYear) {
        // *|--
        if (startVacationWeek === week) {
            if (endWeekDayOfYear < startWeekDayOfYear) {
                return {
                    ...defaultValues,
                    width: `${
                        (WEEK - getNumberDayInWeek({ year, day: startVacationDayOfYear }) + 1) * cellWidth -
                        2 * periodHorizontalOffset
                    }px`,
                    left: `${(startVacationDayOfYear - startWeekDayOfYear) * cellWidth + periodHorizontalOffset}px`
                };
            }
            return {
                ...defaultValues,
                width: `${(endWeekDayOfYear - startWeekDayOfYear - 1) * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${(startVacationDayOfYear - startWeekDayOfYear) * cellWidth + periodHorizontalOffset}px`
            };
        }
        // --|*
        if (startVacationWeek < week) {
            return {
                ...defaultValues,
                width: `${width - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }
    }
    // --|--|*
    if (year > startVacationYear && year === endVacationYear) {
        // --|*
        if (week === endVacationWeek) {
            return {
                ...defaultValues,
                width: `${(endVacationDayOfYear - startWeekDayOfYear + 1) * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }

        // *|--
        if (endVacationWeek > week) {
            return {
                ...defaultValues,
                width: `${width - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }
    }

    return null;
};

export const resolveMonthTimeline = ({
    year,
    month,
    width,
    dayMonth,
    startVacationDate,
    startVacationMonth,
    endVacationDate,
    endVacationMonth,
    startVacationYear,
    endVacationYear,
    periodHorizontalOffset,
    defaultValues
}) => {
    const cellWidth = width / dayMonth;
    const left = (startVacationDate - 1) * cellWidth;

    if (year > startVacationYear && year < endVacationYear) {
        // --|*|--
        return {
            ...defaultValues,
            width: `${width - 2 * periodHorizontalOffset}px`,
            left: `${periodHorizontalOffset}px`
        };
    }

    if (year === startVacationYear && year === endVacationYear) {
        // --|*|--
        if (startVacationMonth < month && endVacationMonth > month) {
            return {
                ...defaultValues,
                width: `${width - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }
        // -*|--|--
        if (startVacationMonth === month && month < endVacationMonth) {
            return {
                ...defaultValues,
                width: `${(dayMonth - startVacationDate + 1) * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${left + periodHorizontalOffset}px`
            };
        }

        // --|--|*
        if (startVacationMonth < month && month === endVacationMonth) {
            return {
                ...defaultValues,
                width: `${endVacationDate * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }

        // |-*-|
        if (startVacationMonth === endVacationMonth && startVacationMonth === month) {
            return {
                ...defaultValues,
                width: `${(endVacationDate - startVacationDate + 1) * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${(startVacationDate - 1) * cellWidth + periodHorizontalOffset}px`
            };
        }
    }

    // *|--|--
    if (year === startVacationYear && year < endVacationYear) {
        // *|--
        if (startVacationMonth === month) {
            return {
                ...defaultValues,
                width: `${(dayMonth - startVacationDate + 1) * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${(startVacationDate - 1) * cellWidth + periodHorizontalOffset}px`
            };
        }
        // --|*
        if (startVacationMonth < month) {
            return {
                ...defaultValues,
                width: `${width - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }
    }

    // --|--|*
    if (year > startVacationYear && year === endVacationYear) {
        // --|*
        if (month === endVacationMonth) {
            return {
                ...defaultValues,
                width: `${endVacationDate * cellWidth - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }

        // *|--
        if (endVacationMonth > month) {
            return {
                ...defaultValues,
                width: `${width - 2 * periodHorizontalOffset}px`,
                left: `${periodHorizontalOffset}px`
            };
        }
    }

    return null;
};

export const resolveYearTimeline = ({
    year,
    startVacationYear,
    endVacationYear,
    startVacation,
    endVacation,
    defaultValues,
    width,
    yearDays
}) => {
    const cellWidth = width / yearDays;

    if (startVacationYear === endVacationYear && startVacationYear === year) {
        const timeDiff = Math.abs(endVacation.getTime() - startVacation.getTime());
        const diffDays = Math.ceil(timeDiff === 0 ? 1 : timeDiff / (1000 * MICROTIME_MINUTE * HOUR));
        const offsetDays = getAllDaysUpToMonth({ date: startVacation, year }) - 1;
        return {
            ...defaultValues,
            width: `${diffDays * cellWidth}px`,
            left: `${offsetDays * cellWidth}px`
        };
    }

    if (year > startVacationYear && year < endVacationYear) {
        return {
            ...defaultValues,
            width: `${width}px`,
            left: 0
        };
    }

    if (year === startVacationYear) {
        const offsetDays = getAllDaysUpToMonth({ date: startVacation, year });
        if (year < endVacationYear) {
            return {
                ...defaultValues,
                width: `${(yearDays - offsetDays) * cellWidth}px`,
                left: `${offsetDays * cellWidth}px`
            };
        }

        if (year === endVacationYear) {
            const endDays = getAllDaysUpToMonth({ date: endVacation, year });
            return {
                ...defaultValues,
                width: `${(offsetDays - (yearDays - endDays)) * cellWidth}px`,
                left: `${offsetDays * cellWidth}px`
            };
        }
    }

    if (year > startVacationYear && year === endVacationYear) {
        const offsetDays = getAllDaysUpToMonth({ date: endVacation, year });
        return {
            ...defaultValues,
            width: `${offsetDays * cellWidth}px`,
            left: `${0}px`
        };
    }

    return null;
};

export const resolveColumnStyle = ({
    isMonthFormat,
    isWeekFormat,
    defaultStyles,
    day,
    productionCalendarIndexes,
    productionCalendarSettings,
    filterSettings,
    shouldShowCurrentDate,
    showSolidLine,
    color
}) => {
    if (isMonthFormat) {
        if (
            isCurrentDay({ day, filterSettings, isMonthFormat, isWeekFormat }) &&
            shouldShowCurrentDate &&
            showSolidLine
        ) {
            return {
                ...defaultStyles,
                background: color
            };
        }

        if (productionCalendarIndexes.length === 0) {
            return defaultStyles;
        }

        return {
            ...defaultStyles,
            background: resolveBackgroundColor({
                dayType: productionCalendarIndexes[day - 1],
                settings: productionCalendarSettings
            })
        };
    }
    if (isWeekFormat) {
        if (
            isCurrentDay({ day: day - 1, filterSettings, isMonthFormat, isWeekFormat }) &&
            shouldShowCurrentDate &&
            showSolidLine
        ) {
            return {
                ...defaultStyles,
                background: color
            };
        }

        if (productionCalendarIndexes.length === 0) {
            return defaultStyles;
        }

        return {
            ...defaultStyles,
            background: resolveBackgroundColor({
                dayType: productionCalendarIndexes[day - 1],
                settings: productionCalendarSettings
            })
        };
    }

    return defaultStyles;
};

export const resolveHeadColumnStyle = ({
    isMonthFormat,
    isWeekFormat,
    defaultStyles,
    day,
    productionCalendarIndexes,
    productionCalendarSettings,
    filterSettings,
    shouldShowCurrentDate,
    showSolidLine,
    color
}) => {
    if (isMonthFormat) {
        if (
            isCurrentDay({ day: day + 1, isMonthFormat, isWeekFormat, filterSettings }) &&
            shouldShowCurrentDate &&
            showSolidLine
        ) {
            return {
                ...defaultStyles,
                background: color
            };
        }

        if (productionCalendarIndexes.length === 0) {
            return defaultStyles;
        }

        return {
            ...defaultStyles,
            background: resolveBackgroundColor({
                dayType: productionCalendarIndexes[day],
                settings: productionCalendarSettings
            })
        };
    }

    if (isWeekFormat) {
        if (
            isCurrentDay({ day, filterSettings, isMonthFormat, isWeekFormat }) &&
            shouldShowCurrentDate &&
            showSolidLine
        ) {
            return {
                ...defaultStyles,
                background: color
            };
        }

        if (productionCalendarIndexes.length === 0) {
            return defaultStyles;
        }

        return {
            ...defaultStyles,
            background: resolveBackgroundColor({
                dayType: productionCalendarIndexes[day],
                settings: productionCalendarSettings
            })
        };
    }

    return defaultStyles;
};
