import uniq from 'lodash/uniq';
import { DayType, FilterFormatNames } from '../config';

export const buildCssStyles = (styles) =>
    styles.reduce((acc, style) => {
        const [key, value] = style.split(':');
        return { ...acc, [key]: value };
    }, {});

export const resolveBackgroundColor = ({ dayType, settings }) => {
    const { weekendColor, shortdayColor, isEnabled } = settings;
    if (!isEnabled) {
        return 'transparent';
    }

    if (dayType === DayType.SHORTDAY) {
        return shortdayColor;
    }

    if (dayType === DayType.WEEKEND) {
        return weekendColor;
    }

    return 'transparent';
};

const convertDate = (date) => date?.split('.').reverse().join('-');

export const resolveDateMetricsByRender = ({ rows, useDoubleValuesWithIconRender, metricsDate, format }) => {
    const { metricsStart, metricsEnd, metricsForGlobalFormat, additionalMetricsStart, additionalMetricsEnd } =
        metricsDate;
    return rows.map((item) => {
        const dateMetrics =
            format === FilterFormatNames.WEEK_MONTH_YEAR && useDoubleValuesWithIconRender
                ? {
                      [metricsForGlobalFormat]: convertDate(item[metricsForGlobalFormat])
                  }
                : {
                      [metricsStart]: convertDate(item[metricsStart]),
                      [metricsEnd]: convertDate(item[metricsEnd]),
                      [additionalMetricsStart]: convertDate(item[additionalMetricsStart]),
                      [additionalMetricsEnd]: convertDate(item[additionalMetricsEnd])
                  };

        return {
            ...item,
            ...dateMetrics
        };
    });
};

export const buildTableRows = ({
    useDefaultPagination = false,
    rows,
    metricId,
    shouldPinTableRow,
    useDoubleValuesWithIconRender,
    metricsDate,
    format
}) => {
    const rowsIds = useDefaultPagination ? rows.map((row) => row[metricId]) : uniq(rows.map((row) => row[metricId]));
    const settings = { format, metricsDate, useDoubleValuesWithIconRender };
    return shouldPinTableRow
        ? [
              resolveDateMetricsByRender({
                  rows: rows.filter((row) => row[metricId] === null),
                  ...settings
              }),

              ...rowsIds
                  .filter((rowId) => rowId !== null)
                  .map((rowId) =>
                      resolveDateMetricsByRender({
                          rows: rows.filter((row) => row[metricId] === rowId),
                          ...settings
                      })
                  )
          ]
        : rowsIds.map((rowId) =>
              resolveDateMetricsByRender({
                  rows: rows.filter((row) => row[metricId] === rowId),
                  ...settings
              })
          );
};

export const buildCurrentDayStyle = ({ width, currentDay, cellWidth, showSolidLine }) => ({
    right: `${width - currentDay * cellWidth}px`,
    borderRightWidth: showSolidLine ? `${cellWidth}px` : '1px',
    borderRightStyle: showSolidLine ? 'solid' : 'dashed',
    opacity: 1
});

export const extractStyle = (metric) => {
    const { metrics, metricsStart, metricsEnd, fontSizeUnit, ...style } = metric;
    return style;
};
