/* eslint-disable no-magic-numbers */
/* eslint-disable no-restricted-syntax */
import panels from './panels';
import { buildCssVarValue } from './utils';
import { DIRECTION_ROW, LEFT_TO_RIGHT } from './constants';
/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        dimension: {
            type: String,
            default: ''
        },
        dimensionFontFamily: {
            type: String,
            default: 'Roboto, Sans Serif'
        },
        dimensionFontSize: {
            type: String,
            default: '16px'
        },
        buttonFontSize: {
            type: String,
            default: '22px'
        },
        buttonFontSizeUnit: {
            type: String,
            default: 'px'
        },
        buttonActiveAreaFontSize: {
            type: String,
            default: ''
        },
        buttonBackgroundColor: {
            type: String,
            default: ''
        },
        dimensionFontSizeUnit: {
            type: String,
            default: 'px'
        },
        dimensionColor: {
            type: String,
            default: '#000000'
        },
        dimensionMargin: {
            type: String,
            default: '20px'
        },
        dimensionMarginVertical: {
            type: String,
            default: '0px'
        },
        type: {
            type: String,
            default: 'checkbox'
        },
        activeButtonColor: {
            type: String,
            default: '#ff6a6a'
        },
        dimensionTextColor: {
            type: String,
            default: ''
        },
        notActiveButtonColor: {
            type: String,
            default: '#808080'
        },
        title: {
            type: String,
            default: ''
        },
        all: {
            type: Boolean,
            default: false
        },
        valueByDefault: {
            type: String,
            default: ''
        },
        direction: {
            type: String,
            default: DIRECTION_ROW
        },
        iconSettings: {
            type: Object,
            default: () => ({
                icon: '',
                fontSize: '10px',
                color: '#ffffff'
            })
        },
        buttonPossition: {
            type: String,
            default: LEFT_TO_RIGHT
        },
        isVariableWritenAsArray: {
            type: Boolean,
            default: false
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    cssVars: {
        'dimension-margin': (props) => buildCssVarValue(props.dimensionMargin, 'px'),
        'dimension-margin-vertical': 'dimensionMarginVertical',
        'dimension-font-family': 'dimensionFontFamily',
        'dimension-color': 'dimensionColor',
        'dimension-font-size': (props) => `${props.dimensionFontSize}${props.dimensionFontSizeUnit}`,
        'not-active-button-color': 'notActiveButtonColor',
        'button-font-size': (props) => `${props.buttonFontSize}${props.buttonFontSizeUnit}`,
        'active-button-color': 'activeButtonColor',
        'icon-font-size': (props) => props.iconSettings.fontSize,
        'icon-color': (props) => props.iconSettings.color,
        'text-color-active': (props) =>
            props.dimensionTextColor.length > 0 ? props.dimensionTextColor : props.activeButtonColor,
        'button-active-area-font-size': 'buttonActiveAreaFontSize',
        'button-background-color': 'buttonBackgroundColor'
    }
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: false
};

export default descriptor;
