import panels from './panels';
import { cssVars } from './css-vars';
import { DefaultBlockSettings, HeaderSettings, IconSettings, LegendSettings, ProgressBarSettings } from './config';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

export const Events = Object.freeze({
    UPDATE_WIDGET: 'updateWidget'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        height: {
            type: String,
            default: '100'
        },
        heightUnit: {
            type: String,
            default: '%'
        },
        dremio: {
            type: Object,
            default: null
        },
        header: {
            type: Object,
            default: () => HeaderSettings
        },
        rowLengthChecked: {
            type: Boolean,
            default: false
        },
        rowLengthSize: {
            type: Number,
            default: null
        },
        mainWayDimension: {
            type: String
        },
        mainWayMetric: {
            type: String
        },
        mainWayPaintingCondition: {
            type: Array,
            default: () => []
        },
        secondWay: {
            type: Boolean,
            default: false
        },
        secondWayChecked: {
            type: Boolean,
            default: false
        },
        secondWayStep: {
            type: String
        },
        metricPlanName: {
            type: String
        },
        metricPlanColor: {
            type: String
        },
        metricRealName: {
            type: String
        },
        metricRealColor: {
            type: String
        },
        iconSettings: {
            type: Object,
            default: () => IconSettings
        },
        defaultBlock: {
            type: Object,
            default: () => DefaultBlockSettings
        },
        metricPercent: {
            type: Boolean,
            default: false
        },
        legend: {
            type: Boolean,
            default: () => LegendSettings
        },
        progressBar: {
            type: Object,
            default: () => ProgressBarSettings
        },
        events: {
            type: Object,
            default: () => ({
                [Events.UPDATE_WIDGET]: ''
            })
        }
    },
    events: {
        [Events.UPDATE_WIDGET]: ['listen']
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    cssVars,
    slotNames: [],
    isChildAllowed: false
};
