/* eslint-disable no-restricted-syntax */
import {
    DEFAULT_OPTIMIZATION_SIZE,
    DEFAULT_SIZE_POINT,
    DEFAULT_CONTROL_SCALE,
    DEFAULT_FILL_OPACITY,
    MAX_SIZE_POINT,
    GRADIENT_SMOOTH_DEFAULT,
    DEFAULT_REGION_MESSAGE,
    DEFAULT_MO_MESSAGE
} from './utils/constants';
import { cssVars } from './css-vars';
import panels from './panels';

export const Vars = {
    MOVING: 'перемещение',
    SCALING: 'масштабирование'
};

const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default() {
                return null;
            }
        },
        additionalDremio: {
            type: Array,
            default: () => null
        },
        dimensionAdditionalOptions: {
            type: Object,
            default() {
                return {};
            }
        },
        minWidth: {
            type: String,
            default: '600px'
        },
        minHeight: {
            type: String,
            default: '400px'
        },
        pointHover: {
            type: Object,
            default: () => ({
                active: false,
                hovered: {
                    opacity: 1,
                    fillOpacity: 0.8
                },
                unHovered: {
                    opacity: 0.3,
                    fillOpacity: 0.1
                }
            })
        },
        iconAdditionalPoint: {
            type: String,
            default: ''
        },
        iconVariantMetric: {
            type: String,
            default: null
        },
        additionalIconVariants: {
            type: Array,
            default() {
                return [];
            }
        },
        widthAdditionalPoint: {
            type: Number,
            default: 40
        },
        heightAdditionalPoint: {
            type: Number,
            default: 40
        },
        metricNames: {
            type: Array,
            default: () => []
        },
        infoPanel: {
            type: Boolean,
            default: true
        },
        infoPanelTexts: {
            type: Object,
            default: () => ({
                firstLayer: DEFAULT_REGION_MESSAGE,
                secondLayer: DEFAULT_MO_MESSAGE
            })
        },
        hasShowPoint: {
            type: Boolean,
            default: true
        },
        isFiltrationMode: {
            type: Boolean,
            default: false
        },
        clusterFilterMetric: {
            type: String,
            default: null
        },
        showRegionRangeMin: {
            type: Number,
            default: 1
        },
        showRegionRangeMax: {
            type: Number,
            default: 3
        },
        controlScale: {
            type: Object,
            default() {
                return {
                    active: false,
                    maxWidth: DEFAULT_CONTROL_SCALE
                };
            }
        },
        defaultStyleInHover: {
            type: Object,
            default() {
                return {
                    weight: 1,
                    color: '#ff1f1f',
                    fillOpacity: DEFAULT_FILL_OPACITY,
                    fillColor: '#ff6868'
                };
            }
        },
        sizeWidthMap: {
            type: String,
            default: '100%'
        },
        sizeHeightMap: {
            type: String,
            default: '400px'
        },
        zoom: {
            type: Object,
            default: () => ({
                outputZoom: false,
                zoomMap: 7,
                minZoomMap: 2,
                maxZoomMap: 18,
                zoomFlightOfTheBumblebee: 7,
                zoomSnap: 1,
                zoomDelta: 1,
                wheelPxPerZoomLevel: 60,
                autoZoom: false
            })
        },
        animateDuration: {
            type: [String, Number],
            default: '10'
        },
        layerTile: {
            type: Boolean,
            default: true
        },
        layer: {
            type: String,
            default: 'https://tile.openstreetmap.org/{z}/{x}/{y}.png'
        },
        layerLabels: {
            type: String,
            default: null
        },
        metricsLan: {
            type: [String, Number],
            default: null
        },
        metricsLon: {
            type: [String, Number],
            default: null
        },
        clusters: {
            type: Object,
            default() {
                return {
                    active: true,
                    weight: 5,
                    color: '#b43',
                    opacity: 1,
                    fillColor: '#000',
                    fillOpacity: 0.2,
                    defaultBackground: 'rgba(0, 255, 35, 1)',
                    defaultColor: '#fff',
                    rules: [],
                    useRules: false
                };
            }
        },
        tooltip: {
            type: Object,
            default() {
                return {
                    viewMode: 'hover',
                    background: '#ffffff',
                    direction: 'left',
                    verticalPadding: '1rem',
                    horizontalPadding: '0.75rem',
                    triangleColor: 'rgba(0, 145, 255, 1)',
                    boxShadow: '0 1px 3px rgba(0, 0, 0, 0.4)',
                    metrics: [],
                    borderWidth: '1px'
                };
            }
        },
        panelTemplates: {
            type: Array,
            default() {
                return [
                    {
                        metricFilter: '',
                        layers: '',
                        metrics: [],
                        metricJSON: 'id',
                        fontSize: '14px',
                        color: 'black'
                    }
                ];
            }
        },
        metricsFlightOfTheBumblebee: {
            type: String,
            default: null
        },
        centerLongitude: {
            type: String,
            default: null
        },
        centerLatitude: {
            type: String,
            default: null
        },
        searchMetric: {
            type: [String, Number],
            default: null
        },
        rangeMetric: {
            type: [String],
            default: 0
        },
        sizePoint: {
            type: [String, Number],
            default: DEFAULT_SIZE_POINT
        },
        maxSizePoint: {
            type: Number,
            default: MAX_SIZE_POINT
        },
        rangeDefaultColor: {
            type: [String],
            default: '#ff0000'
        },
        optimizationSize: {
            type: [String, Number],
            default: DEFAULT_OPTIMIZATION_SIZE
        },
        popupUrl: {
            type: String
        },
        additionalLayers: {
            type: Array,
            default() {
                return [
                    {
                        active: false,
                        name: 'Границы регионов',
                        value: 'russian',
                        metricJSON: 'state_id_num',
                        hideLayerOnZoom: 0,
                        geoJsonFiles: [],
                        range: {
                            metricsFilter: null,
                            metricsValue: null,
                            styleTitle: {
                                fontSize: '1rem',
                                fontFamily: 'roboto',
                                textAlign: 'center',
                                marginBottom: '10px',
                                color: 'black'
                            },
                            format: '',
                            title: 'Границы МО регионов',
                            data: []
                        },
                        component: {
                            name: 'SettingsMOLayer',
                            options: {
                                activeLegend: false,
                                color: '#000000',
                                fillColor: '#BFBFBF',
                                opacity: 1,
                                fillOpacity: 1,
                                weight: 1
                            }
                        }
                    },
                    {
                        active: false,
                        name: 'МО регионов',
                        value: 'border_mo',
                        metricJSON: 'oktmo',
                        hideLayerOnZoom: 0,
                        geoJsonFiles: [],
                        range: {
                            metricsFilter: null,
                            metricsValue: null,
                            title: 'Цвета МО регионов',
                            styleTitle: {
                                fontSize: '1rem',
                                fontFamily: 'roboto',
                                textAlign: 'center',
                                marginBottom: '10px',
                                color: 'black'
                            },
                            format: '',
                            data: []
                        },
                        component: {
                            name: 'SettingsMOLayer',
                            options: {
                                activeLegend: false,
                                color: '#BFBFBF',
                                fillColor: '#000000',
                                opacity: 1,
                                fillOpacity: 1,
                                weight: 1
                            }
                        }
                    }
                    // ,{
                    //     active: false,
                    //     name: 'Фап',
                    //     value: 'fap',
                    //     hideLayerOnZoom: 0,
                    //     component: {
                    //         name: 'SettingsMarkerLayer',
                    //         options: {
                    //             radius: DEFAULT_RADIUS_MARKER,
                    //             img: {
                    //                 url: 'http://www.roteqturbo.com/wp-content/uploads/2016/10/Logomakr_5o4FdO-e1480175097659.png',
                    //                 size: [DEFAULT_SIZE_MARKER, DEFAULT_SIZE_MARKER],
                    //                 rotate: 0,
                    //                 offset: { x: 0, y: 0 }
                    //             }
                    //         }
                    //     }
                    // },
                    // {
                    //     active: false,
                    //     name: 'Точки больниц',
                    //     value: 'tbo',
                    //     hideLayerOnZoom: 0,
                    //     component: {
                    //         name: 'SettingsMarkerLayer',
                    //         options: {
                    //             radius: DEFAULT_RADIUS_MARKER,
                    //             img: {
                    //                 url: 'https://sch1194zg.mskobr.ru/files/1555/dopobraz/19-20/1unnamed.jpg',
                    //                 size: [DEFAULT_SIZE_MARKER, DEFAULT_SIZE_MARKER],
                    //                 rotate: 0,
                    //                 offset: { x: 0, y: 0 }
                    //             }
                    //         }
                    //     }
                    // },
                    // {
                    //     active: false,
                    //     name: 'Дороги',
                    //     value: 'road',
                    //     hideLayerOnZoom: 0,
                    //     component: {
                    //         name: 'SettingsRoadLayer',
                    //         options: {
                    //             color: '#000',
                    //             weight: 1
                    //         }
                    //     }
                    // }
                ];
            }
        },
        hasFilterPointsByRegion: {
            type: Boolean,
            default: false
        },
        openTooltipValue: {
            type: Boolean,
            default: false
        },
        openPopupValue: {
            type: Boolean,
            default: false
        },
        metricsSizeIcon: {
            type: [String, Number],
            default: 0
        },
        sizeIcon: {
            type: Array,
            default() {
                return [];
            }
        },
        range: {
            type: Array,
            default() {
                return [];
            }
        },
        iconMarker: {
            type: String,
            default: ''
        },
        gradient: {
            type: Object,
            default() {
                return {
                    gradientColorUse: false,
                    gradientColorMax: 'rgba(0, 255, 0, 1)',
                    gradientColorMin: 'rgba(255, 0, 0, 1)',
                    gradientSmoothing: GRADIENT_SMOOTH_DEFAULT,
                    gradientFormat: null
                };
            }
        },
        pointsDataset: {
            type: [String, Number],
            default: null
        },
        isVisibleControlHome: {
            type: Boolean,
            default: true
        }
    },
    vars: Object.values(Vars).reduce((acc, vvv) => {
        acc[vvv] = { description: vvv };
        return acc;
    }, {})
});

export const meta = {
    descriptor,
    cssVars,
    panels
};

export default descriptor;
