// немного магии для того чтобы убрать не нужные данные из файлов, избавляемся от лишнего веса файла
// заходим в папку с файлом, запускаем скрипт

const { writeFile, readdirSync, existsSync } = require('fs');
const path = require('path');

class Optimization {
    constructor(data, filename) {
        this.localDir = __dirname;
        // записываем оригинальные файлы
        this.optimiztionData = this.dataFiles(data);
        this.newFileName = filename;
    }

    dataFiles(data) {
        const { name, postfix, callback } = data;
        const folders = readdirSync(this.localDir, { withFileTypes: true })
            .filter((item) => item.isDirectory())
            .map((item) => item.name);

        const optimizationFilesArray = folders.reduce((acc, folder) => {
            const postfixFile = postfix ? `${postfix}${folder}` : '';
            const filePath = `./${folder}/${name}${postfixFile}.json`;

            if (existsSync(filePath)) {
                return [
                    {
                        // eslint-disable-next-line global-require,import/no-dynamic-require
                        data: require(`./${folder}/${name}${postfixFile}.json`),
                        dir: folder,
                        callback
                    },
                    ...acc
                ];
            }
            return acc;
        }, []);

        return optimizationFilesArray;
    }

    optimization() {
        this.optimiztionData.forEach((item) => {
            const { data, dir, callback } = item;
            const object = JSON.parse(JSON.stringify(data));
            const { features } = object;

            const newFeatures = features.map(callback);

            const optimizationData = {
                ...data,
                features: newFeatures
            };

            const localPath = path.join(this.localDir, dir);

            writeFile(`${localPath}/${this.newFileName}`, JSON.stringify(optimizationData), (err) => {
                if (err) {
                    throw err;
                }

                return 'Файл создан';
            });
        });
    }
}

const callback = (item) => {
    const saveKey = ['name', 'id', 'addr_regio'];
    const { properties } = item;
    const keys = Object.keys(properties);

    keys.forEach((key) => {
        if (!saveKey.includes(key)) {
            delete properties[key];
        }
    });

    return { ...item, properties };
};

new Optimization(
    {
        name: 'road',
        postfix: '_',
        callback
    },
    'road_optimization.json'
).optimization();
