export const mixinMathematicsAndMutation = {
    methods: {
        toRad(val) {
            return val * Math.PI / 180;
        },
        toDeg(val) {
            return val * (180 / Math.PI);
        },
        middlePoint(start, end) {
            let [lat1, lng1] = start
            let [lat2, lng2] = end

            let dLng = this.toRad(lng2 - lng1)

            lat1 = this.toRad(lat1)
            lat2 = this.toRad(lat2)
            lng1 = this.toRad(lng1)

            let bX = Math.cos(lat2) * Math.cos(dLng)
            let bY = Math.cos(lat2) * Math.sin(dLng)
            let lat3 = Math.atan2(
                Math.sin(lat1) + Math.sin(lat2),
                Math.sqrt((Math.cos(lat1) + bX) * (Math.cos(lat1) + bX) + bY * bY)
            )
            let lng3 = lng1 + Math.atan2(bY, Math.cos(lat1) + bX)

            return [this.toDeg(lat3), this.toDeg(lng3)]
        },
        formatMetric(value, format = 0, separator = 0) {

            if (!isNaN(parseFloat(value)) && isFinite(value)) {
                value = +value;

                let separators = [undefined, 'ru-RU', 'de-DE', 'en-EN'];

                let fixNum = (num, frDigits) => num.toFixed(frDigits);

                let formatNum = (num, localeSep, frDigits, style = 'decimal') =>
                    new Intl.NumberFormat(localeSep, {
                        style,
                        minimumFractionDigits: frDigits
                    }).format(num);

                let availableFormats = {
                    0: ({ value, sep }) => formatNum(fixNum(value, 0), sep, 0),
                    1: ({ value, sep }) => formatNum(fixNum(value, 1), sep, 1),
                    2: ({ value, sep }) => formatNum(fixNum(value, 2), sep, 2),
                    '0%': ({ value, sep }) => formatNum(value / 100, sep, 0, 'percent'),
                    '1%': ({ value, sep }) => formatNum(value / 100, sep, 1, 'percent'),
                    '2%': ({ value, sep }) => formatNum(value / 100, sep, 2, 'percent')
                };

                return availableFormats[format]({ value, sep: separators[separator] });
            }

            return value;
        },
        rgba2hex(orig) {
            let a, isPercent,
                rgb = orig.replace(/\s/g, '').match(/^rgba?\((\d+),(\d+),(\d+),?([^,\s)]+)?/i),
                alpha = (rgb && rgb[4] || "").trim(),
                hex = rgb ?
                    (rgb[1] | 1 << 8).toString(16).slice(1) +
                    (rgb[2] | 1 << 8).toString(16).slice(1) +
                    (rgb[3] | 1 << 8).toString(16).slice(1) : orig;
            if (alpha !== "") {
                a = alpha;
            } else {
                a = '01';
            }

            a = Math.round(a * 100) / 100;
            alpha = Math.round(a * 255);
            let hexAlpha = (alpha + 0x10000).toString(16).substr(-2).toUpperCase();
            hex = hex + hexAlpha;

            return hex;
        },
        arrowMidPointAndRotationHandler(datapoints, eachpoint) {
            const firstPoint = [...datapoints[eachpoint]['polyline']['cord'][0]]
            const secondPoint = [...datapoints[eachpoint]['polyline']['cord'][1]]
            const slope = (secondPoint[1] - firstPoint[1]) / (secondPoint[0] - firstPoint[0])
            const angle = Math.atan(slope)
            let rotation

            secondPoint[0] = secondPoint[0] - firstPoint[0];
            secondPoint[1] = secondPoint[1] - firstPoint[1];

            if (secondPoint[0] > 0 && secondPoint[1] < 0) {
                rotation = angle * 180 / Math.PI / 2
            } else if (secondPoint[0] < 0 && secondPoint[1] > 0) {
                rotation = 180 + angle * 180 / Math.PI
            } else if (secondPoint[0] < 0 && secondPoint[1] < 0) {
                rotation = 180 + angle * 180 / Math.PI
            } else if (secondPoint[0] > 0 && secondPoint[1] > 0) {
                rotation = angle * 180 / Math.PI
            }

            const midPoint = this.middlePoint(
                [...datapoints[eachpoint]['polyline']['cord'][0]],
                [...datapoints[eachpoint]['polyline']['cord'][1]]
            );

            return {
                midPoint,  rotation
            }
        }
    }
}









// old
// dataAll.forEach(datapoints => {
//     const markersStart = new L.MarkerClusterGroup()
//     const markersEnd   = new L.MarkerClusterGroup()
//
//     for (let eachpoint in datapoints) {
//         let startMarker = null
//
//         if (this.props.developerMetrics.img == 'rhombus') {
//             startMarker = L.marker([datapoints[eachpoint]['start']["lat"], datapoints[eachpoint]['start']["lon"]],
//                 {
//                     icon: this.createRhombus(
//                         this.rgba2hex(datapoints[eachpoint]['start']["color"]),
//                         datapoints[eachpoint]['start']["width"]
//                     )
//                 })
//         } else {
//             startMarker = L.circle(
//                 [datapoints[eachpoint]['start']["lat"], datapoints[eachpoint]['start']["lon"]],
//                 {
//                     radius: datapoints[eachpoint]['start']["width"],
//                     opacity: 1,
//                     fillOpacity: 0.8,
//                     color: datapoints[eachpoint]['start']["color"]
//                 }
//             )
//         }
//
//         startMarker.on('click', this.markerHandler.bind(this, datapoints[eachpoint]['elem']))
//             .bindTooltip(datapoints[eachpoint]['start']["comments"], {
//                 direction: "top",
//                 className: "leaflet-tooltip-comments"
//             })
//
//         if (!this.recyclerId) {
//             if (this.props.clusters.active) {
//                 markersStart.addLayer(startMarker);
//             } else {
//                 startMarker.addTo(this.Map)
//             }
//         }
//
//         if (this.props.polygonMetrics.lan && this.props.polygonMetrics.lon) {
//             let endMarker = null
//
//             if (this.props.polygonMetrics.img == 'rhombus') {
//                 endMarker = L.marker([datapoints[eachpoint]['end']["lat"], datapoints[eachpoint]['end']["lon"]],
//                     {
//                         icon: this.createRhombus(
//                             this.rgba2hex(datapoints[eachpoint]['end']["color"]),
//                             datapoints[eachpoint]['end']["width"]
//                         )
//                     })
//             } else {
//                 endMarker = L.circle(
//                     [datapoints[eachpoint]['end']["lat"], datapoints[eachpoint]['end']["lon"]],
//                     {
//                         radius: datapoints[eachpoint]['end']["width"],
//                         opacity: 1,
//                         fillOpacity: 0.8,
//                         color: datapoints[eachpoint]['end']["color"]
//                     }
//                 )
//             }
//
//             endMarker.on('click', this.markerHandler.bind(this, datapoints[eachpoint]['elem']))
//                 .bindTooltip(datapoints[eachpoint]['end']["comments"], {
//                     direction: "top",
//                     className: "leaflet-tooltip-comments"
//                 })
//
//             if (this.props.polilyneArrow.active && !this.contractorId) {
//                 if (this.props.clusters.active) {
//                     markersEnd.addLayer(endMarker)
//                 } else {
//                     endMarker.addTo(this.Map)
//                 }
//             }
//
//             if (this.props.polilyneArrow.active) {
//                 const polyline = L.polyline(datapoints[eachpoint]['polyline'].cord, {
//                     color: this.props.polilyneArrow.color,
//                     weight: this.props.polilyneArrow.weight
//                 }).addTo(this.Map)
//
//                 const widthArrow = this.props.polilyneArrow.width
//                 //transform: rotate(-90deg);
//                 const arrowIcon = L.icon({
//                     iconUrl: `data:image/svg+xml,%3C%3Fxml version='1.0' encoding='iso-8859-1'%3F%3E%3Csvg version='1.1' id='Capa_1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' fill='%23${this.rgba2hex(this.props.polilyneArrow.color).replace('#', '')}' x='0px' y='0px' viewBox='0 0 320.001 320.001' style='enable-background:new 0 0 320.001 320.001;transform: rotate(-90deg);' xml:space='preserve'%3E%3Cpath d='M295.84,146.049l-256-144c-4.96-2.784-11.008-2.72-15.904,0.128C19.008,5.057,16,10.305,16,16.001v288 c0,5.696,3.008,10.944,7.936,13.824c2.496,1.44,5.28,2.176,8.064,2.176c2.688,0,5.408-0.672,7.84-2.048l256-144 c5.024-2.848,8.16-8.16,8.16-13.952S300.864,148.897,295.84,146.049z'/%3E%3C/svg%3E`,
//                     iconSize: [widthArrow, widthArrow],
//                     iconAnchor: [(widthArrow / 2), (widthArrow / 2)]
//                 });
//
//                 const firstPoint = [...datapoints[eachpoint]['polyline']['cord'][0]]
//                 const secondPoint = [...datapoints[eachpoint]['polyline']['cord'][1]]
//                 const slope = (secondPoint[1] - firstPoint[1]) / (secondPoint[0] - firstPoint[0])
//                 const angle = Math.atan(slope)
//                 let rotation
//
//                 secondPoint[0] = secondPoint[0] - firstPoint[0];
//                 secondPoint[1] = secondPoint[1] - firstPoint[1];
//
//                 if (secondPoint[0] > 0 && secondPoint[1] < 0) {
//                     rotation = angle * 180 / Math.PI / 2
//                 } else if (secondPoint[0] < 0 && secondPoint[1] > 0) {
//                     rotation = 180 + angle * 180 / Math.PI
//                 } else if (secondPoint[0] < 0 && secondPoint[1] < 0) {
//                     rotation = 180 + angle * 180 / Math.PI
//                 } else if (secondPoint[0] > 0 && secondPoint[1] > 0) {
//                     rotation = angle * 180 / Math.PI
//                 }
//
//                 const midPoint = this.middlePoint(
//                     [...datapoints[eachpoint]['polyline']['cord'][0]],
//                     [...datapoints[eachpoint]['polyline']['cord'][1]]
//                 );
//
//                 L.marker(midPoint,
//                     { icon: arrowIcon, rotationAngle: rotation })
//                     .addTo(this.Map)
//
//                 this.Map.fitBounds(polyline.getBounds())
//             }
//         }
//
//         this.Map.addLayer(markersEnd)
//     }
//     this.Map.addLayer(markersStart)
// })