/* eslint-disable id-length */
import dayjs from 'dayjs';

const isNum = (str) => str != null && !Number.isNaN(Number(str));

export const ParamType = {
    METRIC_DIMENSION: {
        name: 'метрика/измерение',
        handler: (value, row) => row[value] || null
    },
    INPUT: { name: 'ввод', handler: (value, row) => value }
};

export const ParamSeparateType = {
    METRIC: {
        name: 'метрика',
        handler: (value, row) => row[value] || null
    },
    DIMENSION: {
        name: 'измерение',
        handler: (value, row) => row[value] || null
    },
    INPUT: { name: 'ввод', handler: (value, row) => value }
};

export const ParamFormat = {
    NUM: {
        name: 'число',
        handler: (value, { prec = -1, tsep = '', fsep = '.', pref = '', postf = '', mult = 1 }) => {
            // eslint-disable-next-line no-restricted-syntax
            if (!isNum(value)) {
                return value;
            }
            const n = Number(value) * mult;
            // eslint-disable-next-line radix
            const str = prec >= 0 ? n.toFixed(parseInt(prec)) : n.toString();
            const a = str.split('.');
            a[0] = a[0]
                .split('')
                .reverse()
                .join('')
                .replace(/(\d{3})/g, `$1${tsep}`)
                .split('')
                .reverse()
                .join('');
            return pref + a.join(fsep) + postf;
        },
        options: {
            prec: {
                name: '.000',
                type: Number
            },
            tsep: {
                name: '1 000',
                type: String
            },
            fsep: {
                name: '0.0',
                type: String
            },
            pref: {
                name: '{A} 123',
                type: String
            },
            postf: {
                name: '123 {A}',
                type: String
            },
            mult: {
                name: '*N',
                type: Number
            }
        }
    },
    DATE: {
        name: 'дата',
        handler: (value, { format = 'DD/MM/YYYY' }) => {
            const day = dayjs(value);
            return day.isValid() ? day.format(format) : value;
        },
        options: {
            format: {
                name: 'формат',
                type: String
            }
        }
    }
};

export const ParamStyleType = {
    ALL: {
        name: 'всегда',
        handler: (paramValue, styleValue) => true
    },
    EQ: {
        name: '=',
        handler: (paramValue, styleValue) =>
            isNum(paramValue) && isNum(styleValue)
                ? Number(paramValue) === Number(styleValue)
                : paramValue === styleValue
    },
    GT: {
        name: '>',
        handler: (paramValue, styleValue) => Number(paramValue) > Number(styleValue)
    },
    LT: {
        name: '<',
        handler: (paramValue, styleValue) => Number(paramValue) < Number(styleValue)
    }
};

export const SeparatorOptions = [
    { label: '10000', value: 'n' },
    { label: '10 000', value: '0' },
    { label: '10.000', value: '1' },
    { label: '10,000', value: '2' }
];

export const FormatOptions = [
    { label: 'Без форматирования', value: 'n' },
    { label: '1000', value: '0' },
    { label: '1000,1', value: '1' },
    { label: '1000,12', value: '2' },
    { label: '12%', value: '0%' },
    { label: '12,3%', value: '1%' },
    { label: '12,34%', value: '2%' }
];
