import panels from './panels';
import {
    SectionActiveGradientBackgroundColorOptions,
    SectionGradientBackgroundColorOptions,
    SectionHoverGradientBackgroundColorOptions
} from './config';
import { createSlotName } from './utils';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        height: {
            type: String,
            default: '100'
        },
        heightUnit: {
            type: String,
            default: '%'
        },
        menuItems: {
            type: Array,
            default: () => [],
            options: {
                create: (menuItems = [], { id } = {}) => ({
                    id: id ?? (menuItems[menuItems.length - 1]?.id ?? 0) + 1,
                    isSlot: false,
                    title: 'Новый пункт',
                    iconName: '',
                    iconColor: '',
                    iconSize: '1.5rem',
                    textColor: '',
                    fontSize: '',
                    url: '',
                    cssStyles: [],
                    eventName: ''
                })
            }
        },
        /** section hover */
        sectionHoverEnable: {
            type: Boolean,
            default: false
        },
        sectionHoverIconColor: {
            type: String,
            default: 'rgb(255, 0, 5, 1)'
        },
        sectionHoverTextColor: {
            type: String,
            default: 'rgb(255, 0, 5, 1)'
        },
        sectionHoverGradientEnable: {
            type: Boolean,
            default: false
        },
        sectionHoverGradientBackgroundColor: {
            type: Object,
            default: () => SectionHoverGradientBackgroundColorOptions
        },
        sectionHoverBackground: {
            type: String,
            default: 'rgba(0, 0, 0, 0.4)'
        },

        /** gradient background color */
        sectionGradientEnable: {
            type: Boolean,
            default: false
        },
        sectionGradientBackgroundColor: {
            type: Object,
            default: () => SectionGradientBackgroundColorOptions
        },

        /** section settings */
        sectionBackgroundColor: {
            type: String,
            default: 'rgb(255, 255, 255, 1)'
        },
        fontFamily: {
            type: String,
            default: 'Roboto'
        },

        /** section active settings */
        sectionActiveTextColor: {
            type: String,
            default: 'rgb(0, 235, 255, 1)'
        },
        sectionActiveIconColor: {
            type: String,
            default: 'rgb(0, 235, 255, 1)'
        },
        sectionActiveGradientEnable: {
            type: Boolean,
            default: false
        },
        sectionActiveGradientBackgroundColor: {
            type: Object,
            default: () => SectionActiveGradientBackgroundColorOptions
        },
        sectionActiveBackground: {
            type: String,
            default: 'rgb(0,0,0, 0.3)'
        },
        distanceBetweenIconAndText: {
            type: String,
            default: '0.25rem'
        }
    }
});

export const meta = {
    descriptor,
    panels,
    slotNames: (vm) => vm.props.menuItems.map(({ id }) => createSlotName(id)),
    isChildAllowed: true,
    cssVars
};

export default descriptor;
