import panels from './panels';

/**
 * @typedef {object} DremioReport
 * @property {string} tpl
 * @property {DremioReportDataItem[]} data
 */
/**
 * @typedef {object} DremioReportDataItem
 * @property {string} name        name
 * @property {object} [query]     dremio query
 * @property {object} [dim]       dremio dimension list
 * @property {number} [limit]     limit size
 */
/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

export const Events = Object.freeze({
    RUN_REPORT: 'runReport',
    START_RUNNING: 'startRunning',
    END_RUNNING: 'endRunning'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        report: {
            type: Object,
            default: () => ({ tpl: '', data: [] }),
            dataItemFactory: ({ name = '', query = null, dim = {}, limit = 0 } = {}) => ({
                name,
                query,
                dim,
                limit
            })
        },
        reportServiceUrl: {
            type: String,
            default: 'https://goodt-dev.goodt.me:8487/',
            hasConst: true
        },
        events: {
            type: Object,
            default() {
                return {
                    [Events.RUN_REPORT]: 'report/run',
                    [Events.START_RUNNING]: 'report/start',
                    [Events.END_RUNNING]: 'report/end'
                };
            }
        },
        isShowPreloader: {
            type: Boolean,
            default: true,
            label: 'Прелоадер при загрузке'
        },
        shouldDownloadInEditorMode: {
            type: Boolean,
            default: true
        },
        shouldDownloadWithFolderName: {
            type: Boolean,
            default: true
        },
        shouldDownloadWithCurrentDate: {
            type: Boolean,
            default: false
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    events: {
        [Events.RUN_REPORT]: {
            listen: `events[${Events.RUN_REPORT}]`
        },
        [Events.START_RUNNING]: {
            trigger: `events[${Events.START_RUNNING}]`
        },
        [Events.END_RUNNING]: {
            trigger: `events[${Events.END_RUNNING}]`
        }
    },
    cssVars: {}
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: true,
    slotNames: ['default']
};

export default descriptor;
