import { Query } from '@goodt-common/dremio';
import cloneDeep from 'lodash/cloneDeep';

/**
 * @param {IQuerySchema} query      query
 * @param {object} dimensionList    dimensions' list
 * @return {string[]}
 */
export const extractQueryFilterNames = (query, dimensionList = {}) => {
    const fieldNames = Query.queryFieldNames(query);
    const metricNames = Query.queryMetricNames(query);
    const dimensionNames = Object.keys(dimensionList);
    return [...new Set([...fieldNames, ...metricNames, ...dimensionNames])];
};

/**
 * @param {IQuerySchema} sourceQuery    query
 * @param {object} [dimensionList]      dimensions' list
 * @param {object} [filtersMap]         filters to applied
 * @return {IQuerySchema} new built query
 */
export const buildQuery = (sourceQuery, dimensionList = {}, filtersMap = {}) => {
    const query = new Query({ query: cloneDeep(sourceQuery), dimensionList }).buildQuery();
    const filterNames = extractQueryFilterNames(query, dimensionList);

    Object.entries(filtersMap).forEach(([key, val]) => {
        if (!filterNames.includes(key)) {
            return;
        }
        if (val) {
            const value = Array.isArray(val) ? val : [val];
            const type = Array.isArray(val) ? Query.FILTER_TYPE.IN : Query.FILTER_TYPE.EQ;
            const filter = Query.createFilter({ name: key, type, value });
            Query.queryInsertUpdateFilter(query, filter);
        } else {
            Query.queryRemoveFilter(query, key);
        }
    });
    return query;
};
