import memoize from 'lodash/memoize';

class Cache {
    constructor() {
        this.deque = [];
        this.index = {};
        this.offset = 0;
    }

    get cacheSize() {
        return this.deque.length;
    }

    put([hashCode, result]) {
        this.deque.push(result);
        const pos = this.cacheSize - 1;
        this.index[hashCode] = pos + this.offset;
    }

    get(hashCode) {
        const pos = this.index[hashCode] - this.offset;
        return pos >= 0 ? this.deque[pos] : null;
    }

    clear(count = this.cacheSize) {
        this.deque.splice(0, count);
        this.offset += count;
    }
}

const cache = new Cache();

function getHashCode(str) {
    const code = str.split('').reduce((hash, symbol) => {
        // eslint-disable-next-line no-bitwise
        const num = (hash << 5) - hash + symbol.charCodeAt(0);
        // eslint-disable-next-line no-bitwise
        return num & num;
    }, 0);
    return code.toString();
}

export const CacheMixin = {
    created() {
        this.memoizedGetHashCode = memoize(getHashCode);
    },
    methods: {
        manipulateCache() {
            if (cache.cacheSize >= 25) {
                cache.clear(1);
            }
        },
        clearCache() {
            cache.clear();
        },
        addToCache([hashCode, result]) {
            cache.put([hashCode, result]);
        },
        getFromCache(hashCode) {
            return cache.get(hashCode);
        }
    }
};
