import { Vars as DremioTableVars } from '../ElemDremioTable/descriptor';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({
    ...DremioTableVars,
    FILTERING_CHILD_FIELD: 'filtering_child_field',
    TRIGGER_METRIC: 'trigger_metric'
});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({
    UPDATE: 'updateEvent',
    CHANGE_TRIGGER_METRIC: 'changeTriggerMetric'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        parentIdField: {
            type: String,
            default: ''
        },
        idField: {
            type: String,
            default: ''
        },
        isRowMultiselect: {
            type: Boolean,
            default: false
        },
        marginLeft: {
            type: Object,
            default: () => ({
                min: '0rem',
                value: '0%',
                max: '0rem'
            })
        },
        divisionFieldId: {
            type: String,
            default: ''
        },
        parentDivisionFieldId: {
            type: String,
            default: ''
        },
        events: {
            type: Object,
            default: () => ({
                [Events.UPDATE]: 'update-table',
                [Events.CHANGE_TRIGGER_METRIC]: 'changeTriggerMetric'
            })
        },
        childTableProps: {
            type: Object,
            default: () => ({
                marginLeft: {
                    min: '0rem',
                    value: '0%',
                    max: '0rem'
                },
                paddingLeft: {
                    value: '0.5rem',
                    columns: ''
                },
                cssClass: [],
                cssStyle: {},
                showHead: false,
                pagination: {
                    fontSize: '',
                    fontFamily: '',
                    color: '',
                    activeColor: '',
                    background: ''
                }
            })
        },
        buttons: { type: Array, default: () => [] }
    },
    events: {
        [Events.UPDATE]: ['listen'],
        [Events.CHANGE_TRIGGER_METRIC]: ['trigger']
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    isChildAllowed: true,
    slotNames: (vm) => [vm.slotDefault],
    cssVars: {
        'table_margin-left-min': 'marginLeft.min',
        'table_margin-left': 'marginLeft.value',
        'table_margin-left-max': 'marginLeft.max'
    }
};

export default descriptor;
