/* eslint-disable no-restricted-syntax */
import { TooltipDefaultFactory } from '@goodt-wcore/components';
import { cssVars } from './css-vars';
import panels from './panels';
import { SearchLabels, SearchSettings } from './config';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({
    TRIGGER_METRIC: 'TRIGGER_METRIC',
    FILTER_METRIC: 'filter_metric_by_task_id',
    STRICT_FILTER_METRIC: 'strict_filter_metric',
    NESTED_ID: 'nested_id',
    VARIABLE_TO_NULL: 'variable_to_null',
    TRIGGER_SELECTED_ID: 'trigger_selected_id',
    TRIGGER_SELECTED_IDS: 'trigger_selected_ids'
});

export const Events = Object.freeze({
    UPDATE: 'update',
    ITEM_EVENT_TRIGGER: 'item_event_trigger',
    TRIGGER_AFTER_COMMIT_TO_STORE: 'triggerAfterCommitToStore'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        dremioMetrics: {
            type: Object,
            default: () => ({
                taskId: 'id_task',
                parentId: 'id_parent'
            })
        },
        tileCssStyle: {
            type: Array,
            default: ['margin: 1rem', 'boxShadow: 0 0.125rem 0.5rem #00000014']
        },
        nestedItemCssStyle: {
            type: Array,
            default: ['padding: 1rem 2rem']
        },
        paddingLeftTreeItem: {
            type: String,
            default: '2rem'
        },
        header: {
            type: Object,
            default() {
                return {
                    trigger: false,
                    enabled: false,
                    isClosed: false,
                    isAlwaysOpened: false,
                    text: 'Все классы',
                    marginBottom: '1rem',
                    styles: ['padding: 1rem 2rem'],
                    iconName: 'cog',
                    iconSize: '0.75rem',
                    iconColor: '#999999',
                    marginRight: '1.5rem',
                    hasInactiveState: false,
                    inactiveStyles: ['padding: 1rem 2rem']
                };
            }
        },
        activeNestedItem: {
            type: Object,
            default() {
                return {
                    background: '#2355ea',
                    color: '#f6f5f5'
                };
            }
        },
        hoverNestedItem: {
            type: Object,
            default() {
                return {
                    active: false,
                    background: '#666666',
                    color: '#e2e2e2'
                };
            }
        },
        pickMetric: {
            type: String,
            default: null
        },
        nestedItemTitleMetric: {
            type: String,
            default: null
        },
        defaultValue: {
            type: Object,
            default() {
                return {
                    active: false,
                    metric: null,
                    id: null
                };
            }
        },
        counting: {
            type: Object,
            default() {
                return {
                    active: false,
                    metric: null,
                    onlyHeader: false,
                    upperLevel: false
                };
            }
        },
        link: {
            type: Object,
            default() {
                return {
                    active: false,
                    iconName: 'link',
                    fontSize: '0.75rem',
                    color: '#182fc1',
                    path: '',
                    isHover: false
                };
            }
        },
        event: {
            type: Object,
            default() {
                return {
                    active: false,
                    showOnlyParents: true,
                    shouldShowOnlyForChildren: false,
                    sortChildren: false,
                    iconName: 'calendar-outline',
                    fontSize: '0.75rem',
                    color: '#9418c1',
                    event: '',
                    isHover: false,
                    isAdditional: false
                };
            }
        },
        additionalEvents: {
            type: Array,
            default: () => []
        },
        menu: {
            type: Object,
            default() {
                return {
                    active: false,
                    iconName: 'dots-horizontal',
                    fontSize: '0.75rem',
                    color: '#9418c1'
                };
            }
        },
        borderBottom: {
            type: Object,
            default() {
                return {
                    active: false,
                    onlyUpperLevel: false,
                    haveChildren: false,
                    width: '0.125rem',
                    color: '#e2e2e2'
                };
            }
        },
        nestedIconSettingsArrow: {
            type: Object,
            default() {
                return {
                    marginRight: '1.5rem',
                    fontSize: '1.5rem',
                    color: '#999999'
                };
            }
        },
        nestedParentIconSettings: {
            type: Object,
            default() {
                return {
                    openIconName: 'menu-down',
                    closeIconName: 'menu-right',
                    marginRight: '1.5rem',
                    fontSize: '1.5rem',
                    color: '#999999'
                };
            }
        },
        nestedChildIconSettings: {
            type: Object,
            default() {
                return {
                    iconName: 'stop',
                    marginRight: '1rem',
                    fontSize: '1rem',
                    color: '#999999'
                };
            }
        },
        updateEvent: {
            type: String,
            default: ''
        },
        isStoreCommitChildrenMetrics: {
            type: Boolean,
            default: false
        },
        strictFilterMetric: {
            type: String,
            default: null
        },
        isHidden: {
            type: Boolean,
            default: false
        },
        customTooltip: {
            type: Object,
            default: TooltipDefaultFactory
        },
        isFixedTooltip: {
            type: Boolean,
            default: false
        },
        shouldPinHeader: {
            type: Boolean,
            default: false,
            label: 'Закрепить шапку с поиском сверху'
        },
        search: {
            type: Object,
            default: () => ({ ...SearchSettings }),
            label: SearchLabels
        },
        events: {
            type: Object,
            default: {
                [Events.TRIGGER_AFTER_COMMIT_TO_STORE]: ''
            }
        }
    },
    events: {
        [Events.UPDATE]: {
            listen: `updateEvent`
        },
        [Events.ITEM_EVENT_TRIGGER]: {
            trigger: `event.event`
        },
        [Events.TRIGGER_AFTER_COMMIT_TO_STORE]: {
            trigger: `events['${Events.TRIGGER_AFTER_COMMIT_TO_STORE}']`
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: true,
    slotNames: ['tooltip'],
    cssVars
};

export default descriptor;
