import { TooltipDefaultFactory } from '@goodt-wcore/components';
import {
    RADIUS,
    SPLIT_NUMBER,
    TITLE_FONT_SIZE,
    TITLE_FONT_WEIGHT,
    LEGEND_GAP,
    LEGEND_FONT_SIZE,
    LEGEND_FONT_WEIGHT,
    LEGEND_BORDER_RADIUS,
    NAME_FONT_SIZE,
    AXIS_LABEL_FONT_SIZE,
    AxisLineFactory
} from './panels/config';
import panels from './panels';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

export const descriptor = () => ({
    props: {
        title: {
            type: Object,
            default: () => ({
                show: false,
                text: '',
                left: 'left',
                textStyle: {
                    fontSize: TITLE_FONT_SIZE,
                    fontWeight: TITLE_FONT_WEIGHT,
                    color: '#000000',
                    fontFamily:'Roboto'
                }
            })
        },
        useColorSet: {
            type: Boolean,
            default: true
        },
        useCustomColors: {
            type: Boolean,
            default: false
        },
        colorSet: {
            type: Array,
            default: () => []
        },
        dremio: {
            type: Object,
            default: null
        },
        height: {
            default: '100'
        },
        shape: {
            type: String,
            default: ''
        },
        radius: {
            type: [Number, String],
            default: RADIUS
        },
        radarAreaStyleColor: {
            type: String,
            default: 'rgba(255,255,255,0)'
        },
        radarSplitNumber: {
            type: Number,
            default: SPLIT_NUMBER
        },
        gradientBackground: {
            type: Boolean,
            default: false
        },
        gradient: {
            type: Object,
            default: () => ({
                first: 'rgba(255, 145, 124, 0.1)',
                second: 'rgba(255, 15, 124, 0.9)',
                direction: '',
                offSetFirstColor: 0,
                offSetSecondColor: 1
            })
        },
        showLegend: {
            type: Boolean,
            default: true
        },
        legendOptions: {
            type: Object,
            default: () => ({
                top: '1',
                left: 'center',
                right: 'auto',
                bottom: 'auto',
                orient: 'horizontal',
                align: 'left',
                itemGap: LEGEND_GAP,
                textStyle: {
                    color: '#000000',
                    fontSize: LEGEND_FONT_SIZE,
                    fontWeight: LEGEND_FONT_WEIGHT,
                    fontFamily: 'Roboto',
                    backgroundColor: 'rgba(250,250,250,0)',
                    borderColor: 'rgba(79,140,244,0.7)',
                    borderWidth: 0,
                    borderRadius: LEGEND_BORDER_RADIUS
                }
            })
        },

        nameOptions: {
            type: Object,
            default: () => ({
                color: 'black',
                fontSize: NAME_FONT_SIZE,
                rich: {
                    active: {
                        fontWeight: 'bold',
                        fontSize: NAME_FONT_SIZE,
                        fontFamily: 'Roboto'
                    }
                },
                fontFamily: 'Roboto'
            })
        },
        tooltip: {
            type: Object,
            default: () => ({
                show: true,
                textStyle: {
                    color: 'white',
                    fontFamily: ''
                },
                format: '0',
                separator: '1',
                prefix: '',
                postfix: ''
            })
        },
        dimension: {
            type: String,
            default: null
        },
        customDimensionsColors: {
            type: Object,
            default: () => ({})
        },
        metrics: {
            type: Object,
            default: () => null
        },
        customTooltip: {
            type: Object,
            default: () => ({
                show: false,
                showIndicatorName: false,
                color: '#fff',
                background: '#000',
                opacity: 0.5,
                fontSize: '14px',
                boxShadow: '1px 1px 20px 1px rgba(0, 0, 0, 0.2)',
                format: '',
                prefix: '',
                postfix: '',
                fontFamily: '',
                offsetX: 10,
                offsetY: 10,
                styles: ['padding: 1rem']
            })
        },
        customComponentTooltip: {
            type: Object,
            default: TooltipDefaultFactory
        },
        axisLabelSettings: {
            type: Object,
            default: () => ({
                show: false,
                margin: 0,
                fontWeight: '500',
                fontFamily: 'Roboto',
                fontSize: AXIS_LABEL_FONT_SIZE,
                align: '',
                verticalAlign: '',
                color: '',
                backgroundColor: 'transparent',
                borderColor: 'transparent',
                borderWidth: 0,
                borderRadius: 0,
                // eslint-disable-next-line no-restricted-syntax
                padding: '0, 0, 0, 0',
                shadowColor: 'transparent',
                shadowBlur: 0,
                shadowOffsetX: 0,
                shadowOffsetY: 0,
                format: '',
                rich: {}
            })
        },
        axisLine: {
            type: Object,
            default: AxisLineFactory
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    cssVars,
    slotNames: ['default', 'tooltip'],
    isChildAllowed: true
};
