export const cssVars = {
    page_width: 'widthPage',
    page_height: 'heightPage',
    'page_margin-right': 'marginHorizPage',
    'page_margin-bottom': 'marginVerPage',
    page_shadow: ({ shadowBlurPage, shadowColorPage, shadowOffsetXPage, shadowOffsetYPage }) =>
        `${shadowOffsetXPage} ${shadowOffsetYPage} ${shadowBlurPage} ${shadowColorPage}`,
    'page_border-radius': 'borderPage',
    page_border: ({ borderStylePage, borderWidthPage, borderColorPage }) =>
        `${borderWidthPage} ${borderStylePage} ${borderColorPage}`,
    'tags-area_height': 'heightAreaTags',
    'tags-area_position': 'positionAreaTags',
    'tags-items_position': 'positionItemTags',
    'tags-area_color': 'colorAreaTags',
    prompt_background: ({
        colorBackPrompt,
        isGradientPrompt,
        gradientFirstColorPrompt,
        gradientSecondColorPrompt,
        gradientDirectionColorPrompt
    }) =>
        isGradientPrompt
            ? `linear-gradient(${gradientDirectionColorPrompt}, ${gradientFirstColorPrompt}, ${gradientSecondColorPrompt})`
            : colorBackPrompt,
    prompt_width: 'widthPrompt',
    prompt_animate: 'animatePrompt',
    prompt_margin: 'marginPrompt',
    'prompt-item_position': 'positionItemPrompt',
    'page-avatar_font-family': 'page.avatarFont',
    'page-avatar_font-size': 'page.avatarFontSize',
    'page-avatar_font-weight': 'page.avatarFontWeight',
    'page-name_color': 'colorNamePage',
    'page-name_font': 'fontPage',
    'page-name_font-size': 'sizeFontPage',
    'page-name_font-weight': 'weightFontPage',
    'page-name_position': 'positionNamePage',
    'page-name_margin': ({ signaturePositionPage, marginNamePage }) => {
        if (signaturePositionPage === 'pos-top') {
            return `0 0 ${marginNamePage} 0`;
        }
        if (signaturePositionPage === 'pos-right') {
            return `0 0 0 ${marginNamePage}`;
        }
        if (signaturePositionPage === 'pos-left') {
            return `0 ${marginNamePage} 0 0`;
        }

        return `${marginNamePage} 0 0 0`;
    },
    'page-name-width': 'widthNamePage',
    'page-name-height': 'heightNamePage',
    'page-name_background': ({
        bgNameColorPage,
        isBackgroundNamePageGradient,
        bgNamePageGradientFirstColor,
        bgNamePageGradientSecondColor,
        bgNamePageGradientDirectionColor
    }) =>
        isBackgroundNamePageGradient
            ? `linear-gradient(${bgNamePageGradientDirectionColor}, ${bgNamePageGradientFirstColor}, ${bgNamePageGradientSecondColor})`
            : bgNameColorPage,
    pagination_font: 'paginationFont',
    'pagination_font-size': 'paginationSizeFont',
    'pagination__item--default_color': 'paginationColorText',
    'pagination__item--active_color': 'paginationColorActiveText',
    'pagination_item--active_background-color': 'paginationColorActive'
};

export const buildTagsCssVarsMapping = (ids) => ({
    tags_width: (props) => props.metricsTags[ids].widthTag,
    tags_height: (props) => props.metricsTags[ids].heightTag,
    'tags_color-text': (props) => props.metricsTags[ids].colorText,
    'tags_color-font-size': (props) => props.metricsTags[ids].sizeText,
    'tags_color-font-weight': (props) => props.metricsTags[ids].fontWeight,
    'tags_color-font-family': (props) => props.metricsTags[ids].fontText,
    tags_background: (props) => {
        const { isGradient, colorBackground, gradientFirstColor, gradientSecondColor, gradientDirectionColor } =
            props.metricsTags[ids];

        return isGradient
            ? `linear-gradient(${gradientDirectionColor}, ${gradientFirstColor}, ${gradientSecondColor})`
            : colorBackground;
    }
});

export const buildNamesCssVarsMapping = (ids) => ({
  'signature_header-margin': (props) => props.metricsSignatureNames[ids].headerMargin,
  'signature_metric-text-align': (props) => props.metricsSignatureNames[ids].positionItem,

  'signature_metric-color': (props) => props.metricsSignatureNames[ids].colorText,
  'signature_metric-font-family': (props) => props.metricsSignatureNames[ids].fontText,
  'signature_metric-font-size': (props) => props.metricsSignatureNames[ids].sizeText,
  'signature_metric-font-weight': (props) => props.metricsSignatureNames[ids].fontWeight,

  'signature_metric_prefix-color': (props) => props.metricsSignatureNames[ids].prefixColor,
  'signature_metric_prefix-font-family': (props) => props.metricsSignatureNames[ids].prefixFontFamily,
  'signature_metric_prefix-font-size': (props) => props.metricsSignatureNames[ids].prefixFontSize,
  'signature_metric_prefix-font-weight': (props) => props.metricsSignatureNames[ids].prefixFontWeight,

  'signature_metric_postfix-color': (props) => props.metricsSignatureNames[ids].postfixColor,
  'signature_metric_postfix-font-family': (props) => props.metricsSignatureNames[ids].postfixFontFamily,
  'signature_metric_postfix-font-size': (props) => props.metricsSignatureNames[ids].postfixFontSize,
  'signature_metric_postfix-font-weight': (props) => props.metricsSignatureNames[ids].postfixFontWeight
});

export const buildPromptCssVarsMapping = (ids) => ({
  'prompt_header-color': (props) => props.metricsPrompt[ids].headerColor,
  'prompt_header-font-family': (props) => props.metricsPrompt[ids].headerFontFamily,
  'prompt_header-font-size': (props) => props.metricsPrompt[ids].headerFontSize,
  'prompt_header-font-weight': (props) => props.metricsPrompt[ids].headerFontWeight,
  'prompt_header-margin': (props) => props.metricsPrompt[ids].headerMargin,

  'prompt_avatar-size': (props) => props.metricsPrompt[ids].imageSize,
  'prompt_avatar-border-radius': (props) => props.metricsPrompt[ids].circleBorder,
  'prompt_avatar-name-color': (props) => props.metricsPrompt[ids].colorFIO,
  'prompt_avatar-name-font-family': (props) => props.metricsPrompt[ids].fontFIO,
  'prompt_avatar-name-font-size': (props) => props.metricsPrompt[ids].sizeFIO,
  'prompt_avatar-name-font-weight': (props) => props.metricsPrompt[ids].fontWeightFIO,

  'prompt_metric-color': (props) => props.metricsPrompt[ids].colorText,
  'prompt_metric-font-family': (props) => props.metricsPrompt[ids].fontFamily,
  'prompt_metric-font-size': (props) => props.metricsPrompt[ids].fontSize,

  'prompt_metric_prefix-color': (props) => props.metricsPrompt[ids].prefixColor,
  'prompt_metric_prefix-font-family': (props) => props.metricsPrompt[ids].prefixFontFamily,
  'prompt_metric_prefix-font-size': (props) => props.metricsPrompt[ids].prefixFontSize,
  'prompt_metric_prefix-font-weight': (props) => props.metricsPrompt[ids].prefixFontWeight,

  'prompt_metric_postfix-color': (props) => props.metricsPrompt[ids].postfixColor,
  'prompt_metric_postfix-font-family': (props) => props.metricsPrompt[ids].postfixFontFamily,
  'prompt_metric_postfix-font-size': (props) => props.metricsPrompt[ids].postfixFontSize,
  'prompt_metric_postfix-font-weight': (props) => props.metricsPrompt[ids].postfixFontWeight
});
