import panels from './panels';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        page: {
            type: Object,
            default: () => ({
                isAvatar: false,
                avatarAltText: '',
                avatarColorText: '#fff',
                avatarColorBack: '#1868cc',
                avatarFont: '',
                avatarFontSize: '0rem',
                avatarFontWeight: '400',
                isAvatarGradient: false,
                avatarGradientFirstColor: '',
                avatarGradientSecondColor: '',
                avatarGradientDirectionColor: 'to top',
                tooltip: ''
            })
        },
        eventPageByClick: {
            type: String
        },
        imagePage: {
            type: String
        },
        urlPage: {
            type: String
        },
        urlPageTargetBlank: {
            type: Boolean,
            default: false
        },
        namePage: {
            type: String
        },
        namePageCustom: {
            type: String,
            default: ''
        },
        colorNamePage: {
            type: String
        },
        fontPage: {
            type: String
        },
        sizeFontPage: {
            type: String,
            default: '12px'
        },
        weightFontPage: {
            type: String,
            default: '400'
        },
        positionNamePage: {
            type: String
        },
        marginNamePage: {
            type: String
        },
        widthPage: {
            type: String,
            default: '200px'
        },
        heightPage: {
            type: String,
            default: '100px'
        },
        marginHorizPage: {
            type: String,
            default: '0px'
        },
        marginVerPage: {
            type: String,
            default: '12px'
        },
        shadowBlurPage: {
            type: String,
            default: '0rem'
        },
        shadowColorPage: {
            type: String,
            default: ''
        },
        shadowOffsetXPage: {
            type: String,
            default: '0rem'
        },
        shadowOffsetYPage: {
            type: String,
            default: '0rem'
        },
        borderPage: {
            type: String,
            default: '0px'
        },
        borderStylePage: {
            type: String,
            default: 'none'
        },
        borderWidthPage: {
            type: String,
            default: '0px'
        },
        borderColorPage: {
            type: String,
            default: ''
        },
        showPrompt: {
            type: Boolean
        },
        metricsSignatureNames: {
            type: Array,
            default: () => []
        },
        metricsTags: {
            type: Array,
            default: () => [
                {
                    name: '',
                    colorText: '',
                    sizeText: '',
                    fontText: '',
                    colorBackground: '',
                    widthTag: '',
                    heightTag: ''
                }
            ]
        },
        metricsPrompt: {
            type: Array,
            default: () => [
                {
                    isAvatar: false,
                    metricAvatar: '',
                    metricFIO: '',
                    imageSize: '',
                    circleBorder: '',
                    colorFIO: '',
                    fontFIO: '',
                    sizeFIO: '',
                    name: '',
                    colorText: '',
                    fontFamily: '',
                    fontSize: '',
                    prefix: '',
                    postfix: '',
                    prefixColor: '',
                    prefixFontFamily: '',
                    prefixFontSize: '',
                    prefixFontWeight: '400',
                    postfixColor: '',
                    postfixFontFamily: '',
                    postfixFontSize: '',
                    postfixFontWeight: '400',
                    shouldUseFormatNumber: false,
                    formatNumber: 0,
                    formatSpace: 0,
                    header: '',
                    headerColor: '',
                    headerFontFamily: '',
                    headerFontSize: '',
                    headerMargin: '',
                    headerFontWeight: '400'
                }
            ]
        },
        colorBackPrompt: {
            type: String,
            default: 'var(--color-white)'
        },
        isGradientPrompt: {
            type: Boolean,
            default: false
        },
        gradientFirstColorPrompt: {
            type: String,
            default: ''
        },
        gradientSecondColorPrompt: {
            type: String,
            default: ''
        },
        gradientDirectionColorPrompt: {
            type: String,
            default: 'to top'
        },
        widthPrompt: {
            type: String,
            default: '50%'
        },
        iconPropmpt: {
            type: String,
            default: 'alert-circle'
        },
        marginPrompt: {
            type: String,
            default: '0'
        },
        colorIcon: {
            type: String,
            default: 'var(--color-black)'
        },
        colorActiveIcon: {
            type: String
        },
        locationIcon: {
            type: String,
            default: 'pos-right'
        },
        positionIcon: {
            type: String,
            default: 'pos-top'
        },
        eventPrompt: {
            type: Number,
            default: 0
        },
        animatePrompt: {
            type: String
        },
        positionItemPrompt: {
            type: String
        },
        showTags: {
            type: Boolean
        },
        colorAreaTags: {
            type: String,
            default: 'var(--color-white)'
        },
        heightAreaTags: {
            type: String,
            default: '20%'
        },
        positionAreaTags: {
            type: String,
            default: 'auto'
        },
        positionItemTags: {
            type: String,
            default: 'auto'
        },
        paginationShow: {
            type: Boolean,
            default: true
        },
        paginationFont: {
            type: String
        },
        paginationSizeFont: {
            type: String
        },
        paginationColorText: {
            type: String
        },
        paginationColorActive: {
            type: String
        },
        paginationColorActiveText: {
            type: String
        },
        shouldShowPaginationArrows: {
            type: Boolean,
            default: false
        },
        signaturePositionPage: {
            type: String,
            default: 'pos-bot'
        },
        widthNamePage: {
            type: String,
            default: ''
        },
        heightNamePage: {
            type: String,
            default: ''
        },
        bgNameColorPage: {
            type: String,
            default: ''
        },
        isBackgroundNamePageGradient: {
            type: Boolean,
            default: false
        },
        bgNamePageGradientFirstColor: {
            type: String,
            default: ''
        },
        bgNamePageGradientSecondColor: {
            type: String,
            default: ''
        },
        bgNamePageGradientDirectionColor: {
            type: String,
            default: 'to top'
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: false,
    cssVars,
    slotNames: ['default']
};

export default descriptor;
