import panels from './panels';
import { cssVars } from './css-vars';
import { FormatSpace } from './utils/constants';
/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        hasConst: true,
        dremio: {
            type: Object,
            default: null
        },
        height: {
            default: '100'
        },
        axisXDimName: {
            type: Number,
            default: 0
        },
        axisYDimName: {
            type: Number,
            default: 1
        },
        metric: {
            type: Number,
            default: 0
        },
        formatNumber: {
            type: Number,
            default: 0
        },
        formatSpace: {
            type: Number,
            default: FormatSpace.SPACE
        },
        seriesLabel: {
            type: Boolean,
            default: true
        },
        colorLabel: {
            type: String,
            default: '#FFF'
        },
        fontSizeLabel: {
            type: String,
            default: '12'
        },
        fontFamilyLabel: {
            type: String,
            default: 'Arial'
        },
        isColorGradient: {
            type: Boolean,
            default: true
        },
        colorRangeMin: {
            type: String,
            default: '#bf444c'
        },
        colorRangeMax: {
            type: String,
            default: '#f6efa6'
        },
        colorValueFrom: {
            type: Number
        },
        colorValueTo: {
            type: Number
        },
        colorValue: {
            type: Array,
            default: () => []
        },
        positionAxisX: {
            type: String,
            default: 'bottom'
        },
        positionAxisY: {
            type: String,
            default: 'left'
        },
        axisTickX: {
            type: Boolean
        },
        axisTickY: {
            type: Boolean
        },
        axisLabelX: {
            type: Boolean,
            default: true
        },
        axisLabelY: {
            type: Boolean,
            default: true
        },
        axisLabelColorX: {
            type: String,
            default: '#333'
        },
        axisLabelColorY: {
            type: String,
            default: '#333'
        },
        axisLabelTransferX: {
            type: Boolean
        },
        axisLabelTransferY: {
            type: Boolean
        },
        axisLabelMarginX: {
            type: Number,
            default: 8
        },
        axisLabelMarginY: {
            type: Number,
            default: 8
        },
        axisLabelRotateX: {
            type: Number,
            default: 0
        },
        axisLabelRotateY: {
            type: Number,
            default: 0
        },
        axisLabelFontFamilyX: {
            type: String
        },
        axisLabelFontFamilyY: {
            type: String
        },
        axisLabelFontSizeX: {
            type: String,
            default: '12px'
        },
        axisLabelFontSizeY: {
            type: String,
            default: '12px'
        },
        axisLabelIntervalX: {
            type: Number,
            default: 0
        },
        axisLabelIntervalY: {
            type: Number,
            default: 0
        },
        visualMapShow: {
            type: Boolean,
            default: false
        },
        visualMapMin: {
            type: Number,
            default: null
        },
        visualMapMax: {
            type: Number,
            default: null
        },
        visualMapHeight: {
            type: Number,
            default: 140
        },
        visualMapWidth: {
            type: Number,
            default: 20
        },
        visualMapTextColor: {
            type: String,
            default: '#333'
        },
        visualMapTextFontFamily: {
            type: String
        },
        visualMapTextFontSize: {
            type: String,
            default: '10px'
        },
        visualMapPositionX: {
            type: String,
            default: '0%'
        },
        visualMapPositionY: {
            type: String,
            default: '0%'
        },
        visualMapBackgroundColor: {
            type: String,
            default: '#ccc'
        },
        tooltipShow: {
            type: Boolean
        },
        tooltipPosition: {
            type: String,
            default: 'top'
        },
        tooltipTextColor: {
            type: String,
            default: '#FFF'
        },
        tooltipTextFontFamily: {
            type: String
        },
        tooltipTextFontSize: {
            type: String,
            default: '12'
        },
        tooltipBackgroundColor: {
            type: String,
            default: 'rgba(0,0,0,0.7)'
        },
        tooltipBorderColor: {
            type: String,
            default: 'rgba(0,0,0,0.7)'
        },
        tooltipBorderWidth: {
            type: Number,
            default: 0
        },
        tooltipPaddingTop: {
            type: String,
            default: '10'
        },
        tooltipPaddingRight: {
            type: String,
            default: '10'
        },
        tooltipPaddingDown: {
            type: String,
            default: '10'
        },
        tooltipPaddingLeft: {
            type: String,
            default: '10'
        },
        url: {
            type: String
        },
        tooltipPrefix: {
            type: String,
            default: ''
        },
        tooltipPostfix: {
            type: String,
            default: ''
        },
        tooltipDataAxisX: {
            type: Boolean,
            default: false
        },
        tooltipDataAxisY: {
            type: Boolean,
            default: false
        },
        gridWidth: {
            type: String,
            default: '80%'
        },
        gridHeight: {
            type: String,
            default: '80%'
        },
        gridPositionX: {
            type: String,
            default: '10%'
        },
        gridPositionY: {
            type: String,
            default: '10%'
        },
        buttonBackgroundColor: {
            type: String,
            default: '#f6efa6'
        },
        buttonIconColor: {
            type: String,
            default: '#333'
        },
        buttonIcon: {
            type: String,
            default: 'arrow-left-bold'
        },
        buttonSize: {
            type: String,
            default: '32px'
        },
        buttonPositionX: {
            type: String,
            default: '0'
        },
        buttonPositionY: {
            type: String,
            default: '0'
        },
        emphasisStyle: {
            type: Object,
            default: () => ({
                color: null,
                borderColor: '',
                borderWidth: 0,
                shadowBlur: 10,
                shadowColor: 'rgba(0, 0, 0, 0.5)'
            })
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});
export const meta = {
    descriptor,
    cssVars,
    panels,
    isChildAllowed: true,
    slotNames: ['default']
};
