import { FormatNumber, FormatSpace } from './constants';

/**
 *
 * @param val
 * @return {string|*}
 */
export const convertFromRem = (val) => {
    if (val.includes('rem')) {
        return `${parseInt(val.replace('rem', ''), 10) * 16}px`;
    }
    return val;
};

/**
 *
 * @param {number} format
 * @param {string} number
 * @return {string}
 */
export const formatNumber = (format, number) => {
    switch (format) {
        case FormatNumber.WITHOUT: {
            return parseFloat(number).toFixed(0);
        }
        case FormatNumber.POINT_ONE: {
            return parseFloat(number).toFixed(1).replace('.', ',');
        }
        case FormatNumber.POINT_TWO: {
            return parseFloat(number).toFixed(2).replace('.', ',');
        }
        case FormatNumber.PERCENT: {
            return `${parseFloat(number).toFixed(0)}%`;
        }
        case FormatNumber.PERCENT_POINT_ONE: {
            return `${parseFloat(number).toFixed(1).replace('.', ',')}%`;
        }
        case FormatNumber.PERCENT_POINT_TWO: {
            return `${parseFloat(number).toFixed(2).replace('.', ',')}%`;
        }
        default:
            return number;
    }
};

/**
 *
 * @param {number} spaceFormat
 * @param {number} numberFormat
 * @param {string} value
 * @return {string}
 */
export const formatSpace = (spaceFormat, numberFormat, value) => {
    switch (spaceFormat) {
        case FormatSpace.WITHOUT:
            return value.replace(' ', '');
        case FormatSpace.SPACE:
            return value.replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
        case FormatSpace.SPACE_POINT:
            return value.replace(/\B(?=(\d{3})+(?!\d))/g, '.');
        case FormatSpace.SPACE_COMMA:
            if ([FormatNumber.WITHOUT, FormatNumber.PERCENT].includes(numberFormat)) {
                return value.replace(/\B(?=(\d{3})+(?!\d))/g, ',');
            }
            return value;
        default:
            return value;
    }
};
