/**
 * Генератор декартова произведения массивов (все возможные комбинации элементов)
 */
function* generateCartesianProduct([head, ...tail]) {
    const restProducts = tail.length > 0 ? cartesianProduct(tail) : [[]];
    for (let restProduct of restProducts) {
        for (let item of head) {
            yield [item, ...restProduct];
        }
    }
}

/**
 * Декартово произведение массивов (все возможные комбинации элементов)
 * @param {Array<Array<any>>} arrays Список наборов возможных элементов для каждой позиции
 */
export function cartesianProduct(arrays) {
    return [...generateCartesianProduct(arrays)];
}

/**
 * Разбивает массив на части заданного размера
 * @param {Array<any>} array 
 * @param {number} chunkSize 
 */
export function chunkify(array, chunkSize) {
    const chunks = [];
    for (let i = 0; i < array.length; i += chunkSize) {
        chunks.push(array.slice(i, i + chunkSize));
    }
    return chunks;
}