/**
 * Переводит первый символ строки в верхний регистр
 * @param {*} str 
 */
export function upperFirst(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}

/**
 * Преобразует строку в число. Поддерживает запятые в качестве разделителей.
 * Если вместо строки передано число, возвращается оно же.
 * @param {string|number} str 
 */
export function parseNumber(str) {
    if (typeof str === 'number') {
        return str;
    }
    if (str && typeof str === 'object') {
        console.warn(`Got object inside parseNumber`, str);
    }
    return parseFloat((str || '').replace(/\,/ig, '.').replace(/[^0-9\.]/ig, '').trim(), 10);
}

/**
 * Форматирует строковое редставление числа с заданными опциями.
 * Вставляет разделители между группами разрядов.
 * Округляет до заданного размера дробной части.
 * @param {number} num Число
 * @param {object} options Опции 
 */
export function prettyNumber(num, {
    groupSeparator = ' ',
    groupSize = 3,
    fractionalDigits = 0
} = {}) {
    let parts = parseNumber(num).toString().split('.');
    let integerString = '';
    let i = 0;
    let j = 0;
    i = parts[0].length;
    while (i > groupSize) {
        j = i - groupSize;
        integerString = groupSeparator + parts[0].slice(j, i) + integerString;
        i = j;
    }
    
    integerString = parts[0].slice(0, i) + integerString;
    parts[0] = integerString;
    if (parts.length > 1) {
        parts[1] = parts[1].slice(0, fractionalDigits);
    }
    return (parts.length > 1 && parts[1]) ? parts.join('.') : integerString;
}