/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default() {
                return null;
            }
        },
        metrics: {
            type: Array,
            default() {
                return [];
            }
        },
        dimensions: {
            type: Array,
            default() {
                return [];
            }
        },
        width: {
            type: String,
            default: '100'
        },
        widthUnit: {
            type: String,
            default: '%'
        },
        height: {
            type: String,
            default: '144'
        },
        heightUnit: {
            type: String,
            default: 'px'
        },
        selectedDimension: {
            type: String,
            default: ''
        },
        titleFontFamily: {
            type: String,
            default: 'Roboto, San serif'
        },
        titleFontSize: {
            type: Number,
            default: 14
        },
        titleFontSizeUnit: {
            type: String,
            default: 'px'
        },
        titleColor: {
            type: String,
            default: '#000000'
        },
        photoSize: {
            type: Number,
            default: 40
        },
        photoSizeUnit: {
            type: String,
            default: 'px'
        },
        photoBorderWidth: {
            type: String,
            default: '0px'
        },
        photoBorderColor: {
            type: String,
            default: '#ffffff'
        },
        photoDistance: {
            type: Number,
            default: 20
        },
        hintColor: {
            type: String,
            default: '#000000'
        },
        valueFontFamily: {
            type: String,
            default: 'Roboto, San serif'
        },
        valueFontSize: {
            type: Number,
            default: 30
        },
        valueFontSizeUnit: {
            type: String,
            default: 'px'
        },
        valueColor: {
            type: String,
            default: '#000000'
        },
        styleData: {
            type: Array,
            default() {
                return [];
            }
        },
        enableBackgroundGradient: {
            type: Boolean,
            default: false
        },
        backgroundGradientFirstColor: {
            type: String,
            default: '#ffffff'
        },
        backgroundGradientSecondColor: {
            type: String,
            default: '#ffffff'
        },
        backgroundColor: {
            type: String,
            default: '#ffffff'
        },
        backgroundGradientDirection: {
            type: String,
            default: 'to top'
        },
        selectedTitle: {
            type: String,
            default: ''
        },
        selectedID: {
            type: String,
            default: ''
        },
        selectedPhotos: {
            type: String,
            default: ''
        },
        selectedName: {
            type: String,
            default: ''
        },
        selectedSurname: {
            type: String,
            default: ''
        },
        selectedHint: {
            type: String,
            default: ''
        },
        hintMaxWidth: {
            type: Number,
            default: 320
        },
        hintMaxWidthUnit: {
            type: String,
            default: 'px'
        },
        hintFontSize: {
            type: Number,
            default: 14
        },
        hintFontSizeUnit: {
            type: String,
            default: 'px'
        },
        isOnlyPhoto: {
            type: Boolean,
            default: false
        },
        numberOfPhoto: {
            type: Number,
            default: 10
        },
        photoMarginLeft: {
            type: String,
            default: '-5px'
        },
        isCutText: {
            type: Boolean,
            default: false
        },
        isShowDimension: {
            type: Boolean,
            default: true
        },
        isShowDimensionValue: {
            type: Boolean,
            default: true
        },
        isShowHintIcon: {
            type: Boolean,
            default: true
        },
        isCutPhoto: {
            type: Boolean,
            default: false
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    cssVars: {
        'kpi_bg-color': 'backgroundColor',
        'kpi_bg-gradient-color': ({
            backgroundGradientDirection,
            backgroundGradientFirstColor,
            backgroundGradientSecondColor
        }) =>
            `linear-gradient(${backgroundGradientDirection},${backgroundGradientFirstColor},${backgroundGradientSecondColor})`,
        'kpi-title_font-family': 'titleFontFamily',
        'kpi-title_font-size': ({ titleFontSize, titleFontSizeUnit }) => `${titleFontSize}${titleFontSizeUnit}`,
        'kpi-title_color': 'titleColor',
        photo_height: ({ photoSize, photoSizeUnit }) => `${photoSize}${photoSizeUnit}`,
        photo_width: ({ photoSize, photoSizeUnit }) => `${photoSize}${photoSizeUnit}`,
        'photo_border-color': 'photoBorderColor',
        'photo_border-width': 'photoBorderWidth',
        'photo_margin-left': 'photoMarginLeft',
        'kpi-value_font-family': 'valueFontFamily',
        'kpi-value_font-size': ({ valueFontSize, valueFontSizeUnit }) => `${valueFontSize}${valueFontSizeUnit}`,
        'kpi-value_color': 'valueColor',
        'kpi-icon_color': 'hintColor',
        'hint_font-size': ({ hintFontSize, hintFontSizeUnit }) => `${hintFontSize}${hintFontSizeUnit}`,
        'hint_max-width': ({ hintMaxWidth, hintMaxWidthUnit }) => `${hintMaxWidth}${hintMaxWidthUnit}`
    }
});

export default descriptor;
