let isNum = str => {
    return str != null && !isNaN(Number(str));
};
import dayjs from 'dayjs';

export const COLUMN_PARAM_FORMATS = {
    NUM: {
        name: 'число',
        handler: (value, { prec = -1, tsep = '', fsep = '.', pref = '', postf = '', mult = 1 }) => {
            if (!isNum(value)) {
                return value;
            }
            let n = Number(value) * mult;
            let s = prec >= 0 ? n.toFixed(parseInt(prec)) : n.toString();
            let a = s.split('.');
            a[0] = a[0]
                .split('')
                .reverse()
                .join('')
                .replace(/(\d{3})/g, `$1${tsep}`)
                .split('')
                .reverse()
                .join('');
            return pref + a.join(fsep) + postf;
        },
        options: {
            prec: {
                name: '.000',
                type: Number
            },
            tsep: {
                name: '1 000',
                type: String
            },
            fsep: {
                name: '0.0',
                type: String
            },
            pref: {
                name: '{A} 123',
                type: String
            },
            postf: {
                name: '123 {A}',
                type: String
            },
            mult: {
                name: '*N',
                type: Number
            }
        }
    },
    DATE: {
        name: 'дата',
        handler: (value, { format = 'DD/MM/YYYY' }) => {
            let d = dayjs(value);
            return d.isValid() ? d.format(format) : value;
        },
        options: {
            format: {
                name: 'формат',
                type: String
            }
        }
    },
    STR: {
        name: 'строка',
        handler: (value, { pref = '', postf = '' }) => {
            return pref + value + postf;
        },
        options: {
            pref: {
                name: '{A} TEXT',
                type: String
            },
            postf: {
                name: 'TEXT {A}',
                type: String
            }
        }
    }
};
