import { BorderWidthUnits } from '@goodt-wcore/panels';
import { ConditionalValueType } from '../../constants';
import { createMetricConditionEntry } from '../../descriptor';

import {
    FontUnits,
    MetricValueNumberType,
    ColorDirectionOptions,
    DigitCapacityOptions,
    FormatterOptions,
    OperationOptions,
    ConditionalValueTypeOptions
} from '../constants';

import UiConditionalSection from '../components/ConditionalSection.vue';
import UiGradientColor from '../components/GradientColor.vue';

export default {
    name: 'MetricsMixin',
    components: {
        UiConditionalSection,
        UiGradientColor
    },
    static: {
        BorderWidthUnits,
        FontUnits,
        ColorDirectionOptions,
        DigitCapacityOptions,
        FormatterOptions,
        MetricValueNumberType,
        ConditionalValueType,
        OperationOptions,
        ConditionalValueTypeOptions
    },
    provide() {
        const vm = this;
        return {
            get descriptor() {
                return vm.descriptor;
            },
            propChanged: this.propChanged
        };
    },
    data() {
        return {
            // Название пропсы дескриптора, в которой хранится название метрики
            metricPropName: '',
            // Название пропсы дескриптора, в которой хранится список условий
            conditionsPropName: ''
        };
    },
    computed: {
        metric: {
            get() {
                return this.props[this.metricPropName];
            },
            set(metric) {
                this.props[this.metricPropName] = metric;
            }
        },
        metricConditionsEntry: {
            get() {
                return this.props[this.conditionsPropName]?.[this.metric] ?? null;
            },
            set(value) {
                if (value == null) {
                    delete this.props[this.conditionsPropName][this.metric];
                } else {
                    this.props[this.conditionsPropName][this.metric] = value;
                }
                this.updateMetricStyleConditions();
            }
        },
        conditions: {
            get() {
                return this.metricConditionsEntry?.list ?? [];
            },
            set(list) {
                this.updateConditionsList(this.metric, list);
            }
        },
        isConditionsEnabled: {
            get() {
                return this.metricConditionsEntry?.enabled ?? false;
            },
            set(enabled) {
                this.ensureMetricStyleCondition(this.metric);
                this.$nextTick(() => {
                    this.metricConditionsEntry.enabled = enabled;
                    this.updateMetricStyleConditions();
                });
            }
        }
    },
    methods: {
        getConditionStyle(idx, conditions = this.conditions) {
            return conditions[idx]?.[1] ?? {};
        },
        updateMetricStyleConditions() {
            this.propChanged(this.conditionsPropName);
        },
        updateConditionsList(metricName, list) {
            if (list.length === 0) {
                this.metricConditionsEntry = null;
                return;
            }
            this.ensureMetricStyleCondition();
            this.$nextTick(() => {
                this.metricConditionsEntry.list = list;
                this.updateMetricStyleConditions();
            });
        },
        ensureMetricStyleCondition() {
            if (this.metricConditionsEntry === null) {
                this.metricConditionsEntry = createMetricConditionEntry();
            }
        },
        onConditionStyleChanged(idx, newStyle) {
            const style = this.getConditionStyle(idx);
            // eslint-disable-next-line better-mutation/no-mutating-functions
            Object.assign(style, newStyle);
            this.updateMetricStyleConditions();
        }
    }
};
