/* eslint-disable id-length */
import { DEFAULT_FONT_SIZE, NumberFormattingType, Operation, Position, NO_FORMATTING } from './constants';

const formatNumberDigitCapacity = (str, formatter) => str.replace(/(\d)(?=(\d\d\d)+([^\d]|$))/g, `$1${formatter}`);

const formatMetricDigitCapacity = (num, formatter) => {
    const numStringify = String(num);

    const formatType = {
        [NumberFormattingType.EXACT]: (value) => value,
        [NumberFormattingType.NUM_INT]: (value) => formatNumberDigitCapacity(value, ' '),
        [NumberFormattingType.NUM_DECIMAL]: (value) => {
            const parts = value.split('.');
            const firstPart = formatNumberDigitCapacity(parts[0], '.');
            let secondPart = '';
            if (parts[1]) {
                secondPart = formatNumberDigitCapacity(parts[1], '.');
            }
            return secondPart ? `${firstPart},${secondPart}` : firstPart;
        },
        [NumberFormattingType.NUM_HUNDRED]: (value) => formatNumberDigitCapacity(value, ',')
    };

    return formatType[formatter](numStringify);
};

const formatNumber = (num, formatter, formatterCapacity) => {
    const fixedNumber = Number(num);
    let result;

    const formattedDecimal = 1;
    const formattedHundred = 2;

    const formatType = {
        [NumberFormattingType.EXACT]: (value) => value,
        [NumberFormattingType.NUM_INT]: (value) => value.toFixed(0),
        [NumberFormattingType.NUM_DECIMAL]: (value) => value.toFixed(1),
        [NumberFormattingType.NUM_HUNDRED]: (value) => value.toFixed(formattedHundred),
        [NumberFormattingType.PERCENT_INT]: (value) => `${(value * 100).toFixed(0)}%`,
        [NumberFormattingType.PERCENT_DECIMAL]: (value) => `${(value * 100).toFixed(formattedDecimal)}%`,
        [NumberFormattingType.PERCENT_HUNDRED]: (value) => `${(value * 100).toFixed(formattedDecimal)}%`
    };

    result = formatType[formatter] ? formatType[formatter](fixedNumber) : fixedNumber;
    result = formatMetricDigitCapacity(result, formatterCapacity);

    return result;
};

const createMetric = () => ({
    color: '#000000',
    value: '0',
    valueColor: '#000000',
    valueColorByLine: false,
    metricName: '',
    showTitle: false,
    title: 'Метрика',
    titleColor: '#000000',
    titleColorByLine: false,
    titlePosition: Position.BOTTOM,
    formattedValue: '',
    titleFontSize: DEFAULT_FONT_SIZE,
    valueFontSize: DEFAULT_FONT_SIZE,
    valueDigitCapacity: '0',
    valueFormatter: NO_FORMATTING,
    valueType: NO_FORMATTING,
    valuePosition: Position.BOTTOM,
    metricPrefix: '',
    metricPostfix: '',
    width: '0.0625rem',
    hideTriangle: false,
    radius: '0px',
    signAlignment: NO_FORMATTING,
    settingPrefix: {
        type: Object,
        default: () => ({
            color: '#000000',
            font: 'Roboto',
            fontSize: '0,875rem',
            fontWeight: '',
            margin: '0px',
            icon: '',
            iconSize: '1,875rem',
            iconColor: '#000000'
        })
    },
    settingPostfix: {
        type: Object,
        default: () => ({
            color: '#000000',
            font: 'Roboto',
            fontSize: '0,875rem',
            fontWeight: '',
            margin: '0px',
            icon: '',
            iconSize: '1,875rem',
            iconColor: '#000000'
        })
    }
});

/**
 *
 * @return {boolean}
 */
export const isPassCondition = ({ checkingValue, conditionalValue, operation }) => {
    const { pass: isPass } = Operation[operation];
    return isPass(checkingValue, conditionalValue);
};

export { formatNumberDigitCapacity, formatMetricDigitCapacity, formatNumber, createMetric };
