import {Query} from "goodt-dremio-sdk";
import {cloneDeep} from 'lodash';

const formulas = {
    '0': {
        value: '0',
        label: 'Абсолютное отклонение',
        func: (a, b) => +a - +b
    },
    '1': {
        value: '1',
        label: 'Процентное отклонение',
        func: (a, b) => (+a - +b) / +a
    },
    getFormulaByTypeId(typeId) {
        return this[typeId].func;
    },
    getSelectObjectsArray() {
        return Object.values(this).map( ({value, label}) => ({value, label}) );
    }
};
Object.defineProperty(formulas, 'getFormulaByTypeId', {
    enumerable: false,
    writable: false,
    configurable: false
});
Object.defineProperty(formulas, 'getSelectObjectsArray', {
    enumerable: false,
    writable: false,
    configurable: false
});

let mixin = {
    data() {
        return {
            resultDif: null,
            queryDiffHelper: null,
            dremioDiffVars: [],
            dremioDiffFilters: []
        }
    },
    methods: {
        setVars() {
            if (this.props.dremioDif) {
                let dremioDiffParams = this.getDremioDiffQueryParamNames();
                this.dremioDiffVars = this.dremioDiffVars.reduce((arr, name) => {
                    if (dremioDiffParams.includes(name)) {
                        arr.push(name);
                        return arr;
                    }
                    this.$delete(this.descriptor.vars, name);
                    return arr;
                }, []);

                dremioDiffParams.forEach(name => {
                    let variable = { description: name };
                    this.$set(this.descriptor.vars, name, variable);
                    this.dremioDiffVars.push(name);
                });
            }
        },

        getDiffDremioData(source, target, meta) {
            if (source && target)
                return source.reduce( (res, sourceRow) => {
                    let sourceId = sourceRow[meta.sourceIdKey];
                    let diffObj = {};
                    let targetObj = {};
                    target.forEach( (targetItem) => {
                        targetObj[ targetItem[meta.targetIdKey] ] = targetItem;
                    });

                    let targetRow = targetObj[sourceId];
                    if ( targetRow ) {
                        meta.diffs.forEach(diff => {
                            if (diff.sourceKey && diff.targetKey && diff.functionType) {
                                let sourceMetricValue = sourceRow[diff.sourceKey];
                                let targetMetricValue = targetRow[diff.targetKey];
                                let formula = formulas.getFormulaByTypeId(diff.functionType);
                                diffObj[diff.name] = formula(sourceMetricValue, targetMetricValue);
                            }
                        });
                        res.push( { ...targetRow, ...sourceRow, ...diffObj } );
                    }
                    return res;
                }, []);
            else return [];
        },

        loadQueryData() {
            //TODO испоьзовать { } = this.props ,добавить dremio
            let dremioDif = this.props.dremioDif;
            let metaDif = this.props.metaDif;

            if (!this.props.dremio || !dremioDif)
                this.resultDif = null;
            else if ( this.props.dremio && dremioDif && metaDif && metaDif?.sourceIdKey && metaDif?.targetIdKey && this.result ) {
                let filter = Query.createFilter({
                    name: metaDif.targetIdKey,
                    value: this.result.rows.map( row => row[metaDif.sourceIdKey] ),
                    type: Query.FILTER_TYPE.IN
                });
                this.dremioDiffFilters.forEach( f => Query.queryInsertUpdateFilter(this.queryDiffHelper.query, f) );
                Query.queryInsertUpdateFilter(this.queryDiffHelper.query, filter);

                let query = this.queryDiffHelper.buildQuery();

                this.dremioSdk
                    .getData(query, 0, 0)
                    .then(resultDif => {
                        let newRes = {
                            rowCount: this.result.rowCount
                        };
                        if (this.result.hasOwnProperty('schema'))
                            newRes.schema = this.result.schema;
                        newRes.rows = this.getDiffDremioData(this.result.rows, resultDif.rows, metaDif);
                        this.resultDif = newRes;
                    })
            }
        },

        applyDremioDiffFilters(params) {
            let { query } = this.queryDiffHelper;
            let dremioParams = this.getDremioDiffQueryParamNames();
            let anyFilterApplied = false;

            Object.entries(params).forEach(([name, paramVal]) => {
                if (dremioParams.includes(name)) {
                    anyFilterApplied = true;
                    if (paramVal !== null) {
                        //createDremioFilter from dremioMixin (SDK.js)
                        let filter = this.createDremioFilter(name, paramVal);
                        this.queryDiffHelper.query = Query.queryInsertUpdateFilter(query, filter);
                    } else {
                        this.queryDiffHelper.query = Query.queryRemoveFilter(query, name);
                    }
                }
            });

            this.dremioDiffFilters = cloneDeep(this.queryDiffHelper.query.$filters);

            return anyFilterApplied;
        },

        getDremioDiffQueryParamNames() {
            let { query, dimensionList } = this.queryDiffHelper;
            let metrics = Query.queryMetricNames(query);
            let dimensions = Object.keys(dimensionList);
            let fields = Query.queryFieldNames(query);
            return [...metrics, ...dimensions, ...fields];
        },

        dremioDiffHandler() {
            let { dremioDif } = this.props;
            if (!dremioDif) {
                this.resultDif = null;
                return;
            }
            this.queryDiffHelper = new Query(cloneDeep(dremioDif));
            this.setVars();
            this.loadQueryData();
        },
        subscribe() {
            this.$eventBus.listenStateChange((e, state) => {
                if ( this.applyDremioDiffFilters(state) )
                    this.loadQueryData();
            });
        },
    },
    created() {
        this.dremioDiffHandler();

        if (this.isEditorMode) {
            this.$watch('props.dremioDif', this.dremioDiffHandler, {deep: true});
            this.$watch('props.dremio', this.dremioDiffHandler, {deep: true});
            this.$watch('props.metaDif', this.dremioDiffHandler, {deep: true});
            this.$watch('result', this.dremioDiffHandler, {deep: true});
        }
    }
};

export { mixin, formulas };
