export default {
    labelFormatter({ value }) {
        if (value === 0) return '';

        let { metricFormat, metricSeparator, metricPrefix, metricPostfix } = this;
        let sep = separators[metricSeparator];
        let opts = { value, sep };
        let formattedValue = availableFormats[metricFormat](opts);

        return `${metricPrefix} ${formattedValue} ${metricPostfix}`;
    },

    tooltipSeriesFormatter({ seriesName, name, value }) {
        let { metricFormat, metricSeparator, metricPrefix, metricPostfix } = this;
        let sep = separators[metricSeparator];
        let tooltipFormat = `${seriesName}</br>${name}: `;
        let opts = { value, sep };
        let formattedValue = availableFormats[metricFormat](opts);

        return `${tooltipFormat} ${metricPrefix} ${formattedValue} ${metricPostfix}`;
    },
    
    tooltipFormatter(data) {
        let { format, separator, prefix = '', postfix = '', showCategory, showNullishValues, reverseMetrics } = this;
        let sep = separators[separator];
        let category = data[0].name;
        let values = data
            .reduce((arr, { seriesName, value }) => {
                let tooltipFormat = `${seriesName}: `;
                let opts = { value, sep };
                let formattedValue = availableFormats[format](opts);
                if (!showNullishValues && formattedValue == 0 || formattedValue == '0%') {
                    return arr;
                }
                arr.push(`${tooltipFormat}${prefix}${formattedValue}${postfix}<br/>`);
                return arr;
            }, []);
        if (reverseMetrics) {
            values.reverse();
        }
        values = values.join('');
        return showCategory ? `${category}<br/>${values}` : values;
    },

    uid() {
        return `f${(~~(Math.random() * 1e8)).toString(16)}`;
    }
};

let separators = ['default', 'ru-RU', 'de-DE', 'en-EN'];

let availableFormats = {
    0: ({ value, sep }) => formatNum(fixNum(value, 0), sep, 0),
    1: ({ value, sep }) => formatNum(fixNum(value, 1), sep, 1),
    2: ({ value, sep }) => formatNum(fixNum(value, 2), sep, 2),
    '0%': ({ value }) => calcPercentage(value, 0),
    '1%': ({ value }) => calcPercentage(value, 1),
    '2%': ({ value }) => calcPercentage(value, 2)
};

let fixNum = (num, frDigits) => num.toFixed(frDigits);

let calcPercentage = (value, frDigits) => value.toLocaleString(undefined, {
    style: 'percent',
    minimumFractionDigits: frDigits
});

let formatNum = (num, localeSep, frDigits) => {
    return localeSep === 'default'
        ? num
        : new Intl.NumberFormat(localeSep, {
              minimumFractionDigits: frDigits
          }).format(num);
};
