/**
 *
 * @param {{ [name]: string, [classes]: string, [style]: object, [format]: string} | string} options
 * @returns {{ name: string, classes: string, style: object, format: string}}
 */
export const datasetFieldFactory = (options = {}) => {
    const isOptionsString = typeof options === 'string';
    const field = {
        name: isOptionsString ? options : '',
        classes: '',
        style: {},
        format: ''
    };
    if (isOptionsString) {
        return field;
    }
    return { ...field, ...options };
};

export const DatasetField = Object.freeze({
    CARD_HEADER_IMG: datasetFieldFactory({
        name: 'card_header_img'
    }),
    CARD_HEADER_TITLE: datasetFieldFactory({
        name: 'card_header_title'
    }),
    CARD_HEADER_ICON: datasetFieldFactory({
        name: 'card_header_icon'
    }),
    CARD_HEADER_TITLE_ICON: datasetFieldFactory({
        name: 'card_header_title_icon'
    }),
    CARD_HEADER_DESCRIPTION: datasetFieldFactory({
        name: 'card_header_description'
    }),
    CARD_BODY_TITLE: datasetFieldFactory({
        name: 'card_body_title'
    }),
    CARD_BODY_DESCRIPTION: datasetFieldFactory({
        name: 'card_body_description'
    }),
    CARD_FOOTER_TITLE: datasetFieldFactory({
        name: 'card_footer_title'
    }),
    CARD_FOOTER_DATE: datasetFieldFactory({
        name: 'card_footer_date'
    }),
    CARD_FOOTER_EMPLOYEE: datasetFieldFactory({
        name: 'card_footer_employee'
    }),
    CARD_FOOTER_EMPLOYEE_IMG: datasetFieldFactory({
        name: 'card_footer_employee_img'
    }),
    CARD_PROGRESS_TITLE: datasetFieldFactory({
        name: 'card_progress_title'
    }),
    CARD_PROGRESS_FACT: datasetFieldFactory({
        name: 'card_progress_fact',
        style: {
            backgroundColor: '#1a67fe'
        }
    }),
    CARD_PROGRESS_PLAN: datasetFieldFactory({
        name: 'card_progress_plan',
        style: {
            backgroundColor: '#eee',
            height: '0.5rem'
        }
    }),
    CARD_PROGRESS_RANGE: datasetFieldFactory({
        name: 'card_progress_range'
    }),
    CARD_PROGRESS_FACT_VALUE: datasetFieldFactory({
        name: 'card_progress_fact_value'
    }),
    CARD_PROGRESS_SUBTITLE: datasetFieldFactory({
        name: 'card_progress_subtitle'
    })
});
export const DateFormats = Object.freeze({
    DAY_FIRST: 'DD.MM.YYYY',
    YEAR_FIRST: 'YYYY-MM-DD'
});

export const datasetFields = Object.values(DatasetField).reduce(
    (acc, field) => ({ ...acc, [field.name]: datasetFieldFactory(field) }),
    {}
);

export const columnFactory = () => ({
    metricValues: [],
    title: 'Название',
    icon: 'mdi mdi-check-circle',
    color: '#c6392e',
    datasetFields: { ...datasetFields },
    cardBodyTitleTitle: '',
    cardBodyDescriptionTitle: '',
    btnCommit: {
        text: 'Подобрать',
        class: 'btn btn-primary text-upper shadow-2',
        isIcon: false,
        iconClasses: 'mdi mdi-star',
        isShowBtnCommit: true,
        isShowBtnInsteadOfHeaderIcon: false
    },
    initialsSettings: {
        isActive: false,
        nameMetric: '',
        surnameMetric: ''
    },
    metricFilterToCommit: '',
    shouldUsePathFromMetric: false,
    metricWithPath: '',
    path: '/',
    classes: {
        titleClass: 'text-h3 text-bold',
        descriptionTitleClass: 'color-grey text-upper',
        cardFooterDateIcon: 'mdi-calendar-range',
        columnHeaderClass: 'shadow-2',
        cardClass: 'd-flex tile pad-5'
    },
    styles: {
        headerBorderStyle: {
            color: '#c0c7d3'
        },
        bodyBorderStyle: {
            color: '#c0c7d3'
        }
    },
    columnScroll: {
        isScroll: false,
        height: '400px'
    },
    width: '400px',
    isMaxWidth: false,
    maxWidth: '400px',
    isHeaderBorder: true,
    isBodyBorder: true,
    dateFormat: 'DD.MM.YYYY',
    notification: {
        isShowed: false,
        code: 293,
        iconClass: 'mdi mdi-bell-outline',
        parameter: ''
    }
});
