/* eslint-disable no-magic-numbers */
import { ColumnHeaderStyles } from './constants';
import { columnFactory } from './config';
import panels from './panels';
import { cssVars } from './css-vars';

export const Events = Object.freeze({
    UPDATE_EVENT: 'updateEvent'
});

/* eslint-disable no-restricted-syntax */
/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({
    METRIC_VALUE: 'metric_value'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        rostalentApiUrl: {
            type: String,
            default: 'https://goodt-dev.goodt.me:8486'
        },
        events: {
            type: Object,
            default: () => ({
                [Events.UPDATE_EVENT]: 'updateEvent'
            })
        },
        dremio: {
            type: Object,
            default: null
        },
        metricFilter: {
            type: String,
            default: ''
        },
        columns: {
            type: Array,
            default() {
                return [columnFactory()];
            }
        },
        columnHeaderStyle: {
            type: Number,
            default: ColumnHeaderStyles.THIRD
        },
        canTransform: {
            type: Boolean,
            default: false
        },
        maxCardsShownCount: {
            type: Number,
            default: 5
        },
        countToShowCardsPerClick: {
            type: Number,
            default: 5
        },
        columnGap: {
            type: String,
            default: '2rem'
        },
        cardMargin: {
            type: String,
            default: '1rem'
        },
        notFoundMessage: {
            type: Object,
            default: () => ({
                isShowed: false,
                message: 'Нет данных',
                style: {
                    fontFamily: '',
                    fontSize: '',
                    textColor: ''
                }
            })
        },
        awaitVariableMode: {
            type: Object,
            default: () => ({
                isEnabled: false,
                variables: []
            }),
            label: {
                'awaitVariableMode.isEnabled': 'Ожидать фильтрацию из хранилища',
                'awaitVariableMode.variables': 'Переменные'
            }
        }
    },
    events: {
        [Events.UPDATE_EVENT]: {
            listen: `events['${Events.UPDATE_EVENT}']`
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: true,
    slotNames: ['progressBarSlot'],
    cssVars
};

export default descriptor;
