import panels from './panels';
import { WorkTypes } from './constants';

/**
 * @typedef {object} FilterDateItem
 * @property {string} key
 * @property {string} format
 * @property {boolean} enable
 */
/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

export const Events = Object.freeze({
    TRIGGER_EVENT: 'triggerEvent'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        currentMetric: {
            type: String,
            default: ''
        },
        enableCurrentMetric: {
            type: Boolean,
            default: false
        },
        filters: {
            type: Array,
            default() {
                return {};
            }
        },
        filterDate: {
            type: Object,
            /** @return {FilterDateItem} */
            default() {
                return { key: '', format: 'YYYY-MM-DD', enable: false };
            }
        },
        workType: {
            type: String,
            default: WorkTypes.START_AT_BOOT
        },
        profileVars: {
            type: Object,
            default: () => ({
                canWrite: false
            })
        },
        awaitVariableModeSettings: {
            type: Object,
            default: () => ({
                isAwaitVariableMode: false,
                variables: []
            })
        },
        events: {
            type: Object,
            default: () => ({
                [Events.TRIGGER_EVENT]: ''
            })
        }
    },
    events: {
        [Events.TRIGGER_EVENT]: {
            listen: `events['${Events.TRIGGER_EVENT}']`
        }
    },
    vars: Vars
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: false,
    slotNames: ['default'],
    cssVars: {}
};

export default descriptor;
