import { TooltipDefaultFactory } from '@goodt-wcore/components';
import panels from './panels';
import { cssVars } from './utils/css-vars';
/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
import {
    TRANSITION_DEFAULT,
    CELL_SIZE_DEFAULT,
    COLS_AMOUNT_DEFAULT,
    // GRADIENT_MAX_DEFAULT,
    FORMAT_DIGITS_DEFAULT
} from './utils/constants';

export const Vars = Object.freeze({
    SELECTED_REGION: 'selectedCell',
    SELECTED_REGIONS: 'selectedCells',
    IN_DRILL_LEVEL: 'inDrillLevel',
    PREV_STATE: 'stateGoPrev'
});
/**
 * @description Don't change `descriptor` exported name
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: () => null
        },
        height: {
            default: '100'
        },
        // Metrics
        drilldownActive: {
            type: Boolean
        },
        drilldown: {
            type: Object,
            default() {
                return {};
            }
        },
        layerCurrent: {
            type: Number,
            default: 0
        },
        layersArray: {
            type: Array,
            default() {
                return [];
            }
        },
        // Widget settings
        svgWrapperPaddingY: {
            type: String,
            default: '0px'
        },
        svgWrapperPaddingX: {
            type: String,
            default: '0px'
        },
        waveAnimation: {
            type: Boolean,
            default: true
        },
        waveAnimationSpeed: {
            type: Number,
            default: TRANSITION_DEFAULT
        },
        navigateUrl: {
            type: String,
            default: ''
        },
        isBaikonur: {
            type: Boolean
        },
        // Heatmap
        heatmapActive: {
            type: Boolean,
            default: false
        },
        heatmapDefault: {
            type: Boolean
        },
        heatmapDescending: {
            type: Boolean,
            default: true
        },
        heatmapSortType: {
            type: Boolean,
            default: true
        },
        heatmapColsAmount: {
            type: Number,
            default: COLS_AMOUNT_DEFAULT
        },
        heatmapBtnSize: {
            type: String,
            default: '45px'
        },
        heatmapIconSize: {
            type: String
        },
        heatmapBtnY: {
            type: String,
            default: '0%'
        },
        heatmapBtnX: {
            type: String,
            default: '10%'
        },
        heatmapBtnColor: {
            type: String,
            default: 'rgba(255, 255, 255, 1)'
        },
        heatmapBtnIconColor: {
            type: String,
            default: 'rgba(0, 0, 0, 1)'
        },
        heatmapBtnIconUrlIn: {
            type: String,
            default: 'mdi-map'
        },
        heatmapBtnIconUrlOut: {
            type: String,
            default: 'mdi-periodic-table'
        },
        heatmapTransitionSpeed: {
            type: Number,
            default: TRANSITION_DEFAULT
        },
        // Drilldown settings
        drilldownSortType: {
            type: Boolean,
            default: true
        },
        drilldownColsAmount: {
            type: Number,
            default: COLS_AMOUNT_DEFAULT
        },
        drilldownBtnSize: {
            type: String,
            default: '45px'
        },
        drilldownIconSize: {
            type: String
        },
        drilldownBtnY: {
            type: String,
            default: '0%'
        },
        drilldownBtnX: {
            type: String,
            default: '10%'
        },
        drilldownBtnColor: {
            type: String,
            default: 'rgba(255, 255, 255, 1)'
        },
        drilldownBtnIconColor: {
            type: String,
            default: 'rgba(0, 0, 0, 1)'
        },
        drilldownBtnIconUrlIn: {
            type: String,
            default: 'mdi-star'
        },
        drilldownBtnIconUrlOut: {
            type: String,
            default: 'mdi-pencil'
        },
        hideDrilldownBtn: {
            type: Boolean,
            default: false
        },
        customTooltip: {
            type: Object,
            default: TooltipDefaultFactory
        },
        // -+_+-
        arrayOfSettingsObjects: {
            type: Array,
            default() {
                return [
                    {
                        layerId: 0,
                        layerOptions: {
                            metrics: {
                                regionMetric: '',
                                contentMetric: '',
                                valueMetric: ''
                            },
                            // Legend
                            legendShow: true,
                            legendType: 1,
                            legendTypes: [
                                { value: 0, label: 'Обычная' },
                                { value: 1, label: 'С кнопками' },
                                // eslint-disable-next-line no-magic-numbers
                                { value: 2, label: 'Градиентная' }
                            ],
                            legendX: '0px',
                            legendY: '0px',
                            legendHeader: '',
                            legendHeaderTextColor: 'rgba(0, 0, 0, 1)',
                            legendHeaderTextSize: '16px',
                            legendHeaderPosition: 'center',
                            legendHeaderFontWeight: '',
                            legendWidthGradient: '100px',
                            legendPosValGradient: 0,
                            // eslint-disable-next-line no-restricted-syntax
                            legendNoDataText: [{ text: 'н/д', color: '' }],
                            legendHiddenNoData: false,
                            legendFontWeight: '',
                            // Segments Colors
                            noDataFill: '#FFFFFF',
                            defaultFill: '#FFFF13',
                            fills: [],
                            fillsTextsSize: '16px',
                            fillsTextsColor: 'rgba(0, 0, 0, 1)',
                            fillsTextFontWeight: '',
                            fillsBorderWidth: '0px',
                            fillsBorderColor: 'rgba(0, 0, 0, 1)',
                            fillsAmountTextsSize: '16px',
                            fillsAmountTextsColor: 'rgba(0, 0, 0, 1)',
                            fillsAmountTextFontWeight: '',
                            // Gradient
                            gradientColorUse: false,
                            gradientUseConditionViaMetrics: false,
                            gradientColorMax: 'rgba(255, 0, 0, 1)',
                            gradientColorMin: 'rgba(0, 255, 0, 1)',
                            gradientValueMax: '', // GRADIENT_MAX_DEFAULT,
                            gradientValueMin: '',
                            // Cell
                            cellStrokeColor: 'rgba(75, 0, 255, 1)',
                            cellTextSize: '0.8rem',
                            cellTextColor: 'rgba(0, 0, 0, 1)',
                            cellWidth: CELL_SIZE_DEFAULT,
                            cellHeight: CELL_SIZE_DEFAULT,
                            // Tooltip
                            tooltipShow: false,
                            tooltipMetric: 'M_value',
                            headerTooltipMetric: '',
                            tooltipBackgroundColor: 'rgba(0, 0, 0, 1)',
                            tooltipFormatUseGrouping: true,
                            tooltipFormatPrefix: '',
                            tooltipFormatPostfix: '',
                            tooltipWidth: '100px',
                            tooltipHeight: '100px',
                            tooltipIsSize: true,
                            tooltipIsShowNoData: false,
                            tooltipFormatMaxFractionDigits: FORMAT_DIGITS_DEFAULT,
                            tooltipItems: [
                                {
                                    value: '',
                                    prefix: '',
                                    postfix: '',
                                    size: '0.8rem',
                                    color: 'rgba(255, 255, 255, 1)',
                                    style: '',
                                    noData: '',
                                    formatNumber: '-',
                                    formatSpace: '10000',
                                    description: ''
                                }
                            ],
                            tooltipTextPosition: 'center',
                            tooltipAdvancedNoData: ''
                        }
                    }
                ];
            },
        },
        showUpdatedMap: { type: Boolean, default: false }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: true,
    cssVars,
    slotNames: ['default', 'tooltip']
};
