/* eslint-disable id-length */
import dayjs from 'dayjs';
import isNumber from 'lodash/isNumber';

export const ParamTypes = {
    METRIC_DIMENSION: {
        name: 'метрика/измерение',
        handler: (value, row) => row[value] || null
    },
    INPUT: { name: 'ввод', handler: (value, row) => value }
};

export const ParamSeparateTypes = {
    METRIC: {
        name: 'метрика',
        handler: (value, row) => row[value] || null
    },
    DIMENSION: {
        name: 'измерение',
        handler: (value, row) => row[value] || null
    },
    INPUT: { name: 'ввод', handler: (value, row) => value }
};

export const ParamFormats = {
    NUM: {
        name: 'число',
        handler: (value, { prec = -1, tsep = '', fsep = '.', pref = '', postf = '', mult = 1 }) => {
            if (!isNumber(value)) {
                return value;
            }
            const n = Number(value) * mult;
            const s = prec >= 0 ? n.toFixed(parseInt(prec, 10)) : n.toString();
            let [a] = s.split('.');
            a = a.replace(/(\d)(?=(\d{3})+(?!\d))/g, `$1${tsep}`);
            return pref + a.join(fsep) + postf;
        },
        options: {
            prec: {
                name: '.000',
                type: Number
            },
            tsep: {
                name: '1 000',
                type: String
            },
            fsep: {
                name: '0.0',
                type: String
            },
            pref: {
                name: '{A} 123',
                type: String
            },
            postf: {
                name: '123 {A}',
                type: String
            },
            mult: {
                name: '*N',
                type: Number
            }
        }
    },
    DATE: {
        name: 'дата',
        handler: (value, { format = 'DD/MM/YYYY' }) => {
            const d = dayjs(value);
            return d.isValid() ? d.format(format) : value;
        },
        options: {
            format: {
                name: 'формат',
                type: String
            }
        }
    }
};

export const ParamStyleTypes = {
    ALL: {
        name: 'всегда',
        handler: (paramValue, styleValue) => true
    },
    EQ: {
        name: '=',
        handler: (paramValue, styleValue) =>
            isNumber(paramValue) && isNumber(styleValue)
                ? Number(paramValue) === Number(styleValue)
                : paramValue === styleValue
    },
    GT: {
        name: '>',
        handler: (paramValue, styleValue) => Number(paramValue) > Number(styleValue)
    },
    LT: {
        name: '<',
        handler: (paramValue, styleValue) => Number(paramValue) < Number(styleValue)
    }
};

export const PARAM_STYLE_FACTORY = () => ({ type: null, value: '', style: '' });

/**
 * @param {number|string} value
 * @param {string} unit
 * @return string
 */
export const resolveValueWithUnits = (value, unit) => Number.isNaN(value) ? value : `${value}${unit}`;
