import panels from './panels';
import { cssVars } from './css-vars';

import { ControlActionId, DEFAULT_BALANCE_Y_AXIOS, MAX_LENGTH_NAME, DEFAULT_ZOOM_CARD } from './constants';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({
    SELF_ID: 'selfId',
    ROOT_ID: 'rootId',
    OPENED_ID: 'openId',
    SEARCH_ID: 'searchId'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        additionalDremio: {
            type: Object,
            default: null
        },
        dynamicMetrics: {
            type: Array,
            default: () => [
                {
                    value: 'id',
                    role: 'id'
                },
                {
                    value: 'parentId',
                    role: 'parentId'
                }
            ]
        },
        widgetOptions: {
            type: Object,
            default: () => ({
                card: {
                    width: '300px',
                    height: '150px',
                    pathPadding: '30px',

                    borderWidth: '2px',
                    borderRadius: '20px',
                    borderColor: '#0F8C79B2',

                    backGroundColorStart: '#ECEDF0',
                    backGroundColorEnd: '#ECEDF0',
                    backGroundDirection: '90deg',
                    boxShadow: '0px 4px 8px #00000029',
                    childrenMargin: '20px',
                    siblingsMargin: '10px',
                    initialZoom: 0.7,

                    openIcon: 'chevron-down',
                    closeIcon: 'chevron-up',
                    iconColor: '#000000',

                    buttonBorderWidth: '2px',
                    buttonBorderColor: '#000000',
                    buttonRadius: '20px',
                    buttonColor: '#17dcbb'
                },
                picture: {
                    width: '64px',
                    height: '64px',
                    borderRadius: '64px',
                    align: '',
                    bg: '#17dcbb',
                    colorBg: '#000000',
                    size: '16px',
                    isAbsoluteImage: false,
                    top: '',
                    right: ''
                },
                title: {
                    size: '16px',
                    weight: '700',
                    style: 'normal',
                    color: '#000',
                    separator: '0',
                    format: '0'
                },
                metric: {
                    size: '16px',
                    weight: '700',
                    style: 'normal',
                    color: '#000',
                    separator: '0',
                    format: '0'
                },
                options: [],
                self: {
                    color: '#ed5564',
                    size: '0.5rem'
                },
                search: {
                    color: '#0acf83',
                    size: '0.5rem'
                },
                chart: {
                    lineColor: '#000000',
                    boldLineWidth: 2,
                    boldLineColor: '#17dcbb'
                }
            }),
            hasConst: true
        },
        actionNames: {
            type: Object,
            default: () => ({
                [ControlActionId.SHOW_ALL]: {
                    name: 'Раскрытие',
                    show: true
                },
                [ControlActionId.SHOW_SELF]: {
                    name: 'Отобразить меня',
                    show: true
                },
                [ControlActionId.SHOW_PATH]: {
                    name: 'Отобразить путь подчиненности',
                    show: true
                },
                [ControlActionId.SHOW_PATH_SEARCH]: {
                    name: 'Отобразить путь подчиненности сотрудника',
                    show: true
                },
                [ControlActionId.ROTATE]: {
                    name: 'Поворот',
                    show: true
                },
                [ControlActionId.CLEAN]: {
                    name: 'Очистить',
                    show: true
                },
                [ControlActionId.CENTER]: {
                    name: 'Центр',
                    show: true
                }
            })
        },

        hasParentSelf: {
            type: Boolean,
            default: false
        },
        hasParentSearch: {
            type: Boolean,
            default: false
        },
        isAdditionalData: {
            type: Boolean,
            default: false
        },
        isCenterTextAddit: {
            type: Boolean,
            default: false
        },
        balanceYAxios: {
            type: Number,
            default: DEFAULT_BALANCE_Y_AXIOS
        },
        zoomCard: {
            type: Number,
            default: DEFAULT_ZOOM_CARD
        },
        lengthName: {
            type: Number,
            default: MAX_LENGTH_NAME
        },
        showNotify: {
            type: Object,
            default: () => ({
                isShow: false,
                time: 3000
            })
        },
        filters: {
            type: Array,
            default() {
                return [];
            },
            factory() {
                return { name: '', data: '' };
            }
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    cssVars
};
