/* eslint-disable no-magic-numbers */
export const DEFAULT_DATA_COLOR = '#acacac';
export const TROTTLE_WAIT_TIME = 500;

export const SortTypes = {
    ASC: 'asc',
    DESC: 'desc'
};

export const DEFAULT_BREAKPOINT_SCALE = 1;

export const createBreakpoint = ({ size = 0, scale = DEFAULT_BREAKPOINT_SCALE } = {}) => ({
    size,
    scale
});

export const createLabelNormal = ({ show, position, formatter, lineHeight = 20, rich }) => ({
    show,
    position,
    formatter,
    lineHeight,
    rich
});

export const createLegend = ({
    show,
    type = 'scroll',
    position,
    isShownTitle,
    padding = [8, 8, 24, 8],
    textStyle,
    itemStyle = {
        borderWidth: 0,
        borderColor: 'rgba(255, 255, 255, 1)'
    },
    top,
    left,
    right,
    bottom
}) => {
    const isHorizontalView = position === 'top' || position === 'bottom';
    const isVerticalView = position === 'left' || position === 'right';

    const calcTop = () => {
        if (position === 'top') {
            if (isShownTitle) {
                return 32;
            }
            return 24;
        }
        if (isVerticalView) {
            return 'center';
        }
        return 'auto';
    };
    const calcLeft = () => {
        if (position === 'left') {
            return 15;
        }
        if (isHorizontalView) {
            return 'center';
        }
        return 'auto';
    };
    return {
        show,
        type,
        orient: isHorizontalView ? 'horizontal' : 'vertical',
        top: top || calcTop(),
        bottom: bottom || (position === 'bottom' ? 8 : 'auto'),
        left: left || calcLeft(),
        right: right || (position === 'right' ? 15 : 'auto'),
        padding,
        textStyle,
        itemStyle
    };
};

export const createTitle = ({
    show,
    text,
    backgroundColor = 'transparent',
    left = 'center',
    top = 'auto',
    padding = [8, 8, 24, 8],
    textStyle
}) => ({
    show,
    text,
    backgroundColor,
    left,
    top,
    padding,
    textStyle
});

export const createOptions = ({ title, legend, tooltip, toolbox, color = [], series = [] }) => ({
    title,
    legend,
    tooltip,
    toolbox,
    color,
    series
});

export const createPieSeries = ({
    name,
    type = 'pie',
    top,
    left,
    padding = [20, 0],
    radius,
    center = ['50%', '50%'],
    itemStyle = {
        shadowBlur: 2,
        shadowColor: 'rgba(0, 0, 0, 0.3)'
    },
    minShowLabelAngle,
    label,
    animation,
    animationEasing,
    animationEasingUpdate,
    animationDuration,
    animationDurationUpdate,
    animationDelay,
    animationDelayUpdate,
    animationType,
    data = []
}) => ({
    name,
    type,
    top,
    left,
    padding,
    radius,
    center,
    itemStyle,
    minShowLabelAngle,
    label,
    animation,
    animationEasing,
    animationEasingUpdate,
    animationDuration,
    animationDurationUpdate,
    animationDelay,
    animationDelayUpdate,
    animationType,
    data
});

export const BreakpointsTemplate = () => ({
    isUsed: false,
    large: createBreakpoint({ scale: 1 }),
    points: []
});

export const seriesItemFactory = () => ({
    shadowBlur: 2,
    shadowColor: 'rgba(0, 0, 0, 0.3)',
    shadowOffsetX: 0,
    shadowOffsetY: 0,
    borderRadius: 0,
    borderColor: 'rgba(255, 255, 255, 1)',
    borderWidth: 0
});

export const tooltipFactory = () => ({
    formatter: '0',
    position: 'inside',
    offsetX: 10,
    offsetY: 10,
    fontSize: 14,
    textColor: 'rgba(255, 255, 255, 1)',
    backgroundColor: 'rgba(50, 50, 50, 0.7)',
    borderWidth: 0,
    borderColor: 'rgba(0, 0, 0, 0.5)'
});

export const Metrics = {
    name: 'Метрика',
    selected: '',
    numberToShow: 'all',
    separator: '1',
    color: 'rgba(50,131,168,1)',
    colorStep: 10,
    chart: {
        type: 'pie',
        left: '-39',
        hUnit: '%',
        top: '0',
        vUnit: '%',
        outsideRadius: 81,
        insideRadius: 25
    },
    sum: {
        show: false,
        left: '50',
        hUnit: '%',
        top: '50',
        vUnit: '%',
        name: 'Всего',
        namePosition: 'left',
        textAlign: 'left',
        nameTextAlign: 'left',
        formatter: '0',
        nameColor: '#a5a5a5',
        nameFontFamily: 'Roboto, sans-serif',
        nameFontSize: '16',
        nameFontSizeUnit: 'px',
        fontWeight: '400',
        nameFontWeight: '400',
        color: '#a5a5a5',
        fontFamily: 'Roboto, sans-serif',
        fontSize: '16',
        fontSizeUnit: 'px'
    },
    label: {
        show: false,
        position: 'inside',
        minShowAngle: 25,
        formatter: '0',
        value: {
            show: true,
            color: '#ffffff',
            fontFamily: 'Roboto, sans-serif',
            fontSize: 12,
            fontWeight: null,
            prefix: '',
            postfix: ''
        },
        dimension: {
            show: true,
            color: '#ffffff',
            fontFamily: 'Roboto, sans-serif',
            fontSize: 12,
            fontWeight: null,
            prefix: '',
            postfix: ''
        }
    },
    itemStyle: seriesItemFactory(),
    tooltip: tooltipFactory(),
    shouldSyncShadowColor: false,
    animation: true,
    animationEasing: 'cubicOut',
    animationEasingUpdate: 'cubicOut',
    animationDuration: 1000,
    animationDurationUpdate: 1000,
    animationDelay: 0,
    animationDelayUpdate: 0,
    animationType: 'expansion'
};

export const Tile = {
    show: false,
    text: '',
    color: '#a5a5a5',
    fontFamily: 'Roboto, sans-serif',
    fontSize: 14
};

export const Legend = {
    show: true,
    position: 'right',
    color: '#a5a5a5',
    fontFamily: 'Roboto, sans-serif',
    fontSize: 11,
    itemStyle: {
        borderWidth: 0,
        borderColor: 'rgba(255, 255, 255, 1)'
    }
};

export const Background = {
    show: true,
    gradient: {
        show: false,
        position: 'to top',
        color1: '#ffffff',
        color2: '#ffffff'
    },
    color: '#ffffff'
};

export const FormatOptions = [
    { value: '0', label: '1000' },
    { value: '1', label: '1000,1' },
    { value: '2', label: '1000,12' },
    { value: '3', label: '12%' },
    { value: '4', label: '12,3%' },
    { value: '5', label: '12,34%' }
];

export const SeparatorOptions = [
    { value: '0', label: '10000' },
    { value: '1', label: '10 000' },
    { value: '2', label: '10.000' },
    { value: '3', label: '10,000' }
];

export const TooltipPositionOptions = [
    { label: 'Внутри', value: 'inside' },
    { label: 'Сверху', value: 'top' },
    { label: 'Справа', value: 'right' },
    { label: 'Слева', value: 'left' },
    { label: 'Снизу', value: 'bottom' }
];

export const GradientPositionOptions = [
    { value: 'to top', label: '↑' },
    { value: 'to left', label: '←' },
    { value: 'to right', label: '→' },
    { value: 'to bottom', label: '↓' },
    { value: 'to top left', label: '↖' },
    { value: 'to top right', label: '↗' },
    { value: 'to bottom right', label: '↘' },
    { value: 'to bottom left', label: '↙' }
];

export const Tooltip = {
    isCustomize: false,
    bgColor: '',
    baseStyle: {
        backgroundColor: 'rgba(50,50,50,0.7)',
        borderColor: 'rgba(0,0,0,0)',
        borderWidth: '0'
    },
    textStyle: {
        color: '#ffffff',
        fontSize: '14'
    },
    maxWidth: '100%',
    metrics: []
};

export const TooltipMetric = {
    name: '',
    text: '',
    color: '#ffffff',
    textAlign: 'left',
    fontSize: '1em',
    isString: false,
    separator: ';<br>',
    format: ''
};

export const DRAG_ANIMATION_TIME = 200;

export const LegendManualSizeTemplate = () => ({
    isManualMode: false,
    left: '50%',
    top: '50%',
    right: '50%',
    bottom: '50%'
});

export const toolboxOptionsFactory = () => ({
    show: true,
    itemSize: 16,
    iconStyle: {
        color: 'rgba(102, 102, 102, 1)',
        borderWidth: 0
    },
    emphasis: {
        iconStyle: {
            color: 'rgba(102, 102, 102, 1)'
        }
    },
    feature: {
        myPrevBtn: {
            show: false,
            title: null,
            icon: 'path://M12.5,8C9.85,8 7.45,9 5.6,10.6L2,7V16H11L7.38,12.38C8.77,11.22 10.54,10.5 12.5,10.5C16.04,10.5 19.05,12.81 20.1,16L22.47,15.22C21.08,11.03 17.15,8 12.5,8Z',
            onclick: null
        }
    }
});
