import { convertCssVarToComputedValue } from '@goodt-common/utils';
import Color from 'color';
import { SortTypes } from './constants';

/**
 * @param { string } color
 * @param { number } colorShift
 * @param { number } startLightness
 * @returns { string|null }
 */
export const shiftColorByNumber = ({ color, colorShift, computedStyle }, startLightness = 20) => {
    if (color == null) {
        return null;
    }
    const convertedColor = convertCssVarToComputedValue({ color }, computedStyle);
    const colorData = Color(convertedColor.color.trim()).hsl().lightness(startLightness).object();
    const { l: light } = colorData;
    return Color(colorData)
        .lightness(light + colorShift)
        .string();
};

/**
 * @param { Array } arr
 * @param { string } sortOrder
 */
export const sortSeriesData = (arr, sortOrder) =>
    arr.sort((prev, next) => {
        if (sortOrder === SortTypes.ASC) {
            return prev.name.localeCompare(next.name);
        }
        if (sortOrder === SortTypes.DESC) {
            return next.name.localeCompare(prev.name);
        }
        return 0;
    });

export const formatValues = ({ formatter, val, separator }) => {
    const separators = ['default', 'ru-RU', 'de-DE', 'en-EN'];
    const fixVal = (value, n) => value.toFixed(n);

    function formatNum(num, localeSep, decimal) {
        if (localeSep === 'default') {
            return num;
        }
        return new Intl.NumberFormat(localeSep, { minimumFractionDigits: decimal }).format(num);
    }

    switch (formatter) {
        case '1':
            return formatNum(fixVal(val, 1), separators[separator], 1);
        case '2':
            return formatNum(fixVal(val, 2), separators[separator], 2);
        case '3':
            return fixVal(val, 0);
        case '4':
            return fixVal(val, 1);
        case '5':
            return fixVal(val, 2);
        case '0':
        default:
            return formatNum(fixVal(val, 0), separators[separator], 0);
    }
};

export const resolveFlexDirection = (position) => {
    if (position === 'top') {
        return 'column';
    }

    if (position === 'right') {
        return 'row-reverse';
    }

    if (position === 'bottom') {
        return 'column-reverse';
    }

    return 'row';
};

export const createText = ({ text, postfix = '', prefix = '' }) => `${prefix}${text}${postfix}`;

export const takeRadiusValue = (radiusValue, takeUnit2Px) =>
    Number(radiusValue) === radiusValue || /%$/.test(radiusValue) === true
        ? `${parseFloat(radiusValue)}%`
        : takeUnit2Px({ size: radiusValue });
