/* eslint-disable no-restricted-syntax */
import panels from './panels';
import { TotalPositions } from './utils/constants';
import { cssVars } from './styles/css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        reportApplicationApiUrl: {
            type: String,
            default: '',
            hasConst: true
        },
        height: {
            type: String,
            default: '100'
        },
        rows: {
            type: Array,
            default: () => []
        },
        columns: {
            type: Array,
            default: () => []
        },
        values: {
            type: Array,
            default: () => []
        },
        rowsHeight: {
            type: Number,
            // eslint-disable-next-line no-magic-numbers
            default: 48
        },
        titleHeight: {
            type: Number,
            // eslint-disable-next-line no-magic-numbers
            default: 48
        },
        cellWidth: {
            type: String,
            // eslint-disable-next-line no-magic-numbers
            default: '150px'
        },
        columnsWidth: {
            type: String,
            // eslint-disable-next-line no-magic-numbers
            default: '150px'
        },
        indexesHeight: {
            type: Number,
            // eslint-disable-next-line no-magic-numbers
            default: 32
        },
        isUsedCollapse: {
            type: Boolean,
            default: true
        },
        isUsedIndexes: {
            type: Boolean,
            default: false
        },
        isShownColumnsTotal: {
            type: Boolean,
            default: false
        },
        columnsTotalPosition: {
            type: String,
            default: TotalPositions.END
        },
        isShownRowTotal: {
            type: Boolean,
            default: false
        },
        isDuplicateDimensions: {
            type: Boolean,
            default: true
        },
        shouldBeFixedHeader: {
            type: Boolean,
            default: false
        },
        rowTotalPosition: {
            type: String,
            default: TotalPositions.END
        },
        cssClass: {
            type: Array,
            default: ['bg-white']
        },
        filters: {
            type: Object,
            default: () => ({})
        },
        toolboxButtonBackground: {
            type: String,
            default: ''
        },
        toolboxButtonFontColor: {
            type: String,
            default: ''
        },
        toolboxButtonIconColor: {
            type: String,
            default: ''
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: false,
    cssVars
};

export default descriptor;
