import {
    VerticalAligns,
    HorizontalAligns,
    DRAG_ANIMATION_TIME,
    FieldsPopupDraggableGroupNames,
    AggregateMethodsKeys,
    TotalPositions,
    NumberFormatPatternModifierKeys,
    NumberFormatTypeKeys
} from './constants';

import { calcArraySum, calcArrayAvg, findArrayMax, findArrayMin, uniqArray } from './utils';

export const NumberFormatTypesOptions = [
    { label: 'Число', value: NumberFormatTypeKeys.DECIMAL },
    { label: 'Валюта', value: NumberFormatTypeKeys.CURRENCY }
];

export const NumberFormatPatternModifierOptions = [
    { label: 'Режим проценты', value: NumberFormatPatternModifierKeys.PERCENT },
    { label: 'Компактный режим', value: NumberFormatPatternModifierKeys.COMPACT },
    { label: 'Отображать нули', value: NumberFormatPatternModifierKeys.FIXED }
];

export const VerticalTotalPositionOptions = [
    { label: 'Слева', value: TotalPositions.START },
    { label: 'Справа', value: TotalPositions.END }
];
export const TotalPositionOptions = [
    { label: 'Сверху', value: TotalPositions.START },
    { label: 'Снизу', value: TotalPositions.END }
];

export const HorizontalAlignsOptions = [
    { label: 'Сверху', value: HorizontalAligns.TOP },
    { label: 'Центр', value: HorizontalAligns.CENTER },
    { label: 'Снизу', value: HorizontalAligns.BOTTOM }
];

export const VerticalAlignsOptions = [
    { label: 'Слева', value: VerticalAligns.LEFT },
    { label: 'Центр', value: VerticalAligns.CENTER },
    { label: 'Справа', value: VerticalAligns.RIGHT }
];

export const DraggableOptions = {
    animation: DRAG_ANIMATION_TIME,
    handle: '.drag-handle'
};

export const DimensionsDraggableOptions = {
    animation: DRAG_ANIMATION_TIME,
    handle: '.drag-handle',
    group: 'dimensions'
};

export const FieldsPopupDraggableOptions = {
    animation: DRAG_ANIMATION_TIME,
    handle: '.drag-handle'
};
export const FieldsPopupValuesDraggableOptions = {
    ...FieldsPopupDraggableOptions,
    group: FieldsPopupDraggableGroupNames.METRICS
};
export const FieldsPopupDimensionsDraggableOptions = {
    ...FieldsPopupDraggableOptions,
    group: {
        name: FieldsPopupDraggableGroupNames.FIELDS,
        put: [
            FieldsPopupDraggableGroupNames.FIELDS,
            FieldsPopupDraggableGroupNames.FILTERS,
            FieldsPopupDraggableGroupNames.DIMENSIONS
        ],
        pull: [FieldsPopupDraggableGroupNames.FIELDS, FieldsPopupDraggableGroupNames.FILTERS]
    }
};
export const AllFieldsPopupDraggableOptions = {
    ...FieldsPopupDraggableOptions,
    sort: false
};

export const AllFieldsPopupDimensionsDraggableOptions = {
    ...AllFieldsPopupDraggableOptions,
    group: { name: FieldsPopupDraggableGroupNames.DIMENSIONS, pull: 'clone', put: false }
};
export const AllFieldsPopupMetricsDraggableOptions = {
    ...AllFieldsPopupDraggableOptions,
    group: { name: FieldsPopupDraggableGroupNames.METRICS, pull: 'clone', put: false }
};

/*export const AggregateMethodsOptions = Object.entries(AggregateMethodsKeys).map(([key, val]) => ({
    label: key,
    value: val
}));*/

export const AggregateMethodsOptions = [
    {
        label: 'Значение',
        value: AggregateMethodsKeys.VALUE
    },
    {
        label: 'Сумма',
        value: AggregateMethodsKeys.SUM
    },
    {
        label: 'Количество',
        value: AggregateMethodsKeys.COUNT
    },
    {
        label: 'Среднее',
        value: AggregateMethodsKeys.AVG
    },
    {
        label: 'Максимум',
        value: AggregateMethodsKeys.MAX
    },
    {
        label: 'Минимум',
        value: AggregateMethodsKeys.MIN
    },
    {
        label: 'Группировка с объединением',
        value: AggregateMethodsKeys.GROUP_CONCAT
    },
    {
        label: 'Группировка с объединением уникальных',
        value: AggregateMethodsKeys.GROUP_CONCAT_UNIQ
    }
];

export const AggregateMethodsFunctions = {
    [AggregateMethodsKeys.VALUE]: (values) => values?.[0],
    [AggregateMethodsKeys.SUM]: calcArraySum,
    [AggregateMethodsKeys.COUNT]: (values) => values.length,
    [AggregateMethodsKeys.AVG]: calcArrayAvg,
    [AggregateMethodsKeys.MAX]: findArrayMax,
    [AggregateMethodsKeys.MIN]: findArrayMin,
    [AggregateMethodsKeys.GROUP_CONCAT]: (values) => values,
    [AggregateMethodsKeys.GROUP_CONCAT_UNIQ]: uniqArray
};
