import { runWorker } from './worker';

function generateTableMaps({ data, rowsNames, columnsNames, valuesNames, filtersNames, filtersValues, isUsedFilters }) {
    const uniqValuesNames = valuesNames != null ? utils.uniqArray(valuesNames) : [];
    const filtersValuesMap = isUsedFilters
        ? filtersValues.map((filters) =>
              filters.reduce((acc, key) => {
                  acc[key] = true;
                  return acc;
              }, {})
          )
        : [];
    const rebuildValues = ({ target, values }) =>
        uniqValuesNames.reduce((acc, valueName) => {
            if (acc?.[valueName] == null) {
                acc[valueName] = [];
            }
            acc[valueName].push(values[valueName]);
            return acc;
        }, Object.assign(target ?? {}));
    const updateHeap = ({ heap, row, paths, values, names }) => {
        let heapLevel = heap;
        const columnNames = [];
        for (let i = 0; i < names.length; i++) {
            const name = row[names[i]];
            columnNames.push(name);
            if (heapLevel?.[name] == null) {
                heapLevel[name] = {};
                if (i === names.length - 1) {
                    heap.count = heap?.count != null ? heap.count : 0;
                    heapLevel[name].index = heap.count;
                    heap.count++;
                    paths[heapLevel[name].index] = columnNames;
                }
            }
            heapLevel = heapLevel[name];

            heapLevel.values = rebuildValues({
                target: heapLevel.values,
                values
            });
        }
        return heapLevel;
    };
    const updateFilters = (filters, row) => {
        return filtersNames.reduce(
            (acc, name, i) => {
                if (acc[i] == null) {
                    acc[i] = {};
                }
                acc[i][row[name]] = true;
                return acc;
            },
            filters.map((filter) => Object.assign(filter))
        );
    };
    const checkSkipRow = (row) =>
        isUsedFilters && filtersValuesMap.some((filters, i) => filters?.[row?.[filtersNames[i]]] == null);
    const result = data.reduce(
        ({ rowsHeap, columnsHeap, valuesMap, columnsPaths, rowsPaths, uniqFilters }, row) => {
            uniqFilters = updateFilters(uniqFilters, row);

            if (checkSkipRow(row)) {
                return { rowsHeap, columnsHeap, valuesMap, columnsPaths, rowsPaths, uniqFilters };
            }

            const values = valuesNames.reduce((acc, name) => {
                const { [name]: value } = row;
                acc[name] = Number(value);
                return acc;
            }, {});
            const columnsLevel = updateHeap({
                heap: columnsHeap,
                row,
                paths: columnsPaths,
                values,
                names: columnsNames
            });
            const rowsLevel = updateHeap({
                heap: rowsHeap,
                row,
                paths: rowsPaths,
                values,
                names: rowsNames
            });

            if (valuesMap?.[rowsLevel.index] == null) {
                valuesMap[rowsLevel.index] = {};
            }

            valuesMap[rowsLevel.index][columnsLevel.index] = rebuildValues({
                target: valuesMap[rowsLevel.index][columnsLevel.index],
                values
            });

            valuesMap.rows = rowsHeap.count;
            valuesMap.columns = columnsHeap.count;
            return {
                uniqFilters,
                rowsHeap,
                columnsHeap,
                valuesMap,
                columnsPaths,
                rowsPaths
            };
        },
        {
            rowsHeap: { count: 0 },
            columnsHeap: { count: 0 },
            valuesMap: {},
            columnsPaths: {},
            rowsPaths: {},
            uniqFilters: []
        }
    );
    result.uniqFilters = result.uniqFilters.map((filters) =>
        Object.keys(filters)
            .sort()
            .map((name, id) => ({ id, name, size: constants.FILTER_HEIGHT }))
    );
    return result;
}

export const asyncGenerateTableMaps = ({
    data,
    rowsNames,
    columnsNames,
    valuesNames,
    filtersNames,
    filtersValues,
    isUsedFilters
}) => {
    return runWorker({
        func: generateTableMaps,
        message: { data, rowsNames, columnsNames, valuesNames, filtersNames, filtersValues, isUsedFilters }
    });
};
