import { CellsTypes, TotalPositions, FILTER_HEIGHT } from '../constants';
import { AggregateMethodsFunctions } from '../config';
import { uniqArray } from '../utils';

const AggregateMethodsFunctionsValue = Object.entries(AggregateMethodsFunctions)
    .reduce((acc, [key, func]) => [...acc, `${key}:${func}`], [])
    .join(',');

const workerConstants = `${JSON.stringify({ CellsTypes, TotalPositions, FILTER_HEIGHT })}`;
const workerConfig = `{AggregateMethodsFunctions: {${AggregateMethodsFunctionsValue}}}`;
const workerUtils = `{uniqArray: ${uniqArray}}`;

const buildWorkerHandler = (func) => `  
    const constants = ${workerConstants};
    const config = ${workerConfig};
    const utils = ${workerUtils};
    self.onmessage = function(event) {
      self.postMessage((${func})(event.data.message));
      return close();
    }
`;

const createWorker = ({ func = () => {} }) => {
    const blob = new Blob([buildWorkerHandler(func)], { type: 'application/javascript' });
    const url = window.URL.createObjectURL(blob);
    const worker = new Worker(url);
    worker.disconnect = () => {
        //window.URL.revokeObjectURL(url);
        //worker.terminate();
    };
    return worker;
};

export const runWorker = ({ func = () => {}, message = {} }) => {
    const worker = createWorker({ func });
    return new Promise((resolve, reject) => {
        worker.onmessage = (event) => {
            worker.disconnect();
            resolve(event.data);
        };
        worker.onerror = (e) => {
            worker.disconnect();
            console.error(`Error: Line ${e.lineno} in ${e.filename}: ${e.message}`);
            reject(e);
        };
        worker.postMessage({ message });
    });
};
