const formatNum = (num, localeSep, frDigits) =>
    localeSep === 'default'
        ? num
        : new Intl.NumberFormat(localeSep, {
              minimumFractionDigits: frDigits
          }).format(num);
const calcPercentage = (value, frDigits) =>
    value.toLocaleString(undefined, {
        style: 'percent',
        minimumFractionDigits: frDigits
    });

const fixNum = (num, frDigits) => (num != null ? num.toFixed(frDigits) : num);

const separators = ['default', 'ru-RU', 'de-DE', 'en-EN'];

const availableFormats = {
    0: ({ value, sep }) => formatNum(fixNum(value, 0), sep, 0),
    1: ({ value, sep }) => formatNum(fixNum(value, 1), sep, 1),
    2: ({ value, sep }) => formatNum(fixNum(value, 2), sep, 2),
    '0%': ({ value }) => calcPercentage(value, 0),
    '1%': ({ value }) => calcPercentage(value, 1),
    '2%': ({ value }) => calcPercentage(value, 2)
};

export default {
    tooltipFormatter({ data }) {
        const { format, separator, prefix, postfix, indicators } = this;
        const sep = separators[separator];
        const { name, value } = data;
        const tooltipData = indicators.map((indicator, i) => ({
            indicatorName: indicator.name,
            metricValue: value[i],
            metricName: name
        }));

        const values = tooltipData
            .reduce((arr, { indicatorName, metricValue }) => {
                const tooltipFormat = `${indicatorName}: `;
                const formattedValue = availableFormats[format]({ value: metricValue, sep });
                // if ( formattedValue === 0 || formattedValue === '0%') {
                //     return arr;
                // }
                arr.push(`${tooltipFormat}${prefix}${formattedValue}${postfix}<br/>`);
                return arr;
            }, [])
            .join('');

        return `${name}<br/>${values}`;
    }
};
