const convertToNumber = (item) => {
    if (typeof item === 'number') {
        return item;
    }

    return Number(item.replace(',', '.'));
};

const takeNewDigitCapacity = (str, formatter) => str.replace(/(\d)(?=(\d\d\d)+([^\d]|$))/g, `$1${formatter}`);

const takeMetricDigitCapacity = (num, formatter) => {
    const numStringify = String(num);

    const formatType = {
        0: (value) => value,
        1: (value) => takeNewDigitCapacity(value, ' '),
        2: (value) => {
            const parts = value.split('.');
            const firstPart = takeNewDigitCapacity(parts[0], '.');
            let secondPart = '';
            if (parts[1]) {
                secondPart = takeNewDigitCapacity(parts[1], '.');
            }
            return secondPart ? `${firstPart},${secondPart}` : firstPart;
        },
        3: (value) => takeNewDigitCapacity(value, ',')
    };
    return formatType[formatter](numStringify);
};

const takeFormattedValue = (num, formatter, formatterCapacity) => {
    const format = formatter;
    const numFix = typeof num === 'undefined' ? 0 : Number(num);
    const fixedNumber = convertToNumber(numFix);
    const hundredType = 2;
    let result = null;

    const formatType = {
        n: (value) => value,
        0: (value) => value.toFixed(0),
        1: (value) => value.toFixed(1),
        2: (value) => value.toFixed(hundredType),
        '0%': (value) => `${(value * 100).toFixed(0)}%`,
        '1%': (value) => `${(value * 100).toFixed(1)}%`,
        '2%': (value) => `${(value * 100).toFixed(hundredType)}%`
    };

    result = formatType[format] ? formatType[format](fixedNumber) : fixedNumber;
    result = takeMetricDigitCapacity(result, formatterCapacity);
    return result;
};

const createGradient = (firstColor, secondColor, gradientDirection, offset1, offset2, name = 'Gradient') => {
    const gradPos = gradientDirection.split(' ');
    return `<linearGradient x1="${gradPos[0]}" y1="${gradPos[1]}" x2="${gradPos[2]}" y2="${gradPos[3]}" id="${name}">\n' +
                    '          <stop offset="${offset1}%" stop-color="${firstColor}" />\n' +
                    '          <stop offset="${offset2}%" stop-color="${secondColor}" />\n' +
                    '        </linearGradient>`;
};

const getObjData = (target, attr) => {
    const data = target.getAttribute(attr);
    return {
        el: target,
        data: data.replace(/'/g, '"')
    };
};

export {
    convertToNumber,
    takeFormattedValue,
    takeMetricDigitCapacity,
    takeNewDigitCapacity,
    createGradient,
    getObjData
};
