import { cloneDeep } from 'lodash';

/**
 * @typedef {object} TreeOptions
 * @property {array<object>} data
 * @property {string} start
 * @property {string} end
 */
const TreeOptionsDefault = {
    source: 'Начало',
    target: 'Конец'
};

export class Tree {
    /**
     * @param {TreeOptions} options
     */
    constructor(options = {}) {
        const { data } = { ...options, ...TreeOptionsDefault };

        this.data = data;
        this._treeNodes = null;

        this._init();
    }

    get treeNodes() {
        return this._treeNodes;
    }

    /**
     * @param {array<object>} data
     * @return {object<TreeNode>}
     */
    makeTreeNode(data) {
        const parents = data
            .filter(({ source }) => {
                // eslint-disable-next-line no-restricted-syntax
                const parent = data.find(({ target }) => target === source);
                return parent === undefined;
            })
            .map((item) => ({ ...item, depth: 0 }));

        return this.buildChildrenNode(data, {
            parents
        });
    }

    /**
     * @param {array<object>} data
     * @param {array<object>} parents
     * @param {number} depth
     * @return {object<TreeNode>}
     */
    buildChildrenNode(data, { parents, depth = 1 }) {
        return parents.map((item) => {
            // eslint-disable-next-line no-restricted-syntax
            const children = data.filter(({ source }) => source === item?.target);

            // eslint-disable-next-line no-restricted-syntax
            const treeChildren = children.map((childrenItem) => {
                const newDepth = depth + 1;

                const searchChildren = this.buildChildrenNode(data, {
                    parents: [childrenItem],
                    depth: newDepth
                });

                return { ...childrenItem, depth: newDepth, children: searchChildren };
            });

            return {
                ...item,
                depth,
                children: treeChildren
            };
        });
    }

    /**
     * @param {array<object>} data
     * @param {string} target
     * @param {object} tempObj
     * @return {object<TreeNode>}
     */
    getNodeInTheTree({ data = this._treeNodes, target, tempObj = {} }) {
        if (data == null || target == null) {
            return null;
        }

        data.forEach((node) => {
            if (node?.target === target) {
                tempObj.found = node;
                return node;
            }
            return this.getNodeInTheTree({ data: node?.children, target, tempObj });
        });

        if (tempObj?.found != null) {
            return tempObj.found;
        }

        return null;
    }

    _init() {
        const { data } = this;
        const cloneData = cloneDeep(data);
        const treeNodes = this.makeTreeNode(cloneData);

        this._treeNodes = treeNodes;
    }
}
