function getNumberFormat(val, format, separator) {
    // eslint-disable-next-line no-restricted-syntax
    if (!format || !separator) {
        return val;
    }
    let value = val;
    const fraction = parseInt(format, 10);
    let percentSymbol = '';
    if (format.length > 1) {
        value *= 100;
        percentSymbol = '%';
    }
    value = Number(value.toFixed(fraction));
    if (separator !== '0') {
        value = value.toLocaleString(separator, { minimumFractionDigits: fraction });
    } else {
        value = value.toLocaleString('ru-RU', { minimumFractionDigits: fraction });
        value = value.replace(/\s/g, '');
    }

    return `${value}${percentSymbol}`;
}

function findNodeSum(nodes, alreadySummed, nodeName, { nodeSum, parentNames }) {
    if (alreadySummed.includes(nodeName)) {
        return 0;
    }
    if (parentNames === null) {
        alreadySummed.push(nodeName);
        return nodeSum;
    }
    return parentNames.reduce(
        (acc, parentName) => acc + findNodeSum(nodes, alreadySummed, parentName, nodes[parentName]),
        0
    );
}

export const extractValue = (cssVarOrValue, computedStyles) => {
    const cssVar = `${cssVarOrValue}`.match(/--[-_0-9a-zA-Z%]+/)?.[0];
    return cssVar != null ? computedStyles.getPropertyValue(cssVar) : cssVarOrValue;
};

export const extractTooltipValue = (cssVarOrValue, computedStyles) => {
    const regExps = {
        REMS: /(?<=\d+)(rem)$/,
        EMS: /(?<=\d+)(em)$/,
        PXS: /px/,
        PERCENTS: /%$/
    };
    const cssVar = `${cssVarOrValue}`.match(/--[-_0-9a-zA-Z%]+/)?.[0];
    const trimmedCssVar = computedStyles.getPropertyValue(cssVar).replace(/[a-z]/g, '');
    const convertRemsToPixels = (rems) => rems * parseFloat(getComputedStyle(document.documentElement).fontSize);
    const convertEmsToPixels = (ems) => ems * parseFloat(getComputedStyle(document.documentElement).fontSize);

    if (cssVar != null) {
        return convertRemsToPixels(trimmedCssVar);
    }
    const trimmedValue = cssVarOrValue.replace(/[a-z]/g, '');
    const computeSizeUnit = (sizeUnit) =>
        Object.keys(regExps)
            .map((e) => sizeUnit.match(regExps[e])?.[0])
            .reduce((acc, e) => (e === undefined ? acc : e), '');
    if (computeSizeUnit(cssVarOrValue) === 'px') {
        return trimmedValue;
    }
    if (computeSizeUnit(cssVarOrValue) === '%') {
        return cssVarOrValue;
    }
    if (computeSizeUnit(cssVarOrValue) === 'em') {
        return convertEmsToPixels(trimmedValue);
    }
    if (computeSizeUnit(cssVarOrValue) === 'rem') {
        return convertRemsToPixels(trimmedValue);
    }
    return '';
};

export const resolveItemStyleValues = (styles) =>
    Object.entries(styles).reduce((acc, [key, value]) => ({ ...acc, [key]: value !== '' ? value : null }), {});

export { getNumberFormat, findNodeSum };
