import { TooltipDefaultFactory } from '@goodt-wcore/components';
import panels from './panels';
import { echartsObj, MetricDimensionEnum, toolboxOptionsFactory, rippleOptionsFactory } from './constants';
import { buildLabelStyles } from './utils/utils';

const descriptor = () => ({
    props: {
        width: {
            type: String,
            default: '100'
        },
        widthUnit: {
            type: String,
            default: '%'
        },
        height: {
            type: String,
            default: '60'
        },
        heightUnit: {
            type: String,
            default: 'rem'
        },
        dremio: {
            type: Object,
            default: null
        },
        echarts: {
            type: Object,
            default() {
                return echartsObj;
            }
        },
        dataZoomSettings: {
            type: Array,
            default: () => [
                {
                    shouldChangePosition: false,
                    left: 'center',
                    top: 'bottom',
                    right: 'auto',
                    bottom: 'auto'
                },
                {
                    shouldChangePosition: false,
                    left: 'right',
                    top: 'middle',
                    right: 'auto',
                    bottom: 'auto'
                }
            ]
        },
        pointsLabelSettings: {
            type: Object,
            default: () => ({
                isVisible: false,
                position: 'top',
                labelStyles: [
                    buildLabelStyles(MetricDimensionEnum.X_AXIS),
                    buildLabelStyles(MetricDimensionEnum.Y_AXIS),
                    buildLabelStyles(MetricDimensionEnum.DIMENSION),
                    buildLabelStyles(MetricDimensionEnum.LEGEND)
                ],
                // eslint-disable-next-line no-restricted-syntax
                offset: [0, 0]
            })
        },
        customTooltip: {
            type: Object,
            default: TooltipDefaultFactory
        },
        toolbox: {
            type: Object,
            default: toolboxOptionsFactory
        },
        selectedDimension: {
            type: String,
            default: ''
        },
        isDrilldown: {
            type: Boolean,
            default: false
        },
        ripple: {
            type: Object,
            default: rippleOptionsFactory
        }
    }
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: true,
    slotNames: ['tooltip']
};
