export const buildLabelStyles = (name) => ({
    show: name === 'xAxis',
    shouldSyncLabelColor: false,
    color: '#333',
    fontFamily: '',
    fullFontSize: '16px',
    fontWeight: 'normal',
    align: 'center',
    longValuesLength: 0,
    name,
    format: ''
});

export function setShadowStyle(style, shadowSettings) {
    const istyle = shadowSettings?.isShadow
        ? {
              ...style,
              ...shadowSettings,
              shadowColor: shadowSettings.shouldSyncShadowColor ? style.color : shadowSettings.shadowColor,
              ...(style.isGradient && {
                  shadowColor: shadowSettings.shouldSyncShadowColor
                      ? style.gradientColor.colorStops[1].color
                      : shadowSettings.shadowColor
              })
          }
        : {
              ...style,
              shadowColor: 'transparent'
          };
    return istyle;
}

export const getMaxAndMinValues = (values) => ({
    max: Math.max(...values),
    min: Math.min(...values)
});

export const calculateSymbolSize = (defaultSymbolSize, sizesRange, coefficient, maxSize, minSize) => {
    const percent = (sizesRange / coefficient) * 100;
    const symbolSizeResult =
        sizesRange > 0 && coefficient > 0 ? ((maxSize - minSize) * percent) / 100 + Number(minSize) : Number(minSize);

    return defaultSymbolSize === 0 ? symbolSizeResult : defaultSymbolSize;
};

export const splitStrByWord = ({ longValuesLength, str }) =>
    longValuesLength === 0 || longValuesLength == null
        ? str
        : str
              .split(/\s+/g)
              .reduce(
                  (acc, word) =>
                      acc[acc.length - 1] === undefined ||
                      acc[acc.length - 1].length >= longValuesLength ||
                      acc[acc.length - 1].length + word.length + 1 > longValuesLength
                          ? [...acc, word]
                          : [...acc.slice(0, acc.length - 1), `${acc[acc.length - 1]} ${word}`],
                  []
              )
              .join('\n');
