import Color from 'color';
import { convertCssVarToComputedValue } from '@goodt-common/utils';
import { GradientPositionOptions } from '../config';
/**
 * @param { Object } dremioResult
 * @param { string } dimension
 * @param { Object } metrics
 * @return { Object }
 */
export const getDremioDimensionMetrics = ({ rows, dimension, metrics }) =>
    rows.reduce(
        (acc, row) => ({
            ...acc,
            [row[dimension]]: metrics.reduce(
                (accMetrics, metric) => ({
                    ...accMetrics,
                    [metric]:
                        acc[row[dimension]] === undefined
                            ? [row[metric]]
                            : [...acc[row[dimension]][metric], row[metric]]
                }),
                {}
            )
        }),
        {}
    );
/**
 * @param { string } color
 * @param { number } number
 * @returns { string }
 */
export const shiftColorByNumber = ({ color, number, computedStyle }) => {
    const convertedColor = convertCssVarToComputedValue({ color }, computedStyle);
    const colorData = Color(convertedColor.color);
    const { l: light } = colorData.hsl().object();
    return colorData.lightness(light + number).string();
};

/**
 * @param { string } name
 * @param { string } value
 * @param { boolean } isShowName
 * @param { boolean } isShowValue
 * @returns { string }
 */
export const buildLabelFormatterString = ({ name, value, isShowName, isShowValue }) => {
    const patterns = [];
    if (isShowName) {
        patterns.push(`{name|${name}}`);
    }
    if (isShowValue) {
        patterns.push(`{value|${value}}`);
    }
    return [...(isShowName ? [`{name|${name}}`] : []), isShowValue ? `{value|${value}}` : []].join('\n');
};
/**
 * @param { string } text
 * @param { string } value
 * @param { string } color
 * @param { string } textAlign
 * @param { string } fontSize
 * @param { string } maxWidth
 * @returns { string }
 */
export const buildTooltipContent = ({ text, value, styles: { color, textAlign, fontSize, maxWidth } }) =>
    `<div style="${Object.entries({
        color,
        'text-align': textAlign,
        'font-size': fontSize,
        'max-width': maxWidth,
        'white-space': 'normal'
    })
        .map(([key, val]) => `${key}:${val};`)
        .join('')}">${text}${value}</div>`;

/**
 * @param { number } firstOffset
 * @param { number } secondOffset
 * @param { string } firstColor
 * @param { string } secondColor
 * @param { string } position
 * @return {{x: string, y: string, y2: string, x2: string, colorStops: [{offset: number, color: string}, {offset: number, color: string}], type: string}}
 */
export const buildColorGradient = ({ firstOffset, secondOffset, firstColor, secondColor, position }) => {
    // eslint-disable-next-line id-length
    const [x, y, x2, y2] = position.split(' ');

    return {
        type: 'linear',
        x,
        y,
        // eslint-disable-next-line id-length
        x2,
        // eslint-disable-next-line id-length
        y2,
        colorStops: [
            {
                offset: firstOffset,
                color: firstColor
            },
            {
                offset: secondOffset,
                color: secondColor
            }
        ]
    };
};

// eslint-disable-next-line id-length
export const findGradientPositionDeg = (position) => {
    const { deg } = GradientPositionOptions.find(({ value }) => value === position);
    return deg;
};

export const buildTooltipColoredContent = ({ color, name, value }) => {
    const background =
        typeof color === 'string'
            ? color
            : `linear-gradient(${findGradientPositionDeg(
                  [color.x, color.y, color.x2, color.y2].join(' ')
              )}deg, ${color.colorStops.map(({ color: stopColor }) => stopColor).join(',')})`;
    return `<div style="display:inline-block; width: 10px; height: 10px; border-radius: 10px; background: ${background}"></div> ${name}: ${value}`;
};
