import panels from './panels';

import { DEFAULT_SIDE_BAR_POSITION } from './constants';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 */
export const descriptor = () => ({
    props: {
        'open-behaviour': {
            type: String,
            default: 'click'
        },
        buttonOpenClose: {
            type: Object,
            default() {
                return {
                    openCloseByButton: true,
                    showCaption: true,
                    isBackground: true,
                    isBorder: true,
                    style: {
                        'justify-content': 'flex-start',
                        'font-size': '0.875rem',
                        color: '#0048ba',
                        background: 'linear-gradient(0.25turn, #3f87a6, #ebf8e1, #f69d3c)',
                        'border-color': 'gold',
                        'border-width': '0.125rem',
                        'border-style': 'solid',
                        'border-radius': '0.25rem'
                    },
                    vertical: 'bottom',
                    textOpenState: 'Свернуть',
                    textCloseState: 'Развернуть'
                };
            }
        },
        'arrow-left-class': {
            type: String,
            default: 'mdi-arrow-left-circle-outline'
        },
        'arrow-right-class': {
            type: String,
            default: 'mdi-arrow-right-circle-outline'
        },
        'sidebars-pos': {
            type: String,
            default: DEFAULT_SIDE_BAR_POSITION
        },
        'sidebars-margin': {
            type: String,
            default: '1rem'
        },
        anim: {
            type: Object,
            default() {
                return { duration: '0.4s', timingFunc: 'linear', delay: '0s' };
            }
        },
        arrSideBars: {
            type: Array,
            default() {
                return [];
            }
        },
        isShadowBackground: {
            type: Boolean,
            default: false
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    slotNames(vm) {
        return [...vm.props.arrSideBars.map((el) => [`close-${el.uid}`, `open-${el.uid}`]).flat()];
    },
    isChildAllowed: true,
    cssVars: {
        'shadow-width': ({ arrSideBars }) => `max(${arrSideBars.map(({ closeWidth }) => closeWidth).join(',')})`,
        'side-transition': ({ anim: { duration, timingFunc, delay } }) => `all ${duration} ${timingFunc} ${delay}`
    }
};

export default descriptor;
