import dayjs from 'dayjs';
import utc from 'dayjs/plugin/utc';
dayjs.extend(utc);

export default function (list) {
    return [
        {
            id: 1,
            name: 'date_from',
            title: 'Дата заполнения',
            value: row => row.date_from && dayjs(row.date_from).format('DD.MM.YYYY'),
            type: Date
        },
        {
            id: 2,
            name: 'legal_address',
            title: 'Субъект РФ',
            value: row => row.legal_address,
            type: String
        },
        {
            id: 3,
            name: 'school_name',
            title: 'Полное наименование школы',
            value: row => row.school_name,
            type: String,
            list: 'schoolNames'
        },
        {
            id: 4,
            name: 'school_inn',
            title: 'ИНН школы',
            value: row => row.school_inn,
            type: Number,
            notStrict: true
        },
        {
            id: 5,
            name: 'has_hot_free_junior_meals',
            title: 'Горячее бесплатное питание для начальных классов по факту организовано?',
            value: row =>
                list &&
                list.find(x => x.id == row.has_hot_free_junior_meals) &&
                list.find(x => x.id == row.has_hot_free_junior_meals).name,
            type: String,
            list: 1
        },
        {
            id: 6,
            name: 'hot_food_form_name',
            title: 'Форма горячего питания',
            value: row => row.hot_food_form_name,
            type: String,
            list: 2
        },
        {
            id: 7,
            name: 'supplier_form_legal_type',
            title: 'Юридическое/Физическое лицо',
            value: row => row.supplier_form_legal_type && row.supplier_form_legal_type.name,
            type: String,
            list: 3
        },
        {
            id: 8,
            name: 'supplier_inn',
            title: 'ИНН поставщика',
            value: row => row.supplier_inn,
            type: Number
        },
        {
            id: 9,
            name: 'member_fio',
            title: 'Наименование участника/ФИО',
            value: row => row.member_fio,
            type: String
        },
        {
            id: 10,
            name: 'supplier_form_supplier_type',
            title: 'Функциональная роль',
            value: row => row.supplier_form_supplier_type && row.supplier_form_supplier_type.name,
            type: String,
            list: 4
        },
        {
            id: 11,
            name: 'supplier_form_food_type',
            title: 'Виды сырья для приготовления готовых блюд',
            value: row => row.supplier_form_food_type && row.supplier_form_food_type.name,
            type: String,
            list: 5
        },
        {
            id: 12,
            name: 'supplier_form_profuder_type',
            title: 'Регион производства сырья',
            value: row => row.supplier_form_profuder_type && row.supplier_form_profuder_type.name,
            type: String,
            list: 6
        },
        {
            id: 13,
            name: 'supply_size',
            title: 'Объем поставок, кг',
            value: row => row.supply_size,
            type: Number
        },
        {
            id: 14,
            name: 'price',
            title: 'Стоимость',
            value: row => row.price,
            type: Number
        }
    ];
}
