import panels from './panels';
import { TruncateOptions } from './constants';

export const Events = Object.freeze({
    UPDATE: 'updateEvent'
});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({
    ORGUNIT_ID: 'orgunitID',
    ORGUNIT_SELECT: 'orgunit-select'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default() {
                return null;
            }
        },
        clouds: {
            type: Array,
            default() {
                return [];
            }
        },
        fontSize: {
            type: String,
            default: '16px'
        },
        fontFamily: {
            type: String,
            default: 'Roboto, sans-serif'
        },
        octotorp: {
            type: Boolean,
            default: false
        },
        inOutLine: {
            type: Boolean,
            default: false
        },
        height: {
            type: Number,
            default: 100
        },
        heightUnit: {
            type: String,
            default: '%'
        },
        isSeparateTags: {
            type: Boolean,
            default: false
        },
        tagsInRowChecked: {
            type: Boolean,
            default: false
        },
        numberOfTagsInRow: {
            type: Number,
            default: 3
        },
        truncate: {
            type: Object,
            default: () => TruncateOptions
        },
        isCloudOctotorp: {
            type: Boolean,
            default: false
        },
        conditionMetricStyle: {
            type: Object,
            default() {
                // eslint-disable-next-line no-restricted-syntax
                return { type: null, value: '', style: [] };
            }
        },
        postfix: {
            type: Object,
            default: () => ({
                isPostfix: false,
                size: '12px',
                color: 'var(--color-white)',
                margin: '0px'
            })
        },
        updateEvent: {
            type: String,
            default: ''
        }
    },
    events: {
        [Events.UPDATE]: {
            listen: 'updateEvent'
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    cssVars: {
        size_postfix: 'postfix.size',
        margin_postfix: 'postfix.margin'
    }
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: false,
    slotNames: []
};

export default descriptor;
