import { TooltipDefaultFactory } from '@goodt-wcore/components';
import panels from './panels';
import {
    BreadcrumbsOptions,
    ColorsByRules,
    DrilldownOptions,
    EmphasisOptions,
    LevelsOptions,
    MainLabelOptions,
    SunburstDiagramOptions,
    TreeMapOptions,
    UpperLabelIconOptions,
    UpperLabelOptions,
    OtherDimensionLabelStyles
} from './constants';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

export const Events = Object.freeze({
    CLICK_BY_DIMENSION: 'clickByDimension'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        width: {
            type: String,
            default: ''
        },
        widthUnit: {
            type: String,
            default: ''
        },
        height: {
            type: String,
            default: '100'
        },
        heightUnit: {
            type: String,
            default: '%'
        },
        treeMapEcharts: {
            type: Object,
            default: () => TreeMapOptions
        },
        events: {
            type: Array,
            default: () => ({
                [Events.CLICK_BY_DIMENSION]: 'click'
            })
        },
        sunburstDiagram: {
            type: Object,
            default: SunburstDiagramOptions
        },
        levels: {
            type: Object,
            default: LevelsOptions
        },
        breadcrumb: {
            type: Object,
            default: BreadcrumbsOptions
        },
        upperLabel: {
            type: Object,
            default: UpperLabelOptions
        },
        upperLabelIcon: {
            type: Object,
            default: UpperLabelIconOptions
        },
        drilldown: {
            type: Object,
            default: DrilldownOptions
        },
        emphasis: {
            type: Object,
            default: EmphasisOptions
        },
        mainLabel: {
            type: Object,
            default: MainLabelOptions
        },
        labels: {
            type: Array,
            default: () => []
        },
        canZoom: {
            type: Boolean,
            default: false
        },
        colorsByRules: {
            type: Object,
            default: ColorsByRules
        },
        customTooltip: {
            type: Object,
            default: TooltipDefaultFactory
        },
        numberOfDimensionsAfterMerge: {
            type: [String, Number],
            default: 'all'
        },
        isUniteRestDimensions: {
            type: Boolean,
            default: false
        },
        otherDimensionsStyles: {
            type: Object,
            default: OtherDimensionLabelStyles
        }
    },
    events: {
        [Events.CLICK_BY_DIMENSION]: {
            trigger: `events['${Events.CLICK_BY_DIMENSION}']`
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor,
    panels,
    cssVars,
    isChildAllowed: true,
    slotNames: ['tooltip']
};
