/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default() {
                return null;
            }
        },
        treeExterior: {
            type: Array,
            default() {
                return [];
            }
        },
        metricWidthUnit: {
            type: String,
            default: 'rem'
        },
        metricFontSizeUnit: {
            type: String,
            default: 'rem'
        },
        selectedDimension: {
            type: String,
            default: ''
        },
        selectedNameTask: {
            type: String,
            default: ''
        },
        selectedAllSteps: {
            type: String,
            default: ''
        },
        selectedCurrentStep: {
            type: String,
            default: ''
        },
        selectedProgress: {
            type: String,
            default: ''
        },
        selectedFIO: {
            type: String,
            default: ''
        },
        selectedText: {
            type: String,
            default: ''
        },
        selectedImage: {
            type: String,
            default: ''
        },
        selectedParentID: {
            type: String,
            default: ''
        },
        selectedTaskID: {
            type: String,
            default: ''
        },
        treeSettings: {
            type: Array,
            default() {
                return [];
            }
        },
        cardRightPartWidth: {
            type: Number,
            default: 25
        },
        cardRightPartUnit: {
            type: String,
            default: 'rem'
        },
        cardOpenHeight: {
            type: Number,
            default: 4
        },
        cardOpenHeightUnit: {
            type: String,
            default: 'rem'
        },
        cardCloseHeight: {
            type: Number,
            default: 1
        },
        cardCloseHeightUnit: {
            type: String,
            default: 'rem'
        },
        cardMarginTop: {
            type: Number,
            default: 0.15
        },
        cardMarginTopUnit: {
            type: String,
            default: 'rem'
        },
        marginBetweenCard: {
            type: Number,
            default: 1
        },
        marginBetweenCardUnit: {
            type: String,
            default: 'rem'
        },
        enableStepByStep: {
            type: Boolean,
            default: false
        },
        imageStep: {
            type: String,
            default: ''
        },
        indicator: {
            type: String,
            default: ''
        },
        enableTooltip: {
            type: Boolean,
            default: false
        },
        tooltip: {
            type: Array,
            default() {
                return [];
            }
        },
        tooltipSettings: {
            type: Object,
            default() {
                return {};
            }
        },
        orderSteps: {
            type: String,
            default: ''
        },
        showErrors: {
            type: Boolean,
            default: false
        },
        progressStepTitleWidth: {
            type: String,
            default: ''
        },
        progressStepTitleBackGround: {
            type: String,
            default: ''
        },
        progressStepTitleFontSize: {
            type: String,
            default: ''
        },
        progressStepTitleColor: {
            type: String,
            default: 'rgb(0, 0, 0)'
        },
        progressStepTitleMetrics: {
            type: Array,
            default() {
                return [];
            }
        },
        isEnableProgressStepTitles: {
            type: Boolean,
            default: false
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    cssVars: {
        'card-right-side_width': ({ cardRightPartWidth, cardRightPartUnit }) =>
            `${cardRightPartWidth}${cardRightPartUnit}`,
        'card-closed-state_height': ({ cardCloseHeight, cardCloseHeightUnit }) =>
            `${cardCloseHeight}${cardCloseHeightUnit}`,
        'card-opened-state_height': ({ cardOpenHeight, cardOpenHeightUnit }) =>
            `${cardOpenHeight}${cardOpenHeightUnit}`,
        'card-indent_margin-top': ({ cardMarginTop, cardMarginTopUnit }) => `${cardMarginTop}${cardMarginTopUnit}`,
        'card_margin-bottom': ({ marginBetweenCard, marginBetweenCardUnit }) =>
            `${marginBetweenCard}${marginBetweenCardUnit}`,
        'progress-step-title_width': 'progressStepTitleWidth',
        'progress-step-title_bg-color': 'progressStepTitleBackGround',
        'progress-step-title_font-size': 'progressStepTitleFontSize',
        'progress-step-title_color': 'progressStepTitleColor'
    }
});

export const createTreeNodeCssVarsByTierMap = (tier) => ({
    'node-button_size': ({ treeSettings }) => `${treeSettings[tier].buttonSize}${treeSettings[tier].buttonSizeUnit}`,
    'node-button_bg-color': `treeSettings[${tier}].buttonColor`,
    'node-button-icon_font-size': ({ treeSettings }) =>
        `${treeSettings[tier].buttonIconFontSize}${treeSettings[tier].buttonIconFontSizeUnit}`,
    'node-button-icon_color': `treeSettings[${tier}].buttonIconColor`,
    'node-button-metric_color': `treeSettings[${tier}].buttonMetricColor`,
    'node-button-metric_font-size': ({ treeSettings }) =>
        `${treeSettings[tier].buttonMetricFontSize}${treeSettings[tier].buttonMetricFontSizeUnit}`,
    'node_bg-color': `treeSettings[${tier}].cardBackGround`,
    'node_margin-top': ({ treeSettings }) =>
        `${treeSettings[tier].progressMarginTop}${treeSettings[tier].progressMarginTopUnit}`,
    'node-title_font-size': ({ treeSettings }) =>
        `${treeSettings[tier].textProgressFontSize}${treeSettings[tier].textProgressFontSizeUnit}`,
    'node-title_color': `treeSettings[${tier}].textProgressColor`,
    'node-title_margin-bottom': ({ treeSettings }) =>
        `${treeSettings[tier].textProgressMargin}${treeSettings[tier].textProgressMarginUnit}`,
    'node-progress-bar_height': ({ treeSettings }) =>
        `${treeSettings[tier].progressHeight}${treeSettings[tier].progressHeightUnit}`,
    'node-progress-bar_margin-left': ({ treeSettings }) =>
        `${treeSettings[tier].nameMargin}${treeSettings[tier].nameMarginUnit}`,
    'node-progress-step_bg-color': `treeSettings[${tier}].progressBackground`,
    'node-progress-step_margin-left': ({ treeSettings }) =>
        `${treeSettings[tier].progressMargin}${treeSettings[tier].progressMarginUnit}`,
    'node-progress-avatar_size': ({ treeSettings }) =>
        `${treeSettings[tier].imageHeight}${treeSettings[tier].imageHeightUnit}`,
    'node-progress-avatar_border-color': `treeSettings[${tier}].indicatorBorder`,
    'node-progress-avatar-full-name_font-size': ({ treeSettings }) =>
        `${treeSettings[tier].FIOFontSize}${treeSettings[tier].FIOFontSizeUnit}`,
    'node-progress-avatar-full-name_color': `treeSettings[${tier}].FIOColor`,
    'node-progress-avatar-full-name_width': ({ treeSettings }) =>
        `${treeSettings[tier].textFIOWidth}${treeSettings[tier].textFIOWidthUnit}`,
    'node-progress-avatar-step-text_color': `treeSettings[${tier}].stepColor`,
    'node-progress-avatar-step-text_font-size': ({ treeSettings }) =>
        `${treeSettings[tier].stepFontSize}${treeSettings[tier].stepFontSizeUnit}`
});

export default descriptor;
