import { LayerSettingsTemplate } from './constants';

const createLayerSettingsTemplate = () => ({ ...LayerSettingsTemplate });

const createStepNameList = (selectedMetric, dremioRow) => {
    if (!dremioRow[selectedMetric]) {
        return [];
    }

    const titleList = dremioRow[selectedMetric].split(/,?(\d+)\.\s+/);
    const numberAndTitleList = titleList.splice(1, titleList.length - 1);

    const { serialNumbers, titles } = numberAndTitleList.reduce(
        (result, item, index) => {
            const isEvenIndex = !(index % 2);

            if (isEvenIndex) {
                result.serialNumbers.push(item);
            } else {
                result.titles.push(item);
            }

            return result;
        },
        {
            serialNumbers: [],
            titles: []
        }
    );

    return serialNumbers.reduce((result, number, index) => {
        result.push(`${number}. ${titles[index]}`);
        return result;
    }, []);
};

const takeAllStepsCount = (selectedMetric, dremioRow) => {
    const isAllSteps = dremioRow[selectedMetric];
    if (isAllSteps == null) {
        return 0;
    }

    return dremioRow[selectedMetric];
};

const buildMetricList = (selectedMetric, dremioRow) => {
    if (!dremioRow[selectedMetric]) {
        return [];
    }

    return dremioRow[selectedMetric].split(',').map((value) => Number(value));
};

const buildSortedMetricsByOrder = (order, imageSteps, outDatedSteps, progress, stepTitles) => {
    if (order.length === 0) {
        return {
            steps: imageSteps,
            outDatedSteps,
            progress,
            stepTitles
        };
    }

    const sortedMetrics = order
        .reduce(
            (result, serialNumber, index) => [
                ...result,
                {
                    imageStep: imageSteps[index],
                    outDate: outDatedSteps[index],
                    progress: progress[index],
                    stepTitles: stepTitles[index],
                    index: serialNumber
                }
            ],
            []
        )
        .sort((a, b) => a.index - b.index);

    return sortedMetrics.reduce(
        (result, metrics) => {
            result.steps = [...result.steps, metrics.imageStep];
            result.outDatedSteps = [...result.outDatedSteps, metrics.outDate];
            result.progress = [...result.progress, metrics.progress];
            result.stepTitles = [...result.stepTitles, metrics.stepTitles];

            return result;
        },
        {
            steps: [],
            outDatedSteps: [],
            progress: [],
            stepTitles: []
        }
    );
};

const createTreeExteriorTemplate = (name) => ({
    name,
    metricWidth: 1,
    metricColor: '#000000',
    metricFontSize: 1,
    prefix: '',
    isImage: false,
    imageSize: '40px',
    imageBorderRadius: '50%',
    metricWidthUnit: 'rem',
    metricFontSizeUnit: 'rem'
});

export {
    createStepNameList,
    takeAllStepsCount,
    buildMetricList,
    buildSortedMetricsByOrder,
    createTreeExteriorTemplate,
    createLayerSettingsTemplate
};
