/* eslint-disable no-magic-numbers */
/* eslint-disable no-restricted-syntax */

import { GradientPositionOptions, SortOptions, DimensionValueFormats } from './config';

export const DEFAULT_VOID_VALUE = '-';
export const STACK_NAME = 'Total';
export const SERIES_TYPE = 'bar';
export const SERIES_SILENT = true;
export const MAIN_SILENT = false;

export const DiagramBarTypeNames = {
    PLUS: 'plus',
    MINUS: 'minus',
    ADDITIONAL: 'additional'
};

export const DiagramBarNames = {
    PLUS: 'Положительные',
    MINUS: 'Отрицательные',
    ADDITIONAL: 'Дополнительные'
};

export const createGradient = ({
    isUsed = false,
    firstOffset = 0,
    secondOffset = 1,
    firstColor = '#000000',
    secondColor = '#ff0000',
    position = GradientPositionOptions[3].value
} = {}) => ({
    isUsed,
    firstOffset,
    secondOffset,
    firstColor,
    secondColor,
    position
});

export const createBar = ({
    name = '',
    isUsed = false,
    isAfter = false,
    dimension = '',
    value = 0,
    isTotal = true
} = {}) => ({
    isUsed,
    isAfter,
    name,
    dimension,
    value,
    isTotal
});

export const createLabelOptions = ({
    isShown = true,
    color = '',
    text = '',
    fontFamily = 'Roboto',
    fontSize = '12',
    align = 'center',
    format = '',
    prefix = createLabelOptions({ prefix: null, postfix: null }),
    postfix = createLabelOptions({ prefix: null, postfix: null })
} = {}) => ({
    isShown,
    color,
    text,
    fontFamily,
    fontSize,
    format,
    align,
    prefix,
    postfix
});

export const MetricOptionsTemplate = () => ({
    isShownLabelData: {
        [DiagramBarTypeNames.PLUS]: {
            name: true,
            value: true
        },
        [DiagramBarTypeNames.MINUS]: {
            name: true,
            value: true
        },
        [DiagramBarTypeNames.ADDITIONAL]: {
            name: true,
            value: true
        }
    },
    labelDataOptions: {
        types: {
            [DiagramBarTypeNames.PLUS]: {
                isShown: true,
                position: 'top',
                name: createLabelOptions(),
                value: createLabelOptions()
            },
            [DiagramBarTypeNames.MINUS]: {
                isShown: true,
                position: 'top',
                name: createLabelOptions(),
                value: createLabelOptions()
            },
            [DiagramBarTypeNames.ADDITIONAL]: {
                isShown: true,
                position: 'top',
                name: createLabelOptions(),
                value: createLabelOptions()
            }
        },
        maxLabelLength: 10
    },
    colors: {
        [DiagramBarTypeNames.PLUS]: '#00ff00',
        [DiagramBarTypeNames.MINUS]: '#ff0000',
        [DiagramBarTypeNames.ADDITIONAL]: '#333333'
    },
    gradient: {
        [DiagramBarTypeNames.PLUS]: createGradient(),
        [DiagramBarTypeNames.MINUS]: createGradient(),
        [DiagramBarTypeNames.ADDITIONAL]: createGradient()
    },
    conditions: {},
    additionalBars: {
        start: createBar(),
        end: createBar(),
        others: []
    },
    generalOptions: {
        barWidth: '50',
        barMinWidth: 1,
        barMaxWidth: 20,
        barMinHeight: 1
    }
});

export const DimensionOptionsTemplate = () => ({
    format: DimensionValueFormats[0].value,
    sort: SortOptions[0].value
});

export const DiagramStateNames = {
    DEFAULT: 'DEFAULT',
    POSITIVE_TO_NEGATIVE: 'POSITIVE_TO_NEGATIVE',
    NEGATIVE_TO_POSITIVE: 'NEGATIVE_TO_POSITIVE',
    POSITIVE_PLUS: 'POSITIVE_PLUS',
    POSITIVE_MINUS: 'POSITIVE_MINUS',
    NEGATIVE_PLUS: 'NEGATIVE_PLUS',
    NEGATIVE_MINUS: 'NEGATIVE_MINUS'
};
export const SeriesTypeNames = {
    POSITIVE: 'POSITIVE',
    NEGATIVE: 'NEGATIVE',
    TOTAL: 'TOTAL'
};

export const ChartOptions = {
    grid: {
        left: '15',
        right: '15',
        bottom: '15',
        containLabel: true
    },
    xAxis: {
        type: 'category',
        offset: 10,
        splitLine: { show: false }
    },
    yAxis: {
        type: 'value'
    }
};

export const LegendTemplate = () => ({
    show: false,
    type: 'scroll',
    position: 'top',
    bottom: null,
    top: 0,
    left: 'center',
    padding: [5, 45, 5, 5],
    textStyle: {
        fontSize: '12',
        fontFamily: 'sans-serif',
        color: '#000'
    }
});

export const LegendManualSizeTemplate = () => ({
    isManualMode: false,
    left: '50%',
    top: '50%',
    right: '50%',
    bottom: '50%'
});

export const AxisTemplate = () => ({
    typeAxis: 'x',
    showAxisName: false,
    silent: true,
    triggerEvent: false,
    id: 0,
    type: 'value',
    format: 'value',
    boundaryGap: [0, 0],
    hasGap: true,
    isFullPercentageScale: true,
    calcMinMax: true,
    manualMinMax: false,
    min: 0,
    max: null,
    isRoundedDynamicMinValue: true,
    isRoundedDynamicMaxValue: true,
    dynamicMinValue: 25,
    dynamicMaxValue: 25,
    minValue: 0,
    maxValue: 100,
    enableMax: false,
    name: 'name',
    show: true,
    position: 'left',
    axisSplitNum: null,
    inverse: false,
    scale: false,
    offset: 0,
    nameTextStyle: {
        color: '#000000'
    },
    nameLocation: 'middle',
    nameGap: 20,
    nameRotate: 0,
    valueFontSize: '12',
    interval: 0,
    axisLabel: {
        show: true,
        margin: 8,
        interval: 0,
        fontFamily: 'sans-serif',
        color: 'rgba(0, 0, 0, 0.4)',
        backgroundColor: 'transparent',
        rotate: 0,
        format: '0',
        separator: '1',
        formatter: null,
        longValuesLength: 0,
        rich: {},
        type: 'text',
        imageMetric: '',
        imageHeight: 24
    },
    axisLine: {
        show: false,
        lineStyle: {
            color: 'rgba(0, 0, 0, 0.4)',
            width: 2
        }
    },
    axisTick: {
        show: false
    },
    axisPointer: {
        show: false
    },
    splitLine: {
        show: true,
        lineStyle: {
            color: 'rgba(0, 0, 0, 0.4)',
            type: 'dashed'
        }
    }
});

export const Axes = [
    {
        ...AxisTemplate(),
        type: 'category',
        boundaryGap: true,
        position: 'bottom',
        splitLine: {
            show: true,
            lineStyle: {
                type: 'solid',
                color: 'rgba(0, 0, 0, 0.3)'
            }
        },
        splitNumber: 0
    },
    {
        ...AxisTemplate(),
        typeAxis: 'y',
        nameGap: 25,
        nameRotate: 90,
        splitNumber: 0
    }
];

export const DataZoomOptionsTemplate = () => ({
    show: false,
    backgroundColor: 'rgba(24, 61, 127, 1)',
    fillerColor: 'rgba(104, 227, 246, 1)',
    borderColor: 'rgba(24, 61, 127, 1)',
    handleSize: '100%',
    handleIcon:
        'M8.2,13.6V3.9H6.3v9.7H3.1v14.9h3.3v9.7h1.8v-9.7h3.3V13.6H8.2z M9.7,24.4H4.8v-1.4h4.9V24.4z M9.7,19.1H4.8v-1.4h4.9V19.1z',
    handleStyle: {
        color: 'rgba(167, 183, 204, 1)',
        borderColor: 'rgba(0, 0, 0, 1)',
        borderWidth: 0
    },
    textStyle: {
        color: 'rgba(51, 51, 51, 1)',
        fontFamily: 'Roboto',
        fontSize: '12'
    },
    dataBackground: {
        lineStyle: {
            color: 'rgba(24, 61, 127, 0.3)',
            opacity: 1,
            width: 0.5
        },
        areaStyle: {
            color: 'rgba(104, 227, 246, 0.3)',
            opacity: 1
        }
    },
    showDetail: true,
    xAxisIndex: null,
    yAxisIndex: null,
    isPercent: false,
    startValue: 0,
    endValue: 10,
    startPercentValue: 0,
    endPercentValue: 100,
    minPercentValue: 0,
    maxPercentValue: 100,
    orient: 'horizontal',
    zoomLock: false,
    left: 'center',
    top: 'bottom',
    right: 'auto',
    bottom: '-5%',
    isUsedBaseMinMaxValue: true
});

export const DataZoomInsideOptionsTemplate = () => ({
    type: 'inside',
    zoomOnMouseWheel: false,
    moveOnMouseMove: false,
    moveOnMouseWheel: false
});
