import { Url } from '@goodt-common/utils';
import panels from './panels';
import {
    WorkMode,
    PharmacyCoefficient,
    ManagementPremiumType,
    IndividualPremiumType,
    PremiumRetentionType
} from '../helpers/constants';

export const Vars = Object.freeze({
    POSITION_ID: 'positionId'
});

export const Events = Object.freeze({});

export const descriptor = () => ({
    props: {
        riglaApiBaseUrl: {
            type: String,
            default: '%rigla%',
            options: {
                apiPath: '/api/',
                build(host) {
                    return Url.join(host, this.apiPath);
                }
            }
        },

        wfmApiBaseUrl: {
            type: String,
            default: '%wfm%',
            options: {
                apiPath: '/api/v1/',
                build(host) {
                    return Url.join(host, this.apiPath);
                }
            }
        },

        workMode: {
            type: String,
            default: WorkMode.INDIVIDUAL_FIXED_PREMIUM_RETENTION
        },

        pharmacyCoefficient: {
            type: Number,
            default: PharmacyCoefficient.PLAN_IMPLEMENTATION_COEFFICIENT
        },

        managementPremiumType: {
            type: Number,
            default: ManagementPremiumType.BASE_PREMIUM_ON_TURNOVER
        },

        individualPremiumType: {
            type: Number,
            default: IndividualPremiumType.INDIVIDUAL_FIXED_PREMIUM_BY_SURNAME
        },

        premiumRetentionType: {
            type: Number,
            default: PremiumRetentionType.MONTHLY_RETENTION_FROM_EMPLOYEES_FROM_UW_DEPARTMENT
        },

        rowHoverColor: {
            type: String,
            default: 'rgba(26, 103, 254, 0.3)'
        },

        rowHighlightColor: {
            type: String,
            default: '#f7c844'
        },

        rowChangedColor: {
            type: String,
            default: 'rgba(255, 153, 77, 0.3)'
        },

        keyColumnColor: {
            type: String,
            default: 'rgba(0, 80, 255, 0.1)'
        },

        rowSelectedColor: {
            type: String,
            default: 'rgba(255,225,116,0.9)'
        }
    },
    events: {},
    vars: {
        [Vars.POSITION_ID]: { description: 'ID позиции' }
    }
});

export const meta = {
    descriptor,
    isChildAllowed: false,
    panels,
    slotNames: ['default']
};
