import { BaseApiService, buildRequest, ApiClientMethod } from '@goodt-common/api';
import { useApiService } from '@goodt-common/api';
import { createTransport, HttpAuthTransportSymbol } from '@goodt-common/net';

import { dayjs } from '@goodt-common/utils';

const ServiceAction = {
    BRAND: {
        url: 'brand'
    },
    PHARMACY: {
        url: 'pharmacy'
    },
    LEVEL: {
        url: 'level'
    },
    REGION: {
        url: 'region'
    },
    EMPLOYEES: {
        url: 'employee'
    },

    CITY: {
      url: 'city'
    },

    CLUSTER: {
        url: 'cluster'
    },

    COEFFICIENT: {
        url: 'coefficient'
    },

    PRIVATE_LABEL_COEFFICIENT: {
        url: 'private-label-coefficient'
    },

    PRIVATE_LABEL_COEFFICIENT_ID: {
        url: 'private-label-coefficient/:id'
    },

    PRIVATE_LABEL_COEFFICIENT_SEARCH: {
        url: 'private-label-coefficient/search/all'
    },

    PHARMACY_SEARCH: {
        url: 'pharmacy/search/all'
    },

    PHARMACY_BY_ID: {
        url: 'pharmacy/:id'
    },

    PHARMACY_COEFFICIENT: {
        url: 'pharmacy-coefficient'
    },

    PHARMACY_COEFFICIENT_SEARCH: {
        url: 'pharmacy-coefficient/search/all'
    },

    PHARMACY_COEFFICIENT_ID: {
        url: 'pharmacy-coefficient/:id'
    },

    FIXED_PREMIUM_RETENTION: {
        url: 'fixed-premium-retention'
    },

    FIXED_PREMIUM_RETENTION_SEARCH: {
        url: 'fixed-premium-retention/search/all'
    },

    FIXED_PREMIUM_RETENTION_ID: {
        url: 'fixed-premium-retention/:id'
    },

    MANAGEMENT_PREMIUM_TYPE: {
        url: 'management-premium-type'
    },

    PREMIUM_FORMAT: {
        url: 'premium-format'
    },

    ROLE: {
        url: 'role'
    },

    STANDARD_ORDERS_COMPLETED: {
        url: 'standard-orders-completed'
    },

    STANDARD_ORDERS_COMPLETED_ID: {
        url: 'standard-orders-completed/:id'
    },

    STANDARD_ORDERS_COMPLETED_SEARCH: {
        url: 'standard-orders-completed/search/all'
    },

    ADDWORK_RULES: {
        url: 'addwork-rules'
    },

    ADDWORK_RULES_ID: {
        url: 'addwork-rules/:id'
    },

    ADDWORK_RULES_SEARCH: {
        url: 'addwork-rules/search/all'
    },

    INDIVIDUAL_FIXED_PREMIUM_RETENTION: {
        url: 'individual-fixed-premium-retention'
    },

    INDIVIDUAL_FIXED_PREMIUM_RETENTION_ID: {
        url: 'individual-fixed-premium-retention/:id'
    },

    INDIVIDUAL_FIXED_PREMIUM_RETENTION_SEARCH: {
        url: 'individual-fixed-premium-retention/search/all'
    },

    FIXED_PREMIUM_RETENTION_MANAGEMENT: {
        url: 'fixed-premium-retention-management'
    },

    FIXED_PREMIUM_RETENTION_MANAGEMENT_ID: {
        url: 'fixed-premium-retention-management/:id'
    },

    FIXED_PREMIUM_RETENTION_MANAGEMENT_SEARCH: {
        url: 'fixed-premium-retention-management/search/all'
    },

    SEARCH_STORE: {
        url: 'org-unit/store/search/by-name'
    },

    SEARCH_REGION: {
        url: 'org-unit/region/search/by-name'
    },

    SEARCH_CITY: {
        url: 'org-unit/city/search/by-name'
    },

    SEARCH_KUST: {
        url: 'org-unit/kust/search/by-name'
    },

    SEARCH_POSITION: {
        url: 'org-unit/position/search/by-name'
    },

    UNIT_TREE_STORE_BY_LEVEL: {
        url: 'org-unit/store/search/by-level'
    },

    STORE_OPTIONS: {
        url: 'org-unit/store'
    },

    REGION_OPTIONS: {
        url: 'org-unit/region'
    },

    CITY_OPTIONS: {
        url: 'org-unit/city'
    },

    KUST_OPTIONS: {
        url: 'org-unit/kust'
    },

    POSITION_OPTIONS: {
        url: 'employee-position/position'
    },
    
    IMPORT_PRIVATE_LABEL_COEFFICIENT_FROM_XLS_TEMPLATE: {
        url: 'utils/import-private-label-coefficient-from-xls/template'

    },
    
    IMPORT_PRIVATE_LABEL_COEFFICIENT_FROM_XLS: {
        url: 'utils/import-private-label-coefficient-from-xls'
    },

    UNIT_TREE_STORE_BY_LEVEL_AND_MOTIVATION_SCHEMA: {
        url: 'private-label-coefficient/search/by-level/by-motivation-schema'
    }
};

export class RiglaApiService extends BaseApiService {
    getApiBaseUrl() {
        return this.apiBaseURL;
    }

    downloadExternalParticipantsXlsTemplate() {
        const request = buildRequest({
            action: ServiceAction.IMPORT_PRIVATE_LABEL_COEFFICIENT_FROM_XLS_TEMPLATE,
            options: { method: ApiClientMethod.GET, responseType: 'blob' }
        });

        return this.request(request);
    }

    exportExternalParticipantsXls(file) {
        const request = buildRequest({
            action: ServiceAction.IMPORT_PRIVATE_LABEL_COEFFICIENT_FROM_XLS,
            options: {
                method: ApiClientMethod.POST,
                responseType: 'blob'
                // headers: {
                //     'Content-Type': 'file'
                // }
            },
            params: file
        });

        return this.request(request);
    }

    getBrands() {
        const request = buildRequest({
            action: ServiceAction.BRAND,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request);
    }

    getLevels() {
        const request = buildRequest({
            action: ServiceAction.LEVEL,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request)
    }

    getStoreElements() {
        const request = buildRequest({
            action: ServiceAction.STORE_OPTIONS,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request)
    }

    getCityElements() {
        const request = buildRequest({
            action: ServiceAction.CITY_OPTIONS,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request)
    }

    getRegionElements() {
        const request = buildRequest({
            action: ServiceAction.REGION_OPTIONS,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request)
    }

    getUnitTreeStoreByMotivationSchema(elementId, motivationSchema) {
        const request = buildRequest({
            action: ServiceAction.UNIT_TREE_STORE_BY_LEVEL_AND_MOTIVATION_SCHEMA,
            options: {
                method: ApiClientMethod.GET
            },
            queryParams: {
                motivation_schema: motivationSchema,
                element_id: elementId,
            }
        });

        return this.request(request);
    }

    getKustElements() {
        const request = buildRequest({
            action: ServiceAction.KUST_OPTIONS,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request)
    }

    getPositionElements() {
        const request = buildRequest({
            action: ServiceAction.POSITION_OPTIONS,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request)
    }

    searchElement(name = 'region', value) {
        const request = buildRequest({
            action: ServiceAction[`SEARCH_${name.toUpperCase()}`],
            options: {
                method: ApiClientMethod.GET
            },
            queryParams: {
                name: value
            }
        });

        return this.request(request)
    }

    getPharmacies() {
        const request = buildRequest({
            action: ServiceAction.PHARMACY,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request);
    }

    getRegions() {
        const request = buildRequest({
            action: ServiceAction.REGION,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request);
    }

    getPremiumFormats() {
        const request = buildRequest({
            action: ServiceAction.PREMIUM_FORMAT,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request);
    }

    getCoefficients() {
        const request = buildRequest({
            action: ServiceAction.COEFFICIENT,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request);
    }

    getEmployees() {
        const request = buildRequest({
            action: ServiceAction.EMPLOYEES,
            options: {
                method: ApiClientMethod.GET
            },
            params: {}
        });

        return this.request(request);
    }

    getUnitTreeStoreByLevel(elementId) {
        const request = buildRequest({
            action: ServiceAction.UNIT_TREE_STORE_BY_LEVEL,
            options: {
                method: ApiClientMethod.GET
            },
            params: {
                elementId,
            }
        });

        return this.request(request);
    }

    getPrivateLabelCoefficient() {
        const request = buildRequest({
            action: ServiceAction.PRIVATE_LABEL_COEFFICIENT,
            options: {
                method: ApiClientMethod.GET
            },
        });

        return this.request(request);
    }

    fetchClusters() {
        const request = buildRequest({
            action: ServiceAction.CLUSTER,
            options: {
                method: ApiClientMethod.GET
            }
        });

        return this.request(request);
    }

    addPrivateLabelCoefficient({ id, shift, date_start, date_from, orderOrigin, coefficient, element, value }) {
        const request = buildRequest({
            action: ServiceAction.PRIVATE_LABEL_COEFFICIENT,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                date_to: null,
                date_from: date_from || undefined,
                date_start,
                store_outer_id: element,
                shift,
                order_origin: orderOrigin,
                coefficient,
                value: value ? Number(value) : 0
            }
        });

        return this.request(request);
    }

    addPharmacy({ cluster, motivation_schema, date_from, name, store, brand, date_end, date_start }) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                brand: brand.id ? String(brand.id) : null,
                date_start,
                name,
                cluster: cluster ? String(cluster) : null,
                motivation_schema,
                store_outer_id: store ? Number(store) : null,
                date_end,
                date_from
            }
        });

        return this.request(request);
    }

    updatePharmacyById(id, { cluster, motivation_schema, date_start, date_end, date_from, name, store, brand }) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_BY_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                brand: brand.id ? String(brand.id) : null,
                date_start,
                name,
                cluster: cluster ? String(cluster) : null,
                motivation_schema,
                store_outer_id: store ? Number(store) : null,
                date_end,
                date_from
            }
        });

        return this.request(request);
    }

    deletePharmacyById(id) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_BY_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    fetchPrivateLabelCoefficientsByParams({ actualDate }, levelId = 0, elementsId = '') {
        const request = buildRequest({
            action: ServiceAction.PRIVATE_LABEL_COEFFICIENT_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                params: [
                    {
                        level_id: levelId,
                        element_ids: [elementsId]
                    }
                ],
                date_actual: actualDate
            }
        });

        return this.request(request);
    }

    fetchPrivateLabelCoefficientById(id) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_COEFFICIENT_ID,
            options: {
                method: ApiClientMethod.GET
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    updatePrivateLabelCoefficientById(id, { shift, date_start, date_from, orderOrigin, coefficient, element, value }) {
        const request = buildRequest({
            action: ServiceAction.PRIVATE_LABEL_COEFFICIENT_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                date_to: null,
                date_from: date_from || undefined,
                date_start,
                store_outer_id: element,
                shift,
                order_origin: orderOrigin,
                coefficient,
                value: value ? Number(value) : 0
            }
        });

        return this.request(request);
    }

    deletePrivateLabelCoefficientById(id) {
        const request = buildRequest({
            action: ServiceAction.PRIVATE_LABEL_COEFFICIENT_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    addPharmacyCoefficient({ brand, region, coefficient, minPlan, maxPlan, coefficientValue, level, element, date_start, date_from, }) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_COEFFICIENT,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                brand,
                region,
                coefficient,
                date_from: date_from || undefined,
                min_plan: minPlan,
                date_start,
                max_plan: maxPlan,
                level: String(level),
                element_id: element,
                coefficient_value: coefficientValue
            }
        });

        return this.request(request);
    }

    addAddworkRules({
        premiumFormat,
        addworkRate,
        brand,
        region,
        pharmacy,
        role,
        addworkBrand,
        addworkRegion,
        addworkPharmacy,
        addworkRole
    }) {
        const request = buildRequest({
            action: ServiceAction.ADDWORK_RULES,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                premium_format: premiumFormat,
                addwork_rate: addworkRate,
                brand,
                region,
                pharmacy,
                role,
                addwork_brand: addworkBrand,
                addwork_region: addworkRegion,
                addwork_pharmacy: addworkPharmacy,
                addwork_role: addworkRole
            }
        });

        return this.request(request);
    }

    fetchAddworkRulesListByParams({ actualDate }) {
        const request = buildRequest({
            action: ServiceAction.ADDWORK_RULES_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                date_actual: actualDate || undefined
            }
        });

        return this.request(request);
    }

    updateAddworkRulesById(
        id,
        {
            premiumFormat,
            addworkRate,
            brand,
            region,
            pharmacy,
            role,
            addworkBrand,
            addworkRegion,
            addworkPharmacy,
            addworkRole
        }
    ) {
        const request = buildRequest({
            action: ServiceAction.ADDWORK_RULES_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                premium_format: premiumFormat,
                addwork_rate: addworkRate,
                brand,
                region,
                pharmacy,
                role,
                addwork_brand: addworkBrand,
                addwork_region: addworkRegion,
                addwork_pharmacy: addworkPharmacy,
                addwork_role: addworkRole
            }
        });

        return this.request(request);
    }

    deleteAddworkRulesById(id) {
        const request = buildRequest({
            action: ServiceAction.ADDWORK_RULES_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    fetchIndividualFixedPremiumRetentionListByParams({ actualDate, premiumTypeIds }) {
        const request = buildRequest({
            action: ServiceAction.INDIVIDUAL_FIXED_PREMIUM_RETENTION_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                date_actual: actualDate || undefined,
                premium_type_ids: premiumTypeIds
            }
        });

        return this.request(request);
    }

    addIndividualFixedPremiumRetention({ brand, region, pharmacy, employee, managementPremiumType, value, date }) {
        const request = buildRequest({
            action: ServiceAction.INDIVIDUAL_FIXED_PREMIUM_RETENTION,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                date_from: date.date_from,
                brand,
                region,
                pharmacy,
                employee,
                management_premium_type: managementPremiumType,
                value
            }
        });

        return this.request(request);
    }

    updateIndividualFixedPremiumRetentionById(id, obj) {
        const request = buildRequest({
            action: ServiceAction.INDIVIDUAL_FIXED_PREMIUM_RETENTION_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                date_to: obj.date.date_to
            }
        });

        return this.request(request);
    }

    deleteIndividualFixedPremiumRetentionById(id) {
        const request = buildRequest({
            action: ServiceAction.INDIVIDUAL_FIXED_PREMIUM_RETENTION_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    fetchPharmacyCoefficientsByParams({ actualDate, coefficientIds }) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_COEFFICIENT_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                // params: [
                //     {
                //         level_id: 1,
                //         element_ids: ['']
                //     }
                // ],
                // level_all: 0,
                coefficient: coefficientIds,
                date_actual: actualDate || undefined
            }
        });

        return this.request(request);
    }

    fetchPharmacyByParams({ actualDate }) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                params: [
                    {
                        level_id: 0,
                        element_ids: ['']
                    }
                ],
                brand: [
                    0
                ],
                cluster: [
                    0
                ],
                date_actual: actualDate || undefined
            }
        });

        return this.request(request);
    }

    fetchPharmacyCoefficientById(id) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_COEFFICIENT_ID,
            options: {
                method: ApiClientMethod.GET
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    updatePharmacyCoefficientById(id, { brand, region, coefficient, minPlan, maxPlan, coefficientValue }) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_COEFFICIENT_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                brand,
                region,
                coefficient,
                min_plan: minPlan,
                max_plan: maxPlan,
                coefficient_value: coefficientValue
            }
        });

        return this.request(request);
    }

    deletePharmacyCoefficientById(id) {
        const request = buildRequest({
            action: ServiceAction.PHARMACY_COEFFICIENT_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    addFixedPremiumRetention({
        brand,
        region,
        city,
        pharmacy,
        minPlan,
        maxPlan,
        unitCategory,
        role,
        value,
        premiumType
    }) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                brand,
                region,
                city,
                pharmacy,
                role,
                value,
                min_plan: minPlan,
                max_plan: maxPlan,
                unit_category: unitCategory,
                premium_type: premiumType
            }
        });

        return this.request(request);
    }

    fetchFixedPremiumRetentionsByParams({ actualDate, premiumTypeIds }) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                date_actual: actualDate || undefined,
                premium_type_ids: premiumTypeIds
            }
        });

        return this.request(request);
    }

    fetchFixedPremiumRetentionById(id) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_ID,
            options: {
                method: ApiClientMethod.GET
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    updateFixedPremiumRetentionById(
        id,
        { brand, region, city, pharmacy, minPlan, maxPlan, unitCategory, role, value, premiumType }
    ) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                brand,
                region,
                city,
                pharmacy,
                role,
                value,
                min_plan: minPlan,
                max_plan: maxPlan,
                unit_category: unitCategory,
                premium_type: premiumType
            }
        });

        return this.request(request);
    }

    deleteFixedPremiumRetentionById(id) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    fetchManagementPremiumTypes() {
        const request = buildRequest({
            action: ServiceAction.MANAGEMENT_PREMIUM_TYPE,
            options: {
                method: ApiClientMethod.GET
            }
        });

        return this.request(request);
    }

    fetchRoles() {
        const request = buildRequest({
            action: ServiceAction.ROLE,
            options: {
                method: ApiClientMethod.GET
            }
        });

        return this.request(request);
    }

    addStandardOrderCompleted({ brand, region, pharmacy, role, standard }) {
        const request = buildRequest({
            action: ServiceAction.STANDARD_ORDERS_COMPLETED,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                brand,
                region,
                pharmacy,
                role,
                standard
            }
        });

        return this.request(request);
    }

    fetchStandardOrdersCompletedListByParams({ actualDate }) {
        const request = buildRequest({
            action: ServiceAction.STANDARD_ORDERS_COMPLETED_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                date_actual: actualDate || undefined
            }
        });

        return this.request(request);
    }

    fetchStandardOrderCompletedById(id) {
        const request = buildRequest({
            action: ServiceAction.STANDARD_ORDERS_COMPLETED_ID,
            options: {
                method: ApiClientMethod.GET
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    updateStandardOrderCompletedById(id, { brand, region, pharmacy, role, standard }) {
        const request = buildRequest({
            action: ServiceAction.STANDARD_ORDERS_COMPLETED_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                brand,
                region,
                pharmacy,
                role,
                standard
            }
        });

        return this.request(request);
    }

    deleteStandardOrderCompletedById(id) {
        const request = buildRequest({
            action: ServiceAction.STANDARD_ORDERS_COMPLETED_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    addFixedPremiumRetentionManagement({
        brand,
        region,
        cluster,
        pharmacy,
        employee,
        managementPremiumType,
        value,
        comment
    }) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_MANAGEMENT,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                brand,
                region,
                cluster,
                pharmacy,
                employee,
                management_premium_type: managementPremiumType,
                value,
                comment
            }
        });

        return this.request(request);
    }

    fetchFixedPremiumRetentionManagementListByParams({ actualDate, premiumRetentionTypeIds }) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_MANAGEMENT_SEARCH,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                date_actual: actualDate || undefined,
                premium_retention_type_ids: premiumRetentionTypeIds
            }
        });

        return this.request(request);
    }

    fetchFixedPremiumRetentionManagementById(id) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_MANAGEMENT_ID,
            options: {
                method: ApiClientMethod.GET
            },
            pathParams: { id }
        });

        return this.request(request);
    }

    updateFixedPremiumRetentionManagementById(
        id,
        { brand, region, cluster, pharmacy, employee, managementPremiumType, value, comment }
    ) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_MANAGEMENT_ID,
            options: {
                method: ApiClientMethod.PATCH
            },
            pathParams: { id },
            params: {
                brand,
                region,
                cluster,
                pharmacy,
                employee,
                management_premium_type: managementPremiumType,
                value,
                comment
            }
        });

        return this.request(request);
    }

    deleteFixedPremiumRetentionManagementById(id) {
        const request = buildRequest({
            action: ServiceAction.FIXED_PREMIUM_RETENTION_MANAGEMENT_ID,
            options: {
                method: ApiClientMethod.DELETE
            },
            pathParams: { id }
        });

        return this.request(request);
    }
}

/**
 * Service factory
 *
 * @param {import('@goodt-common/api').IApiServiceOptions} options service options
 * @param {import('@goodt-common/net').ITransport} [transport] transport
 * @return {ApiService} service instance
 */
export const createRiglaApiService = (options, transport) => {
    if (transport == null) {
        // eslint-disable-next-line no-param-reassign
        transport = createTransport(HttpAuthTransportSymbol);
    }

    return new RiglaApiService({ transport, options });
};

/**
 *
 * @param {import('@goodt-common/api').IApiServiceOptions} serviceOptions
 * @param {import('@goodt-common/api').IApiServiceMixinOptions} [mixinOptions]
 * @return {import('@goodt-common/api').IApiServiceMixin}
 */
export const useRiglaApiServiceMixin = (serviceOptions, mixinOptions) => {
    const { mixin: ServiceMixin } = useApiService(createRiglaApiService, serviceOptions, mixinOptions);

    return ServiceMixin;
};

/**
 * Это "пустой" вспомогательный объект с JSDOc аннотацией
 * для примешивания информации о сервисе
 * в структуру инстанса компонента и типах
 * исключительно для Vetur
 *
 * @type {{ RiglaApiService: RiglaApiService }}
 */
export const RiglaServiceTypeDescriptor = undefined;
