import { BaseApiService, buildRequest, ApiClientMethod } from '@goodt-common/api';
import { useApiService } from '@goodt-common/api';
import { createTransport, HttpTransportSymbol } from '@goodt-common/net';

const ServiceAction = {
    ORG_UNITS: {
        url: 'org-units'
    }
};

export class WfmApiService extends BaseApiService {
    getApiBaseUrl() {
        return this.apiBaseURL;
    }

    async searchOrgUnits(name) {
        const request = buildRequest({
            action: ServiceAction.ORG_UNITS,
            options: {
                method: ApiClientMethod.POST
            },
            params: {
                size: 45,
                name
            }
        });

        let res = await this.request(request);
        debugger;
    }
}

/**
 * Service factory
 *
 * @param {import('@goodt-common/api').IApiServiceOptions} options service options
 * @param {import('@goodt-common/net').ITransport} [transport] transport
 * @return {ApiService} service instance
 */
export const createWfmApiService = (options, transport) => {
    if (transport == null) {
        // eslint-disable-next-line no-param-reassign
        transport = createTransport(HttpTransportSymbol);
    }

    return new WfmApiService({ transport, options });
};

/**
 *
 * @param {import('@goodt-common/api').IApiServiceOptions} serviceOptions
 * @param {import('@goodt-common/api').IApiServiceMixinOptions} [mixinOptions]
 * @return {import('@goodt-common/api').IApiServiceMixin}
 */
export const useWfmApiServiceMixin = (serviceOptions, mixinOptions) => {
    const { mixin: ServiceMixin } = useApiService(createWfmApiService, serviceOptions, mixinOptions);

    return ServiceMixin;
};

/**
 * Это "пустой" вспомогательный объект с JSDOc аннотацией
 * для примешивания информации о сервисе
 * в структуру инстанса компонента и типах
 * исключительно для Vetur
 *
 * @type {{ WfmApiService: WfmApiService }}
 */
export const WfmServiceTypeDescriptor = undefined;
