import {
    useRiglaApiServiceMixin,
    RiglaServiceTypeDescriptor,
    useWfmApiServiceMixin,
    WfmServiceTypeDescriptor
} from '.';

/**
 * Миксин для использования LearningApiService вместе с компонентом
 * Дефолтные `apiBaseURL` и `name` настройки определены в аргументах миксина
 * @type {import('@goodt-common/api').IApiServiceMixin}
 */
export const RiglaApiServiceMixin = useRiglaApiServiceMixin(
    {
        /** @return {string} */
        apiBaseURL: 'props.riglaApiBaseUrl'
    },
    {
        /**
         * api service accessor name to access in component: `this.apiService`
         * @type {string}
         */
        name: 'riglaApiService'
    }
);

/**
 * Миксин для использования FileUploadApiService вместе с компонентом
 * Дефолтные `apiBaseURL` и `name` настройки определены в аргументах миксина
 * @type {import('@goodt-common/api').IApiServiceMixin}
 */
export const WfmApiServiceMixin = useWfmApiServiceMixin(
    {
        /** @return {string} */
        apiBaseURL: 'props.wfmApiBaseUrl'
    },
    { name: 'wfmApiService' }
);

export const ApiServiceMixins = [RiglaApiServiceMixin, WfmApiServiceMixin];

export const ApiMixinsTypeDescriptor = undefined;

export const ApiMixinsTypesDescriptor = {
    ...ApiMixinsTypeDescriptor,
    ...RiglaServiceTypeDescriptor,
    ...WfmServiceTypeDescriptor
};
