import { get as _get } from 'lodash';
import { API_DATE_FORMAT, ColName, INPUT_DATE_FORMAT, RowCRUDAction } from './constants';
import { dayjs } from '@goodt-common/utils';

export const mapPrivateLabelCoefficientToRow = (data) => ({
    id: data.id,
    action: RowCRUDAction.READ,
    [ColName.SHIFT]: data.shift ? Number(data.shift) : null,
    [ColName.ORDER_ORIGIN]: data.order_origin ? Number(data.order_origin) : null,
    [ColName.COEFFICIENT]: data.coefficient?.id,
    [ColName.VALUE]: String(data.value),
    [ColName.ELEMENT]: data.store_outer_id || '',
    [ColName.DATE_START]: data.date_start
        ? dayjs(data.date_start).format(INPUT_DATE_FORMAT)
        : dayjs().add(1, 'day').format(INPUT_DATE_FORMAT),
    [ColName.LEVEL]: 4 || '',
    isHighlight: false
});

export const mapPharmacyToRow = (data) => ({
    id: data.id,
    action: RowCRUDAction.READ,
    [ColName.MOTIVATION_SCHEMA]: data.motivation_schema || '',
    [ColName.STORE]: data.store_outer_id || '',
    [ColName.CLUSTER]: data.cluster?.id || null,
    [ColName.DATE_START]: dayjs(data.date_start).format(INPUT_DATE_FORMAT) || dayjs().format(INPUT_DATE_FORMAT),
    [ColName.DATE_END]: dayjs(data.date_end).format(INPUT_DATE_FORMAT) || '',
    [ColName.BRAND]: data.brand?.id || null,
    isHighlight: false
});

export const mapPharmacyCoefficientToRow = (data) => ({
    id: data.id,
    action: RowCRUDAction.READ,
    [ColName.BRAND]: data.brand?.id,
    [ColName.REGION]: data.region?.id,
    [ColName.MIN_PLAN]: String(data.min_plan),
    [ColName.MAX_PLAN]: String(data.max_plan),
    [ColName.COEFFICIENT_VALUE]: data.coefficient_value,
    [ColName.ELEMENT]: data.element_id || '',
    [ColName.LEVEL]: data.level.id || '',
    [ColName.DATE_START]: data.date_start
        ? dayjs(data.date_start).format(INPUT_DATE_FORMAT)
        : dayjs().add(1, 'day').format(INPUT_DATE_FORMAT),
    [ColName.DATE_END]: data.date_end
    ? dayjs(data.date_end).format(INPUT_DATE_FORMAT)
    : ''
});

export const mapFixedPremiumRetentionToRow = (data) => {
    const fields = {
        id: { tablePath: 'id', default: null },
        'brand.id': { tablePath: ColName.BRAND, default: null },
        'region.id': { tablePath: ColName.REGION, default: null },
        'city.id': { tablePath: ColName.CITY, default: null },
        'pharmacy.id': { tablePath: ColName.PHARMACY, default: null },
        'pharmacy.motivation_schema': { tablePath: ColName.MOTIVATION_SCHEMA, default: null },
        'premium_type.id': { tablePath: 'premiumType', default: null },
        min_plan: { tablePath: ColName.REV_MIN, default: null },
        max_plan: { tablePath: ColName.REV_MAX, default: null },
        unit_category: { tablePath: ColName.UNIT_CATEGORY, default: null },
        'role.id': { tablePath: ColName.ROLE, default: null },
        value: { tablePath: ColName.BASIC_BONUS, default: null }
    };

    const obj = Object.entries(fields).reduce(
        (acc, [key, value]) => ({
            ...acc,

            [value.tablePath]: _get(data, key, value.default)
        }),
        {}
    );

    return {
        ...obj,

        action: RowCRUDAction.READ
    };
};

export const mapStandardOrderCompletedToRow = (data) => ({
    id: data.id,
    action: RowCRUDAction.READ,
    [ColName.BRAND]: data.brand?.id,
    [ColName.REGION]: data.region?.id,
    [ColName.PHARMACY]: data.pharmacy?.id || null,
    [ColName.MOTIVATION_SCHEMA]: data.pharmacy?.motivation_schema || '',
    [ColName.ROLE]: data.role?.id || null,
    [ColName.STANDARD]: data.standard
});

export const mapAddworkRulesToRow = (data) => ({
    id: data.id,
    action: RowCRUDAction.READ,
    [ColName.ROLE]: data.role?.id || null,
    [ColName.REGION]: data.pharmacy?.region.id || null,
    [ColName.PHARMACY_CODE]: data.pharmacy?.id || null,
    [ColName.BRAND]: data.brand?.id || null,
    [ColName.MOTIVATION_SCHEMA]: data.pharmacy?.motivation_schema || null,
    [ColName.ADDWORK_ROLE]: data.addwork_role?.id || null,
    [ColName.ADDWORK_PHARMACY_CODE]: data.addwork_pharmacy?.id || null,
    [ColName.ADDWORK_BRAND]: data.addwork_brand?.id || null,
    [ColName.ADDWORK_MOTIVATION_SCHEMA]: data.addwork_pharmacy?.motivation_schema || null,
    [ColName.PREMIUM_FORMAT]: data.premium_format ? Number(data.premium_format) : null,
    [ColName.ADDWORK_RATE]: data.addwork_rate,
    [ColName.ADDWORK_REGION]: data.addwork_pharmacy?.region.id || null
});

export const mapFixedPremiumRetentionManagementToRow = (data) => ({
    id: data.id,
    action: RowCRUDAction.READ,
    [ColName.BRAND]: data.brand?.id || null,
    [ColName.REGION]: data.region?.id || null,
    [ColName.CLUSTER]: data.cluster?.id || null,
    [ColName.CLUSTER_MANAGER_FIO]: data.cluster?.manager_full_name,
    [ColName.PHARMACY]: data.pharmacy?.id || null,
    [ColName.EMPLOYEE]: data.employee?.id || null,
    [ColName.ROLE]: data.employee?.role.name || '',
    [ColName.EMPLOYEE_ID]: data.employee?.id || '',
    [ColName.VALUE]: data.value,
    [ColName.COMMENT]: data.comment || ''
});

export const mapIndividualFixedPremiumRetentionToRow = (data) => ({
    id: data.id,
    action: RowCRUDAction.READ,
    [ColName.BRAND]: data.brand?.id,
    [ColName.REGION]: data.region?.id,
    [ColName.CITY]: data.city?.id || null,
    [ColName.PHARMACY]: data.pharmacy?.id || null,
    [ColName.EMPLOYEE]: data.employee?.id || null,
    [ColName.ROLE]: data.employee.role?.name || '',
    [ColName.EMPLOYEE_ID]: data.employee?.id || '',
    [ColName.BASIC_BONUS]: data.value // PrivBasicBonus
});

export const mapRowToPrivateLabelCoefficient = (row) => ({
    level: row[ColName.LEVEL],
    element: row[ColName.ELEMENT],
    shift: row[ColName.SHIFT] ? String(row[ColName.SHIFT]) : null,
    orderOrigin: row[ColName.ORDER_ORIGIN] ? String(row[ColName.ORDER_ORIGIN]) : null,
    coefficient: row[ColName.COEFFICIENT],
    value: Number(row[ColName.VALUE])
});

export const mapRowToPharmacyCoefficient = (row, pharmacyCoefficient) => ({
    brand: row[ColName.BRAND],
    minPlan: row[ColName.MIN_PLAN],
    maxPlan: row[ColName.MAX_PLAN],
    coefficientValue: row[ColName.COEFFICIENT_VALUE] ? Number(row[ColName.COEFFICIENT_VALUE]) : 0,
    coefficient: pharmacyCoefficient,
    date_start: row.date_start
        ? dayjs(row.date_start, INPUT_DATE_FORMAT).format(API_DATE_FORMAT)
        : dayjs().add(1, 'day').format(INPUT_DATE_FORMAT),
    level: row[ColName.LEVEL],
    element: row[ColName.ELEMENT]
});

export const mapRowToFixedPremiumRetention = (row, managementPremiumType) => {
    const fields = {
        brand: { tablePath: ColName.BRAND },
        region: { tablePath: ColName.REGION },
        city: { tablePath: ColName.CITY },
        pharmacy: { tablePath: ColName.PHARMACY },
        minPlan: { tablePath: ColName.REV_MIN, convert: (value) => Number(value) },
        maxPlan: { tablePath: ColName.REV_MAX, convert: (value) => Number(value) },
        unitCategory: { tablePath: ColName.UNIT_CATEGORY },
        role: { tablePath: ColName.ROLE },
        value: { tablePath: ColName.BASIC_BONUS, convert: Number(row[ColName.BASIC_BONUS]) }
    };

    const obj = Object.entries(fields).reduce((acc, [key, value]) => {
        let rowValue = row[value.tablePath];

        if (typeof value.convert === 'function') {
            rowValue = value.convert(rowValue);
        }

        return {
            ...acc,

            [key]: rowValue
        };
    }, {});

    return {
        ...obj,

        premiumType: managementPremiumType
    };
};

export const mapRowToStandardOrderCompleted = (row) => ({
    brand: row[ColName.BRAND],
    region: row[ColName.REGION],
    pharmacy: row[ColName.PHARMACY],
    role: row[ColName.ROLE],
    standard: Number(row[ColName.STANDARD])
});

export const mapRowToIndividualFixedPremiumRetention = (row, managementPremiumType, date) => ({
    brand: row[ColName.BRAND],
    region: row[ColName.REGION],
    pharmacy: row[ColName.PHARMACY],
    date,
    employee: row[ColName.EMPLOYEE],
    managementPremiumType,
    value: row[ColName.BASIC_BONUS]
});

export const mapRowToAddworkRules = (row) => ({
    premiumFormat: row[ColName.PREMIUM_FORMAT],
    addworkRate: row[ColName.ADDWORK_RATE],
    brand: row[ColName.BRAND],
    region: row[ColName.REGION],
    pharmacy: row[ColName.PHARMACY_CODE],
    role: row[ColName.ROLE],
    addworkBrand: row[ColName.ADDWORK_BRAND],
    addworkRegion: row[ColName.ADDWORK_REGION],
    addworkPharmacy: row[ColName.ADDWORK_PHARMACY_CODE],
    addworkRole: row[ColName.ADDWORK_ROLE]
});

export const mapRowToFixedPremiumRetentionManagement = (row, managementPremiumType) => ({
    brand: row[ColName.BRAND],
    region: row[ColName.REGION],
    cluster: row[ColName.CLUSTER],
    pharmacy: row[ColName.PHARMACY],
    employee: row[ColName.EMPLOYEE],
    managementPremiumType,
    value: row[ColName.VALUE],
    comment: row[ColName.COMMENT]
});
