/* eslint-disable no-restricted-syntax */
import { useActionsDescriptor, useStyleConditionsDescriptor, useTableCellDescriptor } from '../shared';
import panels from './panels';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({
    ACTIVE_BADGE: 'activeBadge'
});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        colorDataField: {
            type: String,
            default: null
        },
        gap: {
            type: Array,
            default: () => [null, null]
        },
        borderRadius: {
            type: Array,
            default: () => [null, null, null, null]
        },
        fontSettings: {
            type: Object,
            default: () => ({
                fontSize: null,
                fontWeight: null,
                fontFamily: null,
                color: null
            })
        },
        customBgColor: {
            type: Object,
            default: () => ({
                isEnabled: false,
                colorDefault: null,
                colorStep: 10,
                colorConditions: []
            })
        },
        customBorder: {
            type: Object,
            default: () => ({
                width: '2px',
                color: null
            })
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor: [useTableCellDescriptor, useActionsDescriptor, useStyleConditionsDescriptor].reduce(
        (acc, factory) => factory(acc),
        descriptor
    ),
    panels,
    isChildAllowed: false,
    cssVars
};

export default descriptor;
