/* eslint-disable no-restricted-syntax */
import { useActionsDescriptor, useStyleConditionsDescriptor, useTableCellDescriptor } from '../shared';
import panels from './panels';
import { PictureFormat } from './constants';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({
    /*
    OPEN: 'open',
    CLOSE: 'close'
    */
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        valueToReplace: {
            type: String,
            default: null
        },
        rawValue: {
            type: String,
            default: null
        },
        valueFormat: {
            type: String,
            default: PictureFormat.IMAGE
        },
        imageHeight: {
            type: String,
            default: '100%'
        },
        imageWidth: {
            type: String,
            default: '100%'
        },
        avatarMode: {
            type: Object,
            default: () => ({
                isEnabled: false,
                size: null,
                personDataFields: [],
                bgColor: null,
                color: null,
                fontSize: null,
                offset: null,
                border: {
                    radius: null,
                    width: null,
                    color: null
                },
                styleConditions: []
            }),
            applicable: { borderColor: null }
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor: [useTableCellDescriptor, useActionsDescriptor, useStyleConditionsDescriptor].reduce(
        (acc, factory) => factory(acc),
        descriptor
    ),
    panels,
    isChildAllowed: false,
    cssVars
};

export default descriptor;
