/* eslint-disable no-restricted-syntax */
import { useActionsDescriptor, useStyleConditionsDescriptor, useTableCellDescriptor } from '../shared';
import panels from './panels';
import { factOrPlanSettingsFactory } from './constants';
import { cssVars } from './css-vars';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({
    /*
    OPEN: 'open',
    CLOSE: 'close'
    */
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        planDataField: {
            type: String,
            default: null
        },
        fact: {
            type: Object,
            default: factOrPlanSettingsFactory
        },
        plan: {
            type: Object,
            default: factOrPlanSettingsFactory
        },
        imagesDataField: {
            type: String,
            default: null
        },
        pointsDataField: {
            type: String,
            default: null
        },
        isPointsIntegers: {
            type: Boolean,
            default: true
        },
        imageUrl: {
            type: String,
            default: null
        },
        barHeight: {
            type: String,
            default: null
        },
        barRadius: {
            type: String,
            default: '1rem'
        },
        iconClass: {
            type: String,
            default: 'circle'
        },
        iconOptions: {
            type: Object,
            default: () => ({
                fontSize: null,
                color: null
            })
        },
        imageOptions: {
            type: Object,
            default: () => ({
                height: null,
                width: null
            })
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor: [useTableCellDescriptor, useActionsDescriptor, useStyleConditionsDescriptor].reduce(
        (acc, factory) => factory(acc),
        descriptor
    ),
    panels,
    isChildAllowed: false,
    cssVars
};

export default descriptor;
