/* eslint-disable no-restricted-syntax */
import { useTableCellDescriptor, useActionsDescriptor, useStyleConditionsDescriptor } from '../shared';
import panels from './panels';
import { cssVars } from './css-vars';
import { ValueFormat, DATE_FORMAT_DEFAULT, PrefixOrPostfixFactory } from './constants';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Events = Object.freeze({
    /*
    OPEN: 'open',
    CLOSE: 'close'
    */
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        valueFormat: {
            type: Object,
            default: () => ({
                type: ValueFormat.STRING,
                numberFormat: null,
                dateFormat: DATE_FORMAT_DEFAULT
            })
        },
        rawValue: {
            type: String,
            default: null
        },
        valueToReplace: {
            type: String,
            default: null
        },
        style: {
            type: Object,
            default: () => ({
                fontFamily: '',
                fontSize: null,
                fontWeight: null,
                color: null
            })
        },
        prefix: {
            type: Object,
            default: PrefixOrPostfixFactory
        },
        postfix: {
            type: Object,
            default: PrefixOrPostfixFactory
        },
        shouldWrapText: {
            type: Boolean,
            default: true
        },
        truncate: {
            type: Object,
            default: () => ({
                isEnabled: false,
                linesToDisplay: 1
            })
        },
        benchmark: {
            type: Object,
            default: () => ({
                isDisplayed: false,
                iconDefault: 'menu-up',
                position: 'left',
                offset: '0.5rem',
                size: null,
                iconConditions: []
            }),
            applicable: { mdiClass: '', color: null }
        },
        height: {
            type: String,
            default: '100'
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {})
});

export const meta = {
    descriptor: [useTableCellDescriptor, useActionsDescriptor, useStyleConditionsDescriptor].reduce(
        (acc, factory) => factory(acc),
        descriptor
    ),
    panels,
    isChildAllowed: false,
    cssVars
};

export default descriptor;
