import { merge } from 'lodash';
import { CellContainer as WCellContainer } from '../components';

/**
 * Table cell mixin, used for table column widgets
 * @depends useTableCellDescriptor()
 * @return {Record<string, any>}
 */
export const useTableCell = () => ({
    inject: {
        data: {
            default: null
        }
    },
    components: { WCellContainer },
    computed: {
        rowData() {
            return this.data?.rowData ?? null;
        },
        /**
         * @return {boolean}
         */
        hasContent() {
            return this.value != null;
        },
        cellBinds() {
            const { hasContent, cellCssClass = {}, cellCssStyle = {}, hasActiveActions } = this;
            return {
                hasContent,
                hasActiveActions,
                cssClass: cellCssClass,
                cssStyle: cellCssStyle
            };
        }
    },
    methods: {
        /**
         * @param {Event} event
         */
        onClick(/* event */) {
            const { canSelectRow } = this.props;
            const actions = this.createActions();

            this.dispatchActions(actions, canSelectRow);
        }
    }
});

/**
 * Table-cell descriptor factory
 * @param {() => Record<string, any>} descriptor         custom descriptor factory to merge with
 * @return {() => Record<string, any>}
 */
export function useTableCellDescriptor(descriptor) {
    return () =>
        merge(
            {
                props: {
                    dataField: {
                        type: String,
                        default: null
                    }
                }
            },
            descriptor()
        );
}
