import { merge } from 'lodash';
import { ConditionTypes, ValueTypes } from './constants';

/**
 * @param {string} definition
 * @return {{key: string, value: string}|null}
 */
export const resolveStyleDefinition = (definition) => {
    const [key, value] = definition.split(':');
    return value != null ? { key: key.trim(), value: value.trim() } : null;
};

/**
 * @param {string} type
 * @param {string} format
 * @param {string} valueComparedType
 * @param {string} valueCompared
 * @param {string} valueToCompareType
 * @param {string} valueToCompare
 * @param {Record<string, any>} rowData
 * @return {boolean}
 */
export const shouldUseCssRule = (
    { type, format, valueComparedType, valueCompared, valueToCompareType, valueToCompare },
    rowData
) => {
    const { handler: conditionTypeHandler } = ConditionTypes[type];
    const { handler: valueComparedHandler } = ValueTypes[valueComparedType];
    const { handler: valueToCompareHandler } = ValueTypes[valueToCompareType];

    return conditionTypeHandler(
        valueComparedHandler(valueCompared, rowData),
        valueToCompareHandler(valueToCompare, rowData),
        format
    );
};

/**
 * @param {string} bgColor
 * @param {{ isEnabled: boolean, direction: string, colorStops: [string, string] }} gradient
 * @return {string}
 */
export const resolveBackground = ({ bgColor, gradient }) => {
    const {
        isEnabled,
        direction,
        colorStops: [color1, color2]
    } = gradient;
    if (isEnabled) {
        return `linear-gradient(${direction}, ${color1}, ${color2})`;
    }
    return bgColor;
};

export const mergeProps = (modifiedProps, propsToMerge) => merge(modifiedProps, propsToMerge);
