import panels from './panels';

/**
 * @enum {string}
 * @type {Readonly<Record<string, string>>}
 */
export const Vars = Object.freeze({});

export const Events = Object.freeze({
    AUTO_REFRESH: 'auto_refresh'
});

/**
 * @description Don't change `descriptor` exported name
 * @return {ElemDescriptor}
 */
export const descriptor = () => ({
    props: {
        dremio: {
            type: Object,
            default: null
        },
        colorPlan: {
            type: String,
            default: 'var(--color-muted)'
        },
        colorFact: {
            type: String,
            default: 'var(--color-blue)'
        },
        startPeriod: {
            type: Object,
            default() {
                return {
                    value: '',
                    show: false,
                    color: '',
                    fontFamily: '',
                    fontStyle: '',
                    fontWeight: '',
                    isShowYear: false,
                    size: '',
                    position: 1
                };
            }
        },

        endPeriod: {
            type: Object,
            default() {
                return {
                    value: '',
                    show: false,
                    color: '',
                    fontFamily: '',
                    fontStyle: '',
                    fontWeight: '',
                    isShowYear: false,
                    size: '',
                    position: 1
                };
            }
        },
        insidePeriod: {
            type: Object,
            default() {
                return {
                    value: '',
                    show: false,
                    size: '14px',
                    fontFamily: '',
                    fontStyle: '',
                    fontWeight: '',
                    isShowYear: false,
                    isProportion: false,
                    areUnique: false,
                    externalLine: { background: '' },
                    internalLine: { background: '' },
                    color: '',
                    marginTop: '20px',
                    marginBottom: '10px',
                    position: 0
                };
            }
        },
        icon: {
            type: Object,
            default() {
                return {
                    value: '',
                    fontSize: '14px',
                    color: '',
                    show: false,
                    size: '25px',
                    position: ''
                };
            }
        },
        stokeDays: {
            type: Object,
            default() {
                return {
                    show: false,
                    position: 3,
                    align: 'left',
                    gap: '1rem',
                    pref: '',
                    color: '',
                    fontSize: '',
                    fontFamily: '',
                    fontStyle: '',
                    fontWeight: '',
                    showOnlyWithinRangeDates: false
                };
            }
        },
        progressBar: {
            type: Object,
            default: () => ({
                size: '0.625rem',
                gradientPlan: null,
                gradientFact: null
            })
        },
        isSetFactDate: {
            type: Boolean
        },
        typeData: {
            type: Number,
            default: 0
        },
        datePickerFactDate: {
            type: String,
            default: ''
        },
        metricFactDate: {
            type: String,
            default: ''
        },
        typeProgressBar: {
            type: Number,
            default: 0
        },
        positionVerticalText: {
            type: Number,
            default: 0
        },
        events: {
            type: Object,
            default() {
                return {
                    [Events.AUTO_REFRESH]: 'auto_refresh'
                };
            }
        }
    },
    vars: Object.values(Vars).reduce((acc, varName) => ({ ...acc, [varName]: { description: varName } }), {}),
    events: {
        [Events.AUTO_REFRESH]: {
            listen: `events[${Events.AUTO_REFRESH}]`
        }
    },
    cssVars: {
        'start-period_color': 'startPeriod.color',
        'start-period_font-size': 'startPeriod.size',
        'start-period_font-family': 'startPeriod.fontFamily',
        'start-period_font-style': 'startPeriod.fontStyle',
        'start-period_font-weight': 'startPeriod.fontWeight',

        'end-period_color': 'endPeriod.color',
        'end-period_font-size': 'endPeriod.size',
        'end-period_font-family': 'endPeriod.fontFamily',
        'end-period_font-style': 'endPeriod.fontStyle',
        'end-period_font-weight': 'endPeriod.fontWeight',

        'inside-period_font-size': 'insidePeriod.size',
        'inside-period_color': 'insidePeriod.color',
        'inside-period_margin-top': 'insidePeriod.marginTop',
        'inside-period_margin-bottom': 'insidePeriod.marginBottom',
        'inside-period_font-family': 'insidePeriod.fontFamily',
        'inside-period_font-style': 'insidePeriod.fontStyle',
        'inside-period_font-weight': 'insidePeriod.fontWeight',
        'inside-period_external_line_background': 'insidePeriod.externalLine.background',
        'inside-period_internal_line_background': 'insidePeriod.internalLine.background',

        'size-progress-bar': 'progressBar.size',

        icon_size: 'icon.size',
        icon_position: 'icon.position',
        icon_color: 'icon.color',
        'icon_font-size': 'icon.fontSize',

        'stoke-days_position': 'stokeDays.position',
        'stoke-days_align': 'stokeDays.align',
        'stoke-days_color': 'stokeDays.color',
        'stoke-days_font-size': 'stokeDays.fontSize',
        'stoke-days_font-family': 'stokeDays.fontFamily',
        'stoke-days_font-style': 'stokeDays.fontStyle',
        'stoke-days_font-weight': 'stokeDays.fontWeight',
        wrapper_gap: 'stokeDays.gap'
    }
});

export const meta = {
    descriptor,
    panels,
    isChildAllowed: true,
    slotNames: ['default']
};
