package com.goodt.drive.report.application.configuration;

import io.micrometer.core.instrument.binder.db.PostgreSQLDatabaseMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmGcMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmHeapPressureMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmMemoryMetrics;
import io.micrometer.core.instrument.binder.jvm.JvmThreadMetrics;
import io.micrometer.core.instrument.binder.system.FileDescriptorMetrics;
import io.micrometer.core.instrument.binder.system.UptimeMetrics;
import io.micrometer.prometheus.PrometheusConfig;
import io.micrometer.prometheus.PrometheusMeterRegistry;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.sql.DataSource;

@Configuration
@EnableConfigurationProperties
@ConfigurationProperties
public class AppConfig {
    
    public AppConfig(){
        
    }
    
    public AppConfig(String apiVersion, String environment, String databaseDriver, String databaseUrl, String databaseUsername,
                     String databasePassword, KeyCloakConfig keyCloakConfig, OrgstructureServiceConfig orgstructureConfig){
        this.apiVersion = apiVersion;
        this.environment = environment;
        this.databaseDriver = databaseDriver;
        this.databaseUrl = databaseUrl;
        this.databaseUsername = databaseUsername;
        this.databasePassword = databasePassword;

        this.keyCloakConfig = keyCloakConfig;
        this.orgstructureConfig = orgstructureConfig;
    }
    
    public String getEnvironment(){
        return environment;
    }
    
    public void setEnvironment(String environment) {
        this.environment = environment;
    }
    
    public String getDatabaseDriver(){
        return databaseDriver;
    }
    
    public void setDatabaseDriver(String databaseDriver) {
        this.databaseDriver = databaseDriver;
    }
    
    public String getDatabaseUrl(){
        return databaseUrl;
    }
    
    public void setDatabaseUrl(String databaseUrl) {
        this.databaseUrl = databaseUrl;
    }
    
    public String getApiVersion(){
        return apiVersion;
    }
    
    public void setApiVersion(String apiVersion) {
        this.apiVersion = apiVersion;
    }
    
    public KeyCloakConfig getKeyCloakConfig(){
        return keyCloakConfig;
    }
    
    public void setKeyCloakConfig(KeyCloakConfig keyCloakConfig){
        this.keyCloakConfig = keyCloakConfig;
    }
    
    public String getDatabaseUsername() {
        return databaseUsername;
    }

    public void setDatabaseUsername(String databaseUsername) {
        this.databaseUsername = databaseUsername;
    }

    public String getDatabasePassword() {
        return databasePassword;
    }

    public void setDatabasePassword(String databasePassword) {
        this.databasePassword = databasePassword;
    }
    
    public OrgstructureServiceConfig getOrgstructureConfig(){
        return orgstructureConfig;
    }
    
    public void setOrgstructureConfig(OrgstructureServiceConfig orgstructureConfig){
        this.orgstructureConfig = orgstructureConfig;
    }

    @Bean
    public PrometheusMeterRegistry createMicrometer() {
        PrometheusMeterRegistry registry = new PrometheusMeterRegistry(PrometheusConfig.DEFAULT);
        new io.micrometer.core.instrument.binder.system.ProcessorMetrics().bindTo(registry);
        new JvmHeapPressureMetrics().bindTo(registry);
        new JvmThreadMetrics().bindTo(registry);
        new JvmGcMetrics().bindTo(registry);
        new JvmMemoryMetrics().bindTo(registry);
        new UptimeMetrics().bindTo(registry);
        new FileDescriptorMetrics().bindTo(registry);

        return registry;
    }

    @Value("${appConfig.version}")
    private String apiVersion;
    
    @Value("${appConfig.environment}")
    private String environment;
    
    @Value("${appConfig.dbDriver}")
    private String databaseDriver;
    
    @Value("${appConfig.dbUrl}")
    private String databaseUrl;
    
    @Value("${appConfig.dbUsername}")
    protected String databaseUsername;

    @Value("${appConfig.dbPassword}")
    protected String databasePassword;
    
    @Autowired
    private KeyCloakConfig keyCloakConfig;
    
    @Autowired
    private OrgstructureServiceConfig orgstructureConfig;
}
