package com.goodt.drive.report.application.controllers.api;

import com.goodt.drive.report.GlobalDefs;
import com.goodt.drive.report.application.configuration.AppConfig;
import com.goodt.drive.report.application.data.UserInfo;
import com.goodt.drive.report.application.dto.keycloak.TokenDataDtoBase;
import com.goodt.drive.report.application.exception.UserTokenDataException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.security.oauth2.resource.PrincipalExtractor;
import org.springframework.context.ApplicationContext;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.oauth2.provider.authentication.OAuth2AuthenticationDetails;


public abstract class BaseController {

    @Autowired
    ApplicationContext context;

    @Autowired
    AppConfig appConfig;
    
    public ApplicationContext getContext(){
        return context;
    }
    
    public PrincipalExtractor getPrincipalExtractor(){
        return context.getBean(PrincipalExtractor.class);
    }
    
    public Authentication getAuthentication(){
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        return authentication;
    }
    
    public TokenDataDtoBase getUserTokenDataDtoBase() throws UserTokenDataException {
        Authentication authentication = getAuthentication();
        if (authentication == null || authentication.getPrincipal() == null || authentication.getPrincipal().equals(GlobalDefs.AUTHENTICATION_PRINCIPAL_ANONYMOUS)) {
            throw new UserTokenDataException("User token authentication is anonymous");
        }
        return new TokenDataDtoBase(
                ((OAuth2AuthenticationDetails) authentication.getDetails()).getTokenType(),
                ((OAuth2AuthenticationDetails) authentication.getDetails()).getTokenValue()
        );
    }
    
    public AppConfig getAppConfig(){
        return appConfig;
    }
    
    protected UserInfo getUserInfo() {
        return (UserInfo) getAuthentication().getPrincipal();
    }
    
    protected String getSessionEmployeeId(){
        UserInfo userInfo = (UserInfo) getAuthentication().getPrincipal();
        return userInfo.getEmployeeId() != null ? userInfo.getEmployeeId() : null;
    }
}
