package com.goodt.drive.report.application.controllers.api;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import org.springframework.http.*;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import uk.co.certait.htmlexporter.pdf.PdfExporter;
import uk.co.certait.htmlexporter.writer.excel.ExcelExporter;

import com.goodt.drive.report.application.dto.FileConverterDto;

@RestController
@RequestMapping("/api/fileconverter")
public class FileConverterController extends BaseController {

    @Operation(summary = "Конвертирование файла из html в pdf", description = "Конвертирование файла из html в pdf", tags = { "fileconverter" })
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "В случае если удалось построить отчёт",
                    content = @Content(schema = @Schema(implementation = ResponseEntity.class))),
            @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "500", description = "В случае если: что-то сломалось или не полностью сконфигрурировано приложение",
                    content = @Content(schema = @Schema(implementation = String.class))),
    })
    @PostMapping("htmltopdf")
    public ResponseEntity<byte[]> convertHtmlToPdf(@RequestBody FileConverterDto fileConverterDto) throws Exception {
        byte[] bytes = new PdfExporter().exportHtml("<!DOCTYPE html><html><head></head><body>" + fileConverterDto.getValue() + "</body></html>");
        HttpHeaders headers = new HttpHeaders();
        headers.setContentLength(bytes.length);
        headers.setContentType(MediaType.APPLICATION_PDF);
        headers.setContentDisposition(ContentDisposition.attachment().filename("output.pdf").build());
        return new ResponseEntity<>(bytes, headers, HttpStatus.OK);
    }

    @Operation(summary = "Конвертирование файла из html в xls", description = "Конвертирование файла из html в xls", tags = { "fileconverter" })
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "В случае если удалось построить отчёт",
                    content = @Content(schema = @Schema(implementation = ResponseEntity.class))),
            @ApiResponse(responseCode = "401", description = "В случае если запрос отправлен без токена или с недействительным токеном возвращается ошибка 401 и строка с ошибкой в теле запроса",
                    content = @Content(schema = @Schema(implementation = String.class))),
            @ApiResponse(responseCode = "500", description = "В случае если: что-то сломалось или не полностью сконфигрурировано приложение",
                    content = @Content(schema = @Schema(implementation = String.class))),
    })
    @PostMapping("htmltoxlsx")
    public ResponseEntity<byte[]> convertHtmlToXls(@RequestBody FileConverterDto fileConverterDto) throws Exception {
        byte[] bytes = new ExcelExporter().exportHtml("<!DOCTYPE html><html><head></head><body style=\"border-style:solid;\">" + fileConverterDto.getValue() + "</body></html>");
        HttpHeaders headers = new HttpHeaders();
        headers.setContentLength(bytes.length);
        headers.setContentType(MediaType.valueOf("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"));
        headers.setContentDisposition(ContentDisposition.attachment().filename("output.xlsx").build());
        return new ResponseEntity<>(bytes, headers, HttpStatus.OK);
    }
}
