package com.goodt.drive.report.application.enums;

import com.fasterxml.jackson.annotation.JsonValue;
import com.goodt.drive.report.application.enums.contracts.IFilterSqlOperation;
import org.springframework.util.Assert;

import java.util.List;
import java.util.stream.Collectors;

public enum EFilterType implements IFilterSqlOperation {

    EQ("$eq") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " = " + _value(args.get(0));
        }
    },
    EQ_NOT("$eqn") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " != " + _value(args.get(0));
        }
    },
    LESS("$lt") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " < " + _value(args.get(0));
        }
    },
    LESS_EQ("$ltq") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " <= " + _value(args.get(0));
        }
    },
    GREATER("$gt") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " > " + _value(args.get(0));
        }
    },
    GREATER_EQ("$gtq") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " >= " + _value(args.get(0));
        }
    },
    IN("$in") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 и более аргументов, передаётся " + args.size());
            return _column(colName) + " IN " + "(" + _value(args) + ")";
        }
    },
    IN_NOT("$inn") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 и более аргументов, передаётся " + args.size());
            return _column(colName) + " NOT IN " + "(" + _value(args) + ")";
        }
    },
    BETWEEN("$btw") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 1, "Условие " + name() + " принимает 2 аргумента, передаётся " + args.size());
            return _column(colName) + " BETWEEN " + _value(args.get(0)) + " AND " + _value(args.get(1));
        }
    },
    BETWEEN_NOT("$btwn") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 1, "Условие " + name() + " принимает 2 аргумента, передаётся " + args.size());
            return _column(colName) + " NOT BETWEEN " + _value(args.get(0)) + " AND " + _value(args.get(1));
        }
    },
    LIKE("$lk") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 и более аргументов, передаётся " + args.size());
            List<String> arr = args.stream().map(val -> _column(colName) + " LIKE " + _value(val, false)).collect(Collectors.toList());
            return "(" + arr.stream().reduce((str1, str2) -> str1 + " OR " + str2).get() + ")";
        }
    },
    MAX("$max") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " = (SELECT MAX (" + _column(args.get(0)) + ") FROM " + table + ")";
        }
    },
    MIN("$min") {
        @Override
        public String sql(String colName, List<String> args, String table) {
            Assert.isTrue(args.size() > 0, "Условие " + name() + " принимает 1 аргумент, передаётся " + args.size());
            return _column(colName) + " = (SELECT MIN (" + _column(args.get(0)) + ") FROM " + table + ")";
        }
    };

    String definition;

    EFilterType(String type) {
        this.definition = type;
    }

    @JsonValue
    public String getDef() {
        return definition;
    }
}
