package com.goodt.drive.report.application.services;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.IOException;
import java.net.URL;

import javax.annotation.PostConstruct;

import lombok.extern.slf4j.Slf4j;

import com.goodt.drive.report.application.dto.BuildInfo;

@Slf4j
@Service
public class BuildInfoService {

    private static final String BUILD_INFO_FILE_NAME = "build-info.json";

    @Autowired
    private ObjectMapper mapper;

    private BuildInfo buildInfo = new BuildInfo();

    @PostConstruct
    public void initialize() {
        ClassLoader classLoader = getClass().getClassLoader();
        URL buildInfoUrl = classLoader.getResource(BUILD_INFO_FILE_NAME);
        if (buildInfoUrl == null) {
            String errorMessage = String.format("File '%s' not found.", BUILD_INFO_FILE_NAME);
            log.error(errorMessage);
            return;
        }

        try {
            buildInfo = mapper.readValue(new File(buildInfoUrl.getPath()), BuildInfo.class);
        } catch (IOException e) {
            String errorMessage = String.format("File '%s' can't be loaded.", BUILD_INFO_FILE_NAME);
            log.error(errorMessage, e);
            return;
        }

        log.info(String.format("File '%s' loaded.", BUILD_INFO_FILE_NAME));
    }

    public BuildInfo getBuildInfo() {
        return buildInfo;
    }
}
