package com.goodt.drive.report.application.services;

import com.goodt.drive.report.application.dto.keycloak.TokenDataDtoBase;
import com.goodt.drive.report.application.exception.DremioResponseException;
import io.netty.handler.ssl.SslContext;
import io.netty.handler.ssl.SslContextBuilder;
import io.netty.handler.ssl.util.InsecureTrustManagerFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.client.reactive.ReactorClientHttpConnector;
import org.springframework.stereotype.Service;
import org.springframework.web.reactive.function.BodyInserters;
import org.springframework.web.reactive.function.client.ExchangeStrategies;
import org.springframework.web.reactive.function.client.WebClient;
import org.springframework.web.reactive.function.client.WebClientResponseException;
import reactor.netty.http.client.HttpClient;

import javax.net.ssl.SSLException;

@Service
public class DremioServiceImpl implements DremioService {

    public String request(String json, TokenDataDtoBase token) throws DremioResponseException {
        WebClient webClient = getWebClient(token);
        try {
            String jsonResponse = webClient.post()
                    .uri(uriBuilder -> uriBuilder.path(dremioPath).build())
                    .header(HttpHeaders.CONTENT_TYPE, MediaType.APPLICATION_JSON_VALUE)
                    .body(BodyInserters.fromValue(json))
                    .retrieve().bodyToMono(String.class)
                    .block();
            return jsonResponse;
        } catch (WebClientResponseException e) {
            logger.error(String.format("An error occurred during load data from Dremio (%s%s) with message \"%s\" and json \"%s\"", dremioHost, dremioPath, e.getMessage(), json));
            throw new DremioResponseException("An error occurred during load data from Dremio", e);
        }
    }

    private WebClient getWebClient(TokenDataDtoBase token){
        logger.debug(String.format("Connection to dremio-connector. Connecting host: %s %s.", dremioHost, token != null ? "with token" : "without token"));
        try {
            SslContext sslContext = SslContextBuilder
                    .forClient()
                    .trustManager(InsecureTrustManagerFactory.INSTANCE)
                    .build();
            HttpClient httpClient = HttpClient.create().secure(t -> t.sslContext(sslContext));
            WebClient.Builder builder = WebClient.builder().exchangeStrategies(ExchangeStrategies.builder()
                    .codecs(configurer -> configurer
                            .defaultCodecs()
                            .maxInMemorySize(1024 * 1024 * 128))
                    .build());
            if (token != null) {
                builder = builder.defaultHeader("token", token.getAccessToken());
            }
            WebClient client = builder.baseUrl(dremioHost).clientConnector(new ReactorClientHttpConnector(httpClient)).build();
            return client;
        }catch(SSLException e) {
            logger.error(e.getMessage(), e);
            return null;
        }
    }

    @Value("${yarg.dremio.host}")
    private String dremioHost;

    @Value("${yarg.dremio.path}")
    private String dremioPath;

    private final Logger logger = LoggerFactory.getLogger(this.getClass());
}
