package com.goodt.drive.report.application.utils.yarg;

import com.google.common.collect.ImmutableSet;
import com.google.gson.Gson;
import com.haulmont.yarg.exception.DataLoadingException;
import com.haulmont.yarg.loaders.impl.JsonDataLoader;
import com.haulmont.yarg.structure.ReportQuery;
import org.apache.commons.lang3.StringUtils;

import java.util.*;

import com.goodt.drive.report.application.dto.dremio.ResponseDto;
import com.goodt.drive.report.application.dto.dremio.SchemaDto;

public class JsonDataLoaderExtended extends JsonDataLoader {

    public static final String COLUMN_TYPE_VARCHAR = "VARCHAR";
    public static final String COLUMN_TYPE_INTEGER = "INTEGER";
    public static final String COLUMN_TYPE_DOUBLE = "DOUBLE";
    public static final String COLUMN_TYPE_FLOAT = "FLOAT";
    public static final String COLUMN_TYPE_BIGINT = "BIGINT";
    public static final Set<String> COLUMN_TYPE_NUMERIC = ImmutableSet.of(JsonDataLoaderExtended.COLUMN_TYPE_INTEGER,
                                                                          JsonDataLoaderExtended.COLUMN_TYPE_DOUBLE,
                                                                          JsonDataLoaderExtended.COLUMN_TYPE_FLOAT,
                                                                          JsonDataLoaderExtended.COLUMN_TYPE_BIGINT);

    @Override
    protected List<Map<String, Object>> extractScriptResult(String jsonData, String jsonPathScript, ReportQuery reportQuery) {
        try {
            List<Map<String, Object>> result = new ArrayList<>();
            ResponseDto responseDto = new Gson().fromJson(jsonData, ResponseDto.class);
            if (responseDto == null) {
                return Collections.emptyList();
            }
            List<Map<String, String>> responseRows = responseDto.getRows();
            if (responseRows == null) {
                return Collections.emptyList();
            }
            Map<String, String> schemaMap = buildSchemaMap(responseDto.getSchema());
            for (Map<String, String> responseRow : responseRows) {
                Map<String, Object> resultRow = new HashMap<>();
                for (Map.Entry<String, String> responseCell : responseRow.entrySet()) {
                    String columnName = responseCell.getKey();
                    String columnType = getColumnType(schemaMap, columnName);
                    String cellValue = responseCell.getValue();
                    if (COLUMN_TYPE_NUMERIC.contains(columnType) && StringUtils.isNumeric(cellValue)) {
                        resultRow.put(columnName, Long.valueOf(cellValue));
                    } else {
                        resultRow.put(columnName, cellValue);
                    }
                }
                result.add(resultRow);
            }
            return result;
        } catch (Throwable e) {
            throw new DataLoadingException(String.format("An error occurred while loading data with script [%s]", reportQuery.getScript()), e);
        }
    }

    private String getColumnType(Map<String, String> schemaMap, String columnName) {
        return schemaMap.getOrDefault(columnName, COLUMN_TYPE_VARCHAR);
    }

    private Map<String, String> buildSchemaMap(List<SchemaDto> schema) {
        Map<String, String> result = new HashMap<>();
        if (schema != null) {
            for (SchemaDto schemaDto : schema) {
                result.put(schemaDto.getName(), schemaDto.getType());
            }
        }
        return result;
    }
}
