package com.goodt.drive.report.application.rest;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.web.client.TestRestTemplate;
import org.springframework.boot.web.server.LocalServerPort;
import org.springframework.http.*;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.web.reactive.function.BodyInserters;
import org.springframework.web.reactive.function.client.WebClient;

import com.goodt.drive.report.application.configuration.AppConfig;
import com.goodt.drive.report.application.dto.FileConverterDto;
import com.goodt.drive.report.application.dto.TokenResponseDto;
import com.goodt.drive.report.utils.IntegrationalTestBase;

@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
@ActiveProfiles("integrationaltests")
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class TestFileConverterController extends IntegrationalTestBase {

    @LocalServerPort
    private int port;

    @Autowired
    private TestRestTemplate restTemplate;

    @Autowired
    private AppConfig appConfig;

    private String hostName = "http://localhost:" + port;
    private HttpHeaders requestHeaders;

    @BeforeAll
    void setup() {
        WebClient client = WebClient.builder()
                .baseUrl(appConfig.getKeyCloakConfig().getBaseUrl())
                .build();
        TokenResponseDto result = client.post().uri(appConfig.getKeyCloakConfig().getTokenUrl())
                .header(HttpHeaders.CONTENT_TYPE, MediaType.APPLICATION_FORM_URLENCODED_VALUE)
                .body(BodyInserters.fromFormData("client_id", appConfig.getKeyCloakConfig().getClientId())
                        .with("client_secret", appConfig.getKeyCloakConfig().getClientSecret())
                        .with("grant_type", "password")
.with("username", appConfig.getKeyCloakConfig().getUsername())
                        .with("password", appConfig.getKeyCloakConfig().getPassword()))
                .retrieve().bodyToMono(TokenResponseDto.class).block();

        hostName = "http://localhost:" + port;
        requestHeaders = new HttpHeaders();
        requestHeaders.add("authorization", String.format("%s %s", result.getTokenType(), result.getAccessToken()));
    }

    @Test
    void testHtmlToPdf() {
        FileConverterDto requestBody = new FileConverterDto("asdf asdf asdf asdf");

        HttpHeaders currentHeaders = new HttpHeaders();
        currentHeaders.putAll(requestHeaders);
        HttpEntity<FileConverterDto> requestExtra = new HttpEntity<>(requestBody, currentHeaders);

        ResponseEntity<byte[]> response = restTemplate.exchange(
                hostName + "/api/fileconverter/htmltopdf",
                HttpMethod.POST,
                requestExtra,
                byte[].class
        );
        Assertions.assertEquals(HttpStatus.OK, response.getStatusCode());
        Assertions.assertTrue(response.getBody().length > 0);
    }

    @Test
    void testHtmlToXls() {
        FileConverterDto requestBody = new FileConverterDto("<table><tr><td>zxcv</td><td>qwer</td></tr><tr><td>zxcv 2</td><td>qwer 2</td></tr></table>");

        HttpHeaders currentHeaders = new HttpHeaders();
        currentHeaders.putAll(requestHeaders);
        HttpEntity<FileConverterDto> requestExtra = new HttpEntity<>(requestBody, currentHeaders);

        ResponseEntity<byte[]> response = restTemplate.exchange(
                hostName + "/api/fileconverter/htmltoxls",
                HttpMethod.POST,
                requestExtra,
                byte[].class
        );
        Assertions.assertEquals(HttpStatus.OK, response.getStatusCode());
        Assertions.assertTrue(response.getBody().length > 0);
    }
}
