package com.goodt.drive.report.application.services;

import com.goodt.drive.report.application.asm.ReportAsm;
import com.goodt.drive.report.application.dao.ReportDao;
import com.goodt.drive.report.application.dto.ReportDto;
import com.goodt.drive.report.application.entities.ReportEntity;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import java.util.List;
import java.util.Optional;

import static org.mockito.ArgumentMatchers.any;


@SpringBootTest
@ActiveProfiles("functests")
class TestReportServiceImpl {

    @Mock
    private ReportDao reportDao;
    @InjectMocks
    private ReportServiceImpl reportService;

    @Autowired
    private ReportAsm reportAsm;

    @Test
    void testFindAll() {
        Mockito.when(reportDao.findAll())
                .thenReturn(List.of(new ReportEntity(), new ReportEntity()));

        List<ReportEntity> reportEntities = reportService.getAll();

        Assertions.assertTrue(reportEntities.size() > 0);
    }

    @Test
    void testFindById() {
        Mockito.when(reportDao.findById(any()))
                .thenReturn(Optional.of(new ReportEntity()));

        ReportDto reportDto = reportService.getById(1L, reportAsm::toRes);

        Assertions.assertNotNull(reportDto);
        Mockito.verify(reportDao).findById(1L);
    }

    @Test
    void testCreate() {
        ReportDto reportDto = new ReportDto();
        reportDto.setName("test create report");
        reportDto.setTemplateId("test template id");
        reportDto.setData("{}");
        Mockito.when(reportDao.save(any()))
                .thenReturn(new ReportEntity());

        ReportDto report = reportService.create(entity -> reportAsm.create(entity, reportDto), reportAsm::toRes);

        Assertions.assertNotNull(report);
        ArgumentCaptor<ReportEntity> requestCaptor = ArgumentCaptor.forClass(ReportEntity.class);
        Mockito.verify(reportDao).save(requestCaptor.capture());
        ReportEntity capturedArgument = requestCaptor.getValue();
        Assertions.assertEquals("test create report", capturedArgument.getName());
        Assertions.assertEquals("test template id", capturedArgument.getTemplateId());
        Assertions.assertEquals("{}", capturedArgument.getData());
    }

    @Test
    void testUpdate() {
        ReportDto reportDto = new ReportDto();
        reportDto.setId(2L);
        reportDto.setName("test create report - upd");
        reportDto.setTemplateId("test template id - upd");
        reportDto.setData("{upd}");
        Mockito.when(reportDao.findById(any()))
                .thenReturn(Optional.of(new ReportEntity()));
        Mockito.when(reportDao.save(any()))
                .thenReturn(new ReportEntity());

        ReportEntity updReportEntity = reportService.update(2L, entity -> reportAsm.update(entity, reportDto));

        Assertions.assertNotNull(updReportEntity);
        ArgumentCaptor<ReportEntity> requestCaptor = ArgumentCaptor.forClass(ReportEntity.class);
        Mockito.verify(reportDao).save(requestCaptor.capture());
        ReportEntity capturedArgument = requestCaptor.getValue();
        Assertions.assertEquals("test create report - upd", capturedArgument.getName());
        Assertions.assertEquals("test template id - upd", capturedArgument.getTemplateId());
        Assertions.assertEquals("{upd}", capturedArgument.getData());
    }

    @Test
    void testDelete() {
        Assertions.assertDoesNotThrow(() -> reportService.delete(3L));

        Mockito.verify(reportDao).deleteById(3L);
    }
}
