package com.goodt.drive.report.application.services;

import com.goodt.drive.report.application.dto.ReportCreateDto;
import com.goodt.drive.report.application.exception.DremioResponseException;
import com.haulmont.yarg.reporting.ReportOutputDocument;
import javassist.NotFoundException;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.LinkedList;


@SpringBootTest
@ActiveProfiles("functests")
class TestYargServiceImpl {

    @Autowired
    private YargService yargService;

    @Test
    void testCreateXls() throws NotFoundException, IOException, DremioResponseException {
        ReportCreateDto body = getBodyDto();
        body.setTemplateId("global/template_11.xls");
        ReportOutputDocument reportOutputDocument = yargService.create(body, false, null);
        Assertions.assertTrue(reportOutputDocument.getContent().length > 0);
        Assertions.assertEquals("template_11.xls", reportOutputDocument.getDocumentName());
        Assertions.assertEquals("xls", reportOutputDocument.getReportOutputType().getId());
    }

    @Test
    void testCreateXlsx() throws NotFoundException, IOException, DremioResponseException {
        ReportCreateDto body = getBodyDto();
        body.setTemplateId("global/template_15.xlsx");
        ReportOutputDocument reportOutputDocument = yargService.create(body, false, null);
        Assertions.assertTrue(reportOutputDocument.getContent().length > 0);
        Assertions.assertEquals("template_15.xlsx", reportOutputDocument.getDocumentName());
        Assertions.assertEquals("xlsx", reportOutputDocument.getReportOutputType().getId());
    }

    @Test
    void testCreateDoc() throws NotFoundException, IOException, DremioResponseException {
        ReportCreateDto body = getBodyDto();
        body.setTemplateId("global/template_13.doc");
        ReportOutputDocument reportOutputDocument = yargService.create(body, false, null);
        Assertions.assertTrue(reportOutputDocument.getContent().length > 0);
        Assertions.assertEquals("template_13.doc", reportOutputDocument.getDocumentName());
        Assertions.assertEquals("doc", reportOutputDocument.getReportOutputType().getId());
    }

    @Test
    void testCreateDocx() throws NotFoundException, IOException, DremioResponseException {
        ReportCreateDto body = getBodyDto();
        body.setTemplateId("global/template_16.docx");
        ReportOutputDocument reportOutputDocument = yargService.create(body, false, null);
        Assertions.assertTrue(reportOutputDocument.getContent().length > 0);
        Assertions.assertEquals("template_16.docx", reportOutputDocument.getDocumentName());
        Assertions.assertEquals("docx", reportOutputDocument.getReportOutputType().getId());
    }

    @Test
    void testCreatePdf() throws NotFoundException, IOException, DremioResponseException {
        ReportCreateDto body = getBodyDto();
        body.setTemplateId("global/template_15.xlsx");
        body.setTemplateType("pdf");
        ReportOutputDocument reportOutputDocument = yargService.create(body, false, null);
        Assertions.assertTrue(reportOutputDocument.getContent().length > 0);
        Assertions.assertEquals("template_15.xlsx.pdf", reportOutputDocument.getDocumentName());
        Assertions.assertEquals("pdf", reportOutputDocument.getReportOutputType().getId());
    }

    private ReportCreateDto getBodyDto() {
        ReportCreateDto body = new ReportCreateDto();

        LinkedList<LinkedHashMap<String, Object>> data = new LinkedList<>();

        LinkedHashMap<String, Object> list1header = new LinkedHashMap<String, Object>();
        list1header.put("name", "list1headers");
        list1header.put("data", null);
        data.add(list1header);

        LinkedHashMap<String, Object> list1data = new LinkedHashMap<String, Object>();
        list1data.put("name", "list1data");
        list1data.put("data", null);
        data.add(list1data);

        LinkedHashMap<String, Object> list2header = new LinkedHashMap<String, Object>();
        list2header.put("name", "list2headers");
        list2header.put("data", null);
        data.add(list2header);

        LinkedHashMap<String, Object> list2data = new LinkedHashMap<String, Object>();
        list2data.put("name", "list2data");
        list2data.put("data", null);
        data.add(list2data);

        body.setData(data);
        return body;
    }
}
