package com.goodt.drive.report.utils;

import liquibase.Contexts;
import liquibase.LabelExpression;
import liquibase.Liquibase;
import liquibase.database.Database;
import liquibase.database.DatabaseFactory;
import liquibase.database.jvm.JdbcConnection;
import liquibase.exception.DatabaseException;
import liquibase.exception.LiquibaseException;
import liquibase.resource.ClassLoaderResourceAccessor;
import org.apache.ibatis.jdbc.ScriptRunner;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

public abstract class DatabaseRelatedTestBase {

    Connection conn;
    Database db;
    Liquibase liquibase;

    public void setUp(String url, String user, String password, String changelogFile, String initScript) throws SQLException, DatabaseException, LiquibaseException, FileNotFoundException {
        conn = DriverManager.getConnection(url, user, password);
        db = DatabaseFactory.getInstance().findCorrectDatabaseImplementation(new JdbcConnection(conn));
        liquibase = new Liquibase(changelogFile, new ClassLoaderResourceAccessor(), db);
        liquibase.update(new Contexts(), new LabelExpression());
        ScriptRunner runner = new ScriptRunner(conn);
        runner.runScript(new BufferedReader(new FileReader(initScript)));
    }

    public void tearDown() throws SQLException {
        conn.close();
    }
}
